/*
 * Copyright (c) 2009-2021 The strace developers.
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#include "../64/syscallent.h"
/* [244 ... 259] are arch specific */
[244] = { 1,	0,	SEN(printargs),	"cmpxchg_badaddr"	},
[245] = { 3,	0,	SEN(printargs),	"cacheflush"		},
