/*
 * Copyright (c) 2014-2021 The strace developers.
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#include "userent0.h"
{ PT_FPR0_HI,		"fpr0.hi" },
{ PT_FPR0_LO,		"fpr0.lo" },
{ PT_FPR1_HI,		"fpr1.hi" },
{ PT_FPR1_LO,		"fpr1.lo" },
{ PT_FPR2_HI,		"fpr2.hi" },
{ PT_FPR2_LO,		"fpr2.lo" },
{ PT_FPR3_HI,		"fpr3.hi" },
{ PT_FPR3_LO,		"fpr3.lo" },
{ PT_FPR4_HI,		"fpr4.hi" },
{ PT_FPR4_LO,		"fpr4.lo" },
{ PT_FPR5_HI,		"fpr5.hi" },
{ PT_FPR5_LO,		"fpr5.lo" },
{ PT_FPR6_HI,		"fpr6.hi" },
{ PT_FPR6_LO,		"fpr6.lo" },
{ PT_FPR7_HI,		"fpr7.hi" },
{ PT_FPR7_LO,		"fpr7.lo" },
{ PT_FPR8_HI,		"fpr8.hi" },
{ PT_FPR8_LO,		"fpr8.lo" },
{ PT_FPR9_HI,		"fpr9.hi" },
{ PT_FPR9_LO,		"fpr9.lo" },
{ PT_FPR10_HI,		"fpr10.hi" },
{ PT_FPR10_LO,		"fpr10.lo" },
{ PT_FPR11_HI,		"fpr11.hi" },
{ PT_FPR11_LO,		"fpr11.lo" },
{ PT_FPR12_HI,		"fpr12.hi" },
{ PT_FPR12_LO,		"fpr12.lo" },
{ PT_FPR13_HI,		"fpr13.hi" },
{ PT_FPR13_LO,		"fpr13.lo" },
{ PT_FPR14_HI,		"fpr14.hi" },
{ PT_FPR14_LO,		"fpr14.lo" },
{ PT_FPR15_HI,		"fpr15.hi" },
{ PT_FPR15_LO,		"fpr15.lo" },
/* Other fields in "struct user" */
#include "userent1.h"
