/*
 * Copyright (c) 2014-2021 The strace developers.
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

{ PT_PSWMASK,		"psw_mask" },
{ PT_PSWADDR,		"psw_addr" },
{ PT_GPR0,		"gpr0" },
{ PT_GPR1,		"gpr1" },
{ PT_GPR2,		"gpr2" },
{ PT_GPR3,		"gpr3" },
{ PT_GPR4,		"gpr4" },
{ PT_GPR5,		"gpr5" },
{ PT_GPR6,		"gpr6" },
{ PT_GPR7,		"gpr7" },
{ PT_GPR8,		"gpr8" },
{ PT_GPR9,		"gpr9" },
{ PT_GPR10,		"gpr10" },
{ PT_GPR11,		"gpr11" },
{ PT_GPR12,		"gpr12" },
{ PT_GPR13,		"gpr13" },
{ PT_GPR14,		"gpr14" },
{ PT_GPR15,		"gpr15" },
{ PT_ACR0,		"acr0" },
{ PT_ACR1,		"acr1" },
{ PT_ACR2,		"acr2" },
{ PT_ACR3,		"acr3" },
{ PT_ACR4,		"acr4" },
{ PT_ACR5,		"acr5" },
{ PT_ACR6,		"acr6" },
{ PT_ACR7,		"acr7" },
{ PT_ACR8,		"acr8" },
{ PT_ACR9,		"acr9" },
{ PT_ACR10,		"acr10" },
{ PT_ACR11,		"acr11" },
{ PT_ACR12,		"acr12" },
{ PT_ACR13,		"acr13" },
{ PT_ACR14,		"acr14" },
{ PT_ACR15,		"acr15" },
{ PT_ORIGGPR2,		"orig_gpr2" },
{ PT_FPC,		"fpc" },
/* PT_FPR* differ between s390 and s390x */
{ PT_CR_9,		"cr9" },
{ PT_CR_10,		"cr10" },
{ PT_CR_11,		"cr11" },
{ PT_IEEE_IP,		"ieee_exception_ip" },
