/* Generated by ioctls_gen.sh from definitions found in $linux/arch/mips/include/ tree. */
{ "asm/ioctls.h", "FIOASYNC", 0, 0x667d, 0 },
{ "asm/ioctls.h", "FIOCLEX", 0, 0x6601, 0 },
{ "asm/ioctls.h", "FIONBIO", 0, 0x667e, 0 },
{ "asm/ioctls.h", "FIONCLEX", 0, 0x6602, 0 },
{ "asm/ioctls.h", "FIONREAD", 0, 0x467f, 0 },
{ "asm/ioctls.h", "FIOQSIZE", 0, 0x667f, 0 },
{ "asm/ioctls.h", "TCFLSH", 0, 0x5407, 0 },
{ "asm/ioctls.h", "TCGETA", 0, 0x5401, 0 },
{ "asm/ioctls.h", "TCGETS", 0, 0x540d, 0 },
{ "asm/ioctls.h", "TCGETS2", _IOC_READ, 0x542a, 0x30 },
{ "asm/ioctls.h", "TCSBRK", 0, 0x5405, 0 },
{ "asm/ioctls.h", "TCSBRKP", 0, 0x5486, 0 },
{ "asm/ioctls.h", "TCSETA", 0, 0x5402, 0 },
{ "asm/ioctls.h", "TCSETAF", 0, 0x5404, 0 },
{ "asm/ioctls.h", "TCSETAW", 0, 0x5403, 0 },
{ "asm/ioctls.h", "TCSETS", 0, 0x540e, 0 },
{ "asm/ioctls.h", "TCSETS2", _IOC_WRITE, 0x542b, 0x30 },
{ "asm/ioctls.h", "TCSETSF", 0, 0x5410, 0 },
{ "asm/ioctls.h", "TCSETSF2", _IOC_WRITE, 0x542d, 0x30 },
{ "asm/ioctls.h", "TCSETSW", 0, 0x540f, 0 },
{ "asm/ioctls.h", "TCSETSW2", _IOC_WRITE, 0x542c, 0x30 },
{ "asm/ioctls.h", "TCXONC", 0, 0x5406, 0 },
{ "asm/ioctls.h", "TIOCCBRK", 0, 0x5428, 0 },
{ "asm/ioctls.h", "TIOCCONS", _IOC_WRITE, 0x7478, 0x04 },
{ "asm/ioctls.h", "TIOCEXCL", 0, 0x740d, 0 },
{ "asm/ioctls.h", "TIOCGDEV", _IOC_READ, 0x5432, 0x04 },
{ "asm/ioctls.h", "TIOCGETD", 0, 0x7400, 0 },
{ "asm/ioctls.h", "TIOCGETP", 0, 0x7408, 0 },
{ "asm/ioctls.h", "TIOCGEXCL", _IOC_READ, 0x5440, 0x04 },
{ "asm/ioctls.h", "TIOCGICOUNT", 0, 0x5492, 0 },
{ "asm/ioctls.h", "TIOCGISO7816", _IOC_READ, 0x5442, 0x28 },
{ "asm/ioctls.h", "TIOCGLCKTRMIOS", 0, 0x548b, 0 },
{ "asm/ioctls.h", "TIOCGLTC", 0, 0x7474, 0 },
{ "asm/ioctls.h", "TIOCGPGRP", _IOC_READ, 0x7477, 0x04 },
{ "asm/ioctls.h", "TIOCGPKT", _IOC_READ, 0x5438, 0x04 },
{ "asm/ioctls.h", "TIOCGPTLCK", _IOC_READ, 0x5439, 0x04 },
{ "asm/ioctls.h", "TIOCGPTN", _IOC_READ, 0x5430, 0x04 },
{ "asm/ioctls.h", "TIOCGPTPEER", _IOC_NONE, 0x5441, 0x00 },
{ "asm/ioctls.h", "TIOCGRS485", _IOC_READ, 0x542e, 0x20 },
{ "asm/ioctls.h", "TIOCGSERIAL", 0, 0x5484, 0 },
{ "asm/ioctls.h", "TIOCGSID", 0, 0x7416, 0 },
{ "asm/ioctls.h", "TIOCGSOFTCAR", 0, 0x5481, 0 },
{ "asm/ioctls.h", "TIOCGWINSZ", _IOC_READ, 0x7468, 0x08 },
{ "asm/ioctls.h", "TIOCLINUX", 0, 0x5483, 0 },
{ "asm/ioctls.h", "TIOCMBIC", 0, 0x741c, 0 },
{ "asm/ioctls.h", "TIOCMBIS", 0, 0x741b, 0 },
{ "asm/ioctls.h", "TIOCMGET", 0, 0x741d, 0 },
{ "asm/ioctls.h", "TIOCMIWAIT", 0, 0x5491, 0 },
{ "asm/ioctls.h", "TIOCMSET", 0, 0x741a, 0 },
{ "asm/ioctls.h", "TIOCNOTTY", 0, 0x5471, 0 },
{ "asm/ioctls.h", "TIOCNXCL", 0, 0x740e, 0 },
{ "asm/ioctls.h", "TIOCOUTQ", 0, 0x7472, 0 },
{ "asm/ioctls.h", "TIOCPKT", 0, 0x5470, 0 },
{ "asm/ioctls.h", "TIOCSBRK", 0, 0x5427, 0 },
{ "asm/ioctls.h", "TIOCSCTTY", 0, 0x5480, 0 },
{ "asm/ioctls.h", "TIOCSERCONFIG", 0, 0x5488, 0 },
{ "asm/ioctls.h", "TIOCSERGETLSR", 0, 0x548e, 0 },
{ "asm/ioctls.h", "TIOCSERGETMULTI", 0, 0x548f, 0 },
{ "asm/ioctls.h", "TIOCSERGSTRUCT", 0, 0x548d, 0 },
{ "asm/ioctls.h", "TIOCSERGWILD", 0, 0x5489, 0 },
{ "asm/ioctls.h", "TIOCSERSETMULTI", 0, 0x5490, 0 },
{ "asm/ioctls.h", "TIOCSERSWILD", 0, 0x548a, 0 },
{ "asm/ioctls.h", "TIOCSETD", 0, 0x7401, 0 },
{ "asm/ioctls.h", "TIOCSETN", 0, 0x740a, 0 },
{ "asm/ioctls.h", "TIOCSETP", 0, 0x7409, 0 },
{ "asm/ioctls.h", "TIOCSIG", _IOC_WRITE, 0x5436, 0x04 },
{ "asm/ioctls.h", "TIOCSISO7816", _IOC_READ|_IOC_WRITE, 0x5443, 0x28 },
{ "asm/ioctls.h", "TIOCSLCKTRMIOS", 0, 0x548c, 0 },
{ "asm/ioctls.h", "TIOCSLTC", 0, 0x7475, 0 },
{ "asm/ioctls.h", "TIOCSPGRP", _IOC_WRITE, 0x7476, 0x04 },
{ "asm/ioctls.h", "TIOCSPTLCK", _IOC_WRITE, 0x5431, 0x04 },
{ "asm/ioctls.h", "TIOCSRS485", _IOC_READ|_IOC_WRITE, 0x542f, 0x20 },
{ "asm/ioctls.h", "TIOCSSERIAL", 0, 0x5485, 0 },
{ "asm/ioctls.h", "TIOCSSOFTCAR", 0, 0x5482, 0 },
{ "asm/ioctls.h", "TIOCSTI", 0, 0x5472, 0 },
{ "asm/ioctls.h", "TIOCSWINSZ", _IOC_WRITE, 0x7467, 0x08 },
{ "asm/ioctls.h", "TIOCVHANGUP", 0, 0x5437, 0 },
{ "asm/sockios.h", "FIOGETOWN", _IOC_READ, 0x667b, 0x04 },
{ "asm/sockios.h", "FIOSETOWN", _IOC_WRITE, 0x667c, 0x04 },
{ "asm/sockios.h", "SIOCATMARK", _IOC_READ, 0x7307, 0x04 },
{ "asm/sockios.h", "SIOCGPGRP", _IOC_READ, 0x7309, 0x04 },
{ "asm/sockios.h", "SIOCSPGRP", _IOC_WRITE, 0x7308, 0x04 },
{ "linux/kvm.h", "KVM_CHECK_EXTENSION", _IOC_NONE, 0xae03, 0x00 },
{ "linux/kvm.h", "KVM_CLEAR_DIRTY_LOG", _IOC_READ|_IOC_WRITE, 0xaec0, 0x18 },
{ "linux/kvm.h", "KVM_CREATE_DEVICE", _IOC_READ|_IOC_WRITE, 0xaee0, 0x0c },
{ "linux/kvm.h", "KVM_CREATE_GUEST_MEMFD", _IOC_READ|_IOC_WRITE, 0xaed4, 0x40 },
{ "linux/kvm.h", "KVM_CREATE_IRQCHIP", _IOC_NONE, 0xae60, 0x00 },
{ "linux/kvm.h", "KVM_CREATE_PIT", _IOC_NONE, 0xae64, 0x00 },
{ "linux/kvm.h", "KVM_CREATE_PIT2", _IOC_WRITE, 0xae77, 0x40 },
{ "linux/kvm.h", "KVM_CREATE_VCPU", _IOC_NONE, 0xae41, 0x00 },
{ "linux/kvm.h", "KVM_CREATE_VM", _IOC_NONE, 0xae01, 0x00 },
{ "linux/kvm.h", "KVM_DIRTY_TLB", _IOC_WRITE, 0xaeaa, 0x10 },
{ "linux/kvm.h", "KVM_ENABLE_CAP", _IOC_WRITE, 0xaea3, 0x68 },
{ "linux/kvm.h", "KVM_GET_API_VERSION", _IOC_NONE, 0xae00, 0x00 },
{ "linux/kvm.h", "KVM_GET_CLOCK", _IOC_READ, 0xae7c, 0x30 },
{ "linux/kvm.h", "KVM_GET_DEVICE_ATTR", _IOC_WRITE, 0xaee2, 0x18 },
{ "linux/kvm.h", "KVM_GET_DIRTY_LOG", _IOC_WRITE, 0xae42, 0x10 },
{ "linux/kvm.h", "KVM_GET_FPU", _IOC_READ, 0xae8c, 0x00 },
{ "linux/kvm.h", "KVM_GET_IRQCHIP", _IOC_READ|_IOC_WRITE, 0xae62, 0x208 },
{ "linux/kvm.h", "KVM_GET_MP_STATE", _IOC_READ, 0xae98, 0x04 },
{ "linux/kvm.h", "KVM_GET_NR_MMU_PAGES", _IOC_NONE, 0xae45, 0x00 },
{ "linux/kvm.h", "KVM_GET_ONE_REG", _IOC_WRITE, 0xaeab, 0x10 },
{ "linux/kvm.h", "KVM_GET_REGS", _IOC_READ, 0xae81, 0x118 },
{ "linux/kvm.h", "KVM_GET_REG_LIST", _IOC_READ|_IOC_WRITE, 0xaeb0, 0x08 },
{ "linux/kvm.h", "KVM_GET_SREGS", _IOC_READ, 0xae83, 0x00 },
{ "linux/kvm.h", "KVM_GET_STATS_FD", _IOC_NONE, 0xaece, 0x00 },
{ "linux/kvm.h", "KVM_GET_TSC_KHZ", _IOC_NONE, 0xaea3, 0x00 },
{ "linux/kvm.h", "KVM_GET_VCPU_MMAP_SIZE", _IOC_NONE, 0xae04, 0x00 },
{ "linux/kvm.h", "KVM_HAS_DEVICE_ATTR", _IOC_WRITE, 0xaee3, 0x18 },
{ "linux/kvm.h", "KVM_INTERRUPT", _IOC_WRITE, 0xae86, 0x04 },
{ "linux/kvm.h", "KVM_IOEVENTFD", _IOC_WRITE, 0xae79, 0x40 },
{ "linux/kvm.h", "KVM_IRQFD", _IOC_WRITE, 0xae76, 0x20 },
{ "linux/kvm.h", "KVM_IRQ_LINE", _IOC_WRITE, 0xae61, 0x08 },
{ "linux/kvm.h", "KVM_IRQ_LINE_STATUS", _IOC_READ|_IOC_WRITE, 0xae67, 0x08 },
{ "linux/kvm.h", "KVM_KVMCLOCK_CTRL", _IOC_NONE, 0xaead, 0x00 },
{ "linux/kvm.h", "KVM_MEMORY_ENCRYPT_OP", _IOC_READ|_IOC_WRITE, 0xaeba, 0x08 },
{ "linux/kvm.h", "KVM_MEMORY_ENCRYPT_REG_REGION", _IOC_READ, 0xaebb, 0x10 },
{ "linux/kvm.h", "KVM_MEMORY_ENCRYPT_UNREG_REGION", _IOC_READ, 0xaebc, 0x10 },
{ "linux/kvm.h", "KVM_NMI", _IOC_NONE, 0xae9a, 0x00 },
{ "linux/kvm.h", "KVM_PRE_FAULT_MEMORY", _IOC_READ|_IOC_WRITE, 0xaed5, 0x40 },
{ "linux/kvm.h", "KVM_REGISTER_COALESCED_MMIO", _IOC_WRITE, 0xae67, 0x10 },
{ "linux/kvm.h", "KVM_REINJECT_CONTROL", _IOC_NONE, 0xae71, 0x00 },
{ "linux/kvm.h", "KVM_RESET_DIRTY_RINGS", _IOC_NONE, 0xaec7, 0x00 },
{ "linux/kvm.h", "KVM_RUN", _IOC_NONE, 0xae80, 0x00 },
{ "linux/kvm.h", "KVM_SET_BOOT_CPU_ID", _IOC_NONE, 0xae78, 0x00 },
{ "linux/kvm.h", "KVM_SET_CLOCK", _IOC_WRITE, 0xae7b, 0x30 },
{ "linux/kvm.h", "KVM_SET_DEVICE_ATTR", _IOC_WRITE, 0xaee1, 0x18 },
{ "linux/kvm.h", "KVM_SET_FPU", _IOC_WRITE, 0xae8d, 0x00 },
{ "linux/kvm.h", "KVM_SET_GSI_ROUTING", _IOC_WRITE, 0xae6a, 0x08 },
{ "linux/kvm.h", "KVM_SET_GUEST_DEBUG", _IOC_WRITE, 0xae9b, 0x08 },
{ "linux/kvm.h", "KVM_SET_IDENTITY_MAP_ADDR", _IOC_WRITE, 0xae48, 0x08 },
{ "linux/kvm.h", "KVM_SET_IRQCHIP", _IOC_READ, 0xae63, 0x208 },
{ "linux/kvm.h", "KVM_SET_MEMORY_ATTRIBUTES", _IOC_WRITE, 0xaed2, 0x20 },
{ "linux/kvm.h", "KVM_SET_MP_STATE", _IOC_WRITE, 0xae99, 0x04 },
{ "linux/kvm.h", "KVM_SET_NR_MMU_PAGES", _IOC_NONE, 0xae44, 0x00 },
{ "linux/kvm.h", "KVM_SET_ONE_REG", _IOC_WRITE, 0xaeac, 0x10 },
{ "linux/kvm.h", "KVM_SET_REGS", _IOC_WRITE, 0xae82, 0x118 },
{ "linux/kvm.h", "KVM_SET_SIGNAL_MASK", _IOC_WRITE, 0xae8b, 0x04 },
{ "linux/kvm.h", "KVM_SET_SREGS", _IOC_WRITE, 0xae84, 0x00 },
{ "linux/kvm.h", "KVM_SET_TSC_KHZ", _IOC_NONE, 0xaea2, 0x00 },
{ "linux/kvm.h", "KVM_SET_TSS_ADDR", _IOC_NONE, 0xae47, 0x00 },
{ "linux/kvm.h", "KVM_SET_USER_MEMORY_REGION", _IOC_WRITE, 0xae46, 0x20 },
{ "linux/kvm.h", "KVM_SET_USER_MEMORY_REGION2", _IOC_WRITE, 0xae49, 0xa0 },
{ "linux/kvm.h", "KVM_SET_VAPIC_ADDR", _IOC_WRITE, 0xae93, 0x08 },
{ "linux/kvm.h", "KVM_SIGNAL_MSI", _IOC_WRITE, 0xaea5, 0x20 },
{ "linux/kvm.h", "KVM_SMI", _IOC_NONE, 0xaeb7, 0x00 },
{ "linux/kvm.h", "KVM_TPR_ACCESS_REPORTING", _IOC_READ|_IOC_WRITE, 0xae92, 0x28 },
{ "linux/kvm.h", "KVM_TRANSLATE", _IOC_READ|_IOC_WRITE, 0xae85, 0x18 },
{ "linux/kvm.h", "KVM_UNREGISTER_COALESCED_MMIO", _IOC_WRITE, 0xae68, 0x10 },
