/* Generated by ./src/xlat/gen.sh from ./src/xlat/sock_ipx_options.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(IPX_TYPE) || (defined(HAVE_DECL_IPX_TYPE) && HAVE_DECL_IPX_TYPE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IPX_TYPE) == (1), "IPX_TYPE != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define IPX_TYPE 1
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat sock_ipx_options in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data sock_ipx_options_xdata[] = {
 XLAT(IPX_TYPE),
 #define XLAT_VAL_0 ((unsigned) (IPX_TYPE))
 #define XLAT_STR_0 STRINGIFY(IPX_TYPE)
};
static
const struct xlat sock_ipx_options[1] = { {
 .data = sock_ipx_options_xdata,
 .size = ARRAY_SIZE(sock_ipx_options_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
