/* Generated by ioctls_gen.sh from definitions found in $linux/arch/parisc/include/ tree. */
{ "asm/grfioctl.h", "GCAOFF", _IOC_NONE, 0x4704, 0x00 },
{ "asm/grfioctl.h", "GCAON", _IOC_NONE, 0x4703, 0x00 },
{ "asm/grfioctl.h", "GCDESCRIBE", _IOC_READ, 0x4715, 0x70 },
{ "asm/grfioctl.h", "GCFASTLOCK", _IOC_NONE, 0x471a, 0x00 },
{ "asm/grfioctl.h", "GCID", _IOC_READ, 0x4700, 0x04 },
{ "asm/grfioctl.h", "GCLOCK", _IOC_NONE, 0x4707, 0x00 },
{ "asm/grfioctl.h", "GCLOCK_MINIMUM", _IOC_NONE, 0x4709, 0x00 },
{ "asm/grfioctl.h", "GCMAP", _IOC_READ|_IOC_WRITE, 0x4705, 0x04 },
{ "asm/grfioctl.h", "GCMAP_HPUX", _IOC_NONE, 0x4705, 0x00 },
{ "asm/grfioctl.h", "GCOFF", _IOC_NONE, 0x4702, 0x00 },
{ "asm/grfioctl.h", "GCON", _IOC_NONE, 0x4701, 0x00 },
{ "asm/grfioctl.h", "GCSTATIC_CMAP", _IOC_NONE, 0x470b, 0x00 },
{ "asm/grfioctl.h", "GCTERM", _IOC_READ|_IOC_WRITE, 0x4714, 0x04 },
{ "asm/grfioctl.h", "GCUNLOCK", _IOC_NONE, 0x4708, 0x00 },
{ "asm/grfioctl.h", "GCUNLOCK_MINIMUM", _IOC_NONE, 0x470a, 0x00 },
{ "asm/grfioctl.h", "GCUNMAP", _IOC_READ|_IOC_WRITE, 0x4706, 0x04 },
{ "asm/grfioctl.h", "GCUNMAP_HPUX", _IOC_NONE, 0x4706, 0x00 },
{ "asm/grfioctl.h", "GCVARIABLE_CMAP", _IOC_NONE, 0x470c, 0x00 },
{ "asm/ioctls.h", "FIOASYNC", 0, 0x5452, 0 },
{ "asm/ioctls.h", "FIOCLEX", 0, 0x5451, 0 },
{ "asm/ioctls.h", "FIONBIO", 0, 0x5421, 0 },
{ "asm/ioctls.h", "FIONCLEX", 0, 0x5450, 0 },
{ "asm/ioctls.h", "FIONREAD", 0, 0x541B, 0 },
{ "asm/ioctls.h", "FIOQSIZE", 0, 0x5460, 0 },
{ "asm/ioctls.h", "TCFLSH", _IOC_NONE, 0x5407, 0x00 },
{ "asm/ioctls.h", "TCGETA", _IOC_READ, 0x5401, 0x12 },
{ "asm/ioctls.h", "TCGETS", _IOC_READ, 0x5410, 0x24 },
{ "asm/ioctls.h", "TCGETS2", _IOC_READ, 0x542a, 0x2c },
{ "asm/ioctls.h", "TCSBRK", _IOC_NONE, 0x5405, 0x00 },
{ "asm/ioctls.h", "TCSBRKP", 0, 0x5425, 0 },
{ "asm/ioctls.h", "TCSETA", _IOC_WRITE, 0x5402, 0x12 },
{ "asm/ioctls.h", "TCSETAF", _IOC_WRITE, 0x5404, 0x12 },
{ "asm/ioctls.h", "TCSETAW", _IOC_WRITE, 0x5403, 0x12 },
{ "asm/ioctls.h", "TCSETS", _IOC_WRITE, 0x5411, 0x24 },
{ "asm/ioctls.h", "TCSETS2", _IOC_WRITE, 0x542b, 0x2c },
{ "asm/ioctls.h", "TCSETSF", _IOC_WRITE, 0x5413, 0x24 },
{ "asm/ioctls.h", "TCSETSF2", _IOC_WRITE, 0x542d, 0x2c },
{ "asm/ioctls.h", "TCSETSW", _IOC_WRITE, 0x5412, 0x24 },
{ "asm/ioctls.h", "TCSETSW2", _IOC_WRITE, 0x542c, 0x2c },
{ "asm/ioctls.h", "TCXONC", _IOC_NONE, 0x5406, 0x00 },
{ "asm/ioctls.h", "TIOCCBRK", 0, 0x5428, 0 },
{ "asm/ioctls.h", "TIOCCONS", 0, 0x541D, 0 },
{ "asm/ioctls.h", "TIOCEXCL", 0, 0x540C, 0 },
{ "asm/ioctls.h", "TIOCGDEV", _IOC_READ, 0x5432, 0x04 },
{ "asm/ioctls.h", "TIOCGETD", 0, 0x5424, 0 },
{ "asm/ioctls.h", "TIOCGEXCL", _IOC_READ, 0x5440, 0x04 },
{ "asm/ioctls.h", "TIOCGICOUNT", 0, 0x545D, 0 },
{ "asm/ioctls.h", "TIOCGLCKTRMIOS", 0, 0x5456, 0 },
{ "asm/ioctls.h", "TIOCGPGRP", _IOC_READ, 0x541e, 0x04 },
{ "asm/ioctls.h", "TIOCGPKT", _IOC_READ, 0x5438, 0x04 },
{ "asm/ioctls.h", "TIOCGPTLCK", _IOC_READ, 0x5439, 0x04 },
{ "asm/ioctls.h", "TIOCGPTN", _IOC_READ, 0x5430, 0x04 },
{ "asm/ioctls.h", "TIOCGRS485", _IOC_READ, 0x542e, 0x20 },
{ "asm/ioctls.h", "TIOCGSERIAL", 0, 0x541E, 0 },
{ "asm/ioctls.h", "TIOCGSID", _IOC_READ, 0x5414, 0x04 },
{ "asm/ioctls.h", "TIOCGSOFTCAR", 0, 0x5419, 0 },
{ "asm/ioctls.h", "TIOCGWINSZ", 0, 0x5413, 0 },
{ "asm/ioctls.h", "TIOCLINUX", 0, 0x541C, 0 },
{ "asm/ioctls.h", "TIOCMBIC", 0, 0x5417, 0 },
{ "asm/ioctls.h", "TIOCMBIS", 0, 0x5416, 0 },
{ "asm/ioctls.h", "TIOCMGET", 0, 0x5415, 0 },
{ "asm/ioctls.h", "TIOCMIWAIT", 0, 0x545C, 0 },
{ "asm/ioctls.h", "TIOCMSET", 0, 0x5418, 0 },
{ "asm/ioctls.h", "TIOCNOTTY", 0, 0x5422, 0 },
{ "asm/ioctls.h", "TIOCNXCL", 0, 0x540D, 0 },
{ "asm/ioctls.h", "TIOCOUTQ", 0, 0x5411, 0 },
{ "asm/ioctls.h", "TIOCPKT", 0, 0x5420, 0 },
{ "asm/ioctls.h", "TIOCSBRK", 0, 0x5427, 0 },
{ "asm/ioctls.h", "TIOCSCTTY", 0, 0x540E, 0 },
{ "asm/ioctls.h", "TIOCSERCONFIG", 0, 0x5453, 0 },
{ "asm/ioctls.h", "TIOCSERGETLSR", 0, 0x5459, 0 },
{ "asm/ioctls.h", "TIOCSERGETMULTI", 0, 0x545A, 0 },
{ "asm/ioctls.h", "TIOCSERGSTRUCT", 0, 0x5458, 0 },
{ "asm/ioctls.h", "TIOCSERGWILD", 0, 0x5454, 0 },
{ "asm/ioctls.h", "TIOCSERSETMULTI", 0, 0x545B, 0 },
{ "asm/ioctls.h", "TIOCSERSWILD", 0, 0x5455, 0 },
{ "asm/ioctls.h", "TIOCSETD", 0, 0x5423, 0 },
{ "asm/ioctls.h", "TIOCSIG", _IOC_WRITE, 0x5436, 0x04 },
{ "asm/ioctls.h", "TIOCSLCKTRMIOS", 0, 0x5457, 0 },
{ "asm/ioctls.h", "TIOCSLTC", 0, 0x5462, 0 },
{ "asm/ioctls.h", "TIOCSPGRP", _IOC_WRITE, 0x541d, 0x04 },
{ "asm/ioctls.h", "TIOCSPTLCK", _IOC_WRITE, 0x5431, 0x04 },
{ "asm/ioctls.h", "TIOCSRS485", _IOC_READ|_IOC_WRITE, 0x542f, 0x20 },
{ "asm/ioctls.h", "TIOCSSERIAL", 0, 0x541F, 0 },
{ "asm/ioctls.h", "TIOCSSOFTCAR", 0, 0x541A, 0 },
{ "asm/ioctls.h", "TIOCSTART", 0, 0x5461, 0 },
{ "asm/ioctls.h", "TIOCSTI", 0, 0x5412, 0 },
{ "asm/ioctls.h", "TIOCSTOP", 0, 0x5462, 0 },
{ "asm/ioctls.h", "TIOCSWINSZ", 0, 0x5414, 0 },
{ "asm/ioctls.h", "TIOCVHANGUP", 0, 0x5437, 0 },
{ "asm/perf.h", "PA_PERF_OFF", _IOC_READ, 0x7002, 0x04 },
{ "asm/perf.h", "PA_PERF_ON", _IOC_NONE, 0x7001, 0x00 },
{ "asm/perf.h", "PA_PERF_VERSION", _IOC_READ, 0x7003, 0x04 },
