/* Generated by ./src/xlat/gen.sh from ./src/xlat/nl_route_types.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifndef IN_MPERS

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data nl_route_types_xdata[] = {

 XLAT(RTM_NEWLINK),
 #define XLAT_VAL_0 ((unsigned) (RTM_NEWLINK))
 #define XLAT_STR_0 STRINGIFY(RTM_NEWLINK)
 XLAT(RTM_DELLINK),
 #define XLAT_VAL_1 ((unsigned) (RTM_DELLINK))
 #define XLAT_STR_1 STRINGIFY(RTM_DELLINK)
 XLAT(RTM_GETLINK),
 #define XLAT_VAL_2 ((unsigned) (RTM_GETLINK))
 #define XLAT_STR_2 STRINGIFY(RTM_GETLINK)
 XLAT(RTM_SETLINK),
 #define XLAT_VAL_3 ((unsigned) (RTM_SETLINK))
 #define XLAT_STR_3 STRINGIFY(RTM_SETLINK)

 XLAT(RTM_NEWADDR),
 #define XLAT_VAL_4 ((unsigned) (RTM_NEWADDR))
 #define XLAT_STR_4 STRINGIFY(RTM_NEWADDR)
 XLAT(RTM_DELADDR),
 #define XLAT_VAL_5 ((unsigned) (RTM_DELADDR))
 #define XLAT_STR_5 STRINGIFY(RTM_DELADDR)
 XLAT(RTM_GETADDR),
 #define XLAT_VAL_6 ((unsigned) (RTM_GETADDR))
 #define XLAT_STR_6 STRINGIFY(RTM_GETADDR)

 XLAT(RTM_NEWROUTE),
 #define XLAT_VAL_7 ((unsigned) (RTM_NEWROUTE))
 #define XLAT_STR_7 STRINGIFY(RTM_NEWROUTE)
 XLAT(RTM_DELROUTE),
 #define XLAT_VAL_8 ((unsigned) (RTM_DELROUTE))
 #define XLAT_STR_8 STRINGIFY(RTM_DELROUTE)
 XLAT(RTM_GETROUTE),
 #define XLAT_VAL_9 ((unsigned) (RTM_GETROUTE))
 #define XLAT_STR_9 STRINGIFY(RTM_GETROUTE)

 XLAT(RTM_NEWNEIGH),
 #define XLAT_VAL_10 ((unsigned) (RTM_NEWNEIGH))
 #define XLAT_STR_10 STRINGIFY(RTM_NEWNEIGH)
 XLAT(RTM_DELNEIGH),
 #define XLAT_VAL_11 ((unsigned) (RTM_DELNEIGH))
 #define XLAT_STR_11 STRINGIFY(RTM_DELNEIGH)
 XLAT(RTM_GETNEIGH),
 #define XLAT_VAL_12 ((unsigned) (RTM_GETNEIGH))
 #define XLAT_STR_12 STRINGIFY(RTM_GETNEIGH)

 XLAT(RTM_NEWRULE),
 #define XLAT_VAL_13 ((unsigned) (RTM_NEWRULE))
 #define XLAT_STR_13 STRINGIFY(RTM_NEWRULE)
 XLAT(RTM_DELRULE),
 #define XLAT_VAL_14 ((unsigned) (RTM_DELRULE))
 #define XLAT_STR_14 STRINGIFY(RTM_DELRULE)
 XLAT(RTM_GETRULE),
 #define XLAT_VAL_15 ((unsigned) (RTM_GETRULE))
 #define XLAT_STR_15 STRINGIFY(RTM_GETRULE)

 XLAT(RTM_NEWQDISC),
 #define XLAT_VAL_16 ((unsigned) (RTM_NEWQDISC))
 #define XLAT_STR_16 STRINGIFY(RTM_NEWQDISC)
 XLAT(RTM_DELQDISC),
 #define XLAT_VAL_17 ((unsigned) (RTM_DELQDISC))
 #define XLAT_STR_17 STRINGIFY(RTM_DELQDISC)
 XLAT(RTM_GETQDISC),
 #define XLAT_VAL_18 ((unsigned) (RTM_GETQDISC))
 #define XLAT_STR_18 STRINGIFY(RTM_GETQDISC)

 XLAT(RTM_NEWTCLASS),
 #define XLAT_VAL_19 ((unsigned) (RTM_NEWTCLASS))
 #define XLAT_STR_19 STRINGIFY(RTM_NEWTCLASS)
 XLAT(RTM_DELTCLASS),
 #define XLAT_VAL_20 ((unsigned) (RTM_DELTCLASS))
 #define XLAT_STR_20 STRINGIFY(RTM_DELTCLASS)
 XLAT(RTM_GETTCLASS),
 #define XLAT_VAL_21 ((unsigned) (RTM_GETTCLASS))
 #define XLAT_STR_21 STRINGIFY(RTM_GETTCLASS)

 XLAT(RTM_NEWTFILTER),
 #define XLAT_VAL_22 ((unsigned) (RTM_NEWTFILTER))
 #define XLAT_STR_22 STRINGIFY(RTM_NEWTFILTER)
 XLAT(RTM_DELTFILTER),
 #define XLAT_VAL_23 ((unsigned) (RTM_DELTFILTER))
 #define XLAT_STR_23 STRINGIFY(RTM_DELTFILTER)
 XLAT(RTM_GETTFILTER),
 #define XLAT_VAL_24 ((unsigned) (RTM_GETTFILTER))
 #define XLAT_STR_24 STRINGIFY(RTM_GETTFILTER)

 XLAT(RTM_NEWACTION),
 #define XLAT_VAL_25 ((unsigned) (RTM_NEWACTION))
 #define XLAT_STR_25 STRINGIFY(RTM_NEWACTION)
 XLAT(RTM_DELACTION),
 #define XLAT_VAL_26 ((unsigned) (RTM_DELACTION))
 #define XLAT_STR_26 STRINGIFY(RTM_DELACTION)
 XLAT(RTM_GETACTION),
 #define XLAT_VAL_27 ((unsigned) (RTM_GETACTION))
 #define XLAT_STR_27 STRINGIFY(RTM_GETACTION)

 XLAT(RTM_NEWPREFIX),
 #define XLAT_VAL_28 ((unsigned) (RTM_NEWPREFIX))
 #define XLAT_STR_28 STRINGIFY(RTM_NEWPREFIX)

 XLAT(RTM_GETMULTICAST),
 #define XLAT_VAL_29 ((unsigned) (RTM_GETMULTICAST))
 #define XLAT_STR_29 STRINGIFY(RTM_GETMULTICAST)

 XLAT(RTM_GETANYCAST),
 #define XLAT_VAL_30 ((unsigned) (RTM_GETANYCAST))
 #define XLAT_STR_30 STRINGIFY(RTM_GETANYCAST)

 XLAT(RTM_NEWNEIGHTBL),
 #define XLAT_VAL_31 ((unsigned) (RTM_NEWNEIGHTBL))
 #define XLAT_STR_31 STRINGIFY(RTM_NEWNEIGHTBL)
 XLAT(RTM_GETNEIGHTBL),
 #define XLAT_VAL_32 ((unsigned) (RTM_GETNEIGHTBL))
 #define XLAT_STR_32 STRINGIFY(RTM_GETNEIGHTBL)
 XLAT(RTM_SETNEIGHTBL),
 #define XLAT_VAL_33 ((unsigned) (RTM_SETNEIGHTBL))
 #define XLAT_STR_33 STRINGIFY(RTM_SETNEIGHTBL)

 XLAT(RTM_NEWNDUSEROPT),
 #define XLAT_VAL_34 ((unsigned) (RTM_NEWNDUSEROPT))
 #define XLAT_STR_34 STRINGIFY(RTM_NEWNDUSEROPT)

 XLAT(RTM_NEWADDRLABEL),
 #define XLAT_VAL_35 ((unsigned) (RTM_NEWADDRLABEL))
 #define XLAT_STR_35 STRINGIFY(RTM_NEWADDRLABEL)
 XLAT(RTM_DELADDRLABEL),
 #define XLAT_VAL_36 ((unsigned) (RTM_DELADDRLABEL))
 #define XLAT_STR_36 STRINGIFY(RTM_DELADDRLABEL)
 XLAT(RTM_GETADDRLABEL),
 #define XLAT_VAL_37 ((unsigned) (RTM_GETADDRLABEL))
 #define XLAT_STR_37 STRINGIFY(RTM_GETADDRLABEL)

 XLAT(RTM_GETDCB),
 #define XLAT_VAL_38 ((unsigned) (RTM_GETDCB))
 #define XLAT_STR_38 STRINGIFY(RTM_GETDCB)
 XLAT(RTM_SETDCB),
 #define XLAT_VAL_39 ((unsigned) (RTM_SETDCB))
 #define XLAT_STR_39 STRINGIFY(RTM_SETDCB)

 XLAT(RTM_NEWNETCONF),
 #define XLAT_VAL_40 ((unsigned) (RTM_NEWNETCONF))
 #define XLAT_STR_40 STRINGIFY(RTM_NEWNETCONF)
 XLAT(RTM_DELNETCONF),
 #define XLAT_VAL_41 ((unsigned) (RTM_DELNETCONF))
 #define XLAT_STR_41 STRINGIFY(RTM_DELNETCONF)
 XLAT(RTM_GETNETCONF),
 #define XLAT_VAL_42 ((unsigned) (RTM_GETNETCONF))
 #define XLAT_STR_42 STRINGIFY(RTM_GETNETCONF)

 XLAT(RTM_NEWMDB),
 #define XLAT_VAL_43 ((unsigned) (RTM_NEWMDB))
 #define XLAT_STR_43 STRINGIFY(RTM_NEWMDB)
 XLAT(RTM_DELMDB),
 #define XLAT_VAL_44 ((unsigned) (RTM_DELMDB))
 #define XLAT_STR_44 STRINGIFY(RTM_DELMDB)
 XLAT(RTM_GETMDB),
 #define XLAT_VAL_45 ((unsigned) (RTM_GETMDB))
 #define XLAT_STR_45 STRINGIFY(RTM_GETMDB)

 XLAT(RTM_NEWNSID),
 #define XLAT_VAL_46 ((unsigned) (RTM_NEWNSID))
 #define XLAT_STR_46 STRINGIFY(RTM_NEWNSID)
 XLAT(RTM_DELNSID),
 #define XLAT_VAL_47 ((unsigned) (RTM_DELNSID))
 #define XLAT_STR_47 STRINGIFY(RTM_DELNSID)
 XLAT(RTM_GETNSID),
 #define XLAT_VAL_48 ((unsigned) (RTM_GETNSID))
 #define XLAT_STR_48 STRINGIFY(RTM_GETNSID)

 XLAT(RTM_NEWSTATS),
 #define XLAT_VAL_49 ((unsigned) (RTM_NEWSTATS))
 #define XLAT_STR_49 STRINGIFY(RTM_NEWSTATS)
 XLAT(RTM_GETSTATS),
 #define XLAT_VAL_50 ((unsigned) (RTM_GETSTATS))
 #define XLAT_STR_50 STRINGIFY(RTM_GETSTATS)

 XLAT(RTM_NEWCACHEREPORT),
 #define XLAT_VAL_51 ((unsigned) (RTM_NEWCACHEREPORT))
 #define XLAT_STR_51 STRINGIFY(RTM_NEWCACHEREPORT)

 XLAT(RTM_NEWCHAIN),
 #define XLAT_VAL_52 ((unsigned) (RTM_NEWCHAIN))
 #define XLAT_STR_52 STRINGIFY(RTM_NEWCHAIN)
 XLAT(RTM_DELCHAIN),
 #define XLAT_VAL_53 ((unsigned) (RTM_DELCHAIN))
 #define XLAT_STR_53 STRINGIFY(RTM_DELCHAIN)
 XLAT(RTM_GETCHAIN),
 #define XLAT_VAL_54 ((unsigned) (RTM_GETCHAIN))
 #define XLAT_STR_54 STRINGIFY(RTM_GETCHAIN)

 XLAT(RTM_NEWNEXTHOP),
 #define XLAT_VAL_55 ((unsigned) (RTM_NEWNEXTHOP))
 #define XLAT_STR_55 STRINGIFY(RTM_NEWNEXTHOP)
 XLAT(RTM_DELNEXTHOP),
 #define XLAT_VAL_56 ((unsigned) (RTM_DELNEXTHOP))
 #define XLAT_STR_56 STRINGIFY(RTM_DELNEXTHOP)
 XLAT(RTM_GETNEXTHOP),
 #define XLAT_VAL_57 ((unsigned) (RTM_GETNEXTHOP))
 #define XLAT_STR_57 STRINGIFY(RTM_GETNEXTHOP)

 XLAT(RTM_NEWLINKPROP),
 #define XLAT_VAL_58 ((unsigned) (RTM_NEWLINKPROP))
 #define XLAT_STR_58 STRINGIFY(RTM_NEWLINKPROP)
 XLAT(RTM_DELLINKPROP),
 #define XLAT_VAL_59 ((unsigned) (RTM_DELLINKPROP))
 #define XLAT_STR_59 STRINGIFY(RTM_DELLINKPROP)
 XLAT(RTM_GETLINKPROP),
 #define XLAT_VAL_60 ((unsigned) (RTM_GETLINKPROP))
 #define XLAT_STR_60 STRINGIFY(RTM_GETLINKPROP)

 XLAT(RTM_NEWVLAN),
 #define XLAT_VAL_61 ((unsigned) (RTM_NEWVLAN))
 #define XLAT_STR_61 STRINGIFY(RTM_NEWVLAN)
 XLAT(RTM_DELVLAN),
 #define XLAT_VAL_62 ((unsigned) (RTM_DELVLAN))
 #define XLAT_STR_62 STRINGIFY(RTM_DELVLAN)
 XLAT(RTM_GETVLAN),
 #define XLAT_VAL_63 ((unsigned) (RTM_GETVLAN))
 #define XLAT_STR_63 STRINGIFY(RTM_GETVLAN)

 XLAT(RTM_NEWNEXTHOPBUCKET),
 #define XLAT_VAL_64 ((unsigned) (RTM_NEWNEXTHOPBUCKET))
 #define XLAT_STR_64 STRINGIFY(RTM_NEWNEXTHOPBUCKET)
 XLAT(RTM_DELNEXTHOPBUCKET),
 #define XLAT_VAL_65 ((unsigned) (RTM_DELNEXTHOPBUCKET))
 #define XLAT_STR_65 STRINGIFY(RTM_DELNEXTHOPBUCKET)
 XLAT(RTM_GETNEXTHOPBUCKET),
 #define XLAT_VAL_66 ((unsigned) (RTM_GETNEXTHOPBUCKET))
 #define XLAT_STR_66 STRINGIFY(RTM_GETNEXTHOPBUCKET)
};
const struct xlat nl_route_types[1] = { {
 .data = nl_route_types_xdata,
 .size = ARRAY_SIZE(nl_route_types_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
#  ifdef XLAT_VAL_28
  | XLAT_VAL_28
#  endif
#  ifdef XLAT_VAL_29
  | XLAT_VAL_29
#  endif
#  ifdef XLAT_VAL_30
  | XLAT_VAL_30
#  endif
#  ifdef XLAT_VAL_31
  | XLAT_VAL_31
#  endif
#  ifdef XLAT_VAL_32
  | XLAT_VAL_32
#  endif
#  ifdef XLAT_VAL_33
  | XLAT_VAL_33
#  endif
#  ifdef XLAT_VAL_34
  | XLAT_VAL_34
#  endif
#  ifdef XLAT_VAL_35
  | XLAT_VAL_35
#  endif
#  ifdef XLAT_VAL_36
  | XLAT_VAL_36
#  endif
#  ifdef XLAT_VAL_37
  | XLAT_VAL_37
#  endif
#  ifdef XLAT_VAL_38
  | XLAT_VAL_38
#  endif
#  ifdef XLAT_VAL_39
  | XLAT_VAL_39
#  endif
#  ifdef XLAT_VAL_40
  | XLAT_VAL_40
#  endif
#  ifdef XLAT_VAL_41
  | XLAT_VAL_41
#  endif
#  ifdef XLAT_VAL_42
  | XLAT_VAL_42
#  endif
#  ifdef XLAT_VAL_43
  | XLAT_VAL_43
#  endif
#  ifdef XLAT_VAL_44
  | XLAT_VAL_44
#  endif
#  ifdef XLAT_VAL_45
  | XLAT_VAL_45
#  endif
#  ifdef XLAT_VAL_46
  | XLAT_VAL_46
#  endif
#  ifdef XLAT_VAL_47
  | XLAT_VAL_47
#  endif
#  ifdef XLAT_VAL_48
  | XLAT_VAL_48
#  endif
#  ifdef XLAT_VAL_49
  | XLAT_VAL_49
#  endif
#  ifdef XLAT_VAL_50
  | XLAT_VAL_50
#  endif
#  ifdef XLAT_VAL_51
  | XLAT_VAL_51
#  endif
#  ifdef XLAT_VAL_52
  | XLAT_VAL_52
#  endif
#  ifdef XLAT_VAL_53
  | XLAT_VAL_53
#  endif
#  ifdef XLAT_VAL_54
  | XLAT_VAL_54
#  endif
#  ifdef XLAT_VAL_55
  | XLAT_VAL_55
#  endif
#  ifdef XLAT_VAL_56
  | XLAT_VAL_56
#  endif
#  ifdef XLAT_VAL_57
  | XLAT_VAL_57
#  endif
#  ifdef XLAT_VAL_58
  | XLAT_VAL_58
#  endif
#  ifdef XLAT_VAL_59
  | XLAT_VAL_59
#  endif
#  ifdef XLAT_VAL_60
  | XLAT_VAL_60
#  endif
#  ifdef XLAT_VAL_61
  | XLAT_VAL_61
#  endif
#  ifdef XLAT_VAL_62
  | XLAT_VAL_62
#  endif
#  ifdef XLAT_VAL_63
  | XLAT_VAL_63
#  endif
#  ifdef XLAT_VAL_64
  | XLAT_VAL_64
#  endif
#  ifdef XLAT_VAL_65
  | XLAT_VAL_65
#  endif
#  ifdef XLAT_VAL_66
  | XLAT_VAL_66
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
#  ifdef XLAT_STR_28
  + sizeof(XLAT_STR_28)
#  endif
#  ifdef XLAT_STR_29
  + sizeof(XLAT_STR_29)
#  endif
#  ifdef XLAT_STR_30
  + sizeof(XLAT_STR_30)
#  endif
#  ifdef XLAT_STR_31
  + sizeof(XLAT_STR_31)
#  endif
#  ifdef XLAT_STR_32
  + sizeof(XLAT_STR_32)
#  endif
#  ifdef XLAT_STR_33
  + sizeof(XLAT_STR_33)
#  endif
#  ifdef XLAT_STR_34
  + sizeof(XLAT_STR_34)
#  endif
#  ifdef XLAT_STR_35
  + sizeof(XLAT_STR_35)
#  endif
#  ifdef XLAT_STR_36
  + sizeof(XLAT_STR_36)
#  endif
#  ifdef XLAT_STR_37
  + sizeof(XLAT_STR_37)
#  endif
#  ifdef XLAT_STR_38
  + sizeof(XLAT_STR_38)
#  endif
#  ifdef XLAT_STR_39
  + sizeof(XLAT_STR_39)
#  endif
#  ifdef XLAT_STR_40
  + sizeof(XLAT_STR_40)
#  endif
#  ifdef XLAT_STR_41
  + sizeof(XLAT_STR_41)
#  endif
#  ifdef XLAT_STR_42
  + sizeof(XLAT_STR_42)
#  endif
#  ifdef XLAT_STR_43
  + sizeof(XLAT_STR_43)
#  endif
#  ifdef XLAT_STR_44
  + sizeof(XLAT_STR_44)
#  endif
#  ifdef XLAT_STR_45
  + sizeof(XLAT_STR_45)
#  endif
#  ifdef XLAT_STR_46
  + sizeof(XLAT_STR_46)
#  endif
#  ifdef XLAT_STR_47
  + sizeof(XLAT_STR_47)
#  endif
#  ifdef XLAT_STR_48
  + sizeof(XLAT_STR_48)
#  endif
#  ifdef XLAT_STR_49
  + sizeof(XLAT_STR_49)
#  endif
#  ifdef XLAT_STR_50
  + sizeof(XLAT_STR_50)
#  endif
#  ifdef XLAT_STR_51
  + sizeof(XLAT_STR_51)
#  endif
#  ifdef XLAT_STR_52
  + sizeof(XLAT_STR_52)
#  endif
#  ifdef XLAT_STR_53
  + sizeof(XLAT_STR_53)
#  endif
#  ifdef XLAT_STR_54
  + sizeof(XLAT_STR_54)
#  endif
#  ifdef XLAT_STR_55
  + sizeof(XLAT_STR_55)
#  endif
#  ifdef XLAT_STR_56
  + sizeof(XLAT_STR_56)
#  endif
#  ifdef XLAT_STR_57
  + sizeof(XLAT_STR_57)
#  endif
#  ifdef XLAT_STR_58
  + sizeof(XLAT_STR_58)
#  endif
#  ifdef XLAT_STR_59
  + sizeof(XLAT_STR_59)
#  endif
#  ifdef XLAT_STR_60
  + sizeof(XLAT_STR_60)
#  endif
#  ifdef XLAT_STR_61
  + sizeof(XLAT_STR_61)
#  endif
#  ifdef XLAT_STR_62
  + sizeof(XLAT_STR_62)
#  endif
#  ifdef XLAT_STR_63
  + sizeof(XLAT_STR_63)
#  endif
#  ifdef XLAT_STR_64
  + sizeof(XLAT_STR_64)
#  endif
#  ifdef XLAT_STR_65
  + sizeof(XLAT_STR_65)
#  endif
#  ifdef XLAT_STR_66
  + sizeof(XLAT_STR_66)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
#  undef XLAT_STR_28
#  undef XLAT_VAL_28
#  undef XLAT_STR_29
#  undef XLAT_VAL_29
#  undef XLAT_STR_30
#  undef XLAT_VAL_30
#  undef XLAT_STR_31
#  undef XLAT_VAL_31
#  undef XLAT_STR_32
#  undef XLAT_VAL_32
#  undef XLAT_STR_33
#  undef XLAT_VAL_33
#  undef XLAT_STR_34
#  undef XLAT_VAL_34
#  undef XLAT_STR_35
#  undef XLAT_VAL_35
#  undef XLAT_STR_36
#  undef XLAT_VAL_36
#  undef XLAT_STR_37
#  undef XLAT_VAL_37
#  undef XLAT_STR_38
#  undef XLAT_VAL_38
#  undef XLAT_STR_39
#  undef XLAT_VAL_39
#  undef XLAT_STR_40
#  undef XLAT_VAL_40
#  undef XLAT_STR_41
#  undef XLAT_VAL_41
#  undef XLAT_STR_42
#  undef XLAT_VAL_42
#  undef XLAT_STR_43
#  undef XLAT_VAL_43
#  undef XLAT_STR_44
#  undef XLAT_VAL_44
#  undef XLAT_STR_45
#  undef XLAT_VAL_45
#  undef XLAT_STR_46
#  undef XLAT_VAL_46
#  undef XLAT_STR_47
#  undef XLAT_VAL_47
#  undef XLAT_STR_48
#  undef XLAT_VAL_48
#  undef XLAT_STR_49
#  undef XLAT_VAL_49
#  undef XLAT_STR_50
#  undef XLAT_VAL_50
#  undef XLAT_STR_51
#  undef XLAT_VAL_51
#  undef XLAT_STR_52
#  undef XLAT_VAL_52
#  undef XLAT_STR_53
#  undef XLAT_VAL_53
#  undef XLAT_STR_54
#  undef XLAT_VAL_54
#  undef XLAT_STR_55
#  undef XLAT_VAL_55
#  undef XLAT_STR_56
#  undef XLAT_VAL_56
#  undef XLAT_STR_57
#  undef XLAT_VAL_57
#  undef XLAT_STR_58
#  undef XLAT_VAL_58
#  undef XLAT_STR_59
#  undef XLAT_VAL_59
#  undef XLAT_STR_60
#  undef XLAT_VAL_60
#  undef XLAT_STR_61
#  undef XLAT_VAL_61
#  undef XLAT_STR_62
#  undef XLAT_VAL_62
#  undef XLAT_STR_63
#  undef XLAT_VAL_63
#  undef XLAT_STR_64
#  undef XLAT_VAL_64
#  undef XLAT_STR_65
#  undef XLAT_VAL_65
#  undef XLAT_STR_66
#  undef XLAT_VAL_66
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
