/* Generated by ./src/xlat/gen.sh from ./src/xlat/genl_devlink_cmd.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat genl_devlink_cmd in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data genl_devlink_cmd_xdata[] = {

 [DEVLINK_CMD_UNSPEC] = XLAT(DEVLINK_CMD_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (DEVLINK_CMD_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(DEVLINK_CMD_UNSPEC)

 [DEVLINK_CMD_GET] = XLAT(DEVLINK_CMD_GET),
 #define XLAT_VAL_1 ((unsigned) (DEVLINK_CMD_GET))
 #define XLAT_STR_1 STRINGIFY(DEVLINK_CMD_GET)
 [DEVLINK_CMD_SET] = XLAT(DEVLINK_CMD_SET),
 #define XLAT_VAL_2 ((unsigned) (DEVLINK_CMD_SET))
 #define XLAT_STR_2 STRINGIFY(DEVLINK_CMD_SET)
 [DEVLINK_CMD_NEW] = XLAT(DEVLINK_CMD_NEW),
 #define XLAT_VAL_3 ((unsigned) (DEVLINK_CMD_NEW))
 #define XLAT_STR_3 STRINGIFY(DEVLINK_CMD_NEW)
 [DEVLINK_CMD_DEL] = XLAT(DEVLINK_CMD_DEL),
 #define XLAT_VAL_4 ((unsigned) (DEVLINK_CMD_DEL))
 #define XLAT_STR_4 STRINGIFY(DEVLINK_CMD_DEL)

 [DEVLINK_CMD_PORT_GET] = XLAT(DEVLINK_CMD_PORT_GET),
 #define XLAT_VAL_5 ((unsigned) (DEVLINK_CMD_PORT_GET))
 #define XLAT_STR_5 STRINGIFY(DEVLINK_CMD_PORT_GET)
 [DEVLINK_CMD_PORT_SET] = XLAT(DEVLINK_CMD_PORT_SET),
 #define XLAT_VAL_6 ((unsigned) (DEVLINK_CMD_PORT_SET))
 #define XLAT_STR_6 STRINGIFY(DEVLINK_CMD_PORT_SET)
 [DEVLINK_CMD_PORT_NEW] = XLAT(DEVLINK_CMD_PORT_NEW),
 #define XLAT_VAL_7 ((unsigned) (DEVLINK_CMD_PORT_NEW))
 #define XLAT_STR_7 STRINGIFY(DEVLINK_CMD_PORT_NEW)
 [DEVLINK_CMD_PORT_DEL] = XLAT(DEVLINK_CMD_PORT_DEL),
 #define XLAT_VAL_8 ((unsigned) (DEVLINK_CMD_PORT_DEL))
 #define XLAT_STR_8 STRINGIFY(DEVLINK_CMD_PORT_DEL)

 [DEVLINK_CMD_PORT_SPLIT] = XLAT(DEVLINK_CMD_PORT_SPLIT),
 #define XLAT_VAL_9 ((unsigned) (DEVLINK_CMD_PORT_SPLIT))
 #define XLAT_STR_9 STRINGIFY(DEVLINK_CMD_PORT_SPLIT)
 [DEVLINK_CMD_PORT_UNSPLIT] = XLAT(DEVLINK_CMD_PORT_UNSPLIT),
 #define XLAT_VAL_10 ((unsigned) (DEVLINK_CMD_PORT_UNSPLIT))
 #define XLAT_STR_10 STRINGIFY(DEVLINK_CMD_PORT_UNSPLIT)

 [DEVLINK_CMD_SB_GET] = XLAT(DEVLINK_CMD_SB_GET),
 #define XLAT_VAL_11 ((unsigned) (DEVLINK_CMD_SB_GET))
 #define XLAT_STR_11 STRINGIFY(DEVLINK_CMD_SB_GET)
 [DEVLINK_CMD_SB_SET] = XLAT(DEVLINK_CMD_SB_SET),
 #define XLAT_VAL_12 ((unsigned) (DEVLINK_CMD_SB_SET))
 #define XLAT_STR_12 STRINGIFY(DEVLINK_CMD_SB_SET)
 [DEVLINK_CMD_SB_NEW] = XLAT(DEVLINK_CMD_SB_NEW),
 #define XLAT_VAL_13 ((unsigned) (DEVLINK_CMD_SB_NEW))
 #define XLAT_STR_13 STRINGIFY(DEVLINK_CMD_SB_NEW)
 [DEVLINK_CMD_SB_DEL] = XLAT(DEVLINK_CMD_SB_DEL),
 #define XLAT_VAL_14 ((unsigned) (DEVLINK_CMD_SB_DEL))
 #define XLAT_STR_14 STRINGIFY(DEVLINK_CMD_SB_DEL)

 [DEVLINK_CMD_SB_POOL_GET] = XLAT(DEVLINK_CMD_SB_POOL_GET),
 #define XLAT_VAL_15 ((unsigned) (DEVLINK_CMD_SB_POOL_GET))
 #define XLAT_STR_15 STRINGIFY(DEVLINK_CMD_SB_POOL_GET)
 [DEVLINK_CMD_SB_POOL_SET] = XLAT(DEVLINK_CMD_SB_POOL_SET),
 #define XLAT_VAL_16 ((unsigned) (DEVLINK_CMD_SB_POOL_SET))
 #define XLAT_STR_16 STRINGIFY(DEVLINK_CMD_SB_POOL_SET)
 [DEVLINK_CMD_SB_POOL_NEW] = XLAT(DEVLINK_CMD_SB_POOL_NEW),
 #define XLAT_VAL_17 ((unsigned) (DEVLINK_CMD_SB_POOL_NEW))
 #define XLAT_STR_17 STRINGIFY(DEVLINK_CMD_SB_POOL_NEW)
 [DEVLINK_CMD_SB_POOL_DEL] = XLAT(DEVLINK_CMD_SB_POOL_DEL),
 #define XLAT_VAL_18 ((unsigned) (DEVLINK_CMD_SB_POOL_DEL))
 #define XLAT_STR_18 STRINGIFY(DEVLINK_CMD_SB_POOL_DEL)

 [DEVLINK_CMD_SB_PORT_POOL_GET] = XLAT(DEVLINK_CMD_SB_PORT_POOL_GET),
 #define XLAT_VAL_19 ((unsigned) (DEVLINK_CMD_SB_PORT_POOL_GET))
 #define XLAT_STR_19 STRINGIFY(DEVLINK_CMD_SB_PORT_POOL_GET)
 [DEVLINK_CMD_SB_PORT_POOL_SET] = XLAT(DEVLINK_CMD_SB_PORT_POOL_SET),
 #define XLAT_VAL_20 ((unsigned) (DEVLINK_CMD_SB_PORT_POOL_SET))
 #define XLAT_STR_20 STRINGIFY(DEVLINK_CMD_SB_PORT_POOL_SET)
 [DEVLINK_CMD_SB_PORT_POOL_NEW] = XLAT(DEVLINK_CMD_SB_PORT_POOL_NEW),
 #define XLAT_VAL_21 ((unsigned) (DEVLINK_CMD_SB_PORT_POOL_NEW))
 #define XLAT_STR_21 STRINGIFY(DEVLINK_CMD_SB_PORT_POOL_NEW)
 [DEVLINK_CMD_SB_PORT_POOL_DEL] = XLAT(DEVLINK_CMD_SB_PORT_POOL_DEL),
 #define XLAT_VAL_22 ((unsigned) (DEVLINK_CMD_SB_PORT_POOL_DEL))
 #define XLAT_STR_22 STRINGIFY(DEVLINK_CMD_SB_PORT_POOL_DEL)

 [DEVLINK_CMD_SB_TC_POOL_BIND_GET] = XLAT(DEVLINK_CMD_SB_TC_POOL_BIND_GET),
 #define XLAT_VAL_23 ((unsigned) (DEVLINK_CMD_SB_TC_POOL_BIND_GET))
 #define XLAT_STR_23 STRINGIFY(DEVLINK_CMD_SB_TC_POOL_BIND_GET)
 [DEVLINK_CMD_SB_TC_POOL_BIND_SET] = XLAT(DEVLINK_CMD_SB_TC_POOL_BIND_SET),
 #define XLAT_VAL_24 ((unsigned) (DEVLINK_CMD_SB_TC_POOL_BIND_SET))
 #define XLAT_STR_24 STRINGIFY(DEVLINK_CMD_SB_TC_POOL_BIND_SET)
 [DEVLINK_CMD_SB_TC_POOL_BIND_NEW] = XLAT(DEVLINK_CMD_SB_TC_POOL_BIND_NEW),
 #define XLAT_VAL_25 ((unsigned) (DEVLINK_CMD_SB_TC_POOL_BIND_NEW))
 #define XLAT_STR_25 STRINGIFY(DEVLINK_CMD_SB_TC_POOL_BIND_NEW)
 [DEVLINK_CMD_SB_TC_POOL_BIND_DEL] = XLAT(DEVLINK_CMD_SB_TC_POOL_BIND_DEL),
 #define XLAT_VAL_26 ((unsigned) (DEVLINK_CMD_SB_TC_POOL_BIND_DEL))
 #define XLAT_STR_26 STRINGIFY(DEVLINK_CMD_SB_TC_POOL_BIND_DEL)

 [DEVLINK_CMD_SB_OCC_SNAPSHOT] = XLAT(DEVLINK_CMD_SB_OCC_SNAPSHOT),
 #define XLAT_VAL_27 ((unsigned) (DEVLINK_CMD_SB_OCC_SNAPSHOT))
 #define XLAT_STR_27 STRINGIFY(DEVLINK_CMD_SB_OCC_SNAPSHOT)
 [DEVLINK_CMD_SB_OCC_MAX_CLEAR] = XLAT(DEVLINK_CMD_SB_OCC_MAX_CLEAR),
 #define XLAT_VAL_28 ((unsigned) (DEVLINK_CMD_SB_OCC_MAX_CLEAR))
 #define XLAT_STR_28 STRINGIFY(DEVLINK_CMD_SB_OCC_MAX_CLEAR)

 [DEVLINK_CMD_ESWITCH_GET] = XLAT(DEVLINK_CMD_ESWITCH_GET),
 #define XLAT_VAL_29 ((unsigned) (DEVLINK_CMD_ESWITCH_GET))
 #define XLAT_STR_29 STRINGIFY(DEVLINK_CMD_ESWITCH_GET)
 [DEVLINK_CMD_ESWITCH_SET] = XLAT(DEVLINK_CMD_ESWITCH_SET),
 #define XLAT_VAL_30 ((unsigned) (DEVLINK_CMD_ESWITCH_SET))
 #define XLAT_STR_30 STRINGIFY(DEVLINK_CMD_ESWITCH_SET)

 [DEVLINK_CMD_DPIPE_TABLE_GET] = XLAT(DEVLINK_CMD_DPIPE_TABLE_GET),
 #define XLAT_VAL_31 ((unsigned) (DEVLINK_CMD_DPIPE_TABLE_GET))
 #define XLAT_STR_31 STRINGIFY(DEVLINK_CMD_DPIPE_TABLE_GET)
 [DEVLINK_CMD_DPIPE_ENTRIES_GET] = XLAT(DEVLINK_CMD_DPIPE_ENTRIES_GET),
 #define XLAT_VAL_32 ((unsigned) (DEVLINK_CMD_DPIPE_ENTRIES_GET))
 #define XLAT_STR_32 STRINGIFY(DEVLINK_CMD_DPIPE_ENTRIES_GET)
 [DEVLINK_CMD_DPIPE_HEADERS_GET] = XLAT(DEVLINK_CMD_DPIPE_HEADERS_GET),
 #define XLAT_VAL_33 ((unsigned) (DEVLINK_CMD_DPIPE_HEADERS_GET))
 #define XLAT_STR_33 STRINGIFY(DEVLINK_CMD_DPIPE_HEADERS_GET)
 [DEVLINK_CMD_DPIPE_TABLE_COUNTERS_SET] = XLAT(DEVLINK_CMD_DPIPE_TABLE_COUNTERS_SET),
 #define XLAT_VAL_34 ((unsigned) (DEVLINK_CMD_DPIPE_TABLE_COUNTERS_SET))
 #define XLAT_STR_34 STRINGIFY(DEVLINK_CMD_DPIPE_TABLE_COUNTERS_SET)
 [DEVLINK_CMD_RESOURCE_SET] = XLAT(DEVLINK_CMD_RESOURCE_SET),
 #define XLAT_VAL_35 ((unsigned) (DEVLINK_CMD_RESOURCE_SET))
 #define XLAT_STR_35 STRINGIFY(DEVLINK_CMD_RESOURCE_SET)
 [DEVLINK_CMD_RESOURCE_DUMP] = XLAT(DEVLINK_CMD_RESOURCE_DUMP),
 #define XLAT_VAL_36 ((unsigned) (DEVLINK_CMD_RESOURCE_DUMP))
 #define XLAT_STR_36 STRINGIFY(DEVLINK_CMD_RESOURCE_DUMP)

 [DEVLINK_CMD_RELOAD] = XLAT(DEVLINK_CMD_RELOAD),
 #define XLAT_VAL_37 ((unsigned) (DEVLINK_CMD_RELOAD))
 #define XLAT_STR_37 STRINGIFY(DEVLINK_CMD_RELOAD)

 [DEVLINK_CMD_PARAM_GET] = XLAT(DEVLINK_CMD_PARAM_GET),
 #define XLAT_VAL_38 ((unsigned) (DEVLINK_CMD_PARAM_GET))
 #define XLAT_STR_38 STRINGIFY(DEVLINK_CMD_PARAM_GET)
 [DEVLINK_CMD_PARAM_SET] = XLAT(DEVLINK_CMD_PARAM_SET),
 #define XLAT_VAL_39 ((unsigned) (DEVLINK_CMD_PARAM_SET))
 #define XLAT_STR_39 STRINGIFY(DEVLINK_CMD_PARAM_SET)
 [DEVLINK_CMD_PARAM_NEW] = XLAT(DEVLINK_CMD_PARAM_NEW),
 #define XLAT_VAL_40 ((unsigned) (DEVLINK_CMD_PARAM_NEW))
 #define XLAT_STR_40 STRINGIFY(DEVLINK_CMD_PARAM_NEW)
 [DEVLINK_CMD_PARAM_DEL] = XLAT(DEVLINK_CMD_PARAM_DEL),
 #define XLAT_VAL_41 ((unsigned) (DEVLINK_CMD_PARAM_DEL))
 #define XLAT_STR_41 STRINGIFY(DEVLINK_CMD_PARAM_DEL)

 [DEVLINK_CMD_REGION_GET] = XLAT(DEVLINK_CMD_REGION_GET),
 #define XLAT_VAL_42 ((unsigned) (DEVLINK_CMD_REGION_GET))
 #define XLAT_STR_42 STRINGIFY(DEVLINK_CMD_REGION_GET)
 [DEVLINK_CMD_REGION_SET] = XLAT(DEVLINK_CMD_REGION_SET),
 #define XLAT_VAL_43 ((unsigned) (DEVLINK_CMD_REGION_SET))
 #define XLAT_STR_43 STRINGIFY(DEVLINK_CMD_REGION_SET)
 [DEVLINK_CMD_REGION_NEW] = XLAT(DEVLINK_CMD_REGION_NEW),
 #define XLAT_VAL_44 ((unsigned) (DEVLINK_CMD_REGION_NEW))
 #define XLAT_STR_44 STRINGIFY(DEVLINK_CMD_REGION_NEW)
 [DEVLINK_CMD_REGION_DEL] = XLAT(DEVLINK_CMD_REGION_DEL),
 #define XLAT_VAL_45 ((unsigned) (DEVLINK_CMD_REGION_DEL))
 #define XLAT_STR_45 STRINGIFY(DEVLINK_CMD_REGION_DEL)
 [DEVLINK_CMD_REGION_READ] = XLAT(DEVLINK_CMD_REGION_READ),
 #define XLAT_VAL_46 ((unsigned) (DEVLINK_CMD_REGION_READ))
 #define XLAT_STR_46 STRINGIFY(DEVLINK_CMD_REGION_READ)

 [DEVLINK_CMD_PORT_PARAM_GET] = XLAT(DEVLINK_CMD_PORT_PARAM_GET),
 #define XLAT_VAL_47 ((unsigned) (DEVLINK_CMD_PORT_PARAM_GET))
 #define XLAT_STR_47 STRINGIFY(DEVLINK_CMD_PORT_PARAM_GET)
 [DEVLINK_CMD_PORT_PARAM_SET] = XLAT(DEVLINK_CMD_PORT_PARAM_SET),
 #define XLAT_VAL_48 ((unsigned) (DEVLINK_CMD_PORT_PARAM_SET))
 #define XLAT_STR_48 STRINGIFY(DEVLINK_CMD_PORT_PARAM_SET)
 [DEVLINK_CMD_PORT_PARAM_NEW] = XLAT(DEVLINK_CMD_PORT_PARAM_NEW),
 #define XLAT_VAL_49 ((unsigned) (DEVLINK_CMD_PORT_PARAM_NEW))
 #define XLAT_STR_49 STRINGIFY(DEVLINK_CMD_PORT_PARAM_NEW)
 [DEVLINK_CMD_PORT_PARAM_DEL] = XLAT(DEVLINK_CMD_PORT_PARAM_DEL),
 #define XLAT_VAL_50 ((unsigned) (DEVLINK_CMD_PORT_PARAM_DEL))
 #define XLAT_STR_50 STRINGIFY(DEVLINK_CMD_PORT_PARAM_DEL)

 [DEVLINK_CMD_INFO_GET] = XLAT(DEVLINK_CMD_INFO_GET),
 #define XLAT_VAL_51 ((unsigned) (DEVLINK_CMD_INFO_GET))
 #define XLAT_STR_51 STRINGIFY(DEVLINK_CMD_INFO_GET)

 [DEVLINK_CMD_HEALTH_REPORTER_GET] = XLAT(DEVLINK_CMD_HEALTH_REPORTER_GET),
 #define XLAT_VAL_52 ((unsigned) (DEVLINK_CMD_HEALTH_REPORTER_GET))
 #define XLAT_STR_52 STRINGIFY(DEVLINK_CMD_HEALTH_REPORTER_GET)
 [DEVLINK_CMD_HEALTH_REPORTER_SET] = XLAT(DEVLINK_CMD_HEALTH_REPORTER_SET),
 #define XLAT_VAL_53 ((unsigned) (DEVLINK_CMD_HEALTH_REPORTER_SET))
 #define XLAT_STR_53 STRINGIFY(DEVLINK_CMD_HEALTH_REPORTER_SET)
 [DEVLINK_CMD_HEALTH_REPORTER_RECOVER] = XLAT(DEVLINK_CMD_HEALTH_REPORTER_RECOVER),
 #define XLAT_VAL_54 ((unsigned) (DEVLINK_CMD_HEALTH_REPORTER_RECOVER))
 #define XLAT_STR_54 STRINGIFY(DEVLINK_CMD_HEALTH_REPORTER_RECOVER)
 [DEVLINK_CMD_HEALTH_REPORTER_DIAGNOSE] = XLAT(DEVLINK_CMD_HEALTH_REPORTER_DIAGNOSE),
 #define XLAT_VAL_55 ((unsigned) (DEVLINK_CMD_HEALTH_REPORTER_DIAGNOSE))
 #define XLAT_STR_55 STRINGIFY(DEVLINK_CMD_HEALTH_REPORTER_DIAGNOSE)
 [DEVLINK_CMD_HEALTH_REPORTER_DUMP_GET] = XLAT(DEVLINK_CMD_HEALTH_REPORTER_DUMP_GET),
 #define XLAT_VAL_56 ((unsigned) (DEVLINK_CMD_HEALTH_REPORTER_DUMP_GET))
 #define XLAT_STR_56 STRINGIFY(DEVLINK_CMD_HEALTH_REPORTER_DUMP_GET)
 [DEVLINK_CMD_HEALTH_REPORTER_DUMP_CLEAR] = XLAT(DEVLINK_CMD_HEALTH_REPORTER_DUMP_CLEAR),
 #define XLAT_VAL_57 ((unsigned) (DEVLINK_CMD_HEALTH_REPORTER_DUMP_CLEAR))
 #define XLAT_STR_57 STRINGIFY(DEVLINK_CMD_HEALTH_REPORTER_DUMP_CLEAR)

 [DEVLINK_CMD_FLASH_UPDATE] = XLAT(DEVLINK_CMD_FLASH_UPDATE),
 #define XLAT_VAL_58 ((unsigned) (DEVLINK_CMD_FLASH_UPDATE))
 #define XLAT_STR_58 STRINGIFY(DEVLINK_CMD_FLASH_UPDATE)
 [DEVLINK_CMD_FLASH_UPDATE_END] = XLAT(DEVLINK_CMD_FLASH_UPDATE_END),
 #define XLAT_VAL_59 ((unsigned) (DEVLINK_CMD_FLASH_UPDATE_END))
 #define XLAT_STR_59 STRINGIFY(DEVLINK_CMD_FLASH_UPDATE_END)
 [DEVLINK_CMD_FLASH_UPDATE_STATUS] = XLAT(DEVLINK_CMD_FLASH_UPDATE_STATUS),
 #define XLAT_VAL_60 ((unsigned) (DEVLINK_CMD_FLASH_UPDATE_STATUS))
 #define XLAT_STR_60 STRINGIFY(DEVLINK_CMD_FLASH_UPDATE_STATUS)

 [DEVLINK_CMD_TRAP_GET] = XLAT(DEVLINK_CMD_TRAP_GET),
 #define XLAT_VAL_61 ((unsigned) (DEVLINK_CMD_TRAP_GET))
 #define XLAT_STR_61 STRINGIFY(DEVLINK_CMD_TRAP_GET)
 [DEVLINK_CMD_TRAP_SET] = XLAT(DEVLINK_CMD_TRAP_SET),
 #define XLAT_VAL_62 ((unsigned) (DEVLINK_CMD_TRAP_SET))
 #define XLAT_STR_62 STRINGIFY(DEVLINK_CMD_TRAP_SET)
 [DEVLINK_CMD_TRAP_NEW] = XLAT(DEVLINK_CMD_TRAP_NEW),
 #define XLAT_VAL_63 ((unsigned) (DEVLINK_CMD_TRAP_NEW))
 #define XLAT_STR_63 STRINGIFY(DEVLINK_CMD_TRAP_NEW)
 [DEVLINK_CMD_TRAP_DEL] = XLAT(DEVLINK_CMD_TRAP_DEL),
 #define XLAT_VAL_64 ((unsigned) (DEVLINK_CMD_TRAP_DEL))
 #define XLAT_STR_64 STRINGIFY(DEVLINK_CMD_TRAP_DEL)

 [DEVLINK_CMD_TRAP_GROUP_GET] = XLAT(DEVLINK_CMD_TRAP_GROUP_GET),
 #define XLAT_VAL_65 ((unsigned) (DEVLINK_CMD_TRAP_GROUP_GET))
 #define XLAT_STR_65 STRINGIFY(DEVLINK_CMD_TRAP_GROUP_GET)
 [DEVLINK_CMD_TRAP_GROUP_SET] = XLAT(DEVLINK_CMD_TRAP_GROUP_SET),
 #define XLAT_VAL_66 ((unsigned) (DEVLINK_CMD_TRAP_GROUP_SET))
 #define XLAT_STR_66 STRINGIFY(DEVLINK_CMD_TRAP_GROUP_SET)
 [DEVLINK_CMD_TRAP_GROUP_NEW] = XLAT(DEVLINK_CMD_TRAP_GROUP_NEW),
 #define XLAT_VAL_67 ((unsigned) (DEVLINK_CMD_TRAP_GROUP_NEW))
 #define XLAT_STR_67 STRINGIFY(DEVLINK_CMD_TRAP_GROUP_NEW)
 [DEVLINK_CMD_TRAP_GROUP_DEL] = XLAT(DEVLINK_CMD_TRAP_GROUP_DEL),
 #define XLAT_VAL_68 ((unsigned) (DEVLINK_CMD_TRAP_GROUP_DEL))
 #define XLAT_STR_68 STRINGIFY(DEVLINK_CMD_TRAP_GROUP_DEL)

 [DEVLINK_CMD_TRAP_POLICER_GET] = XLAT(DEVLINK_CMD_TRAP_POLICER_GET),
 #define XLAT_VAL_69 ((unsigned) (DEVLINK_CMD_TRAP_POLICER_GET))
 #define XLAT_STR_69 STRINGIFY(DEVLINK_CMD_TRAP_POLICER_GET)
 [DEVLINK_CMD_TRAP_POLICER_SET] = XLAT(DEVLINK_CMD_TRAP_POLICER_SET),
 #define XLAT_VAL_70 ((unsigned) (DEVLINK_CMD_TRAP_POLICER_SET))
 #define XLAT_STR_70 STRINGIFY(DEVLINK_CMD_TRAP_POLICER_SET)
 [DEVLINK_CMD_TRAP_POLICER_NEW] = XLAT(DEVLINK_CMD_TRAP_POLICER_NEW),
 #define XLAT_VAL_71 ((unsigned) (DEVLINK_CMD_TRAP_POLICER_NEW))
 #define XLAT_STR_71 STRINGIFY(DEVLINK_CMD_TRAP_POLICER_NEW)
 [DEVLINK_CMD_TRAP_POLICER_DEL] = XLAT(DEVLINK_CMD_TRAP_POLICER_DEL),
 #define XLAT_VAL_72 ((unsigned) (DEVLINK_CMD_TRAP_POLICER_DEL))
 #define XLAT_STR_72 STRINGIFY(DEVLINK_CMD_TRAP_POLICER_DEL)

 [DEVLINK_CMD_HEALTH_REPORTER_TEST] = XLAT(DEVLINK_CMD_HEALTH_REPORTER_TEST),
 #define XLAT_VAL_73 ((unsigned) (DEVLINK_CMD_HEALTH_REPORTER_TEST))
 #define XLAT_STR_73 STRINGIFY(DEVLINK_CMD_HEALTH_REPORTER_TEST)

 [DEVLINK_CMD_RATE_GET] = XLAT(DEVLINK_CMD_RATE_GET),
 #define XLAT_VAL_74 ((unsigned) (DEVLINK_CMD_RATE_GET))
 #define XLAT_STR_74 STRINGIFY(DEVLINK_CMD_RATE_GET)
 [DEVLINK_CMD_RATE_SET] = XLAT(DEVLINK_CMD_RATE_SET),
 #define XLAT_VAL_75 ((unsigned) (DEVLINK_CMD_RATE_SET))
 #define XLAT_STR_75 STRINGIFY(DEVLINK_CMD_RATE_SET)
 [DEVLINK_CMD_RATE_NEW] = XLAT(DEVLINK_CMD_RATE_NEW),
 #define XLAT_VAL_76 ((unsigned) (DEVLINK_CMD_RATE_NEW))
 #define XLAT_STR_76 STRINGIFY(DEVLINK_CMD_RATE_NEW)
 [DEVLINK_CMD_RATE_DEL] = XLAT(DEVLINK_CMD_RATE_DEL),
 #define XLAT_VAL_77 ((unsigned) (DEVLINK_CMD_RATE_DEL))
 #define XLAT_STR_77 STRINGIFY(DEVLINK_CMD_RATE_DEL)

 [DEVLINK_CMD_LINECARD_GET] = XLAT(DEVLINK_CMD_LINECARD_GET),
 #define XLAT_VAL_78 ((unsigned) (DEVLINK_CMD_LINECARD_GET))
 #define XLAT_STR_78 STRINGIFY(DEVLINK_CMD_LINECARD_GET)
 [DEVLINK_CMD_LINECARD_SET] = XLAT(DEVLINK_CMD_LINECARD_SET),
 #define XLAT_VAL_79 ((unsigned) (DEVLINK_CMD_LINECARD_SET))
 #define XLAT_STR_79 STRINGIFY(DEVLINK_CMD_LINECARD_SET)
 [DEVLINK_CMD_LINECARD_NEW] = XLAT(DEVLINK_CMD_LINECARD_NEW),
 #define XLAT_VAL_80 ((unsigned) (DEVLINK_CMD_LINECARD_NEW))
 #define XLAT_STR_80 STRINGIFY(DEVLINK_CMD_LINECARD_NEW)
 [DEVLINK_CMD_LINECARD_DEL] = XLAT(DEVLINK_CMD_LINECARD_DEL),
 #define XLAT_VAL_81 ((unsigned) (DEVLINK_CMD_LINECARD_DEL))
 #define XLAT_STR_81 STRINGIFY(DEVLINK_CMD_LINECARD_DEL)

 [DEVLINK_CMD_SELFTESTS_GET] = XLAT(DEVLINK_CMD_SELFTESTS_GET),
 #define XLAT_VAL_82 ((unsigned) (DEVLINK_CMD_SELFTESTS_GET))
 #define XLAT_STR_82 STRINGIFY(DEVLINK_CMD_SELFTESTS_GET)
 [DEVLINK_CMD_SELFTESTS_RUN] = XLAT(DEVLINK_CMD_SELFTESTS_RUN),
 #define XLAT_VAL_83 ((unsigned) (DEVLINK_CMD_SELFTESTS_RUN))
 #define XLAT_STR_83 STRINGIFY(DEVLINK_CMD_SELFTESTS_RUN)

 [DEVLINK_CMD_NOTIFY_FILTER_SET] = XLAT(DEVLINK_CMD_NOTIFY_FILTER_SET),
 #define XLAT_VAL_84 ((unsigned) (DEVLINK_CMD_NOTIFY_FILTER_SET))
 #define XLAT_STR_84 STRINGIFY(DEVLINK_CMD_NOTIFY_FILTER_SET)
};
static
const struct xlat genl_devlink_cmd[1] = { {
 .data = genl_devlink_cmd_xdata,
 .size = ARRAY_SIZE(genl_devlink_cmd_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
#  ifdef XLAT_VAL_28
  | XLAT_VAL_28
#  endif
#  ifdef XLAT_VAL_29
  | XLAT_VAL_29
#  endif
#  ifdef XLAT_VAL_30
  | XLAT_VAL_30
#  endif
#  ifdef XLAT_VAL_31
  | XLAT_VAL_31
#  endif
#  ifdef XLAT_VAL_32
  | XLAT_VAL_32
#  endif
#  ifdef XLAT_VAL_33
  | XLAT_VAL_33
#  endif
#  ifdef XLAT_VAL_34
  | XLAT_VAL_34
#  endif
#  ifdef XLAT_VAL_35
  | XLAT_VAL_35
#  endif
#  ifdef XLAT_VAL_36
  | XLAT_VAL_36
#  endif
#  ifdef XLAT_VAL_37
  | XLAT_VAL_37
#  endif
#  ifdef XLAT_VAL_38
  | XLAT_VAL_38
#  endif
#  ifdef XLAT_VAL_39
  | XLAT_VAL_39
#  endif
#  ifdef XLAT_VAL_40
  | XLAT_VAL_40
#  endif
#  ifdef XLAT_VAL_41
  | XLAT_VAL_41
#  endif
#  ifdef XLAT_VAL_42
  | XLAT_VAL_42
#  endif
#  ifdef XLAT_VAL_43
  | XLAT_VAL_43
#  endif
#  ifdef XLAT_VAL_44
  | XLAT_VAL_44
#  endif
#  ifdef XLAT_VAL_45
  | XLAT_VAL_45
#  endif
#  ifdef XLAT_VAL_46
  | XLAT_VAL_46
#  endif
#  ifdef XLAT_VAL_47
  | XLAT_VAL_47
#  endif
#  ifdef XLAT_VAL_48
  | XLAT_VAL_48
#  endif
#  ifdef XLAT_VAL_49
  | XLAT_VAL_49
#  endif
#  ifdef XLAT_VAL_50
  | XLAT_VAL_50
#  endif
#  ifdef XLAT_VAL_51
  | XLAT_VAL_51
#  endif
#  ifdef XLAT_VAL_52
  | XLAT_VAL_52
#  endif
#  ifdef XLAT_VAL_53
  | XLAT_VAL_53
#  endif
#  ifdef XLAT_VAL_54
  | XLAT_VAL_54
#  endif
#  ifdef XLAT_VAL_55
  | XLAT_VAL_55
#  endif
#  ifdef XLAT_VAL_56
  | XLAT_VAL_56
#  endif
#  ifdef XLAT_VAL_57
  | XLAT_VAL_57
#  endif
#  ifdef XLAT_VAL_58
  | XLAT_VAL_58
#  endif
#  ifdef XLAT_VAL_59
  | XLAT_VAL_59
#  endif
#  ifdef XLAT_VAL_60
  | XLAT_VAL_60
#  endif
#  ifdef XLAT_VAL_61
  | XLAT_VAL_61
#  endif
#  ifdef XLAT_VAL_62
  | XLAT_VAL_62
#  endif
#  ifdef XLAT_VAL_63
  | XLAT_VAL_63
#  endif
#  ifdef XLAT_VAL_64
  | XLAT_VAL_64
#  endif
#  ifdef XLAT_VAL_65
  | XLAT_VAL_65
#  endif
#  ifdef XLAT_VAL_66
  | XLAT_VAL_66
#  endif
#  ifdef XLAT_VAL_67
  | XLAT_VAL_67
#  endif
#  ifdef XLAT_VAL_68
  | XLAT_VAL_68
#  endif
#  ifdef XLAT_VAL_69
  | XLAT_VAL_69
#  endif
#  ifdef XLAT_VAL_70
  | XLAT_VAL_70
#  endif
#  ifdef XLAT_VAL_71
  | XLAT_VAL_71
#  endif
#  ifdef XLAT_VAL_72
  | XLAT_VAL_72
#  endif
#  ifdef XLAT_VAL_73
  | XLAT_VAL_73
#  endif
#  ifdef XLAT_VAL_74
  | XLAT_VAL_74
#  endif
#  ifdef XLAT_VAL_75
  | XLAT_VAL_75
#  endif
#  ifdef XLAT_VAL_76
  | XLAT_VAL_76
#  endif
#  ifdef XLAT_VAL_77
  | XLAT_VAL_77
#  endif
#  ifdef XLAT_VAL_78
  | XLAT_VAL_78
#  endif
#  ifdef XLAT_VAL_79
  | XLAT_VAL_79
#  endif
#  ifdef XLAT_VAL_80
  | XLAT_VAL_80
#  endif
#  ifdef XLAT_VAL_81
  | XLAT_VAL_81
#  endif
#  ifdef XLAT_VAL_82
  | XLAT_VAL_82
#  endif
#  ifdef XLAT_VAL_83
  | XLAT_VAL_83
#  endif
#  ifdef XLAT_VAL_84
  | XLAT_VAL_84
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
#  ifdef XLAT_STR_28
  + sizeof(XLAT_STR_28)
#  endif
#  ifdef XLAT_STR_29
  + sizeof(XLAT_STR_29)
#  endif
#  ifdef XLAT_STR_30
  + sizeof(XLAT_STR_30)
#  endif
#  ifdef XLAT_STR_31
  + sizeof(XLAT_STR_31)
#  endif
#  ifdef XLAT_STR_32
  + sizeof(XLAT_STR_32)
#  endif
#  ifdef XLAT_STR_33
  + sizeof(XLAT_STR_33)
#  endif
#  ifdef XLAT_STR_34
  + sizeof(XLAT_STR_34)
#  endif
#  ifdef XLAT_STR_35
  + sizeof(XLAT_STR_35)
#  endif
#  ifdef XLAT_STR_36
  + sizeof(XLAT_STR_36)
#  endif
#  ifdef XLAT_STR_37
  + sizeof(XLAT_STR_37)
#  endif
#  ifdef XLAT_STR_38
  + sizeof(XLAT_STR_38)
#  endif
#  ifdef XLAT_STR_39
  + sizeof(XLAT_STR_39)
#  endif
#  ifdef XLAT_STR_40
  + sizeof(XLAT_STR_40)
#  endif
#  ifdef XLAT_STR_41
  + sizeof(XLAT_STR_41)
#  endif
#  ifdef XLAT_STR_42
  + sizeof(XLAT_STR_42)
#  endif
#  ifdef XLAT_STR_43
  + sizeof(XLAT_STR_43)
#  endif
#  ifdef XLAT_STR_44
  + sizeof(XLAT_STR_44)
#  endif
#  ifdef XLAT_STR_45
  + sizeof(XLAT_STR_45)
#  endif
#  ifdef XLAT_STR_46
  + sizeof(XLAT_STR_46)
#  endif
#  ifdef XLAT_STR_47
  + sizeof(XLAT_STR_47)
#  endif
#  ifdef XLAT_STR_48
  + sizeof(XLAT_STR_48)
#  endif
#  ifdef XLAT_STR_49
  + sizeof(XLAT_STR_49)
#  endif
#  ifdef XLAT_STR_50
  + sizeof(XLAT_STR_50)
#  endif
#  ifdef XLAT_STR_51
  + sizeof(XLAT_STR_51)
#  endif
#  ifdef XLAT_STR_52
  + sizeof(XLAT_STR_52)
#  endif
#  ifdef XLAT_STR_53
  + sizeof(XLAT_STR_53)
#  endif
#  ifdef XLAT_STR_54
  + sizeof(XLAT_STR_54)
#  endif
#  ifdef XLAT_STR_55
  + sizeof(XLAT_STR_55)
#  endif
#  ifdef XLAT_STR_56
  + sizeof(XLAT_STR_56)
#  endif
#  ifdef XLAT_STR_57
  + sizeof(XLAT_STR_57)
#  endif
#  ifdef XLAT_STR_58
  + sizeof(XLAT_STR_58)
#  endif
#  ifdef XLAT_STR_59
  + sizeof(XLAT_STR_59)
#  endif
#  ifdef XLAT_STR_60
  + sizeof(XLAT_STR_60)
#  endif
#  ifdef XLAT_STR_61
  + sizeof(XLAT_STR_61)
#  endif
#  ifdef XLAT_STR_62
  + sizeof(XLAT_STR_62)
#  endif
#  ifdef XLAT_STR_63
  + sizeof(XLAT_STR_63)
#  endif
#  ifdef XLAT_STR_64
  + sizeof(XLAT_STR_64)
#  endif
#  ifdef XLAT_STR_65
  + sizeof(XLAT_STR_65)
#  endif
#  ifdef XLAT_STR_66
  + sizeof(XLAT_STR_66)
#  endif
#  ifdef XLAT_STR_67
  + sizeof(XLAT_STR_67)
#  endif
#  ifdef XLAT_STR_68
  + sizeof(XLAT_STR_68)
#  endif
#  ifdef XLAT_STR_69
  + sizeof(XLAT_STR_69)
#  endif
#  ifdef XLAT_STR_70
  + sizeof(XLAT_STR_70)
#  endif
#  ifdef XLAT_STR_71
  + sizeof(XLAT_STR_71)
#  endif
#  ifdef XLAT_STR_72
  + sizeof(XLAT_STR_72)
#  endif
#  ifdef XLAT_STR_73
  + sizeof(XLAT_STR_73)
#  endif
#  ifdef XLAT_STR_74
  + sizeof(XLAT_STR_74)
#  endif
#  ifdef XLAT_STR_75
  + sizeof(XLAT_STR_75)
#  endif
#  ifdef XLAT_STR_76
  + sizeof(XLAT_STR_76)
#  endif
#  ifdef XLAT_STR_77
  + sizeof(XLAT_STR_77)
#  endif
#  ifdef XLAT_STR_78
  + sizeof(XLAT_STR_78)
#  endif
#  ifdef XLAT_STR_79
  + sizeof(XLAT_STR_79)
#  endif
#  ifdef XLAT_STR_80
  + sizeof(XLAT_STR_80)
#  endif
#  ifdef XLAT_STR_81
  + sizeof(XLAT_STR_81)
#  endif
#  ifdef XLAT_STR_82
  + sizeof(XLAT_STR_82)
#  endif
#  ifdef XLAT_STR_83
  + sizeof(XLAT_STR_83)
#  endif
#  ifdef XLAT_STR_84
  + sizeof(XLAT_STR_84)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
#  undef XLAT_STR_28
#  undef XLAT_VAL_28
#  undef XLAT_STR_29
#  undef XLAT_VAL_29
#  undef XLAT_STR_30
#  undef XLAT_VAL_30
#  undef XLAT_STR_31
#  undef XLAT_VAL_31
#  undef XLAT_STR_32
#  undef XLAT_VAL_32
#  undef XLAT_STR_33
#  undef XLAT_VAL_33
#  undef XLAT_STR_34
#  undef XLAT_VAL_34
#  undef XLAT_STR_35
#  undef XLAT_VAL_35
#  undef XLAT_STR_36
#  undef XLAT_VAL_36
#  undef XLAT_STR_37
#  undef XLAT_VAL_37
#  undef XLAT_STR_38
#  undef XLAT_VAL_38
#  undef XLAT_STR_39
#  undef XLAT_VAL_39
#  undef XLAT_STR_40
#  undef XLAT_VAL_40
#  undef XLAT_STR_41
#  undef XLAT_VAL_41
#  undef XLAT_STR_42
#  undef XLAT_VAL_42
#  undef XLAT_STR_43
#  undef XLAT_VAL_43
#  undef XLAT_STR_44
#  undef XLAT_VAL_44
#  undef XLAT_STR_45
#  undef XLAT_VAL_45
#  undef XLAT_STR_46
#  undef XLAT_VAL_46
#  undef XLAT_STR_47
#  undef XLAT_VAL_47
#  undef XLAT_STR_48
#  undef XLAT_VAL_48
#  undef XLAT_STR_49
#  undef XLAT_VAL_49
#  undef XLAT_STR_50
#  undef XLAT_VAL_50
#  undef XLAT_STR_51
#  undef XLAT_VAL_51
#  undef XLAT_STR_52
#  undef XLAT_VAL_52
#  undef XLAT_STR_53
#  undef XLAT_VAL_53
#  undef XLAT_STR_54
#  undef XLAT_VAL_54
#  undef XLAT_STR_55
#  undef XLAT_VAL_55
#  undef XLAT_STR_56
#  undef XLAT_VAL_56
#  undef XLAT_STR_57
#  undef XLAT_VAL_57
#  undef XLAT_STR_58
#  undef XLAT_VAL_58
#  undef XLAT_STR_59
#  undef XLAT_VAL_59
#  undef XLAT_STR_60
#  undef XLAT_VAL_60
#  undef XLAT_STR_61
#  undef XLAT_VAL_61
#  undef XLAT_STR_62
#  undef XLAT_VAL_62
#  undef XLAT_STR_63
#  undef XLAT_VAL_63
#  undef XLAT_STR_64
#  undef XLAT_VAL_64
#  undef XLAT_STR_65
#  undef XLAT_VAL_65
#  undef XLAT_STR_66
#  undef XLAT_VAL_66
#  undef XLAT_STR_67
#  undef XLAT_VAL_67
#  undef XLAT_STR_68
#  undef XLAT_VAL_68
#  undef XLAT_STR_69
#  undef XLAT_VAL_69
#  undef XLAT_STR_70
#  undef XLAT_VAL_70
#  undef XLAT_STR_71
#  undef XLAT_VAL_71
#  undef XLAT_STR_72
#  undef XLAT_VAL_72
#  undef XLAT_STR_73
#  undef XLAT_VAL_73
#  undef XLAT_STR_74
#  undef XLAT_VAL_74
#  undef XLAT_STR_75
#  undef XLAT_VAL_75
#  undef XLAT_STR_76
#  undef XLAT_VAL_76
#  undef XLAT_STR_77
#  undef XLAT_VAL_77
#  undef XLAT_STR_78
#  undef XLAT_VAL_78
#  undef XLAT_STR_79
#  undef XLAT_VAL_79
#  undef XLAT_STR_80
#  undef XLAT_VAL_80
#  undef XLAT_STR_81
#  undef XLAT_VAL_81
#  undef XLAT_STR_82
#  undef XLAT_VAL_82
#  undef XLAT_STR_83
#  undef XLAT_VAL_83
#  undef XLAT_STR_84
#  undef XLAT_VAL_84
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
