/* Generated by ./src/xlat/gen.sh from ./src/xlat/genl_netdev_cmd.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat genl_netdev_cmd in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data genl_netdev_cmd_xdata[] = {

 [NETDEV_CMD_DEV_GET] = XLAT(NETDEV_CMD_DEV_GET),
 #define XLAT_VAL_0 ((unsigned) (NETDEV_CMD_DEV_GET))
 #define XLAT_STR_0 STRINGIFY(NETDEV_CMD_DEV_GET)
 [NETDEV_CMD_DEV_ADD_NTF] = XLAT(NETDEV_CMD_DEV_ADD_NTF),
 #define XLAT_VAL_1 ((unsigned) (NETDEV_CMD_DEV_ADD_NTF))
 #define XLAT_STR_1 STRINGIFY(NETDEV_CMD_DEV_ADD_NTF)
 [NETDEV_CMD_DEV_DEL_NTF] = XLAT(NETDEV_CMD_DEV_DEL_NTF),
 #define XLAT_VAL_2 ((unsigned) (NETDEV_CMD_DEV_DEL_NTF))
 #define XLAT_STR_2 STRINGIFY(NETDEV_CMD_DEV_DEL_NTF)
 [NETDEV_CMD_DEV_CHANGE_NTF] = XLAT(NETDEV_CMD_DEV_CHANGE_NTF),
 #define XLAT_VAL_3 ((unsigned) (NETDEV_CMD_DEV_CHANGE_NTF))
 #define XLAT_STR_3 STRINGIFY(NETDEV_CMD_DEV_CHANGE_NTF)
 [NETDEV_CMD_PAGE_POOL_GET] = XLAT(NETDEV_CMD_PAGE_POOL_GET),
 #define XLAT_VAL_4 ((unsigned) (NETDEV_CMD_PAGE_POOL_GET))
 #define XLAT_STR_4 STRINGIFY(NETDEV_CMD_PAGE_POOL_GET)
 [NETDEV_CMD_PAGE_POOL_ADD_NTF] = XLAT(NETDEV_CMD_PAGE_POOL_ADD_NTF),
 #define XLAT_VAL_5 ((unsigned) (NETDEV_CMD_PAGE_POOL_ADD_NTF))
 #define XLAT_STR_5 STRINGIFY(NETDEV_CMD_PAGE_POOL_ADD_NTF)
 [NETDEV_CMD_PAGE_POOL_DEL_NTF] = XLAT(NETDEV_CMD_PAGE_POOL_DEL_NTF),
 #define XLAT_VAL_6 ((unsigned) (NETDEV_CMD_PAGE_POOL_DEL_NTF))
 #define XLAT_STR_6 STRINGIFY(NETDEV_CMD_PAGE_POOL_DEL_NTF)
 [NETDEV_CMD_PAGE_POOL_CHANGE_NTF] = XLAT(NETDEV_CMD_PAGE_POOL_CHANGE_NTF),
 #define XLAT_VAL_7 ((unsigned) (NETDEV_CMD_PAGE_POOL_CHANGE_NTF))
 #define XLAT_STR_7 STRINGIFY(NETDEV_CMD_PAGE_POOL_CHANGE_NTF)
 [NETDEV_CMD_PAGE_POOL_STATS_GET] = XLAT(NETDEV_CMD_PAGE_POOL_STATS_GET),
 #define XLAT_VAL_8 ((unsigned) (NETDEV_CMD_PAGE_POOL_STATS_GET))
 #define XLAT_STR_8 STRINGIFY(NETDEV_CMD_PAGE_POOL_STATS_GET)
 [NETDEV_CMD_QUEUE_GET] = XLAT(NETDEV_CMD_QUEUE_GET),
 #define XLAT_VAL_9 ((unsigned) (NETDEV_CMD_QUEUE_GET))
 #define XLAT_STR_9 STRINGIFY(NETDEV_CMD_QUEUE_GET)
 [NETDEV_CMD_NAPI_GET] = XLAT(NETDEV_CMD_NAPI_GET),
 #define XLAT_VAL_10 ((unsigned) (NETDEV_CMD_NAPI_GET))
 #define XLAT_STR_10 STRINGIFY(NETDEV_CMD_NAPI_GET)
 [NETDEV_CMD_QSTATS_GET] = XLAT(NETDEV_CMD_QSTATS_GET),
 #define XLAT_VAL_11 ((unsigned) (NETDEV_CMD_QSTATS_GET))
 #define XLAT_STR_11 STRINGIFY(NETDEV_CMD_QSTATS_GET)
};
static
const struct xlat genl_netdev_cmd[1] = { {
 .data = genl_netdev_cmd_xdata,
 .size = ARRAY_SIZE(genl_netdev_cmd_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
