/*
 * Test --syscall-limit option in combination with --trace-path option.
 *
 * Copyright (c) 2023 The strace developers.
 * All rights reserved.
 *
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

#define PRINT_VALID 0
#include "strace--syscall-limit.c"
