/*
 * Copyright (c) 2014-2021 The strace developers.
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#include "../s390/userent0.h"
{ PT_FPR0,		"fpr0" },
{ PT_FPR1,		"fpr1" },
{ PT_FPR2,		"fpr2" },
{ PT_FPR3,		"fpr3" },
{ PT_FPR4,		"fpr4" },
{ PT_FPR5,		"fpr5" },
{ PT_FPR6,		"fpr6" },
{ PT_FPR7,		"fpr7" },
{ PT_FPR8,		"fpr8" },
{ PT_FPR9,		"fpr9" },
{ PT_FPR10,		"fpr10" },
{ PT_FPR11,		"fpr11" },
{ PT_FPR12,		"fpr12" },
{ PT_FPR13,		"fpr13" },
{ PT_FPR14,		"fpr14" },
{ PT_FPR15,		"fpr15" },
/* Other fields in "struct user" */
#include "../s390/userent1.h"
