/*
 * Copyright (c) 2015-2021 Dmitry V. Levin <ldv@strace.io>
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#undef MPERS_PRINTER_NAME
#define MPERS_PRINTER_NAME(printer_name) printer_name

#include "native_printer_decls.h"
