/* Generated by ./src/xlat/gen.sh from ./src/xlat/whence_codes.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifndef IN_MPERS

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data whence_codes_xdata[] = {
#if defined(SEEK_SET) || (defined(HAVE_DECL_SEEK_SET) && HAVE_DECL_SEEK_SET)
  XLAT(SEEK_SET),
 #define XLAT_VAL_0 ((unsigned) (SEEK_SET))
 #define XLAT_STR_0 STRINGIFY(SEEK_SET)
#endif
#if defined(SEEK_CUR) || (defined(HAVE_DECL_SEEK_CUR) && HAVE_DECL_SEEK_CUR)
  XLAT(SEEK_CUR),
 #define XLAT_VAL_1 ((unsigned) (SEEK_CUR))
 #define XLAT_STR_1 STRINGIFY(SEEK_CUR)
#endif
#if defined(SEEK_END) || (defined(HAVE_DECL_SEEK_END) && HAVE_DECL_SEEK_END)
  XLAT(SEEK_END),
 #define XLAT_VAL_2 ((unsigned) (SEEK_END))
 #define XLAT_STR_2 STRINGIFY(SEEK_END)
#endif
#if defined(SEEK_DATA) || (defined(HAVE_DECL_SEEK_DATA) && HAVE_DECL_SEEK_DATA)
  XLAT(SEEK_DATA),
 #define XLAT_VAL_3 ((unsigned) (SEEK_DATA))
 #define XLAT_STR_3 STRINGIFY(SEEK_DATA)
#endif
#if defined(SEEK_HOLE) || (defined(HAVE_DECL_SEEK_HOLE) && HAVE_DECL_SEEK_HOLE)
  XLAT(SEEK_HOLE),
 #define XLAT_VAL_4 ((unsigned) (SEEK_HOLE))
 #define XLAT_STR_4 STRINGIFY(SEEK_HOLE)
#endif
};
const struct xlat whence_codes[1] = { {
 .data = whence_codes_xdata,
 .size = ARRAY_SIZE(whence_codes_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
