/* Generated by ./src/xlat/gen.sh from ./src/xlat/sock_caif_options.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(CAIFSO_LINK_SELECT) || (defined(HAVE_DECL_CAIFSO_LINK_SELECT) && HAVE_DECL_CAIFSO_LINK_SELECT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((CAIFSO_LINK_SELECT) == (127), "CAIFSO_LINK_SELECT != 127");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define CAIFSO_LINK_SELECT 127
#endif
#if defined(CAIFSO_REQ_PARAM) || (defined(HAVE_DECL_CAIFSO_REQ_PARAM) && HAVE_DECL_CAIFSO_REQ_PARAM)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((CAIFSO_REQ_PARAM) == (128), "CAIFSO_REQ_PARAM != 128");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define CAIFSO_REQ_PARAM 128
#endif
#if defined(CAIFSO_RSP_PARAM) || (defined(HAVE_DECL_CAIFSO_RSP_PARAM) && HAVE_DECL_CAIFSO_RSP_PARAM)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((CAIFSO_RSP_PARAM) == (129), "CAIFSO_RSP_PARAM != 129");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define CAIFSO_RSP_PARAM 129
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat sock_caif_options in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data sock_caif_options_xdata[] = {
 XLAT(CAIFSO_LINK_SELECT),
 #define XLAT_VAL_0 ((unsigned) (CAIFSO_LINK_SELECT))
 #define XLAT_STR_0 STRINGIFY(CAIFSO_LINK_SELECT)
 XLAT(CAIFSO_REQ_PARAM),
 #define XLAT_VAL_1 ((unsigned) (CAIFSO_REQ_PARAM))
 #define XLAT_STR_1 STRINGIFY(CAIFSO_REQ_PARAM)
 XLAT(CAIFSO_RSP_PARAM),
 #define XLAT_VAL_2 ((unsigned) (CAIFSO_RSP_PARAM))
 #define XLAT_STR_2 STRINGIFY(CAIFSO_RSP_PARAM)
};
static
const struct xlat sock_caif_options[1] = { {
 .data = sock_caif_options_xdata,
 .size = ARRAY_SIZE(sock_caif_options_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
