/* Generated by ./src/xlat/gen.sh from ./src/xlat/pr_mdwe_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(PR_MDWE_REFUSE_EXEC_GAIN) || (defined(HAVE_DECL_PR_MDWE_REFUSE_EXEC_GAIN) && HAVE_DECL_PR_MDWE_REFUSE_EXEC_GAIN)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PR_MDWE_REFUSE_EXEC_GAIN) == ((1U << 0)), "PR_MDWE_REFUSE_EXEC_GAIN != (1U << 0)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PR_MDWE_REFUSE_EXEC_GAIN (1U << 0)
#endif
#if defined(PR_MDWE_NO_INHERIT) || (defined(HAVE_DECL_PR_MDWE_NO_INHERIT) && HAVE_DECL_PR_MDWE_NO_INHERIT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((PR_MDWE_NO_INHERIT) == ((1U << 1)), "PR_MDWE_NO_INHERIT != (1U << 1)");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define PR_MDWE_NO_INHERIT (1U << 1)
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat pr_mdwe_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data pr_mdwe_flags_xdata[] = {
 XLAT(PR_MDWE_REFUSE_EXEC_GAIN),
 #define XLAT_VAL_0 ((unsigned) (PR_MDWE_REFUSE_EXEC_GAIN))
 #define XLAT_STR_0 STRINGIFY(PR_MDWE_REFUSE_EXEC_GAIN)
 XLAT(PR_MDWE_NO_INHERIT),
 #define XLAT_VAL_1 ((unsigned) (PR_MDWE_NO_INHERIT))
 #define XLAT_STR_1 STRINGIFY(PR_MDWE_NO_INHERIT)
};
static
const struct xlat pr_mdwe_flags[1] = { {
 .data = pr_mdwe_flags_xdata,
 .size = ARRAY_SIZE(pr_mdwe_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
