/* Generated by ./src/xlat/gen.sh from ./src/xlat/genl_ctrl_attr_policy.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat genl_ctrl_attr_policy in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data genl_ctrl_attr_policy_xdata[] = {

 [CTRL_ATTR_POLICY_UNSPEC] = XLAT(CTRL_ATTR_POLICY_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (CTRL_ATTR_POLICY_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(CTRL_ATTR_POLICY_UNSPEC)
 [CTRL_ATTR_POLICY_DO] = XLAT(CTRL_ATTR_POLICY_DO),
 #define XLAT_VAL_1 ((unsigned) (CTRL_ATTR_POLICY_DO))
 #define XLAT_STR_1 STRINGIFY(CTRL_ATTR_POLICY_DO)
 [CTRL_ATTR_POLICY_DUMP] = XLAT(CTRL_ATTR_POLICY_DUMP),
 #define XLAT_VAL_2 ((unsigned) (CTRL_ATTR_POLICY_DUMP))
 #define XLAT_STR_2 STRINGIFY(CTRL_ATTR_POLICY_DUMP)
};
static
const struct xlat genl_ctrl_attr_policy[1] = { {
 .data = genl_ctrl_attr_policy_xdata,
 .size = ARRAY_SIZE(genl_ctrl_attr_policy_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
