/* Generated by ./src/xlat/gen.sh from ./src/xlat/genl_nl80211_cmd.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat genl_nl80211_cmd in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data genl_nl80211_cmd_xdata[] = {

 [NL80211_CMD_UNSPEC] = XLAT(NL80211_CMD_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (NL80211_CMD_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(NL80211_CMD_UNSPEC)

 [NL80211_CMD_GET_WIPHY] = XLAT(NL80211_CMD_GET_WIPHY),
 #define XLAT_VAL_1 ((unsigned) (NL80211_CMD_GET_WIPHY))
 #define XLAT_STR_1 STRINGIFY(NL80211_CMD_GET_WIPHY)
 [NL80211_CMD_SET_WIPHY] = XLAT(NL80211_CMD_SET_WIPHY),
 #define XLAT_VAL_2 ((unsigned) (NL80211_CMD_SET_WIPHY))
 #define XLAT_STR_2 STRINGIFY(NL80211_CMD_SET_WIPHY)
 [NL80211_CMD_NEW_WIPHY] = XLAT(NL80211_CMD_NEW_WIPHY),
 #define XLAT_VAL_3 ((unsigned) (NL80211_CMD_NEW_WIPHY))
 #define XLAT_STR_3 STRINGIFY(NL80211_CMD_NEW_WIPHY)
 [NL80211_CMD_DEL_WIPHY] = XLAT(NL80211_CMD_DEL_WIPHY),
 #define XLAT_VAL_4 ((unsigned) (NL80211_CMD_DEL_WIPHY))
 #define XLAT_STR_4 STRINGIFY(NL80211_CMD_DEL_WIPHY)

 [NL80211_CMD_GET_INTERFACE] = XLAT(NL80211_CMD_GET_INTERFACE),
 #define XLAT_VAL_5 ((unsigned) (NL80211_CMD_GET_INTERFACE))
 #define XLAT_STR_5 STRINGIFY(NL80211_CMD_GET_INTERFACE)
 [NL80211_CMD_SET_INTERFACE] = XLAT(NL80211_CMD_SET_INTERFACE),
 #define XLAT_VAL_6 ((unsigned) (NL80211_CMD_SET_INTERFACE))
 #define XLAT_STR_6 STRINGIFY(NL80211_CMD_SET_INTERFACE)
 [NL80211_CMD_NEW_INTERFACE] = XLAT(NL80211_CMD_NEW_INTERFACE),
 #define XLAT_VAL_7 ((unsigned) (NL80211_CMD_NEW_INTERFACE))
 #define XLAT_STR_7 STRINGIFY(NL80211_CMD_NEW_INTERFACE)
 [NL80211_CMD_DEL_INTERFACE] = XLAT(NL80211_CMD_DEL_INTERFACE),
 #define XLAT_VAL_8 ((unsigned) (NL80211_CMD_DEL_INTERFACE))
 #define XLAT_STR_8 STRINGIFY(NL80211_CMD_DEL_INTERFACE)

 [NL80211_CMD_GET_KEY] = XLAT(NL80211_CMD_GET_KEY),
 #define XLAT_VAL_9 ((unsigned) (NL80211_CMD_GET_KEY))
 #define XLAT_STR_9 STRINGIFY(NL80211_CMD_GET_KEY)
 [NL80211_CMD_SET_KEY] = XLAT(NL80211_CMD_SET_KEY),
 #define XLAT_VAL_10 ((unsigned) (NL80211_CMD_SET_KEY))
 #define XLAT_STR_10 STRINGIFY(NL80211_CMD_SET_KEY)
 [NL80211_CMD_NEW_KEY] = XLAT(NL80211_CMD_NEW_KEY),
 #define XLAT_VAL_11 ((unsigned) (NL80211_CMD_NEW_KEY))
 #define XLAT_STR_11 STRINGIFY(NL80211_CMD_NEW_KEY)
 [NL80211_CMD_DEL_KEY] = XLAT(NL80211_CMD_DEL_KEY),
 #define XLAT_VAL_12 ((unsigned) (NL80211_CMD_DEL_KEY))
 #define XLAT_STR_12 STRINGIFY(NL80211_CMD_DEL_KEY)

 [NL80211_CMD_GET_BEACON] = XLAT(NL80211_CMD_GET_BEACON),
 #define XLAT_VAL_13 ((unsigned) (NL80211_CMD_GET_BEACON))
 #define XLAT_STR_13 STRINGIFY(NL80211_CMD_GET_BEACON)
 [NL80211_CMD_SET_BEACON] = XLAT(NL80211_CMD_SET_BEACON),
 #define XLAT_VAL_14 ((unsigned) (NL80211_CMD_SET_BEACON))
 #define XLAT_STR_14 STRINGIFY(NL80211_CMD_SET_BEACON)
 [NL80211_CMD_START_AP] = XLAT(NL80211_CMD_START_AP),
 #define XLAT_VAL_15 ((unsigned) (NL80211_CMD_START_AP))
 #define XLAT_STR_15 STRINGIFY(NL80211_CMD_START_AP)
 [NL80211_CMD_STOP_AP] = XLAT(NL80211_CMD_STOP_AP),
 #define XLAT_VAL_16 ((unsigned) (NL80211_CMD_STOP_AP))
 #define XLAT_STR_16 STRINGIFY(NL80211_CMD_STOP_AP)

 [NL80211_CMD_GET_STATION] = XLAT(NL80211_CMD_GET_STATION),
 #define XLAT_VAL_17 ((unsigned) (NL80211_CMD_GET_STATION))
 #define XLAT_STR_17 STRINGIFY(NL80211_CMD_GET_STATION)
 [NL80211_CMD_SET_STATION] = XLAT(NL80211_CMD_SET_STATION),
 #define XLAT_VAL_18 ((unsigned) (NL80211_CMD_SET_STATION))
 #define XLAT_STR_18 STRINGIFY(NL80211_CMD_SET_STATION)
 [NL80211_CMD_NEW_STATION] = XLAT(NL80211_CMD_NEW_STATION),
 #define XLAT_VAL_19 ((unsigned) (NL80211_CMD_NEW_STATION))
 #define XLAT_STR_19 STRINGIFY(NL80211_CMD_NEW_STATION)
 [NL80211_CMD_DEL_STATION] = XLAT(NL80211_CMD_DEL_STATION),
 #define XLAT_VAL_20 ((unsigned) (NL80211_CMD_DEL_STATION))
 #define XLAT_STR_20 STRINGIFY(NL80211_CMD_DEL_STATION)

 [NL80211_CMD_GET_MPATH] = XLAT(NL80211_CMD_GET_MPATH),
 #define XLAT_VAL_21 ((unsigned) (NL80211_CMD_GET_MPATH))
 #define XLAT_STR_21 STRINGIFY(NL80211_CMD_GET_MPATH)
 [NL80211_CMD_SET_MPATH] = XLAT(NL80211_CMD_SET_MPATH),
 #define XLAT_VAL_22 ((unsigned) (NL80211_CMD_SET_MPATH))
 #define XLAT_STR_22 STRINGIFY(NL80211_CMD_SET_MPATH)
 [NL80211_CMD_NEW_MPATH] = XLAT(NL80211_CMD_NEW_MPATH),
 #define XLAT_VAL_23 ((unsigned) (NL80211_CMD_NEW_MPATH))
 #define XLAT_STR_23 STRINGIFY(NL80211_CMD_NEW_MPATH)
 [NL80211_CMD_DEL_MPATH] = XLAT(NL80211_CMD_DEL_MPATH),
 #define XLAT_VAL_24 ((unsigned) (NL80211_CMD_DEL_MPATH))
 #define XLAT_STR_24 STRINGIFY(NL80211_CMD_DEL_MPATH)

 [NL80211_CMD_SET_BSS] = XLAT(NL80211_CMD_SET_BSS),
 #define XLAT_VAL_25 ((unsigned) (NL80211_CMD_SET_BSS))
 #define XLAT_STR_25 STRINGIFY(NL80211_CMD_SET_BSS)

 [NL80211_CMD_SET_REG] = XLAT(NL80211_CMD_SET_REG),
 #define XLAT_VAL_26 ((unsigned) (NL80211_CMD_SET_REG))
 #define XLAT_STR_26 STRINGIFY(NL80211_CMD_SET_REG)
 [NL80211_CMD_REQ_SET_REG] = XLAT(NL80211_CMD_REQ_SET_REG),
 #define XLAT_VAL_27 ((unsigned) (NL80211_CMD_REQ_SET_REG))
 #define XLAT_STR_27 STRINGIFY(NL80211_CMD_REQ_SET_REG)

 [NL80211_CMD_GET_MESH_CONFIG] = XLAT(NL80211_CMD_GET_MESH_CONFIG),
 #define XLAT_VAL_28 ((unsigned) (NL80211_CMD_GET_MESH_CONFIG))
 #define XLAT_STR_28 STRINGIFY(NL80211_CMD_GET_MESH_CONFIG)
 [NL80211_CMD_SET_MESH_CONFIG] = XLAT(NL80211_CMD_SET_MESH_CONFIG),
 #define XLAT_VAL_29 ((unsigned) (NL80211_CMD_SET_MESH_CONFIG))
 #define XLAT_STR_29 STRINGIFY(NL80211_CMD_SET_MESH_CONFIG)

 [NL80211_CMD_SET_MGMT_EXTRA_IE] = XLAT(NL80211_CMD_SET_MGMT_EXTRA_IE),
 #define XLAT_VAL_30 ((unsigned) (NL80211_CMD_SET_MGMT_EXTRA_IE))
 #define XLAT_STR_30 STRINGIFY(NL80211_CMD_SET_MGMT_EXTRA_IE)

 [NL80211_CMD_GET_REG] = XLAT(NL80211_CMD_GET_REG),
 #define XLAT_VAL_31 ((unsigned) (NL80211_CMD_GET_REG))
 #define XLAT_STR_31 STRINGIFY(NL80211_CMD_GET_REG)

 [NL80211_CMD_GET_SCAN] = XLAT(NL80211_CMD_GET_SCAN),
 #define XLAT_VAL_32 ((unsigned) (NL80211_CMD_GET_SCAN))
 #define XLAT_STR_32 STRINGIFY(NL80211_CMD_GET_SCAN)
 [NL80211_CMD_TRIGGER_SCAN] = XLAT(NL80211_CMD_TRIGGER_SCAN),
 #define XLAT_VAL_33 ((unsigned) (NL80211_CMD_TRIGGER_SCAN))
 #define XLAT_STR_33 STRINGIFY(NL80211_CMD_TRIGGER_SCAN)
 [NL80211_CMD_NEW_SCAN_RESULTS] = XLAT(NL80211_CMD_NEW_SCAN_RESULTS),
 #define XLAT_VAL_34 ((unsigned) (NL80211_CMD_NEW_SCAN_RESULTS))
 #define XLAT_STR_34 STRINGIFY(NL80211_CMD_NEW_SCAN_RESULTS)
 [NL80211_CMD_SCAN_ABORTED] = XLAT(NL80211_CMD_SCAN_ABORTED),
 #define XLAT_VAL_35 ((unsigned) (NL80211_CMD_SCAN_ABORTED))
 #define XLAT_STR_35 STRINGIFY(NL80211_CMD_SCAN_ABORTED)

 [NL80211_CMD_REG_CHANGE] = XLAT(NL80211_CMD_REG_CHANGE),
 #define XLAT_VAL_36 ((unsigned) (NL80211_CMD_REG_CHANGE))
 #define XLAT_STR_36 STRINGIFY(NL80211_CMD_REG_CHANGE)

 [NL80211_CMD_AUTHENTICATE] = XLAT(NL80211_CMD_AUTHENTICATE),
 #define XLAT_VAL_37 ((unsigned) (NL80211_CMD_AUTHENTICATE))
 #define XLAT_STR_37 STRINGIFY(NL80211_CMD_AUTHENTICATE)
 [NL80211_CMD_ASSOCIATE] = XLAT(NL80211_CMD_ASSOCIATE),
 #define XLAT_VAL_38 ((unsigned) (NL80211_CMD_ASSOCIATE))
 #define XLAT_STR_38 STRINGIFY(NL80211_CMD_ASSOCIATE)
 [NL80211_CMD_DEAUTHENTICATE] = XLAT(NL80211_CMD_DEAUTHENTICATE),
 #define XLAT_VAL_39 ((unsigned) (NL80211_CMD_DEAUTHENTICATE))
 #define XLAT_STR_39 STRINGIFY(NL80211_CMD_DEAUTHENTICATE)
 [NL80211_CMD_DISASSOCIATE] = XLAT(NL80211_CMD_DISASSOCIATE),
 #define XLAT_VAL_40 ((unsigned) (NL80211_CMD_DISASSOCIATE))
 #define XLAT_STR_40 STRINGIFY(NL80211_CMD_DISASSOCIATE)

 [NL80211_CMD_MICHAEL_MIC_FAILURE] = XLAT(NL80211_CMD_MICHAEL_MIC_FAILURE),
 #define XLAT_VAL_41 ((unsigned) (NL80211_CMD_MICHAEL_MIC_FAILURE))
 #define XLAT_STR_41 STRINGIFY(NL80211_CMD_MICHAEL_MIC_FAILURE)

 [NL80211_CMD_REG_BEACON_HINT] = XLAT(NL80211_CMD_REG_BEACON_HINT),
 #define XLAT_VAL_42 ((unsigned) (NL80211_CMD_REG_BEACON_HINT))
 #define XLAT_STR_42 STRINGIFY(NL80211_CMD_REG_BEACON_HINT)

 [NL80211_CMD_JOIN_IBSS] = XLAT(NL80211_CMD_JOIN_IBSS),
 #define XLAT_VAL_43 ((unsigned) (NL80211_CMD_JOIN_IBSS))
 #define XLAT_STR_43 STRINGIFY(NL80211_CMD_JOIN_IBSS)
 [NL80211_CMD_LEAVE_IBSS] = XLAT(NL80211_CMD_LEAVE_IBSS),
 #define XLAT_VAL_44 ((unsigned) (NL80211_CMD_LEAVE_IBSS))
 #define XLAT_STR_44 STRINGIFY(NL80211_CMD_LEAVE_IBSS)

 [NL80211_CMD_TESTMODE] = XLAT(NL80211_CMD_TESTMODE),
 #define XLAT_VAL_45 ((unsigned) (NL80211_CMD_TESTMODE))
 #define XLAT_STR_45 STRINGIFY(NL80211_CMD_TESTMODE)

 [NL80211_CMD_CONNECT] = XLAT(NL80211_CMD_CONNECT),
 #define XLAT_VAL_46 ((unsigned) (NL80211_CMD_CONNECT))
 #define XLAT_STR_46 STRINGIFY(NL80211_CMD_CONNECT)
 [NL80211_CMD_ROAM] = XLAT(NL80211_CMD_ROAM),
 #define XLAT_VAL_47 ((unsigned) (NL80211_CMD_ROAM))
 #define XLAT_STR_47 STRINGIFY(NL80211_CMD_ROAM)
 [NL80211_CMD_DISCONNECT] = XLAT(NL80211_CMD_DISCONNECT),
 #define XLAT_VAL_48 ((unsigned) (NL80211_CMD_DISCONNECT))
 #define XLAT_STR_48 STRINGIFY(NL80211_CMD_DISCONNECT)

 [NL80211_CMD_SET_WIPHY_NETNS] = XLAT(NL80211_CMD_SET_WIPHY_NETNS),
 #define XLAT_VAL_49 ((unsigned) (NL80211_CMD_SET_WIPHY_NETNS))
 #define XLAT_STR_49 STRINGIFY(NL80211_CMD_SET_WIPHY_NETNS)

 [NL80211_CMD_GET_SURVEY] = XLAT(NL80211_CMD_GET_SURVEY),
 #define XLAT_VAL_50 ((unsigned) (NL80211_CMD_GET_SURVEY))
 #define XLAT_STR_50 STRINGIFY(NL80211_CMD_GET_SURVEY)
 [NL80211_CMD_NEW_SURVEY_RESULTS] = XLAT(NL80211_CMD_NEW_SURVEY_RESULTS),
 #define XLAT_VAL_51 ((unsigned) (NL80211_CMD_NEW_SURVEY_RESULTS))
 #define XLAT_STR_51 STRINGIFY(NL80211_CMD_NEW_SURVEY_RESULTS)

 [NL80211_CMD_SET_PMKSA] = XLAT(NL80211_CMD_SET_PMKSA),
 #define XLAT_VAL_52 ((unsigned) (NL80211_CMD_SET_PMKSA))
 #define XLAT_STR_52 STRINGIFY(NL80211_CMD_SET_PMKSA)
 [NL80211_CMD_DEL_PMKSA] = XLAT(NL80211_CMD_DEL_PMKSA),
 #define XLAT_VAL_53 ((unsigned) (NL80211_CMD_DEL_PMKSA))
 #define XLAT_STR_53 STRINGIFY(NL80211_CMD_DEL_PMKSA)
 [NL80211_CMD_FLUSH_PMKSA] = XLAT(NL80211_CMD_FLUSH_PMKSA),
 #define XLAT_VAL_54 ((unsigned) (NL80211_CMD_FLUSH_PMKSA))
 #define XLAT_STR_54 STRINGIFY(NL80211_CMD_FLUSH_PMKSA)

 [NL80211_CMD_REMAIN_ON_CHANNEL] = XLAT(NL80211_CMD_REMAIN_ON_CHANNEL),
 #define XLAT_VAL_55 ((unsigned) (NL80211_CMD_REMAIN_ON_CHANNEL))
 #define XLAT_STR_55 STRINGIFY(NL80211_CMD_REMAIN_ON_CHANNEL)
 [NL80211_CMD_CANCEL_REMAIN_ON_CHANNEL] = XLAT(NL80211_CMD_CANCEL_REMAIN_ON_CHANNEL),
 #define XLAT_VAL_56 ((unsigned) (NL80211_CMD_CANCEL_REMAIN_ON_CHANNEL))
 #define XLAT_STR_56 STRINGIFY(NL80211_CMD_CANCEL_REMAIN_ON_CHANNEL)

 [NL80211_CMD_SET_TX_BITRATE_MASK] = XLAT(NL80211_CMD_SET_TX_BITRATE_MASK),
 #define XLAT_VAL_57 ((unsigned) (NL80211_CMD_SET_TX_BITRATE_MASK))
 #define XLAT_STR_57 STRINGIFY(NL80211_CMD_SET_TX_BITRATE_MASK)

 [NL80211_CMD_REGISTER_FRAME] = XLAT(NL80211_CMD_REGISTER_FRAME),
 #define XLAT_VAL_58 ((unsigned) (NL80211_CMD_REGISTER_FRAME))
 #define XLAT_STR_58 STRINGIFY(NL80211_CMD_REGISTER_FRAME)
 [NL80211_CMD_FRAME] = XLAT(NL80211_CMD_FRAME),
 #define XLAT_VAL_59 ((unsigned) (NL80211_CMD_FRAME))
 #define XLAT_STR_59 STRINGIFY(NL80211_CMD_FRAME)
 [NL80211_CMD_FRAME_TX_STATUS] = XLAT(NL80211_CMD_FRAME_TX_STATUS),
 #define XLAT_VAL_60 ((unsigned) (NL80211_CMD_FRAME_TX_STATUS))
 #define XLAT_STR_60 STRINGIFY(NL80211_CMD_FRAME_TX_STATUS)

 [NL80211_CMD_SET_POWER_SAVE] = XLAT(NL80211_CMD_SET_POWER_SAVE),
 #define XLAT_VAL_61 ((unsigned) (NL80211_CMD_SET_POWER_SAVE))
 #define XLAT_STR_61 STRINGIFY(NL80211_CMD_SET_POWER_SAVE)
 [NL80211_CMD_GET_POWER_SAVE] = XLAT(NL80211_CMD_GET_POWER_SAVE),
 #define XLAT_VAL_62 ((unsigned) (NL80211_CMD_GET_POWER_SAVE))
 #define XLAT_STR_62 STRINGIFY(NL80211_CMD_GET_POWER_SAVE)

 [NL80211_CMD_SET_CQM] = XLAT(NL80211_CMD_SET_CQM),
 #define XLAT_VAL_63 ((unsigned) (NL80211_CMD_SET_CQM))
 #define XLAT_STR_63 STRINGIFY(NL80211_CMD_SET_CQM)
 [NL80211_CMD_NOTIFY_CQM] = XLAT(NL80211_CMD_NOTIFY_CQM),
 #define XLAT_VAL_64 ((unsigned) (NL80211_CMD_NOTIFY_CQM))
 #define XLAT_STR_64 STRINGIFY(NL80211_CMD_NOTIFY_CQM)

 [NL80211_CMD_SET_CHANNEL] = XLAT(NL80211_CMD_SET_CHANNEL),
 #define XLAT_VAL_65 ((unsigned) (NL80211_CMD_SET_CHANNEL))
 #define XLAT_STR_65 STRINGIFY(NL80211_CMD_SET_CHANNEL)
 [NL80211_CMD_SET_WDS_PEER] = XLAT(NL80211_CMD_SET_WDS_PEER),
 #define XLAT_VAL_66 ((unsigned) (NL80211_CMD_SET_WDS_PEER))
 #define XLAT_STR_66 STRINGIFY(NL80211_CMD_SET_WDS_PEER)

 [NL80211_CMD_FRAME_WAIT_CANCEL] = XLAT(NL80211_CMD_FRAME_WAIT_CANCEL),
 #define XLAT_VAL_67 ((unsigned) (NL80211_CMD_FRAME_WAIT_CANCEL))
 #define XLAT_STR_67 STRINGIFY(NL80211_CMD_FRAME_WAIT_CANCEL)

 [NL80211_CMD_JOIN_MESH] = XLAT(NL80211_CMD_JOIN_MESH),
 #define XLAT_VAL_68 ((unsigned) (NL80211_CMD_JOIN_MESH))
 #define XLAT_STR_68 STRINGIFY(NL80211_CMD_JOIN_MESH)
 [NL80211_CMD_LEAVE_MESH] = XLAT(NL80211_CMD_LEAVE_MESH),
 #define XLAT_VAL_69 ((unsigned) (NL80211_CMD_LEAVE_MESH))
 #define XLAT_STR_69 STRINGIFY(NL80211_CMD_LEAVE_MESH)

 [NL80211_CMD_UNPROT_DEAUTHENTICATE] = XLAT(NL80211_CMD_UNPROT_DEAUTHENTICATE),
 #define XLAT_VAL_70 ((unsigned) (NL80211_CMD_UNPROT_DEAUTHENTICATE))
 #define XLAT_STR_70 STRINGIFY(NL80211_CMD_UNPROT_DEAUTHENTICATE)
 [NL80211_CMD_UNPROT_DISASSOCIATE] = XLAT(NL80211_CMD_UNPROT_DISASSOCIATE),
 #define XLAT_VAL_71 ((unsigned) (NL80211_CMD_UNPROT_DISASSOCIATE))
 #define XLAT_STR_71 STRINGIFY(NL80211_CMD_UNPROT_DISASSOCIATE)

 [NL80211_CMD_NEW_PEER_CANDIDATE] = XLAT(NL80211_CMD_NEW_PEER_CANDIDATE),
 #define XLAT_VAL_72 ((unsigned) (NL80211_CMD_NEW_PEER_CANDIDATE))
 #define XLAT_STR_72 STRINGIFY(NL80211_CMD_NEW_PEER_CANDIDATE)

 [NL80211_CMD_GET_WOWLAN] = XLAT(NL80211_CMD_GET_WOWLAN),
 #define XLAT_VAL_73 ((unsigned) (NL80211_CMD_GET_WOWLAN))
 #define XLAT_STR_73 STRINGIFY(NL80211_CMD_GET_WOWLAN)
 [NL80211_CMD_SET_WOWLAN] = XLAT(NL80211_CMD_SET_WOWLAN),
 #define XLAT_VAL_74 ((unsigned) (NL80211_CMD_SET_WOWLAN))
 #define XLAT_STR_74 STRINGIFY(NL80211_CMD_SET_WOWLAN)

 [NL80211_CMD_START_SCHED_SCAN] = XLAT(NL80211_CMD_START_SCHED_SCAN),
 #define XLAT_VAL_75 ((unsigned) (NL80211_CMD_START_SCHED_SCAN))
 #define XLAT_STR_75 STRINGIFY(NL80211_CMD_START_SCHED_SCAN)
 [NL80211_CMD_STOP_SCHED_SCAN] = XLAT(NL80211_CMD_STOP_SCHED_SCAN),
 #define XLAT_VAL_76 ((unsigned) (NL80211_CMD_STOP_SCHED_SCAN))
 #define XLAT_STR_76 STRINGIFY(NL80211_CMD_STOP_SCHED_SCAN)
 [NL80211_CMD_SCHED_SCAN_RESULTS] = XLAT(NL80211_CMD_SCHED_SCAN_RESULTS),
 #define XLAT_VAL_77 ((unsigned) (NL80211_CMD_SCHED_SCAN_RESULTS))
 #define XLAT_STR_77 STRINGIFY(NL80211_CMD_SCHED_SCAN_RESULTS)
 [NL80211_CMD_SCHED_SCAN_STOPPED] = XLAT(NL80211_CMD_SCHED_SCAN_STOPPED),
 #define XLAT_VAL_78 ((unsigned) (NL80211_CMD_SCHED_SCAN_STOPPED))
 #define XLAT_STR_78 STRINGIFY(NL80211_CMD_SCHED_SCAN_STOPPED)

 [NL80211_CMD_SET_REKEY_OFFLOAD] = XLAT(NL80211_CMD_SET_REKEY_OFFLOAD),
 #define XLAT_VAL_79 ((unsigned) (NL80211_CMD_SET_REKEY_OFFLOAD))
 #define XLAT_STR_79 STRINGIFY(NL80211_CMD_SET_REKEY_OFFLOAD)

 [NL80211_CMD_PMKSA_CANDIDATE] = XLAT(NL80211_CMD_PMKSA_CANDIDATE),
 #define XLAT_VAL_80 ((unsigned) (NL80211_CMD_PMKSA_CANDIDATE))
 #define XLAT_STR_80 STRINGIFY(NL80211_CMD_PMKSA_CANDIDATE)

 [NL80211_CMD_TDLS_OPER] = XLAT(NL80211_CMD_TDLS_OPER),
 #define XLAT_VAL_81 ((unsigned) (NL80211_CMD_TDLS_OPER))
 #define XLAT_STR_81 STRINGIFY(NL80211_CMD_TDLS_OPER)
 [NL80211_CMD_TDLS_MGMT] = XLAT(NL80211_CMD_TDLS_MGMT),
 #define XLAT_VAL_82 ((unsigned) (NL80211_CMD_TDLS_MGMT))
 #define XLAT_STR_82 STRINGIFY(NL80211_CMD_TDLS_MGMT)

 [NL80211_CMD_UNEXPECTED_FRAME] = XLAT(NL80211_CMD_UNEXPECTED_FRAME),
 #define XLAT_VAL_83 ((unsigned) (NL80211_CMD_UNEXPECTED_FRAME))
 #define XLAT_STR_83 STRINGIFY(NL80211_CMD_UNEXPECTED_FRAME)

 [NL80211_CMD_PROBE_CLIENT] = XLAT(NL80211_CMD_PROBE_CLIENT),
 #define XLAT_VAL_84 ((unsigned) (NL80211_CMD_PROBE_CLIENT))
 #define XLAT_STR_84 STRINGIFY(NL80211_CMD_PROBE_CLIENT)

 [NL80211_CMD_REGISTER_BEACONS] = XLAT(NL80211_CMD_REGISTER_BEACONS),
 #define XLAT_VAL_85 ((unsigned) (NL80211_CMD_REGISTER_BEACONS))
 #define XLAT_STR_85 STRINGIFY(NL80211_CMD_REGISTER_BEACONS)

 [NL80211_CMD_UNEXPECTED_4ADDR_FRAME] = XLAT(NL80211_CMD_UNEXPECTED_4ADDR_FRAME),
 #define XLAT_VAL_86 ((unsigned) (NL80211_CMD_UNEXPECTED_4ADDR_FRAME))
 #define XLAT_STR_86 STRINGIFY(NL80211_CMD_UNEXPECTED_4ADDR_FRAME)

 [NL80211_CMD_SET_NOACK_MAP] = XLAT(NL80211_CMD_SET_NOACK_MAP),
 #define XLAT_VAL_87 ((unsigned) (NL80211_CMD_SET_NOACK_MAP))
 #define XLAT_STR_87 STRINGIFY(NL80211_CMD_SET_NOACK_MAP)

 [NL80211_CMD_CH_SWITCH_NOTIFY] = XLAT(NL80211_CMD_CH_SWITCH_NOTIFY),
 #define XLAT_VAL_88 ((unsigned) (NL80211_CMD_CH_SWITCH_NOTIFY))
 #define XLAT_STR_88 STRINGIFY(NL80211_CMD_CH_SWITCH_NOTIFY)

 [NL80211_CMD_START_P2P_DEVICE] = XLAT(NL80211_CMD_START_P2P_DEVICE),
 #define XLAT_VAL_89 ((unsigned) (NL80211_CMD_START_P2P_DEVICE))
 #define XLAT_STR_89 STRINGIFY(NL80211_CMD_START_P2P_DEVICE)
 [NL80211_CMD_STOP_P2P_DEVICE] = XLAT(NL80211_CMD_STOP_P2P_DEVICE),
 #define XLAT_VAL_90 ((unsigned) (NL80211_CMD_STOP_P2P_DEVICE))
 #define XLAT_STR_90 STRINGIFY(NL80211_CMD_STOP_P2P_DEVICE)

 [NL80211_CMD_CONN_FAILED] = XLAT(NL80211_CMD_CONN_FAILED),
 #define XLAT_VAL_91 ((unsigned) (NL80211_CMD_CONN_FAILED))
 #define XLAT_STR_91 STRINGIFY(NL80211_CMD_CONN_FAILED)

 [NL80211_CMD_SET_MCAST_RATE] = XLAT(NL80211_CMD_SET_MCAST_RATE),
 #define XLAT_VAL_92 ((unsigned) (NL80211_CMD_SET_MCAST_RATE))
 #define XLAT_STR_92 STRINGIFY(NL80211_CMD_SET_MCAST_RATE)

 [NL80211_CMD_SET_MAC_ACL] = XLAT(NL80211_CMD_SET_MAC_ACL),
 #define XLAT_VAL_93 ((unsigned) (NL80211_CMD_SET_MAC_ACL))
 #define XLAT_STR_93 STRINGIFY(NL80211_CMD_SET_MAC_ACL)

 [NL80211_CMD_RADAR_DETECT] = XLAT(NL80211_CMD_RADAR_DETECT),
 #define XLAT_VAL_94 ((unsigned) (NL80211_CMD_RADAR_DETECT))
 #define XLAT_STR_94 STRINGIFY(NL80211_CMD_RADAR_DETECT)

 [NL80211_CMD_GET_PROTOCOL_FEATURES] = XLAT(NL80211_CMD_GET_PROTOCOL_FEATURES),
 #define XLAT_VAL_95 ((unsigned) (NL80211_CMD_GET_PROTOCOL_FEATURES))
 #define XLAT_STR_95 STRINGIFY(NL80211_CMD_GET_PROTOCOL_FEATURES)

 [NL80211_CMD_UPDATE_FT_IES] = XLAT(NL80211_CMD_UPDATE_FT_IES),
 #define XLAT_VAL_96 ((unsigned) (NL80211_CMD_UPDATE_FT_IES))
 #define XLAT_STR_96 STRINGIFY(NL80211_CMD_UPDATE_FT_IES)
 [NL80211_CMD_FT_EVENT] = XLAT(NL80211_CMD_FT_EVENT),
 #define XLAT_VAL_97 ((unsigned) (NL80211_CMD_FT_EVENT))
 #define XLAT_STR_97 STRINGIFY(NL80211_CMD_FT_EVENT)

 [NL80211_CMD_CRIT_PROTOCOL_START] = XLAT(NL80211_CMD_CRIT_PROTOCOL_START),
 #define XLAT_VAL_98 ((unsigned) (NL80211_CMD_CRIT_PROTOCOL_START))
 #define XLAT_STR_98 STRINGIFY(NL80211_CMD_CRIT_PROTOCOL_START)
 [NL80211_CMD_CRIT_PROTOCOL_STOP] = XLAT(NL80211_CMD_CRIT_PROTOCOL_STOP),
 #define XLAT_VAL_99 ((unsigned) (NL80211_CMD_CRIT_PROTOCOL_STOP))
 #define XLAT_STR_99 STRINGIFY(NL80211_CMD_CRIT_PROTOCOL_STOP)

 [NL80211_CMD_GET_COALESCE] = XLAT(NL80211_CMD_GET_COALESCE),
 #define XLAT_VAL_100 ((unsigned) (NL80211_CMD_GET_COALESCE))
 #define XLAT_STR_100 STRINGIFY(NL80211_CMD_GET_COALESCE)
 [NL80211_CMD_SET_COALESCE] = XLAT(NL80211_CMD_SET_COALESCE),
 #define XLAT_VAL_101 ((unsigned) (NL80211_CMD_SET_COALESCE))
 #define XLAT_STR_101 STRINGIFY(NL80211_CMD_SET_COALESCE)

 [NL80211_CMD_CHANNEL_SWITCH] = XLAT(NL80211_CMD_CHANNEL_SWITCH),
 #define XLAT_VAL_102 ((unsigned) (NL80211_CMD_CHANNEL_SWITCH))
 #define XLAT_STR_102 STRINGIFY(NL80211_CMD_CHANNEL_SWITCH)

 [NL80211_CMD_VENDOR] = XLAT(NL80211_CMD_VENDOR),
 #define XLAT_VAL_103 ((unsigned) (NL80211_CMD_VENDOR))
 #define XLAT_STR_103 STRINGIFY(NL80211_CMD_VENDOR)

 [NL80211_CMD_SET_QOS_MAP] = XLAT(NL80211_CMD_SET_QOS_MAP),
 #define XLAT_VAL_104 ((unsigned) (NL80211_CMD_SET_QOS_MAP))
 #define XLAT_STR_104 STRINGIFY(NL80211_CMD_SET_QOS_MAP)

 [NL80211_CMD_ADD_TX_TS] = XLAT(NL80211_CMD_ADD_TX_TS),
 #define XLAT_VAL_105 ((unsigned) (NL80211_CMD_ADD_TX_TS))
 #define XLAT_STR_105 STRINGIFY(NL80211_CMD_ADD_TX_TS)
 [NL80211_CMD_DEL_TX_TS] = XLAT(NL80211_CMD_DEL_TX_TS),
 #define XLAT_VAL_106 ((unsigned) (NL80211_CMD_DEL_TX_TS))
 #define XLAT_STR_106 STRINGIFY(NL80211_CMD_DEL_TX_TS)

 [NL80211_CMD_GET_MPP] = XLAT(NL80211_CMD_GET_MPP),
 #define XLAT_VAL_107 ((unsigned) (NL80211_CMD_GET_MPP))
 #define XLAT_STR_107 STRINGIFY(NL80211_CMD_GET_MPP)

 [NL80211_CMD_JOIN_OCB] = XLAT(NL80211_CMD_JOIN_OCB),
 #define XLAT_VAL_108 ((unsigned) (NL80211_CMD_JOIN_OCB))
 #define XLAT_STR_108 STRINGIFY(NL80211_CMD_JOIN_OCB)
 [NL80211_CMD_LEAVE_OCB] = XLAT(NL80211_CMD_LEAVE_OCB),
 #define XLAT_VAL_109 ((unsigned) (NL80211_CMD_LEAVE_OCB))
 #define XLAT_STR_109 STRINGIFY(NL80211_CMD_LEAVE_OCB)

 [NL80211_CMD_CH_SWITCH_STARTED_NOTIFY] = XLAT(NL80211_CMD_CH_SWITCH_STARTED_NOTIFY),
 #define XLAT_VAL_110 ((unsigned) (NL80211_CMD_CH_SWITCH_STARTED_NOTIFY))
 #define XLAT_STR_110 STRINGIFY(NL80211_CMD_CH_SWITCH_STARTED_NOTIFY)

 [NL80211_CMD_TDLS_CHANNEL_SWITCH] = XLAT(NL80211_CMD_TDLS_CHANNEL_SWITCH),
 #define XLAT_VAL_111 ((unsigned) (NL80211_CMD_TDLS_CHANNEL_SWITCH))
 #define XLAT_STR_111 STRINGIFY(NL80211_CMD_TDLS_CHANNEL_SWITCH)
 [NL80211_CMD_TDLS_CANCEL_CHANNEL_SWITCH] = XLAT(NL80211_CMD_TDLS_CANCEL_CHANNEL_SWITCH),
 #define XLAT_VAL_112 ((unsigned) (NL80211_CMD_TDLS_CANCEL_CHANNEL_SWITCH))
 #define XLAT_STR_112 STRINGIFY(NL80211_CMD_TDLS_CANCEL_CHANNEL_SWITCH)

 [NL80211_CMD_WIPHY_REG_CHANGE] = XLAT(NL80211_CMD_WIPHY_REG_CHANGE),
 #define XLAT_VAL_113 ((unsigned) (NL80211_CMD_WIPHY_REG_CHANGE))
 #define XLAT_STR_113 STRINGIFY(NL80211_CMD_WIPHY_REG_CHANGE)

 [NL80211_CMD_ABORT_SCAN] = XLAT(NL80211_CMD_ABORT_SCAN),
 #define XLAT_VAL_114 ((unsigned) (NL80211_CMD_ABORT_SCAN))
 #define XLAT_STR_114 STRINGIFY(NL80211_CMD_ABORT_SCAN)

 [NL80211_CMD_START_NAN] = XLAT(NL80211_CMD_START_NAN),
 #define XLAT_VAL_115 ((unsigned) (NL80211_CMD_START_NAN))
 #define XLAT_STR_115 STRINGIFY(NL80211_CMD_START_NAN)
 [NL80211_CMD_STOP_NAN] = XLAT(NL80211_CMD_STOP_NAN),
 #define XLAT_VAL_116 ((unsigned) (NL80211_CMD_STOP_NAN))
 #define XLAT_STR_116 STRINGIFY(NL80211_CMD_STOP_NAN)
 [NL80211_CMD_ADD_NAN_FUNCTION] = XLAT(NL80211_CMD_ADD_NAN_FUNCTION),
 #define XLAT_VAL_117 ((unsigned) (NL80211_CMD_ADD_NAN_FUNCTION))
 #define XLAT_STR_117 STRINGIFY(NL80211_CMD_ADD_NAN_FUNCTION)
 [NL80211_CMD_DEL_NAN_FUNCTION] = XLAT(NL80211_CMD_DEL_NAN_FUNCTION),
 #define XLAT_VAL_118 ((unsigned) (NL80211_CMD_DEL_NAN_FUNCTION))
 #define XLAT_STR_118 STRINGIFY(NL80211_CMD_DEL_NAN_FUNCTION)
 [NL80211_CMD_CHANGE_NAN_CONFIG] = XLAT(NL80211_CMD_CHANGE_NAN_CONFIG),
 #define XLAT_VAL_119 ((unsigned) (NL80211_CMD_CHANGE_NAN_CONFIG))
 #define XLAT_STR_119 STRINGIFY(NL80211_CMD_CHANGE_NAN_CONFIG)
 [NL80211_CMD_NAN_MATCH] = XLAT(NL80211_CMD_NAN_MATCH),
 #define XLAT_VAL_120 ((unsigned) (NL80211_CMD_NAN_MATCH))
 #define XLAT_STR_120 STRINGIFY(NL80211_CMD_NAN_MATCH)

 [NL80211_CMD_SET_MULTICAST_TO_UNICAST] = XLAT(NL80211_CMD_SET_MULTICAST_TO_UNICAST),
 #define XLAT_VAL_121 ((unsigned) (NL80211_CMD_SET_MULTICAST_TO_UNICAST))
 #define XLAT_STR_121 STRINGIFY(NL80211_CMD_SET_MULTICAST_TO_UNICAST)

 [NL80211_CMD_UPDATE_CONNECT_PARAMS] = XLAT(NL80211_CMD_UPDATE_CONNECT_PARAMS),
 #define XLAT_VAL_122 ((unsigned) (NL80211_CMD_UPDATE_CONNECT_PARAMS))
 #define XLAT_STR_122 STRINGIFY(NL80211_CMD_UPDATE_CONNECT_PARAMS)

 [NL80211_CMD_SET_PMK] = XLAT(NL80211_CMD_SET_PMK),
 #define XLAT_VAL_123 ((unsigned) (NL80211_CMD_SET_PMK))
 #define XLAT_STR_123 STRINGIFY(NL80211_CMD_SET_PMK)
 [NL80211_CMD_DEL_PMK] = XLAT(NL80211_CMD_DEL_PMK),
 #define XLAT_VAL_124 ((unsigned) (NL80211_CMD_DEL_PMK))
 #define XLAT_STR_124 STRINGIFY(NL80211_CMD_DEL_PMK)

 [NL80211_CMD_PORT_AUTHORIZED] = XLAT(NL80211_CMD_PORT_AUTHORIZED),
 #define XLAT_VAL_125 ((unsigned) (NL80211_CMD_PORT_AUTHORIZED))
 #define XLAT_STR_125 STRINGIFY(NL80211_CMD_PORT_AUTHORIZED)

 [NL80211_CMD_RELOAD_REGDB] = XLAT(NL80211_CMD_RELOAD_REGDB),
 #define XLAT_VAL_126 ((unsigned) (NL80211_CMD_RELOAD_REGDB))
 #define XLAT_STR_126 STRINGIFY(NL80211_CMD_RELOAD_REGDB)

 [NL80211_CMD_EXTERNAL_AUTH] = XLAT(NL80211_CMD_EXTERNAL_AUTH),
 #define XLAT_VAL_127 ((unsigned) (NL80211_CMD_EXTERNAL_AUTH))
 #define XLAT_STR_127 STRINGIFY(NL80211_CMD_EXTERNAL_AUTH)

 [NL80211_CMD_STA_OPMODE_CHANGED] = XLAT(NL80211_CMD_STA_OPMODE_CHANGED),
 #define XLAT_VAL_128 ((unsigned) (NL80211_CMD_STA_OPMODE_CHANGED))
 #define XLAT_STR_128 STRINGIFY(NL80211_CMD_STA_OPMODE_CHANGED)

 [NL80211_CMD_CONTROL_PORT_FRAME] = XLAT(NL80211_CMD_CONTROL_PORT_FRAME),
 #define XLAT_VAL_129 ((unsigned) (NL80211_CMD_CONTROL_PORT_FRAME))
 #define XLAT_STR_129 STRINGIFY(NL80211_CMD_CONTROL_PORT_FRAME)

 [NL80211_CMD_GET_FTM_RESPONDER_STATS] = XLAT(NL80211_CMD_GET_FTM_RESPONDER_STATS),
 #define XLAT_VAL_130 ((unsigned) (NL80211_CMD_GET_FTM_RESPONDER_STATS))
 #define XLAT_STR_130 STRINGIFY(NL80211_CMD_GET_FTM_RESPONDER_STATS)

 [NL80211_CMD_PEER_MEASUREMENT_START] = XLAT(NL80211_CMD_PEER_MEASUREMENT_START),
 #define XLAT_VAL_131 ((unsigned) (NL80211_CMD_PEER_MEASUREMENT_START))
 #define XLAT_STR_131 STRINGIFY(NL80211_CMD_PEER_MEASUREMENT_START)
 [NL80211_CMD_PEER_MEASUREMENT_RESULT] = XLAT(NL80211_CMD_PEER_MEASUREMENT_RESULT),
 #define XLAT_VAL_132 ((unsigned) (NL80211_CMD_PEER_MEASUREMENT_RESULT))
 #define XLAT_STR_132 STRINGIFY(NL80211_CMD_PEER_MEASUREMENT_RESULT)
 [NL80211_CMD_PEER_MEASUREMENT_COMPLETE] = XLAT(NL80211_CMD_PEER_MEASUREMENT_COMPLETE),
 #define XLAT_VAL_133 ((unsigned) (NL80211_CMD_PEER_MEASUREMENT_COMPLETE))
 #define XLAT_STR_133 STRINGIFY(NL80211_CMD_PEER_MEASUREMENT_COMPLETE)

 [NL80211_CMD_NOTIFY_RADAR] = XLAT(NL80211_CMD_NOTIFY_RADAR),
 #define XLAT_VAL_134 ((unsigned) (NL80211_CMD_NOTIFY_RADAR))
 #define XLAT_STR_134 STRINGIFY(NL80211_CMD_NOTIFY_RADAR)

 [NL80211_CMD_UPDATE_OWE_INFO] = XLAT(NL80211_CMD_UPDATE_OWE_INFO),
 #define XLAT_VAL_135 ((unsigned) (NL80211_CMD_UPDATE_OWE_INFO))
 #define XLAT_STR_135 STRINGIFY(NL80211_CMD_UPDATE_OWE_INFO)

 [NL80211_CMD_PROBE_MESH_LINK] = XLAT(NL80211_CMD_PROBE_MESH_LINK),
 #define XLAT_VAL_136 ((unsigned) (NL80211_CMD_PROBE_MESH_LINK))
 #define XLAT_STR_136 STRINGIFY(NL80211_CMD_PROBE_MESH_LINK)

 [NL80211_CMD_SET_TID_CONFIG] = XLAT(NL80211_CMD_SET_TID_CONFIG),
 #define XLAT_VAL_137 ((unsigned) (NL80211_CMD_SET_TID_CONFIG))
 #define XLAT_STR_137 STRINGIFY(NL80211_CMD_SET_TID_CONFIG)

 [NL80211_CMD_UNPROT_BEACON] = XLAT(NL80211_CMD_UNPROT_BEACON),
 #define XLAT_VAL_138 ((unsigned) (NL80211_CMD_UNPROT_BEACON))
 #define XLAT_STR_138 STRINGIFY(NL80211_CMD_UNPROT_BEACON)

 [NL80211_CMD_CONTROL_PORT_FRAME_TX_STATUS] = XLAT(NL80211_CMD_CONTROL_PORT_FRAME_TX_STATUS),
 #define XLAT_VAL_139 ((unsigned) (NL80211_CMD_CONTROL_PORT_FRAME_TX_STATUS))
 #define XLAT_STR_139 STRINGIFY(NL80211_CMD_CONTROL_PORT_FRAME_TX_STATUS)

 [NL80211_CMD_SET_SAR_SPECS] = XLAT(NL80211_CMD_SET_SAR_SPECS),
 #define XLAT_VAL_140 ((unsigned) (NL80211_CMD_SET_SAR_SPECS))
 #define XLAT_STR_140 STRINGIFY(NL80211_CMD_SET_SAR_SPECS)

 [NL80211_CMD_OBSS_COLOR_COLLISION] = XLAT(NL80211_CMD_OBSS_COLOR_COLLISION),
 #define XLAT_VAL_141 ((unsigned) (NL80211_CMD_OBSS_COLOR_COLLISION))
 #define XLAT_STR_141 STRINGIFY(NL80211_CMD_OBSS_COLOR_COLLISION)

 [NL80211_CMD_COLOR_CHANGE_REQUEST] = XLAT(NL80211_CMD_COLOR_CHANGE_REQUEST),
 #define XLAT_VAL_142 ((unsigned) (NL80211_CMD_COLOR_CHANGE_REQUEST))
 #define XLAT_STR_142 STRINGIFY(NL80211_CMD_COLOR_CHANGE_REQUEST)

 [NL80211_CMD_COLOR_CHANGE_STARTED] = XLAT(NL80211_CMD_COLOR_CHANGE_STARTED),
 #define XLAT_VAL_143 ((unsigned) (NL80211_CMD_COLOR_CHANGE_STARTED))
 #define XLAT_STR_143 STRINGIFY(NL80211_CMD_COLOR_CHANGE_STARTED)
 [NL80211_CMD_COLOR_CHANGE_ABORTED] = XLAT(NL80211_CMD_COLOR_CHANGE_ABORTED),
 #define XLAT_VAL_144 ((unsigned) (NL80211_CMD_COLOR_CHANGE_ABORTED))
 #define XLAT_STR_144 STRINGIFY(NL80211_CMD_COLOR_CHANGE_ABORTED)
 [NL80211_CMD_COLOR_CHANGE_COMPLETED] = XLAT(NL80211_CMD_COLOR_CHANGE_COMPLETED),
 #define XLAT_VAL_145 ((unsigned) (NL80211_CMD_COLOR_CHANGE_COMPLETED))
 #define XLAT_STR_145 STRINGIFY(NL80211_CMD_COLOR_CHANGE_COMPLETED)

 [NL80211_CMD_SET_FILS_AAD] = XLAT(NL80211_CMD_SET_FILS_AAD),
 #define XLAT_VAL_146 ((unsigned) (NL80211_CMD_SET_FILS_AAD))
 #define XLAT_STR_146 STRINGIFY(NL80211_CMD_SET_FILS_AAD)

 [NL80211_CMD_ASSOC_COMEBACK] = XLAT(NL80211_CMD_ASSOC_COMEBACK),
 #define XLAT_VAL_147 ((unsigned) (NL80211_CMD_ASSOC_COMEBACK))
 #define XLAT_STR_147 STRINGIFY(NL80211_CMD_ASSOC_COMEBACK)

 [NL80211_CMD_ADD_LINK] = XLAT(NL80211_CMD_ADD_LINK),
 #define XLAT_VAL_148 ((unsigned) (NL80211_CMD_ADD_LINK))
 #define XLAT_STR_148 STRINGIFY(NL80211_CMD_ADD_LINK)
 [NL80211_CMD_REMOVE_LINK] = XLAT(NL80211_CMD_REMOVE_LINK),
 #define XLAT_VAL_149 ((unsigned) (NL80211_CMD_REMOVE_LINK))
 #define XLAT_STR_149 STRINGIFY(NL80211_CMD_REMOVE_LINK)

 [NL80211_CMD_ADD_LINK_STA] = XLAT(NL80211_CMD_ADD_LINK_STA),
 #define XLAT_VAL_150 ((unsigned) (NL80211_CMD_ADD_LINK_STA))
 #define XLAT_STR_150 STRINGIFY(NL80211_CMD_ADD_LINK_STA)
 [NL80211_CMD_MODIFY_LINK_STA] = XLAT(NL80211_CMD_MODIFY_LINK_STA),
 #define XLAT_VAL_151 ((unsigned) (NL80211_CMD_MODIFY_LINK_STA))
 #define XLAT_STR_151 STRINGIFY(NL80211_CMD_MODIFY_LINK_STA)
 [NL80211_CMD_REMOVE_LINK_STA] = XLAT(NL80211_CMD_REMOVE_LINK_STA),
 #define XLAT_VAL_152 ((unsigned) (NL80211_CMD_REMOVE_LINK_STA))
 #define XLAT_STR_152 STRINGIFY(NL80211_CMD_REMOVE_LINK_STA)

 [NL80211_CMD_SET_HW_TIMESTAMP] = XLAT(NL80211_CMD_SET_HW_TIMESTAMP),
 #define XLAT_VAL_153 ((unsigned) (NL80211_CMD_SET_HW_TIMESTAMP))
 #define XLAT_STR_153 STRINGIFY(NL80211_CMD_SET_HW_TIMESTAMP)

 [NL80211_CMD_LINKS_REMOVED] = XLAT(NL80211_CMD_LINKS_REMOVED),
 #define XLAT_VAL_154 ((unsigned) (NL80211_CMD_LINKS_REMOVED))
 #define XLAT_STR_154 STRINGIFY(NL80211_CMD_LINKS_REMOVED)

 [NL80211_CMD_SET_TID_TO_LINK_MAPPING] = XLAT(NL80211_CMD_SET_TID_TO_LINK_MAPPING),
 #define XLAT_VAL_155 ((unsigned) (NL80211_CMD_SET_TID_TO_LINK_MAPPING))
 #define XLAT_STR_155 STRINGIFY(NL80211_CMD_SET_TID_TO_LINK_MAPPING)
};
static
const struct xlat genl_nl80211_cmd[1] = { {
 .data = genl_nl80211_cmd_xdata,
 .size = ARRAY_SIZE(genl_nl80211_cmd_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
#  ifdef XLAT_VAL_16
  | XLAT_VAL_16
#  endif
#  ifdef XLAT_VAL_17
  | XLAT_VAL_17
#  endif
#  ifdef XLAT_VAL_18
  | XLAT_VAL_18
#  endif
#  ifdef XLAT_VAL_19
  | XLAT_VAL_19
#  endif
#  ifdef XLAT_VAL_20
  | XLAT_VAL_20
#  endif
#  ifdef XLAT_VAL_21
  | XLAT_VAL_21
#  endif
#  ifdef XLAT_VAL_22
  | XLAT_VAL_22
#  endif
#  ifdef XLAT_VAL_23
  | XLAT_VAL_23
#  endif
#  ifdef XLAT_VAL_24
  | XLAT_VAL_24
#  endif
#  ifdef XLAT_VAL_25
  | XLAT_VAL_25
#  endif
#  ifdef XLAT_VAL_26
  | XLAT_VAL_26
#  endif
#  ifdef XLAT_VAL_27
  | XLAT_VAL_27
#  endif
#  ifdef XLAT_VAL_28
  | XLAT_VAL_28
#  endif
#  ifdef XLAT_VAL_29
  | XLAT_VAL_29
#  endif
#  ifdef XLAT_VAL_30
  | XLAT_VAL_30
#  endif
#  ifdef XLAT_VAL_31
  | XLAT_VAL_31
#  endif
#  ifdef XLAT_VAL_32
  | XLAT_VAL_32
#  endif
#  ifdef XLAT_VAL_33
  | XLAT_VAL_33
#  endif
#  ifdef XLAT_VAL_34
  | XLAT_VAL_34
#  endif
#  ifdef XLAT_VAL_35
  | XLAT_VAL_35
#  endif
#  ifdef XLAT_VAL_36
  | XLAT_VAL_36
#  endif
#  ifdef XLAT_VAL_37
  | XLAT_VAL_37
#  endif
#  ifdef XLAT_VAL_38
  | XLAT_VAL_38
#  endif
#  ifdef XLAT_VAL_39
  | XLAT_VAL_39
#  endif
#  ifdef XLAT_VAL_40
  | XLAT_VAL_40
#  endif
#  ifdef XLAT_VAL_41
  | XLAT_VAL_41
#  endif
#  ifdef XLAT_VAL_42
  | XLAT_VAL_42
#  endif
#  ifdef XLAT_VAL_43
  | XLAT_VAL_43
#  endif
#  ifdef XLAT_VAL_44
  | XLAT_VAL_44
#  endif
#  ifdef XLAT_VAL_45
  | XLAT_VAL_45
#  endif
#  ifdef XLAT_VAL_46
  | XLAT_VAL_46
#  endif
#  ifdef XLAT_VAL_47
  | XLAT_VAL_47
#  endif
#  ifdef XLAT_VAL_48
  | XLAT_VAL_48
#  endif
#  ifdef XLAT_VAL_49
  | XLAT_VAL_49
#  endif
#  ifdef XLAT_VAL_50
  | XLAT_VAL_50
#  endif
#  ifdef XLAT_VAL_51
  | XLAT_VAL_51
#  endif
#  ifdef XLAT_VAL_52
  | XLAT_VAL_52
#  endif
#  ifdef XLAT_VAL_53
  | XLAT_VAL_53
#  endif
#  ifdef XLAT_VAL_54
  | XLAT_VAL_54
#  endif
#  ifdef XLAT_VAL_55
  | XLAT_VAL_55
#  endif
#  ifdef XLAT_VAL_56
  | XLAT_VAL_56
#  endif
#  ifdef XLAT_VAL_57
  | XLAT_VAL_57
#  endif
#  ifdef XLAT_VAL_58
  | XLAT_VAL_58
#  endif
#  ifdef XLAT_VAL_59
  | XLAT_VAL_59
#  endif
#  ifdef XLAT_VAL_60
  | XLAT_VAL_60
#  endif
#  ifdef XLAT_VAL_61
  | XLAT_VAL_61
#  endif
#  ifdef XLAT_VAL_62
  | XLAT_VAL_62
#  endif
#  ifdef XLAT_VAL_63
  | XLAT_VAL_63
#  endif
#  ifdef XLAT_VAL_64
  | XLAT_VAL_64
#  endif
#  ifdef XLAT_VAL_65
  | XLAT_VAL_65
#  endif
#  ifdef XLAT_VAL_66
  | XLAT_VAL_66
#  endif
#  ifdef XLAT_VAL_67
  | XLAT_VAL_67
#  endif
#  ifdef XLAT_VAL_68
  | XLAT_VAL_68
#  endif
#  ifdef XLAT_VAL_69
  | XLAT_VAL_69
#  endif
#  ifdef XLAT_VAL_70
  | XLAT_VAL_70
#  endif
#  ifdef XLAT_VAL_71
  | XLAT_VAL_71
#  endif
#  ifdef XLAT_VAL_72
  | XLAT_VAL_72
#  endif
#  ifdef XLAT_VAL_73
  | XLAT_VAL_73
#  endif
#  ifdef XLAT_VAL_74
  | XLAT_VAL_74
#  endif
#  ifdef XLAT_VAL_75
  | XLAT_VAL_75
#  endif
#  ifdef XLAT_VAL_76
  | XLAT_VAL_76
#  endif
#  ifdef XLAT_VAL_77
  | XLAT_VAL_77
#  endif
#  ifdef XLAT_VAL_78
  | XLAT_VAL_78
#  endif
#  ifdef XLAT_VAL_79
  | XLAT_VAL_79
#  endif
#  ifdef XLAT_VAL_80
  | XLAT_VAL_80
#  endif
#  ifdef XLAT_VAL_81
  | XLAT_VAL_81
#  endif
#  ifdef XLAT_VAL_82
  | XLAT_VAL_82
#  endif
#  ifdef XLAT_VAL_83
  | XLAT_VAL_83
#  endif
#  ifdef XLAT_VAL_84
  | XLAT_VAL_84
#  endif
#  ifdef XLAT_VAL_85
  | XLAT_VAL_85
#  endif
#  ifdef XLAT_VAL_86
  | XLAT_VAL_86
#  endif
#  ifdef XLAT_VAL_87
  | XLAT_VAL_87
#  endif
#  ifdef XLAT_VAL_88
  | XLAT_VAL_88
#  endif
#  ifdef XLAT_VAL_89
  | XLAT_VAL_89
#  endif
#  ifdef XLAT_VAL_90
  | XLAT_VAL_90
#  endif
#  ifdef XLAT_VAL_91
  | XLAT_VAL_91
#  endif
#  ifdef XLAT_VAL_92
  | XLAT_VAL_92
#  endif
#  ifdef XLAT_VAL_93
  | XLAT_VAL_93
#  endif
#  ifdef XLAT_VAL_94
  | XLAT_VAL_94
#  endif
#  ifdef XLAT_VAL_95
  | XLAT_VAL_95
#  endif
#  ifdef XLAT_VAL_96
  | XLAT_VAL_96
#  endif
#  ifdef XLAT_VAL_97
  | XLAT_VAL_97
#  endif
#  ifdef XLAT_VAL_98
  | XLAT_VAL_98
#  endif
#  ifdef XLAT_VAL_99
  | XLAT_VAL_99
#  endif
#  ifdef XLAT_VAL_100
  | XLAT_VAL_100
#  endif
#  ifdef XLAT_VAL_101
  | XLAT_VAL_101
#  endif
#  ifdef XLAT_VAL_102
  | XLAT_VAL_102
#  endif
#  ifdef XLAT_VAL_103
  | XLAT_VAL_103
#  endif
#  ifdef XLAT_VAL_104
  | XLAT_VAL_104
#  endif
#  ifdef XLAT_VAL_105
  | XLAT_VAL_105
#  endif
#  ifdef XLAT_VAL_106
  | XLAT_VAL_106
#  endif
#  ifdef XLAT_VAL_107
  | XLAT_VAL_107
#  endif
#  ifdef XLAT_VAL_108
  | XLAT_VAL_108
#  endif
#  ifdef XLAT_VAL_109
  | XLAT_VAL_109
#  endif
#  ifdef XLAT_VAL_110
  | XLAT_VAL_110
#  endif
#  ifdef XLAT_VAL_111
  | XLAT_VAL_111
#  endif
#  ifdef XLAT_VAL_112
  | XLAT_VAL_112
#  endif
#  ifdef XLAT_VAL_113
  | XLAT_VAL_113
#  endif
#  ifdef XLAT_VAL_114
  | XLAT_VAL_114
#  endif
#  ifdef XLAT_VAL_115
  | XLAT_VAL_115
#  endif
#  ifdef XLAT_VAL_116
  | XLAT_VAL_116
#  endif
#  ifdef XLAT_VAL_117
  | XLAT_VAL_117
#  endif
#  ifdef XLAT_VAL_118
  | XLAT_VAL_118
#  endif
#  ifdef XLAT_VAL_119
  | XLAT_VAL_119
#  endif
#  ifdef XLAT_VAL_120
  | XLAT_VAL_120
#  endif
#  ifdef XLAT_VAL_121
  | XLAT_VAL_121
#  endif
#  ifdef XLAT_VAL_122
  | XLAT_VAL_122
#  endif
#  ifdef XLAT_VAL_123
  | XLAT_VAL_123
#  endif
#  ifdef XLAT_VAL_124
  | XLAT_VAL_124
#  endif
#  ifdef XLAT_VAL_125
  | XLAT_VAL_125
#  endif
#  ifdef XLAT_VAL_126
  | XLAT_VAL_126
#  endif
#  ifdef XLAT_VAL_127
  | XLAT_VAL_127
#  endif
#  ifdef XLAT_VAL_128
  | XLAT_VAL_128
#  endif
#  ifdef XLAT_VAL_129
  | XLAT_VAL_129
#  endif
#  ifdef XLAT_VAL_130
  | XLAT_VAL_130
#  endif
#  ifdef XLAT_VAL_131
  | XLAT_VAL_131
#  endif
#  ifdef XLAT_VAL_132
  | XLAT_VAL_132
#  endif
#  ifdef XLAT_VAL_133
  | XLAT_VAL_133
#  endif
#  ifdef XLAT_VAL_134
  | XLAT_VAL_134
#  endif
#  ifdef XLAT_VAL_135
  | XLAT_VAL_135
#  endif
#  ifdef XLAT_VAL_136
  | XLAT_VAL_136
#  endif
#  ifdef XLAT_VAL_137
  | XLAT_VAL_137
#  endif
#  ifdef XLAT_VAL_138
  | XLAT_VAL_138
#  endif
#  ifdef XLAT_VAL_139
  | XLAT_VAL_139
#  endif
#  ifdef XLAT_VAL_140
  | XLAT_VAL_140
#  endif
#  ifdef XLAT_VAL_141
  | XLAT_VAL_141
#  endif
#  ifdef XLAT_VAL_142
  | XLAT_VAL_142
#  endif
#  ifdef XLAT_VAL_143
  | XLAT_VAL_143
#  endif
#  ifdef XLAT_VAL_144
  | XLAT_VAL_144
#  endif
#  ifdef XLAT_VAL_145
  | XLAT_VAL_145
#  endif
#  ifdef XLAT_VAL_146
  | XLAT_VAL_146
#  endif
#  ifdef XLAT_VAL_147
  | XLAT_VAL_147
#  endif
#  ifdef XLAT_VAL_148
  | XLAT_VAL_148
#  endif
#  ifdef XLAT_VAL_149
  | XLAT_VAL_149
#  endif
#  ifdef XLAT_VAL_150
  | XLAT_VAL_150
#  endif
#  ifdef XLAT_VAL_151
  | XLAT_VAL_151
#  endif
#  ifdef XLAT_VAL_152
  | XLAT_VAL_152
#  endif
#  ifdef XLAT_VAL_153
  | XLAT_VAL_153
#  endif
#  ifdef XLAT_VAL_154
  | XLAT_VAL_154
#  endif
#  ifdef XLAT_VAL_155
  | XLAT_VAL_155
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
#  ifdef XLAT_STR_16
  + sizeof(XLAT_STR_16)
#  endif
#  ifdef XLAT_STR_17
  + sizeof(XLAT_STR_17)
#  endif
#  ifdef XLAT_STR_18
  + sizeof(XLAT_STR_18)
#  endif
#  ifdef XLAT_STR_19
  + sizeof(XLAT_STR_19)
#  endif
#  ifdef XLAT_STR_20
  + sizeof(XLAT_STR_20)
#  endif
#  ifdef XLAT_STR_21
  + sizeof(XLAT_STR_21)
#  endif
#  ifdef XLAT_STR_22
  + sizeof(XLAT_STR_22)
#  endif
#  ifdef XLAT_STR_23
  + sizeof(XLAT_STR_23)
#  endif
#  ifdef XLAT_STR_24
  + sizeof(XLAT_STR_24)
#  endif
#  ifdef XLAT_STR_25
  + sizeof(XLAT_STR_25)
#  endif
#  ifdef XLAT_STR_26
  + sizeof(XLAT_STR_26)
#  endif
#  ifdef XLAT_STR_27
  + sizeof(XLAT_STR_27)
#  endif
#  ifdef XLAT_STR_28
  + sizeof(XLAT_STR_28)
#  endif
#  ifdef XLAT_STR_29
  + sizeof(XLAT_STR_29)
#  endif
#  ifdef XLAT_STR_30
  + sizeof(XLAT_STR_30)
#  endif
#  ifdef XLAT_STR_31
  + sizeof(XLAT_STR_31)
#  endif
#  ifdef XLAT_STR_32
  + sizeof(XLAT_STR_32)
#  endif
#  ifdef XLAT_STR_33
  + sizeof(XLAT_STR_33)
#  endif
#  ifdef XLAT_STR_34
  + sizeof(XLAT_STR_34)
#  endif
#  ifdef XLAT_STR_35
  + sizeof(XLAT_STR_35)
#  endif
#  ifdef XLAT_STR_36
  + sizeof(XLAT_STR_36)
#  endif
#  ifdef XLAT_STR_37
  + sizeof(XLAT_STR_37)
#  endif
#  ifdef XLAT_STR_38
  + sizeof(XLAT_STR_38)
#  endif
#  ifdef XLAT_STR_39
  + sizeof(XLAT_STR_39)
#  endif
#  ifdef XLAT_STR_40
  + sizeof(XLAT_STR_40)
#  endif
#  ifdef XLAT_STR_41
  + sizeof(XLAT_STR_41)
#  endif
#  ifdef XLAT_STR_42
  + sizeof(XLAT_STR_42)
#  endif
#  ifdef XLAT_STR_43
  + sizeof(XLAT_STR_43)
#  endif
#  ifdef XLAT_STR_44
  + sizeof(XLAT_STR_44)
#  endif
#  ifdef XLAT_STR_45
  + sizeof(XLAT_STR_45)
#  endif
#  ifdef XLAT_STR_46
  + sizeof(XLAT_STR_46)
#  endif
#  ifdef XLAT_STR_47
  + sizeof(XLAT_STR_47)
#  endif
#  ifdef XLAT_STR_48
  + sizeof(XLAT_STR_48)
#  endif
#  ifdef XLAT_STR_49
  + sizeof(XLAT_STR_49)
#  endif
#  ifdef XLAT_STR_50
  + sizeof(XLAT_STR_50)
#  endif
#  ifdef XLAT_STR_51
  + sizeof(XLAT_STR_51)
#  endif
#  ifdef XLAT_STR_52
  + sizeof(XLAT_STR_52)
#  endif
#  ifdef XLAT_STR_53
  + sizeof(XLAT_STR_53)
#  endif
#  ifdef XLAT_STR_54
  + sizeof(XLAT_STR_54)
#  endif
#  ifdef XLAT_STR_55
  + sizeof(XLAT_STR_55)
#  endif
#  ifdef XLAT_STR_56
  + sizeof(XLAT_STR_56)
#  endif
#  ifdef XLAT_STR_57
  + sizeof(XLAT_STR_57)
#  endif
#  ifdef XLAT_STR_58
  + sizeof(XLAT_STR_58)
#  endif
#  ifdef XLAT_STR_59
  + sizeof(XLAT_STR_59)
#  endif
#  ifdef XLAT_STR_60
  + sizeof(XLAT_STR_60)
#  endif
#  ifdef XLAT_STR_61
  + sizeof(XLAT_STR_61)
#  endif
#  ifdef XLAT_STR_62
  + sizeof(XLAT_STR_62)
#  endif
#  ifdef XLAT_STR_63
  + sizeof(XLAT_STR_63)
#  endif
#  ifdef XLAT_STR_64
  + sizeof(XLAT_STR_64)
#  endif
#  ifdef XLAT_STR_65
  + sizeof(XLAT_STR_65)
#  endif
#  ifdef XLAT_STR_66
  + sizeof(XLAT_STR_66)
#  endif
#  ifdef XLAT_STR_67
  + sizeof(XLAT_STR_67)
#  endif
#  ifdef XLAT_STR_68
  + sizeof(XLAT_STR_68)
#  endif
#  ifdef XLAT_STR_69
  + sizeof(XLAT_STR_69)
#  endif
#  ifdef XLAT_STR_70
  + sizeof(XLAT_STR_70)
#  endif
#  ifdef XLAT_STR_71
  + sizeof(XLAT_STR_71)
#  endif
#  ifdef XLAT_STR_72
  + sizeof(XLAT_STR_72)
#  endif
#  ifdef XLAT_STR_73
  + sizeof(XLAT_STR_73)
#  endif
#  ifdef XLAT_STR_74
  + sizeof(XLAT_STR_74)
#  endif
#  ifdef XLAT_STR_75
  + sizeof(XLAT_STR_75)
#  endif
#  ifdef XLAT_STR_76
  + sizeof(XLAT_STR_76)
#  endif
#  ifdef XLAT_STR_77
  + sizeof(XLAT_STR_77)
#  endif
#  ifdef XLAT_STR_78
  + sizeof(XLAT_STR_78)
#  endif
#  ifdef XLAT_STR_79
  + sizeof(XLAT_STR_79)
#  endif
#  ifdef XLAT_STR_80
  + sizeof(XLAT_STR_80)
#  endif
#  ifdef XLAT_STR_81
  + sizeof(XLAT_STR_81)
#  endif
#  ifdef XLAT_STR_82
  + sizeof(XLAT_STR_82)
#  endif
#  ifdef XLAT_STR_83
  + sizeof(XLAT_STR_83)
#  endif
#  ifdef XLAT_STR_84
  + sizeof(XLAT_STR_84)
#  endif
#  ifdef XLAT_STR_85
  + sizeof(XLAT_STR_85)
#  endif
#  ifdef XLAT_STR_86
  + sizeof(XLAT_STR_86)
#  endif
#  ifdef XLAT_STR_87
  + sizeof(XLAT_STR_87)
#  endif
#  ifdef XLAT_STR_88
  + sizeof(XLAT_STR_88)
#  endif
#  ifdef XLAT_STR_89
  + sizeof(XLAT_STR_89)
#  endif
#  ifdef XLAT_STR_90
  + sizeof(XLAT_STR_90)
#  endif
#  ifdef XLAT_STR_91
  + sizeof(XLAT_STR_91)
#  endif
#  ifdef XLAT_STR_92
  + sizeof(XLAT_STR_92)
#  endif
#  ifdef XLAT_STR_93
  + sizeof(XLAT_STR_93)
#  endif
#  ifdef XLAT_STR_94
  + sizeof(XLAT_STR_94)
#  endif
#  ifdef XLAT_STR_95
  + sizeof(XLAT_STR_95)
#  endif
#  ifdef XLAT_STR_96
  + sizeof(XLAT_STR_96)
#  endif
#  ifdef XLAT_STR_97
  + sizeof(XLAT_STR_97)
#  endif
#  ifdef XLAT_STR_98
  + sizeof(XLAT_STR_98)
#  endif
#  ifdef XLAT_STR_99
  + sizeof(XLAT_STR_99)
#  endif
#  ifdef XLAT_STR_100
  + sizeof(XLAT_STR_100)
#  endif
#  ifdef XLAT_STR_101
  + sizeof(XLAT_STR_101)
#  endif
#  ifdef XLAT_STR_102
  + sizeof(XLAT_STR_102)
#  endif
#  ifdef XLAT_STR_103
  + sizeof(XLAT_STR_103)
#  endif
#  ifdef XLAT_STR_104
  + sizeof(XLAT_STR_104)
#  endif
#  ifdef XLAT_STR_105
  + sizeof(XLAT_STR_105)
#  endif
#  ifdef XLAT_STR_106
  + sizeof(XLAT_STR_106)
#  endif
#  ifdef XLAT_STR_107
  + sizeof(XLAT_STR_107)
#  endif
#  ifdef XLAT_STR_108
  + sizeof(XLAT_STR_108)
#  endif
#  ifdef XLAT_STR_109
  + sizeof(XLAT_STR_109)
#  endif
#  ifdef XLAT_STR_110
  + sizeof(XLAT_STR_110)
#  endif
#  ifdef XLAT_STR_111
  + sizeof(XLAT_STR_111)
#  endif
#  ifdef XLAT_STR_112
  + sizeof(XLAT_STR_112)
#  endif
#  ifdef XLAT_STR_113
  + sizeof(XLAT_STR_113)
#  endif
#  ifdef XLAT_STR_114
  + sizeof(XLAT_STR_114)
#  endif
#  ifdef XLAT_STR_115
  + sizeof(XLAT_STR_115)
#  endif
#  ifdef XLAT_STR_116
  + sizeof(XLAT_STR_116)
#  endif
#  ifdef XLAT_STR_117
  + sizeof(XLAT_STR_117)
#  endif
#  ifdef XLAT_STR_118
  + sizeof(XLAT_STR_118)
#  endif
#  ifdef XLAT_STR_119
  + sizeof(XLAT_STR_119)
#  endif
#  ifdef XLAT_STR_120
  + sizeof(XLAT_STR_120)
#  endif
#  ifdef XLAT_STR_121
  + sizeof(XLAT_STR_121)
#  endif
#  ifdef XLAT_STR_122
  + sizeof(XLAT_STR_122)
#  endif
#  ifdef XLAT_STR_123
  + sizeof(XLAT_STR_123)
#  endif
#  ifdef XLAT_STR_124
  + sizeof(XLAT_STR_124)
#  endif
#  ifdef XLAT_STR_125
  + sizeof(XLAT_STR_125)
#  endif
#  ifdef XLAT_STR_126
  + sizeof(XLAT_STR_126)
#  endif
#  ifdef XLAT_STR_127
  + sizeof(XLAT_STR_127)
#  endif
#  ifdef XLAT_STR_128
  + sizeof(XLAT_STR_128)
#  endif
#  ifdef XLAT_STR_129
  + sizeof(XLAT_STR_129)
#  endif
#  ifdef XLAT_STR_130
  + sizeof(XLAT_STR_130)
#  endif
#  ifdef XLAT_STR_131
  + sizeof(XLAT_STR_131)
#  endif
#  ifdef XLAT_STR_132
  + sizeof(XLAT_STR_132)
#  endif
#  ifdef XLAT_STR_133
  + sizeof(XLAT_STR_133)
#  endif
#  ifdef XLAT_STR_134
  + sizeof(XLAT_STR_134)
#  endif
#  ifdef XLAT_STR_135
  + sizeof(XLAT_STR_135)
#  endif
#  ifdef XLAT_STR_136
  + sizeof(XLAT_STR_136)
#  endif
#  ifdef XLAT_STR_137
  + sizeof(XLAT_STR_137)
#  endif
#  ifdef XLAT_STR_138
  + sizeof(XLAT_STR_138)
#  endif
#  ifdef XLAT_STR_139
  + sizeof(XLAT_STR_139)
#  endif
#  ifdef XLAT_STR_140
  + sizeof(XLAT_STR_140)
#  endif
#  ifdef XLAT_STR_141
  + sizeof(XLAT_STR_141)
#  endif
#  ifdef XLAT_STR_142
  + sizeof(XLAT_STR_142)
#  endif
#  ifdef XLAT_STR_143
  + sizeof(XLAT_STR_143)
#  endif
#  ifdef XLAT_STR_144
  + sizeof(XLAT_STR_144)
#  endif
#  ifdef XLAT_STR_145
  + sizeof(XLAT_STR_145)
#  endif
#  ifdef XLAT_STR_146
  + sizeof(XLAT_STR_146)
#  endif
#  ifdef XLAT_STR_147
  + sizeof(XLAT_STR_147)
#  endif
#  ifdef XLAT_STR_148
  + sizeof(XLAT_STR_148)
#  endif
#  ifdef XLAT_STR_149
  + sizeof(XLAT_STR_149)
#  endif
#  ifdef XLAT_STR_150
  + sizeof(XLAT_STR_150)
#  endif
#  ifdef XLAT_STR_151
  + sizeof(XLAT_STR_151)
#  endif
#  ifdef XLAT_STR_152
  + sizeof(XLAT_STR_152)
#  endif
#  ifdef XLAT_STR_153
  + sizeof(XLAT_STR_153)
#  endif
#  ifdef XLAT_STR_154
  + sizeof(XLAT_STR_154)
#  endif
#  ifdef XLAT_STR_155
  + sizeof(XLAT_STR_155)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
#  undef XLAT_STR_16
#  undef XLAT_VAL_16
#  undef XLAT_STR_17
#  undef XLAT_VAL_17
#  undef XLAT_STR_18
#  undef XLAT_VAL_18
#  undef XLAT_STR_19
#  undef XLAT_VAL_19
#  undef XLAT_STR_20
#  undef XLAT_VAL_20
#  undef XLAT_STR_21
#  undef XLAT_VAL_21
#  undef XLAT_STR_22
#  undef XLAT_VAL_22
#  undef XLAT_STR_23
#  undef XLAT_VAL_23
#  undef XLAT_STR_24
#  undef XLAT_VAL_24
#  undef XLAT_STR_25
#  undef XLAT_VAL_25
#  undef XLAT_STR_26
#  undef XLAT_VAL_26
#  undef XLAT_STR_27
#  undef XLAT_VAL_27
#  undef XLAT_STR_28
#  undef XLAT_VAL_28
#  undef XLAT_STR_29
#  undef XLAT_VAL_29
#  undef XLAT_STR_30
#  undef XLAT_VAL_30
#  undef XLAT_STR_31
#  undef XLAT_VAL_31
#  undef XLAT_STR_32
#  undef XLAT_VAL_32
#  undef XLAT_STR_33
#  undef XLAT_VAL_33
#  undef XLAT_STR_34
#  undef XLAT_VAL_34
#  undef XLAT_STR_35
#  undef XLAT_VAL_35
#  undef XLAT_STR_36
#  undef XLAT_VAL_36
#  undef XLAT_STR_37
#  undef XLAT_VAL_37
#  undef XLAT_STR_38
#  undef XLAT_VAL_38
#  undef XLAT_STR_39
#  undef XLAT_VAL_39
#  undef XLAT_STR_40
#  undef XLAT_VAL_40
#  undef XLAT_STR_41
#  undef XLAT_VAL_41
#  undef XLAT_STR_42
#  undef XLAT_VAL_42
#  undef XLAT_STR_43
#  undef XLAT_VAL_43
#  undef XLAT_STR_44
#  undef XLAT_VAL_44
#  undef XLAT_STR_45
#  undef XLAT_VAL_45
#  undef XLAT_STR_46
#  undef XLAT_VAL_46
#  undef XLAT_STR_47
#  undef XLAT_VAL_47
#  undef XLAT_STR_48
#  undef XLAT_VAL_48
#  undef XLAT_STR_49
#  undef XLAT_VAL_49
#  undef XLAT_STR_50
#  undef XLAT_VAL_50
#  undef XLAT_STR_51
#  undef XLAT_VAL_51
#  undef XLAT_STR_52
#  undef XLAT_VAL_52
#  undef XLAT_STR_53
#  undef XLAT_VAL_53
#  undef XLAT_STR_54
#  undef XLAT_VAL_54
#  undef XLAT_STR_55
#  undef XLAT_VAL_55
#  undef XLAT_STR_56
#  undef XLAT_VAL_56
#  undef XLAT_STR_57
#  undef XLAT_VAL_57
#  undef XLAT_STR_58
#  undef XLAT_VAL_58
#  undef XLAT_STR_59
#  undef XLAT_VAL_59
#  undef XLAT_STR_60
#  undef XLAT_VAL_60
#  undef XLAT_STR_61
#  undef XLAT_VAL_61
#  undef XLAT_STR_62
#  undef XLAT_VAL_62
#  undef XLAT_STR_63
#  undef XLAT_VAL_63
#  undef XLAT_STR_64
#  undef XLAT_VAL_64
#  undef XLAT_STR_65
#  undef XLAT_VAL_65
#  undef XLAT_STR_66
#  undef XLAT_VAL_66
#  undef XLAT_STR_67
#  undef XLAT_VAL_67
#  undef XLAT_STR_68
#  undef XLAT_VAL_68
#  undef XLAT_STR_69
#  undef XLAT_VAL_69
#  undef XLAT_STR_70
#  undef XLAT_VAL_70
#  undef XLAT_STR_71
#  undef XLAT_VAL_71
#  undef XLAT_STR_72
#  undef XLAT_VAL_72
#  undef XLAT_STR_73
#  undef XLAT_VAL_73
#  undef XLAT_STR_74
#  undef XLAT_VAL_74
#  undef XLAT_STR_75
#  undef XLAT_VAL_75
#  undef XLAT_STR_76
#  undef XLAT_VAL_76
#  undef XLAT_STR_77
#  undef XLAT_VAL_77
#  undef XLAT_STR_78
#  undef XLAT_VAL_78
#  undef XLAT_STR_79
#  undef XLAT_VAL_79
#  undef XLAT_STR_80
#  undef XLAT_VAL_80
#  undef XLAT_STR_81
#  undef XLAT_VAL_81
#  undef XLAT_STR_82
#  undef XLAT_VAL_82
#  undef XLAT_STR_83
#  undef XLAT_VAL_83
#  undef XLAT_STR_84
#  undef XLAT_VAL_84
#  undef XLAT_STR_85
#  undef XLAT_VAL_85
#  undef XLAT_STR_86
#  undef XLAT_VAL_86
#  undef XLAT_STR_87
#  undef XLAT_VAL_87
#  undef XLAT_STR_88
#  undef XLAT_VAL_88
#  undef XLAT_STR_89
#  undef XLAT_VAL_89
#  undef XLAT_STR_90
#  undef XLAT_VAL_90
#  undef XLAT_STR_91
#  undef XLAT_VAL_91
#  undef XLAT_STR_92
#  undef XLAT_VAL_92
#  undef XLAT_STR_93
#  undef XLAT_VAL_93
#  undef XLAT_STR_94
#  undef XLAT_VAL_94
#  undef XLAT_STR_95
#  undef XLAT_VAL_95
#  undef XLAT_STR_96
#  undef XLAT_VAL_96
#  undef XLAT_STR_97
#  undef XLAT_VAL_97
#  undef XLAT_STR_98
#  undef XLAT_VAL_98
#  undef XLAT_STR_99
#  undef XLAT_VAL_99
#  undef XLAT_STR_100
#  undef XLAT_VAL_100
#  undef XLAT_STR_101
#  undef XLAT_VAL_101
#  undef XLAT_STR_102
#  undef XLAT_VAL_102
#  undef XLAT_STR_103
#  undef XLAT_VAL_103
#  undef XLAT_STR_104
#  undef XLAT_VAL_104
#  undef XLAT_STR_105
#  undef XLAT_VAL_105
#  undef XLAT_STR_106
#  undef XLAT_VAL_106
#  undef XLAT_STR_107
#  undef XLAT_VAL_107
#  undef XLAT_STR_108
#  undef XLAT_VAL_108
#  undef XLAT_STR_109
#  undef XLAT_VAL_109
#  undef XLAT_STR_110
#  undef XLAT_VAL_110
#  undef XLAT_STR_111
#  undef XLAT_VAL_111
#  undef XLAT_STR_112
#  undef XLAT_VAL_112
#  undef XLAT_STR_113
#  undef XLAT_VAL_113
#  undef XLAT_STR_114
#  undef XLAT_VAL_114
#  undef XLAT_STR_115
#  undef XLAT_VAL_115
#  undef XLAT_STR_116
#  undef XLAT_VAL_116
#  undef XLAT_STR_117
#  undef XLAT_VAL_117
#  undef XLAT_STR_118
#  undef XLAT_VAL_118
#  undef XLAT_STR_119
#  undef XLAT_VAL_119
#  undef XLAT_STR_120
#  undef XLAT_VAL_120
#  undef XLAT_STR_121
#  undef XLAT_VAL_121
#  undef XLAT_STR_122
#  undef XLAT_VAL_122
#  undef XLAT_STR_123
#  undef XLAT_VAL_123
#  undef XLAT_STR_124
#  undef XLAT_VAL_124
#  undef XLAT_STR_125
#  undef XLAT_VAL_125
#  undef XLAT_STR_126
#  undef XLAT_VAL_126
#  undef XLAT_STR_127
#  undef XLAT_VAL_127
#  undef XLAT_STR_128
#  undef XLAT_VAL_128
#  undef XLAT_STR_129
#  undef XLAT_VAL_129
#  undef XLAT_STR_130
#  undef XLAT_VAL_130
#  undef XLAT_STR_131
#  undef XLAT_VAL_131
#  undef XLAT_STR_132
#  undef XLAT_VAL_132
#  undef XLAT_STR_133
#  undef XLAT_VAL_133
#  undef XLAT_STR_134
#  undef XLAT_VAL_134
#  undef XLAT_STR_135
#  undef XLAT_VAL_135
#  undef XLAT_STR_136
#  undef XLAT_VAL_136
#  undef XLAT_STR_137
#  undef XLAT_VAL_137
#  undef XLAT_STR_138
#  undef XLAT_VAL_138
#  undef XLAT_STR_139
#  undef XLAT_VAL_139
#  undef XLAT_STR_140
#  undef XLAT_VAL_140
#  undef XLAT_STR_141
#  undef XLAT_VAL_141
#  undef XLAT_STR_142
#  undef XLAT_VAL_142
#  undef XLAT_STR_143
#  undef XLAT_VAL_143
#  undef XLAT_STR_144
#  undef XLAT_VAL_144
#  undef XLAT_STR_145
#  undef XLAT_VAL_145
#  undef XLAT_STR_146
#  undef XLAT_VAL_146
#  undef XLAT_STR_147
#  undef XLAT_VAL_147
#  undef XLAT_STR_148
#  undef XLAT_VAL_148
#  undef XLAT_STR_149
#  undef XLAT_VAL_149
#  undef XLAT_STR_150
#  undef XLAT_VAL_150
#  undef XLAT_STR_151
#  undef XLAT_VAL_151
#  undef XLAT_STR_152
#  undef XLAT_VAL_152
#  undef XLAT_STR_153
#  undef XLAT_VAL_153
#  undef XLAT_STR_154
#  undef XLAT_VAL_154
#  undef XLAT_STR_155
#  undef XLAT_VAL_155
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
