/* Generated by ./src/xlat/gen.sh from ./src/xlat/futex2_sizes.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX2_SIZE_U8) == (0), "FUTEX2_SIZE_U8 != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX2_SIZE_U16) == (1), "FUTEX2_SIZE_U16 != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX2_SIZE_U32) == (2), "FUTEX2_SIZE_U32 != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((FUTEX2_SIZE_U64) == (3), "FUTEX2_SIZE_U64 != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat futex2_sizes in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data futex2_sizes_xdata[] = {
 [FUTEX2_SIZE_U8] = XLAT(FUTEX2_SIZE_U8),
 #define XLAT_VAL_0 ((unsigned) (FUTEX2_SIZE_U8))
 #define XLAT_STR_0 STRINGIFY(FUTEX2_SIZE_U8)
 [FUTEX2_SIZE_U16] = XLAT(FUTEX2_SIZE_U16),
 #define XLAT_VAL_1 ((unsigned) (FUTEX2_SIZE_U16))
 #define XLAT_STR_1 STRINGIFY(FUTEX2_SIZE_U16)
 [FUTEX2_SIZE_U32] = XLAT(FUTEX2_SIZE_U32),
 #define XLAT_VAL_2 ((unsigned) (FUTEX2_SIZE_U32))
 #define XLAT_STR_2 STRINGIFY(FUTEX2_SIZE_U32)
 [FUTEX2_SIZE_U64] = XLAT(FUTEX2_SIZE_U64),
 #define XLAT_VAL_3 ((unsigned) (FUTEX2_SIZE_U64))
 #define XLAT_STR_3 STRINGIFY(FUTEX2_SIZE_U64)
};
static
const struct xlat futex2_sizes[1] = { {
 .data = futex2_sizes_xdata,
 .size = ARRAY_SIZE(futex2_sizes_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
