/*
 * Copyright (c) 2014-2021 The strace developers.
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

XLAT(4*REG_REG0),
{ 4*(REG_REG0+1),	"4*REG_REG1" },
{ 4*(REG_REG0+2),	"4*REG_REG2" },
{ 4*(REG_REG0+3),	"4*REG_REG3" },
{ 4*(REG_REG0+4),	"4*REG_REG4" },
{ 4*(REG_REG0+5),	"4*REG_REG5" },
{ 4*(REG_REG0+6),	"4*REG_REG6" },
{ 4*(REG_REG0+7),	"4*REG_REG7" },
{ 4*(REG_REG0+8),	"4*REG_REG8" },
{ 4*(REG_REG0+9),	"4*REG_REG9" },
{ 4*(REG_REG0+10),	"4*REG_REG10" },
{ 4*(REG_REG0+11),	"4*REG_REG11" },
{ 4*(REG_REG0+12),	"4*REG_REG12" },
{ 4*(REG_REG0+13),	"4*REG_REG13" },
{ 4*(REG_REG0+14),	"4*REG_REG14" },
XLAT(4*REG_REG15),
XLAT(4*REG_PC),
XLAT(4*REG_PR),
XLAT(4*REG_SR),
XLAT(4*REG_GBR),
XLAT(4*REG_MACH),
XLAT(4*REG_MACL),
XLAT(4*REG_SYSCALL),
XLAT(4*REG_FPUL),
XLAT(4*REG_FPREG0),
{ 4*(REG_FPREG0+1),	"4*REG_FPREG1" },
{ 4*(REG_FPREG0+2),	"4*REG_FPREG2" },
{ 4*(REG_FPREG0+3),	"4*REG_FPREG3" },
{ 4*(REG_FPREG0+4),	"4*REG_FPREG4" },
{ 4*(REG_FPREG0+5),	"4*REG_FPREG5" },
{ 4*(REG_FPREG0+6),	"4*REG_FPREG6" },
{ 4*(REG_FPREG0+7),	"4*REG_FPREG7" },
{ 4*(REG_FPREG0+8),	"4*REG_FPREG8" },
{ 4*(REG_FPREG0+9),	"4*REG_FPREG9" },
{ 4*(REG_FPREG0+10),	"4*REG_FPREG10" },
{ 4*(REG_FPREG0+11),	"4*REG_FPREG11" },
{ 4*(REG_FPREG0+12),	"4*REG_FPREG12" },
{ 4*(REG_FPREG0+13),	"4*REG_FPREG13" },
{ 4*(REG_FPREG0+14),	"4*REG_FPREG14" },
XLAT(4*REG_FPREG15),
#ifdef REG_XDREG0
XLAT(4*REG_XDREG0),
{ 4*(REG_XDREG0+2),	"4*REG_XDREG2" },
{ 4*(REG_XDREG0+4),	"4*REG_XDREG4" },
{ 4*(REG_XDREG0+6),	"4*REG_XDREG6" },
{ 4*(REG_XDREG0+8),	"4*REG_XDREG8" },
{ 4*(REG_XDREG0+10),	"4*REG_XDREG10" },
{ 4*(REG_XDREG0+12),	"4*REG_XDREG12" },
XLAT(4*REG_XDREG14),
#endif
XLAT(4*REG_FPSCR),
/* Other fields in "struct user" */
#include "userent0.h"
