/* Generated by ioctls_gen.sh from definitions found in $linux/arch/sh/include/ tree. */
{ "asm/ioctls.h", "FIOASYNC", _IOC_WRITE, 0x667d, 0x04 },
{ "asm/ioctls.h", "FIOCLEX", _IOC_NONE, 0x6601, 0x00 },
{ "asm/ioctls.h", "FIONBIO", _IOC_WRITE, 0x667e, 0x04 },
{ "asm/ioctls.h", "FIONCLEX", _IOC_NONE, 0x6602, 0x00 },
{ "asm/ioctls.h", "FIONREAD", _IOC_READ, 0x667f, 0x04 },
{ "asm/ioctls.h", "FIOQSIZE", _IOC_READ, 0x6680, 0x08 },
{ "asm/ioctls.h", "TCFLSH", _IOC_NONE, 0x741f, 0x00 },
{ "asm/ioctls.h", "TCGETS", 0, 0x5401, 0 },
{ "asm/ioctls.h", "TCGETS2", _IOC_READ, 0x542a, 0x2c },
{ "asm/ioctls.h", "TCSBRK", _IOC_NONE, 0x741d, 0x00 },
{ "asm/ioctls.h", "TCSBRKP", _IOC_WRITE, 0x5425, 0x04 },
{ "asm/ioctls.h", "TCSETS", 0, 0x5402, 0 },
{ "asm/ioctls.h", "TCSETS2", _IOC_WRITE, 0x542b, 0x2c },
{ "asm/ioctls.h", "TCSETSF", 0, 0x5404, 0 },
{ "asm/ioctls.h", "TCSETSF2", _IOC_WRITE, 0x542d, 0x2c },
{ "asm/ioctls.h", "TCSETSW", 0, 0x5403, 0 },
{ "asm/ioctls.h", "TCSETSW2", _IOC_WRITE, 0x542c, 0x2c },
{ "asm/ioctls.h", "TCXONC", _IOC_NONE, 0x741e, 0x00 },
{ "asm/ioctls.h", "TIOCCBRK", _IOC_NONE, 0x5428, 0x00 },
{ "asm/ioctls.h", "TIOCCONS", _IOC_NONE, 0x541d, 0x00 },
{ "asm/ioctls.h", "TIOCEXCL", _IOC_NONE, 0x540c, 0x00 },
{ "asm/ioctls.h", "TIOCGDEV", _IOC_READ, 0x5432, 0x04 },
{ "asm/ioctls.h", "TIOCGETD", _IOC_READ, 0x5424, 0x04 },
{ "asm/ioctls.h", "TIOCGEXCL", _IOC_READ, 0x5440, 0x04 },
{ "asm/ioctls.h", "TIOCGICOUNT", 0, 0x545D, 0 },
{ "asm/ioctls.h", "TIOCGLCKTRMIOS", 0, 0x5456, 0 },
{ "asm/ioctls.h", "TIOCGPGRP", _IOC_READ, 0x7477, 0x04 },
{ "asm/ioctls.h", "TIOCGPKT", _IOC_READ, 0x5438, 0x04 },
{ "asm/ioctls.h", "TIOCGPTLCK", _IOC_READ, 0x5439, 0x04 },
{ "asm/ioctls.h", "TIOCGPTN", _IOC_READ, 0x5430, 0x04 },
{ "asm/ioctls.h", "TIOCGRS485", _IOC_READ, 0x542e, 0x20 },
{ "asm/ioctls.h", "TIOCGSID", _IOC_READ, 0x5429, 0x04 },
{ "asm/ioctls.h", "TIOCGSOFTCAR", _IOC_READ, 0x5419, 0x04 },
{ "asm/ioctls.h", "TIOCLINUX", _IOC_WRITE, 0x541c, 0x01 },
{ "asm/ioctls.h", "TIOCMBIC", _IOC_WRITE, 0x5417, 0x04 },
{ "asm/ioctls.h", "TIOCMBIS", _IOC_WRITE, 0x5416, 0x04 },
{ "asm/ioctls.h", "TIOCMGET", _IOC_READ, 0x5415, 0x04 },
{ "asm/ioctls.h", "TIOCMIWAIT", _IOC_NONE, 0x545c, 0x00 },
{ "asm/ioctls.h", "TIOCMSET", _IOC_WRITE, 0x5418, 0x04 },
{ "asm/ioctls.h", "TIOCNOTTY", _IOC_NONE, 0x5422, 0x00 },
{ "asm/ioctls.h", "TIOCNXCL", _IOC_NONE, 0x540d, 0x00 },
{ "asm/ioctls.h", "TIOCOUTQ", _IOC_READ, 0x7473, 0x04 },
{ "asm/ioctls.h", "TIOCPKT", _IOC_WRITE, 0x5420, 0x04 },
{ "asm/ioctls.h", "TIOCSBRK", _IOC_NONE, 0x5427, 0x00 },
{ "asm/ioctls.h", "TIOCSCTTY", _IOC_NONE, 0x540e, 0x00 },
{ "asm/ioctls.h", "TIOCSERCONFIG", _IOC_NONE, 0x5453, 0x00 },
{ "asm/ioctls.h", "TIOCSERGETLSR", _IOC_READ, 0x5459, 0x04 },
{ "asm/ioctls.h", "TIOCSERGWILD", _IOC_READ, 0x5454, 0x04 },
{ "asm/ioctls.h", "TIOCSERSWILD", _IOC_WRITE, 0x5455, 0x04 },
{ "asm/ioctls.h", "TIOCSETD", _IOC_WRITE, 0x5423, 0x04 },
{ "asm/ioctls.h", "TIOCSIG", _IOC_WRITE, 0x5436, 0x04 },
{ "asm/ioctls.h", "TIOCSLCKTRMIOS", 0, 0x5457, 0 },
{ "asm/ioctls.h", "TIOCSPGRP", _IOC_WRITE, 0x7476, 0x04 },
{ "asm/ioctls.h", "TIOCSPTLCK", _IOC_WRITE, 0x5431, 0x04 },
{ "asm/ioctls.h", "TIOCSRS485", _IOC_READ|_IOC_WRITE, 0x542f, 0x20 },
{ "asm/ioctls.h", "TIOCSSOFTCAR", _IOC_WRITE, 0x541a, 0x04 },
{ "asm/ioctls.h", "TIOCSTART", _IOC_NONE, 0x746e, 0x00 },
{ "asm/ioctls.h", "TIOCSTI", _IOC_WRITE, 0x5412, 0x01 },
{ "asm/ioctls.h", "TIOCSTOP", _IOC_NONE, 0x746f, 0x00 },
{ "asm/ioctls.h", "TIOCVHANGUP", _IOC_NONE, 0x5437, 0x00 },
{ "asm/sockios.h", "FIOGETOWN", _IOC_READ, 0x667b, 0x04 },
{ "asm/sockios.h", "FIOSETOWN", _IOC_WRITE, 0x667c, 0x04 },
{ "asm/sockios.h", "SIOCATMARK", _IOC_READ, 0x7307, 0x04 },
{ "asm/sockios.h", "SIOCGPGRP", _IOC_READ, 0x7309, 0x04 },
{ "asm/sockios.h", "SIOCGSTAMP_OLD", _IOC_READ, 0x7364, 0x08 },
{ "asm/sockios.h", "SIOCGSTAMPNS_OLD", _IOC_READ, 0x7365, 0x08 },
{ "asm/sockios.h", "SIOCSPGRP", _IOC_WRITE, 0x7308, 0x04 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCGGIODATA1", _IOC_READ, 0x6b02, 0x04 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCGGIODATA2", _IOC_READ, 0x6b04, 0x04 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCGGIODATA4", _IOC_READ, 0x6b06, 0x04 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCHARDRESET", _IOC_NONE, 0x6b08, 0x00 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCRESET", _IOC_NONE, 0x6b00, 0x00 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCSGIODATA1", _IOC_WRITE, 0x6b01, 0x04 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCSGIODATA2", _IOC_WRITE, 0x6b03, 0x04 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCSGIODATA4", _IOC_WRITE, 0x6b05, 0x04 },
{ "mach-landisk/mach/gio.h", "GIODRV_IOCSGIOSETADDR", _IOC_WRITE, 0x6b07, 0x04 },
