/* Generated by ./src/xlat/gen.sh from ./src/xlat/rtnl_neigh_fdb_ext_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(NFEA_UNSPEC) || (defined(HAVE_DECL_NFEA_UNSPEC) && HAVE_DECL_NFEA_UNSPEC)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFEA_UNSPEC) == (0), "NFEA_UNSPEC != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NFEA_UNSPEC 0
#endif
#if defined(NFEA_ACTIVITY_NOTIFY) || (defined(HAVE_DECL_NFEA_ACTIVITY_NOTIFY) && HAVE_DECL_NFEA_ACTIVITY_NOTIFY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFEA_ACTIVITY_NOTIFY) == (1), "NFEA_ACTIVITY_NOTIFY != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NFEA_ACTIVITY_NOTIFY 1
#endif
#if defined(NFEA_DONT_REFRESH) || (defined(HAVE_DECL_NFEA_DONT_REFRESH) && HAVE_DECL_NFEA_DONT_REFRESH)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((NFEA_DONT_REFRESH) == (2), "NFEA_DONT_REFRESH != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define NFEA_DONT_REFRESH 2
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat rtnl_neigh_fdb_ext_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data rtnl_neigh_fdb_ext_attrs_xdata[] = {
 [NFEA_UNSPEC] = XLAT(NFEA_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (NFEA_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(NFEA_UNSPEC)
 [NFEA_ACTIVITY_NOTIFY] = XLAT(NFEA_ACTIVITY_NOTIFY),
 #define XLAT_VAL_1 ((unsigned) (NFEA_ACTIVITY_NOTIFY))
 #define XLAT_STR_1 STRINGIFY(NFEA_ACTIVITY_NOTIFY)
 [NFEA_DONT_REFRESH] = XLAT(NFEA_DONT_REFRESH),
 #define XLAT_VAL_2 ((unsigned) (NFEA_DONT_REFRESH))
 #define XLAT_STR_2 STRINGIFY(NFEA_DONT_REFRESH)
};
static
const struct xlat rtnl_neigh_fdb_ext_attrs[1] = { {
 .data = rtnl_neigh_fdb_ext_attrs_xdata,
 .size = ARRAY_SIZE(rtnl_neigh_fdb_ext_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
