/*
 * Copyright (c) 2017-2021 The strace developers.
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#undef TD
#undef TF
#undef TI
#undef TN
#undef TP
#undef TS
#undef TM
#undef TST
#undef TLST
#undef TFST
#undef TSTA
#undef TSF
#undef TFSF
#undef TSFA
#undef PU
#undef NF
#undef MA
#undef SI
#undef SE
#undef CST
#undef TSD
#undef TC
#undef TCL
#undef CC
#undef SEN
