/* Generated by ./src/xlat/gen.sh from ./src/xlat/ifstats_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IFLA_STATS_UNSPEC) == (0), "IFLA_STATS_UNSPEC != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IFLA_STATS_LINK_64) == (1), "IFLA_STATS_LINK_64 != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IFLA_STATS_LINK_XSTATS) == (2), "IFLA_STATS_LINK_XSTATS != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IFLA_STATS_LINK_XSTATS_SLAVE) == (3), "IFLA_STATS_LINK_XSTATS_SLAVE != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IFLA_STATS_LINK_OFFLOAD_XSTATS) == (4), "IFLA_STATS_LINK_OFFLOAD_XSTATS != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((IFLA_STATS_AF_SPEC) == (5), "IFLA_STATS_AF_SPEC != 5");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat ifstats_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data ifstats_attrs_xdata[] = {
 [IFLA_STATS_UNSPEC] = XLAT(IFLA_STATS_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (IFLA_STATS_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(IFLA_STATS_UNSPEC)
 [IFLA_STATS_LINK_64] = XLAT(IFLA_STATS_LINK_64),
 #define XLAT_VAL_1 ((unsigned) (IFLA_STATS_LINK_64))
 #define XLAT_STR_1 STRINGIFY(IFLA_STATS_LINK_64)
 [IFLA_STATS_LINK_XSTATS] = XLAT(IFLA_STATS_LINK_XSTATS),
 #define XLAT_VAL_2 ((unsigned) (IFLA_STATS_LINK_XSTATS))
 #define XLAT_STR_2 STRINGIFY(IFLA_STATS_LINK_XSTATS)
 [IFLA_STATS_LINK_XSTATS_SLAVE] = XLAT(IFLA_STATS_LINK_XSTATS_SLAVE),
 #define XLAT_VAL_3 ((unsigned) (IFLA_STATS_LINK_XSTATS_SLAVE))
 #define XLAT_STR_3 STRINGIFY(IFLA_STATS_LINK_XSTATS_SLAVE)
 [IFLA_STATS_LINK_OFFLOAD_XSTATS] = XLAT(IFLA_STATS_LINK_OFFLOAD_XSTATS),
 #define XLAT_VAL_4 ((unsigned) (IFLA_STATS_LINK_OFFLOAD_XSTATS))
 #define XLAT_STR_4 STRINGIFY(IFLA_STATS_LINK_OFFLOAD_XSTATS)
 [IFLA_STATS_AF_SPEC] = XLAT(IFLA_STATS_AF_SPEC),
 #define XLAT_VAL_5 ((unsigned) (IFLA_STATS_AF_SPEC))
 #define XLAT_STR_5 STRINGIFY(IFLA_STATS_AF_SPEC)
};
static
const struct xlat ifstats_attrs[1] = { {
 .data = ifstats_attrs_xdata,
 .size = ARRAY_SIZE(ifstats_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
