/* Generated by ./src/xlat/gen.sh from ./src/xlat/uring_setup_features.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat uring_setup_features in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data uring_setup_features_xdata[] = {
 XLAT(IORING_FEAT_SINGLE_MMAP),
 #define XLAT_VAL_0 ((unsigned) (IORING_FEAT_SINGLE_MMAP))
 #define XLAT_STR_0 STRINGIFY(IORING_FEAT_SINGLE_MMAP)
 XLAT(IORING_FEAT_NODROP),
 #define XLAT_VAL_1 ((unsigned) (IORING_FEAT_NODROP))
 #define XLAT_STR_1 STRINGIFY(IORING_FEAT_NODROP)
 XLAT(IORING_FEAT_SUBMIT_STABLE),
 #define XLAT_VAL_2 ((unsigned) (IORING_FEAT_SUBMIT_STABLE))
 #define XLAT_STR_2 STRINGIFY(IORING_FEAT_SUBMIT_STABLE)
 XLAT(IORING_FEAT_RW_CUR_POS),
 #define XLAT_VAL_3 ((unsigned) (IORING_FEAT_RW_CUR_POS))
 #define XLAT_STR_3 STRINGIFY(IORING_FEAT_RW_CUR_POS)
 XLAT(IORING_FEAT_CUR_PERSONALITY),
 #define XLAT_VAL_4 ((unsigned) (IORING_FEAT_CUR_PERSONALITY))
 #define XLAT_STR_4 STRINGIFY(IORING_FEAT_CUR_PERSONALITY)
 XLAT(IORING_FEAT_FAST_POLL),
 #define XLAT_VAL_5 ((unsigned) (IORING_FEAT_FAST_POLL))
 #define XLAT_STR_5 STRINGIFY(IORING_FEAT_FAST_POLL)
 XLAT(IORING_FEAT_POLL_32BITS),
 #define XLAT_VAL_6 ((unsigned) (IORING_FEAT_POLL_32BITS))
 #define XLAT_STR_6 STRINGIFY(IORING_FEAT_POLL_32BITS)
 XLAT(IORING_FEAT_SQPOLL_NONFIXED),
 #define XLAT_VAL_7 ((unsigned) (IORING_FEAT_SQPOLL_NONFIXED))
 #define XLAT_STR_7 STRINGIFY(IORING_FEAT_SQPOLL_NONFIXED)
 XLAT(IORING_FEAT_EXT_ARG),
 #define XLAT_VAL_8 ((unsigned) (IORING_FEAT_EXT_ARG))
 #define XLAT_STR_8 STRINGIFY(IORING_FEAT_EXT_ARG)
 XLAT(IORING_FEAT_NATIVE_WORKERS),
 #define XLAT_VAL_9 ((unsigned) (IORING_FEAT_NATIVE_WORKERS))
 #define XLAT_STR_9 STRINGIFY(IORING_FEAT_NATIVE_WORKERS)
 XLAT(IORING_FEAT_RSRC_TAGS),
 #define XLAT_VAL_10 ((unsigned) (IORING_FEAT_RSRC_TAGS))
 #define XLAT_STR_10 STRINGIFY(IORING_FEAT_RSRC_TAGS)
 XLAT(IORING_FEAT_CQE_SKIP),
 #define XLAT_VAL_11 ((unsigned) (IORING_FEAT_CQE_SKIP))
 #define XLAT_STR_11 STRINGIFY(IORING_FEAT_CQE_SKIP)
 XLAT(IORING_FEAT_LINKED_FILE),
 #define XLAT_VAL_12 ((unsigned) (IORING_FEAT_LINKED_FILE))
 #define XLAT_STR_12 STRINGIFY(IORING_FEAT_LINKED_FILE)
 XLAT(IORING_FEAT_REG_REG_RING),
 #define XLAT_VAL_13 ((unsigned) (IORING_FEAT_REG_REG_RING))
 #define XLAT_STR_13 STRINGIFY(IORING_FEAT_REG_REG_RING)
 XLAT(IORING_FEAT_RECVSEND_BUNDLE),
 #define XLAT_VAL_14 ((unsigned) (IORING_FEAT_RECVSEND_BUNDLE))
 #define XLAT_STR_14 STRINGIFY(IORING_FEAT_RECVSEND_BUNDLE)
 XLAT(IORING_FEAT_MIN_TIMEOUT),
 #define XLAT_VAL_15 ((unsigned) (IORING_FEAT_MIN_TIMEOUT))
 #define XLAT_STR_15 STRINGIFY(IORING_FEAT_MIN_TIMEOUT)
};
static
const struct xlat uring_setup_features[1] = { {
 .data = uring_setup_features_xdata,
 .size = ARRAY_SIZE(uring_setup_features_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
#  ifdef XLAT_VAL_7
  | XLAT_VAL_7
#  endif
#  ifdef XLAT_VAL_8
  | XLAT_VAL_8
#  endif
#  ifdef XLAT_VAL_9
  | XLAT_VAL_9
#  endif
#  ifdef XLAT_VAL_10
  | XLAT_VAL_10
#  endif
#  ifdef XLAT_VAL_11
  | XLAT_VAL_11
#  endif
#  ifdef XLAT_VAL_12
  | XLAT_VAL_12
#  endif
#  ifdef XLAT_VAL_13
  | XLAT_VAL_13
#  endif
#  ifdef XLAT_VAL_14
  | XLAT_VAL_14
#  endif
#  ifdef XLAT_VAL_15
  | XLAT_VAL_15
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
#  ifdef XLAT_STR_7
  + sizeof(XLAT_STR_7)
#  endif
#  ifdef XLAT_STR_8
  + sizeof(XLAT_STR_8)
#  endif
#  ifdef XLAT_STR_9
  + sizeof(XLAT_STR_9)
#  endif
#  ifdef XLAT_STR_10
  + sizeof(XLAT_STR_10)
#  endif
#  ifdef XLAT_STR_11
  + sizeof(XLAT_STR_11)
#  endif
#  ifdef XLAT_STR_12
  + sizeof(XLAT_STR_12)
#  endif
#  ifdef XLAT_STR_13
  + sizeof(XLAT_STR_13)
#  endif
#  ifdef XLAT_STR_14
  + sizeof(XLAT_STR_14)
#  endif
#  ifdef XLAT_STR_15
  + sizeof(XLAT_STR_15)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
#  undef XLAT_STR_7
#  undef XLAT_VAL_7
#  undef XLAT_STR_8
#  undef XLAT_VAL_8
#  undef XLAT_STR_9
#  undef XLAT_VAL_9
#  undef XLAT_STR_10
#  undef XLAT_VAL_10
#  undef XLAT_STR_11
#  undef XLAT_VAL_11
#  undef XLAT_STR_12
#  undef XLAT_VAL_12
#  undef XLAT_STR_13
#  undef XLAT_VAL_13
#  undef XLAT_STR_14
#  undef XLAT_VAL_14
#  undef XLAT_STR_15
#  undef XLAT_VAL_15
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
