/* Generated by ./src/xlat/gen.sh from ./src/xlat/random_ioctl_cmds.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(RNDGETENTCNT) || (defined(HAVE_DECL_RNDGETENTCNT) && HAVE_DECL_RNDGETENTCNT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((RNDGETENTCNT) == (_IOR( 'R', 0x00, int )), "RNDGETENTCNT != _IOR( 'R', 0x00, int )");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define RNDGETENTCNT _IOR( 'R', 0x00, int )
#endif
#if defined(RNDADDTOENTCNT) || (defined(HAVE_DECL_RNDADDTOENTCNT) && HAVE_DECL_RNDADDTOENTCNT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((RNDADDTOENTCNT) == (_IOW( 'R', 0x01, int )), "RNDADDTOENTCNT != _IOW( 'R', 0x01, int )");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define RNDADDTOENTCNT _IOW( 'R', 0x01, int )
#endif
#if defined(RNDGETPOOL) || (defined(HAVE_DECL_RNDGETPOOL) && HAVE_DECL_RNDGETPOOL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((RNDGETPOOL) == (_IOR( 'R', 0x02, int [2] )), "RNDGETPOOL != _IOR( 'R', 0x02, int [2] )");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define RNDGETPOOL _IOR( 'R', 0x02, int [2] )
#endif
#if defined(RNDADDENTROPY) || (defined(HAVE_DECL_RNDADDENTROPY) && HAVE_DECL_RNDADDENTROPY)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((RNDADDENTROPY) == (_IOW( 'R', 0x03, int [2] )), "RNDADDENTROPY != _IOW( 'R', 0x03, int [2] )");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define RNDADDENTROPY _IOW( 'R', 0x03, int [2] )
#endif
#if defined(RNDZAPENTCNT) || (defined(HAVE_DECL_RNDZAPENTCNT) && HAVE_DECL_RNDZAPENTCNT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((RNDZAPENTCNT) == (_IO( 'R', 0x04 )), "RNDZAPENTCNT != _IO( 'R', 0x04 )");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define RNDZAPENTCNT _IO( 'R', 0x04 )
#endif
#if defined(RNDCLEARPOOL) || (defined(HAVE_DECL_RNDCLEARPOOL) && HAVE_DECL_RNDCLEARPOOL)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((RNDCLEARPOOL) == (_IO( 'R', 0x06 )), "RNDCLEARPOOL != _IO( 'R', 0x06 )");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define RNDCLEARPOOL _IO( 'R', 0x06 )
#endif
#if defined(RNDRESEEDCRNG) || (defined(HAVE_DECL_RNDRESEEDCRNG) && HAVE_DECL_RNDRESEEDCRNG)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((RNDRESEEDCRNG) == (_IO( 'R', 0x07 )), "RNDRESEEDCRNG != _IO( 'R', 0x07 )");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define RNDRESEEDCRNG _IO( 'R', 0x07 )
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat random_ioctl_cmds in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data random_ioctl_cmds_xdata[] = {
 XLAT(RNDGETENTCNT),
 #define XLAT_VAL_0 ((unsigned) (RNDGETENTCNT))
 #define XLAT_STR_0 STRINGIFY(RNDGETENTCNT)
 XLAT(RNDADDTOENTCNT),
 #define XLAT_VAL_1 ((unsigned) (RNDADDTOENTCNT))
 #define XLAT_STR_1 STRINGIFY(RNDADDTOENTCNT)
 XLAT(RNDGETPOOL),
 #define XLAT_VAL_2 ((unsigned) (RNDGETPOOL))
 #define XLAT_STR_2 STRINGIFY(RNDGETPOOL)
 XLAT(RNDADDENTROPY),
 #define XLAT_VAL_3 ((unsigned) (RNDADDENTROPY))
 #define XLAT_STR_3 STRINGIFY(RNDADDENTROPY)
 XLAT(RNDZAPENTCNT),
 #define XLAT_VAL_4 ((unsigned) (RNDZAPENTCNT))
 #define XLAT_STR_4 STRINGIFY(RNDZAPENTCNT)
 XLAT(RNDCLEARPOOL),
 #define XLAT_VAL_5 ((unsigned) (RNDCLEARPOOL))
 #define XLAT_STR_5 STRINGIFY(RNDCLEARPOOL)
 XLAT(RNDRESEEDCRNG),
 #define XLAT_VAL_6 ((unsigned) (RNDRESEEDCRNG))
 #define XLAT_STR_6 STRINGIFY(RNDRESEEDCRNG)
};
static
const struct xlat random_ioctl_cmds[1] = { {
 .data = random_ioctl_cmds_xdata,
 .size = ARRAY_SIZE(random_ioctl_cmds_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
#  ifdef XLAT_VAL_4
  | XLAT_VAL_4
#  endif
#  ifdef XLAT_VAL_5
  | XLAT_VAL_5
#  endif
#  ifdef XLAT_VAL_6
  | XLAT_VAL_6
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
#  ifdef XLAT_STR_4
  + sizeof(XLAT_STR_4)
#  endif
#  ifdef XLAT_STR_5
  + sizeof(XLAT_STR_5)
#  endif
#  ifdef XLAT_STR_6
  + sizeof(XLAT_STR_6)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
#  undef XLAT_STR_4
#  undef XLAT_VAL_4
#  undef XLAT_STR_5
#  undef XLAT_VAL_5
#  undef XLAT_STR_6
#  undef XLAT_VAL_6
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
