/* Generated by ioctls_gen.sh from definitions found in $linux/arch/alpha/include/ tree. */
{ "asm/ioctls.h", "FIOASYNC", _IOC_WRITE, 0x667d, 0x04 },
{ "asm/ioctls.h", "FIOCLEX", _IOC_NONE, 0x6601, 0x00 },
{ "asm/ioctls.h", "FIONBIO", _IOC_WRITE, 0x667e, 0x04 },
{ "asm/ioctls.h", "FIONCLEX", _IOC_NONE, 0x6602, 0x00 },
{ "asm/ioctls.h", "FIONREAD", _IOC_READ, 0x667f, 0x04 },
{ "asm/ioctls.h", "FIOQSIZE", _IOC_READ, 0x6680, 0x08 },
{ "asm/ioctls.h", "TCFLSH", _IOC_NONE, 0x741f, 0x00 },
{ "asm/ioctls.h", "TCGETA", _IOC_READ, 0x7417, 0x12 },
{ "asm/ioctls.h", "TCGETS", _IOC_READ, 0x7413, 0x2c },
{ "asm/ioctls.h", "TCSBRK", _IOC_NONE, 0x741d, 0x00 },
{ "asm/ioctls.h", "TCSBRKP", 0, 0x5425, 0 },
{ "asm/ioctls.h", "TCSETA", _IOC_WRITE, 0x7418, 0x12 },
{ "asm/ioctls.h", "TCSETAF", _IOC_WRITE, 0x741c, 0x12 },
{ "asm/ioctls.h", "TCSETAW", _IOC_WRITE, 0x7419, 0x12 },
{ "asm/ioctls.h", "TCSETS", _IOC_WRITE, 0x7414, 0x2c },
{ "asm/ioctls.h", "TCSETSF", _IOC_WRITE, 0x7416, 0x2c },
{ "asm/ioctls.h", "TCSETSW", _IOC_WRITE, 0x7415, 0x2c },
{ "asm/ioctls.h", "TCXONC", _IOC_NONE, 0x741e, 0x00 },
{ "asm/ioctls.h", "TIOCCBRK", 0, 0x5428, 0 },
{ "asm/ioctls.h", "TIOCCONS", 0, 0x541D, 0 },
{ "asm/ioctls.h", "TIOCEXCL", 0, 0x540C, 0 },
{ "asm/ioctls.h", "TIOCGDEV", _IOC_READ, 0x5432, 0x04 },
{ "asm/ioctls.h", "TIOCGETC", _IOC_READ, 0x7412, 0x06 },
{ "asm/ioctls.h", "TIOCGETD", 0, 0x5424, 0 },
{ "asm/ioctls.h", "TIOCGETP", _IOC_READ, 0x7408, 0x06 },
{ "asm/ioctls.h", "TIOCGEXCL", _IOC_READ, 0x5440, 0x04 },
{ "asm/ioctls.h", "TIOCGICOUNT", 0, 0x545D, 0 },
{ "asm/ioctls.h", "TIOCGLCKTRMIOS", 0, 0x5456, 0 },
{ "asm/ioctls.h", "TIOCGLTC", _IOC_READ, 0x7474, 0x06 },
{ "asm/ioctls.h", "TIOCGPGRP", _IOC_READ, 0x7477, 0x04 },
{ "asm/ioctls.h", "TIOCGPKT", _IOC_READ, 0x5438, 0x04 },
{ "asm/ioctls.h", "TIOCGPTLCK", _IOC_READ, 0x5439, 0x04 },
{ "asm/ioctls.h", "TIOCGPTN", _IOC_READ, 0x5430, 0x04 },
{ "asm/ioctls.h", "TIOCGRS485", _IOC_READ, 0x542e, 0x20 },
{ "asm/ioctls.h", "TIOCGSERIAL", 0, 0x541E, 0 },
{ "asm/ioctls.h", "TIOCGSID", 0, 0x5429, 0 },
{ "asm/ioctls.h", "TIOCGSOFTCAR", 0, 0x5419, 0 },
{ "asm/ioctls.h", "TIOCGWINSZ", _IOC_READ, 0x7468, 0x08 },
{ "asm/ioctls.h", "TIOCLINUX", 0, 0x541C, 0 },
{ "asm/ioctls.h", "TIOCMBIC", 0, 0x5417, 0 },
{ "asm/ioctls.h", "TIOCMBIS", 0, 0x5416, 0 },
{ "asm/ioctls.h", "TIOCMGET", 0, 0x5415, 0 },
{ "asm/ioctls.h", "TIOCMIWAIT", 0, 0x545C, 0 },
{ "asm/ioctls.h", "TIOCMSET", 0, 0x5418, 0 },
{ "asm/ioctls.h", "TIOCNOTTY", 0, 0x5422, 0 },
{ "asm/ioctls.h", "TIOCNXCL", 0, 0x540D, 0 },
{ "asm/ioctls.h", "TIOCOUTQ", _IOC_READ, 0x7473, 0x04 },
{ "asm/ioctls.h", "TIOCPKT", 0, 0x5420, 0 },
{ "asm/ioctls.h", "TIOCSBRK", 0, 0x5427, 0 },
{ "asm/ioctls.h", "TIOCSCTTY", 0, 0x540E, 0 },
{ "asm/ioctls.h", "TIOCSERCONFIG", 0, 0x5453, 0 },
{ "asm/ioctls.h", "TIOCSERGETLSR", 0, 0x5459, 0 },
{ "asm/ioctls.h", "TIOCSERGETMULTI", 0, 0x545A, 0 },
{ "asm/ioctls.h", "TIOCSERGSTRUCT", 0, 0x5458, 0 },
{ "asm/ioctls.h", "TIOCSERGWILD", 0, 0x5454, 0 },
{ "asm/ioctls.h", "TIOCSERSETMULTI", 0, 0x545B, 0 },
{ "asm/ioctls.h", "TIOCSERSWILD", 0, 0x5455, 0 },
{ "asm/ioctls.h", "TIOCSETC", _IOC_WRITE, 0x7411, 0x06 },
{ "asm/ioctls.h", "TIOCSETD", 0, 0x5423, 0 },
{ "asm/ioctls.h", "TIOCSETN", _IOC_WRITE, 0x740a, 0x06 },
{ "asm/ioctls.h", "TIOCSETP", _IOC_WRITE, 0x7409, 0x06 },
{ "asm/ioctls.h", "TIOCSIG", _IOC_WRITE, 0x5436, 0x04 },
{ "asm/ioctls.h", "TIOCSLCKTRMIOS", 0, 0x5457, 0 },
{ "asm/ioctls.h", "TIOCSLTC", _IOC_WRITE, 0x7475, 0x06 },
{ "asm/ioctls.h", "TIOCSPGRP", _IOC_WRITE, 0x7476, 0x04 },
{ "asm/ioctls.h", "TIOCSPTLCK", _IOC_WRITE, 0x5431, 0x04 },
{ "asm/ioctls.h", "TIOCSRS485", _IOC_READ|_IOC_WRITE, 0x542f, 0x20 },
{ "asm/ioctls.h", "TIOCSSERIAL", 0, 0x541F, 0 },
{ "asm/ioctls.h", "TIOCSSOFTCAR", 0, 0x541A, 0 },
{ "asm/ioctls.h", "TIOCSTART", _IOC_NONE, 0x746e, 0x00 },
{ "asm/ioctls.h", "TIOCSTI", 0, 0x5412, 0 },
{ "asm/ioctls.h", "TIOCSTOP", _IOC_NONE, 0x746f, 0x00 },
{ "asm/ioctls.h", "TIOCSWINSZ", _IOC_WRITE, 0x7467, 0x08 },
{ "asm/ioctls.h", "TIOCVHANGUP", 0, 0x5437, 0 },
{ "asm/sockios.h", "FIOGETOWN", _IOC_READ, 0x667b, 0x04 },
{ "asm/sockios.h", "FIOSETOWN", _IOC_WRITE, 0x667c, 0x04 },
{ "asm/sockios.h", "SIOCATMARK", _IOC_READ, 0x7307, 0x04 },
{ "asm/sockios.h", "SIOCGPGRP", _IOC_READ, 0x7309, 0x04 },
{ "asm/sockios.h", "SIOCSPGRP", _IOC_WRITE, 0x7308, 0x04 },
