/* Generated by ./src/xlat/gen.sh from ./src/xlat/inet_diag_ulp_info_attrs.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((INET_ULP_INFO_UNSPEC) == (0), "INET_ULP_INFO_UNSPEC != 0");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((INET_ULP_INFO_NAME) == (1), "INET_ULP_INFO_NAME != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((INET_ULP_INFO_TLS) == (2), "INET_ULP_INFO_TLS != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((INET_ULP_INFO_MPTCP) == (3), "INET_ULP_INFO_MPTCP != 3");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat inet_diag_ulp_info_attrs in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data inet_diag_ulp_info_attrs_xdata[] = {
 [INET_ULP_INFO_UNSPEC] = XLAT(INET_ULP_INFO_UNSPEC),
 #define XLAT_VAL_0 ((unsigned) (INET_ULP_INFO_UNSPEC))
 #define XLAT_STR_0 STRINGIFY(INET_ULP_INFO_UNSPEC)
 [INET_ULP_INFO_NAME] = XLAT(INET_ULP_INFO_NAME),
 #define XLAT_VAL_1 ((unsigned) (INET_ULP_INFO_NAME))
 #define XLAT_STR_1 STRINGIFY(INET_ULP_INFO_NAME)
 [INET_ULP_INFO_TLS] = XLAT(INET_ULP_INFO_TLS),
 #define XLAT_VAL_2 ((unsigned) (INET_ULP_INFO_TLS))
 #define XLAT_STR_2 STRINGIFY(INET_ULP_INFO_TLS)
 [INET_ULP_INFO_MPTCP] = XLAT(INET_ULP_INFO_MPTCP),
 #define XLAT_VAL_3 ((unsigned) (INET_ULP_INFO_MPTCP))
 #define XLAT_STR_3 STRINGIFY(INET_ULP_INFO_MPTCP)
};
static
const struct xlat inet_diag_ulp_info_attrs[1] = { {
 .data = inet_diag_ulp_info_attrs_xdata,
 .size = ARRAY_SIZE(inet_diag_ulp_info_attrs_xdata),
 .type = XT_INDEXED,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
#  ifdef XLAT_VAL_3
  | XLAT_VAL_3
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
#  ifdef XLAT_STR_3
  + sizeof(XLAT_STR_3)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
#  undef XLAT_STR_3
#  undef XLAT_VAL_3
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
