/* Generated by ./src/xlat/gen.sh from ./src/xlat/mremap_flags.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(MREMAP_MAYMOVE) || (defined(HAVE_DECL_MREMAP_MAYMOVE) && HAVE_DECL_MREMAP_MAYMOVE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MREMAP_MAYMOVE) == (1), "MREMAP_MAYMOVE != 1");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MREMAP_MAYMOVE 1
#endif
#if defined(MREMAP_FIXED) || (defined(HAVE_DECL_MREMAP_FIXED) && HAVE_DECL_MREMAP_FIXED)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MREMAP_FIXED) == (2), "MREMAP_FIXED != 2");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MREMAP_FIXED 2
#endif
#if defined(MREMAP_DONTUNMAP) || (defined(HAVE_DECL_MREMAP_DONTUNMAP) && HAVE_DECL_MREMAP_DONTUNMAP)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((MREMAP_DONTUNMAP) == (4), "MREMAP_DONTUNMAP != 4");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define MREMAP_DONTUNMAP 4
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat mremap_flags in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data mremap_flags_xdata[] = {
 XLAT(MREMAP_MAYMOVE),
 #define XLAT_VAL_0 ((unsigned) (MREMAP_MAYMOVE))
 #define XLAT_STR_0 STRINGIFY(MREMAP_MAYMOVE)
 XLAT(MREMAP_FIXED),
 #define XLAT_VAL_1 ((unsigned) (MREMAP_FIXED))
 #define XLAT_STR_1 STRINGIFY(MREMAP_FIXED)
 XLAT(MREMAP_DONTUNMAP),
 #define XLAT_VAL_2 ((unsigned) (MREMAP_DONTUNMAP))
 #define XLAT_STR_2 STRINGIFY(MREMAP_DONTUNMAP)
};
static
const struct xlat mremap_flags[1] = { {
 .data = mremap_flags_xdata,
 .size = ARRAY_SIZE(mremap_flags_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
