/*
 * Copyright (c) 2015-2021 Dmitry V. Levin <ldv@strace.io>
 * All rights reserved.
 *
 * SPDX-License-Identifier: LGPL-2.1-or-later
 */

#ifndef STRACE_REGS_H
# define STRACE_REGS_H

# include <sys/user.h>
# include "arch_regs.h"

#endif /* !STRACE_REGS_H */
