/* Generated by ./src/xlat/gen.sh from ./src/xlat/sock_iucv_options.in; do not edit. */

#include "gcc_compat.h"
#include "static_assert.h"

#if defined(SO_IPRMDATA_MSG) || (defined(HAVE_DECL_SO_IPRMDATA_MSG) && HAVE_DECL_SO_IPRMDATA_MSG)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SO_IPRMDATA_MSG) == (0x0080), "SO_IPRMDATA_MSG != 0x0080");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SO_IPRMDATA_MSG 0x0080
#endif
#if defined(SO_MSGLIMIT) || (defined(HAVE_DECL_SO_MSGLIMIT) && HAVE_DECL_SO_MSGLIMIT)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SO_MSGLIMIT) == (0x1000), "SO_MSGLIMIT != 0x1000");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SO_MSGLIMIT 0x1000
#endif
#if defined(SO_MSGSIZE) || (defined(HAVE_DECL_SO_MSGSIZE) && HAVE_DECL_SO_MSGSIZE)
DIAG_PUSH_IGNORE_TAUTOLOGICAL_COMPARE
static_assert((SO_MSGSIZE) == (0x0800), "SO_MSGSIZE != 0x0800");
DIAG_POP_IGNORE_TAUTOLOGICAL_COMPARE
#else
# define SO_MSGSIZE 0x0800
#endif
#undef XLAT_PREV_VAL

#ifndef XLAT_MACROS_ONLY

# ifdef IN_MPERS

#  error static const struct xlat sock_iucv_options in mpers mode

# else

DIAG_PUSH_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE
static const struct xlat_data sock_iucv_options_xdata[] = {
 XLAT(SO_IPRMDATA_MSG),
 #define XLAT_VAL_0 ((unsigned) (SO_IPRMDATA_MSG))
 #define XLAT_STR_0 STRINGIFY(SO_IPRMDATA_MSG)
 XLAT(SO_MSGLIMIT),
 #define XLAT_VAL_1 ((unsigned) (SO_MSGLIMIT))
 #define XLAT_STR_1 STRINGIFY(SO_MSGLIMIT)
 XLAT(SO_MSGSIZE),
 #define XLAT_VAL_2 ((unsigned) (SO_MSGSIZE))
 #define XLAT_STR_2 STRINGIFY(SO_MSGSIZE)
};
static
const struct xlat sock_iucv_options[1] = { {
 .data = sock_iucv_options_xdata,
 .size = ARRAY_SIZE(sock_iucv_options_xdata),
 .type = XT_NORMAL,
 .flags_mask = 0
#  ifdef XLAT_VAL_0
  | XLAT_VAL_0
#  endif
#  ifdef XLAT_VAL_1
  | XLAT_VAL_1
#  endif
#  ifdef XLAT_VAL_2
  | XLAT_VAL_2
#  endif
  ,
 .flags_strsz = 0
#  ifdef XLAT_STR_0
  + sizeof(XLAT_STR_0)
#  endif
#  ifdef XLAT_STR_1
  + sizeof(XLAT_STR_1)
#  endif
#  ifdef XLAT_STR_2
  + sizeof(XLAT_STR_2)
#  endif
  ,
} };
DIAG_POP_IGNORE_TAUTOLOGICAL_CONSTANT_COMPARE

#  undef XLAT_STR_0
#  undef XLAT_VAL_0
#  undef XLAT_STR_1
#  undef XLAT_VAL_1
#  undef XLAT_STR_2
#  undef XLAT_VAL_2
# endif /* !IN_MPERS */

#endif /* !XLAT_MACROS_ONLY */
