/* Generated by ioctls_gen.sh from definitions found in $linux/include/ tree. */
{ "acpi/apei.h", "APEI_ERST_CLEAR_RECORD", _IOC_WRITE, 0x4501, 0x08 },
{ "acpi/apei.h", "APEI_ERST_GET_RECORD_COUNT", _IOC_READ, 0x4502, 0x04 },
{ "asm-generic/ioctls.h", "FIOASYNC", 0, 0x5452, 0 },
{ "asm-generic/ioctls.h", "FIOCLEX", 0, 0x5451, 0 },
{ "asm-generic/ioctls.h", "FIONBIO", 0, 0x5421, 0 },
{ "asm-generic/ioctls.h", "FIONCLEX", 0, 0x5450, 0 },
{ "asm-generic/ioctls.h", "FIONREAD", 0, 0x541B, 0 },
{ "asm-generic/ioctls.h", "FIOQSIZE", 0, 0x5460, 0 },
{ "asm-generic/ioctls.h", "TCFLSH", 0, 0x540B, 0 },
{ "asm-generic/ioctls.h", "TCGETA", 0, 0x5405, 0 },
{ "asm-generic/ioctls.h", "TCGETS", 0, 0x5401, 0 },
{ "asm-generic/ioctls.h", "TCGETS2", _IOC_READ, 0x542a, 0x2c },
{ "asm-generic/ioctls.h", "TCGETX", 0, 0x5432, 0 },
{ "asm-generic/ioctls.h", "TCSBRK", 0, 0x5409, 0 },
{ "asm-generic/ioctls.h", "TCSBRKP", 0, 0x5425, 0 },
{ "asm-generic/ioctls.h", "TCSETA", 0, 0x5406, 0 },
{ "asm-generic/ioctls.h", "TCSETAF", 0, 0x5408, 0 },
{ "asm-generic/ioctls.h", "TCSETAW", 0, 0x5407, 0 },
{ "asm-generic/ioctls.h", "TCSETS", 0, 0x5402, 0 },
{ "asm-generic/ioctls.h", "TCSETS2", _IOC_WRITE, 0x542b, 0x2c },
{ "asm-generic/ioctls.h", "TCSETSF", 0, 0x5404, 0 },
{ "asm-generic/ioctls.h", "TCSETSF2", _IOC_WRITE, 0x542d, 0x2c },
{ "asm-generic/ioctls.h", "TCSETSW", 0, 0x5403, 0 },
{ "asm-generic/ioctls.h", "TCSETSW2", _IOC_WRITE, 0x542c, 0x2c },
{ "asm-generic/ioctls.h", "TCSETX", 0, 0x5433, 0 },
{ "asm-generic/ioctls.h", "TCSETXF", 0, 0x5434, 0 },
{ "asm-generic/ioctls.h", "TCSETXW", 0, 0x5435, 0 },
{ "asm-generic/ioctls.h", "TCXONC", 0, 0x540A, 0 },
{ "asm-generic/ioctls.h", "TIOCCBRK", 0, 0x5428, 0 },
{ "asm-generic/ioctls.h", "TIOCCONS", 0, 0x541D, 0 },
{ "asm-generic/ioctls.h", "TIOCEXCL", 0, 0x540C, 0 },
{ "asm-generic/ioctls.h", "TIOCGDEV", _IOC_READ, 0x5432, 0x04 },
{ "asm-generic/ioctls.h", "TIOCGETD", 0, 0x5424, 0 },
{ "asm-generic/ioctls.h", "TIOCGEXCL", _IOC_READ, 0x5440, 0x04 },
{ "asm-generic/ioctls.h", "TIOCGICOUNT", 0, 0x545D, 0 },
{ "asm-generic/ioctls.h", "TIOCGISO7816", _IOC_READ, 0x5442, 0x28 },
{ "asm-generic/ioctls.h", "TIOCGLCKTRMIOS", 0, 0x5456, 0 },
{ "asm-generic/ioctls.h", "TIOCGPGRP", 0, 0x540F, 0 },
{ "asm-generic/ioctls.h", "TIOCGPKT", _IOC_READ, 0x5438, 0x04 },
{ "asm-generic/ioctls.h", "TIOCGPTLCK", _IOC_READ, 0x5439, 0x04 },
{ "asm-generic/ioctls.h", "TIOCGPTN", _IOC_READ, 0x5430, 0x04 },
{ "asm-generic/ioctls.h", "TIOCGPTPEER", _IOC_NONE, 0x5441, 0x00 },
{ "asm-generic/ioctls.h", "TIOCGRS485", 0, 0x542E, 0 },
{ "asm-generic/ioctls.h", "TIOCGSERIAL", 0, 0x541E, 0 },
{ "asm-generic/ioctls.h", "TIOCGSID", 0, 0x5429, 0 },
{ "asm-generic/ioctls.h", "TIOCGSOFTCAR", 0, 0x5419, 0 },
{ "asm-generic/ioctls.h", "TIOCGWINSZ", 0, 0x5413, 0 },
{ "asm-generic/ioctls.h", "TIOCLINUX", 0, 0x541C, 0 },
{ "asm-generic/ioctls.h", "TIOCMBIC", 0, 0x5417, 0 },
{ "asm-generic/ioctls.h", "TIOCMBIS", 0, 0x5416, 0 },
{ "asm-generic/ioctls.h", "TIOCMGET", 0, 0x5415, 0 },
{ "asm-generic/ioctls.h", "TIOCMIWAIT", 0, 0x545C, 0 },
{ "asm-generic/ioctls.h", "TIOCMSET", 0, 0x5418, 0 },
{ "asm-generic/ioctls.h", "TIOCNOTTY", 0, 0x5422, 0 },
{ "asm-generic/ioctls.h", "TIOCNXCL", 0, 0x540D, 0 },
{ "asm-generic/ioctls.h", "TIOCOUTQ", 0, 0x5411, 0 },
{ "asm-generic/ioctls.h", "TIOCPKT", 0, 0x5420, 0 },
{ "asm-generic/ioctls.h", "TIOCSBRK", 0, 0x5427, 0 },
{ "asm-generic/ioctls.h", "TIOCSCTTY", 0, 0x540E, 0 },
{ "asm-generic/ioctls.h", "TIOCSERCONFIG", 0, 0x5453, 0 },
{ "asm-generic/ioctls.h", "TIOCSERGETLSR", 0, 0x5459, 0 },
{ "asm-generic/ioctls.h", "TIOCSERGETMULTI", 0, 0x545A, 0 },
{ "asm-generic/ioctls.h", "TIOCSERGSTRUCT", 0, 0x5458, 0 },
{ "asm-generic/ioctls.h", "TIOCSERGWILD", 0, 0x5454, 0 },
{ "asm-generic/ioctls.h", "TIOCSERSETMULTI", 0, 0x545B, 0 },
{ "asm-generic/ioctls.h", "TIOCSERSWILD", 0, 0x5455, 0 },
{ "asm-generic/ioctls.h", "TIOCSETD", 0, 0x5423, 0 },
{ "asm-generic/ioctls.h", "TIOCSIG", _IOC_WRITE, 0x5436, 0x04 },
{ "asm-generic/ioctls.h", "TIOCSISO7816", _IOC_READ|_IOC_WRITE, 0x5443, 0x28 },
{ "asm-generic/ioctls.h", "TIOCSLCKTRMIOS", 0, 0x5457, 0 },
{ "asm-generic/ioctls.h", "TIOCSPGRP", 0, 0x5410, 0 },
{ "asm-generic/ioctls.h", "TIOCSPTLCK", _IOC_WRITE, 0x5431, 0x04 },
{ "asm-generic/ioctls.h", "TIOCSRS485", 0, 0x542F, 0 },
{ "asm-generic/ioctls.h", "TIOCSSERIAL", 0, 0x541F, 0 },
{ "asm-generic/ioctls.h", "TIOCSSOFTCAR", 0, 0x541A, 0 },
{ "asm-generic/ioctls.h", "TIOCSTI", 0, 0x5412, 0 },
{ "asm-generic/ioctls.h", "TIOCSWINSZ", 0, 0x5414, 0 },
{ "asm-generic/ioctls.h", "TIOCVHANGUP", 0, 0x5437, 0 },
{ "asm-generic/sockios.h", "FIOGETOWN", 0, 0x8903, 0 },
{ "asm-generic/sockios.h", "FIOSETOWN", 0, 0x8901, 0 },
{ "asm-generic/sockios.h", "SIOCATMARK", 0, 0x8905, 0 },
{ "asm-generic/sockios.h", "SIOCGPGRP", 0, 0x8904, 0 },
{ "asm-generic/sockios.h", "SIOCGSTAMPNS_OLD", 0, 0x8907, 0 },
{ "asm-generic/sockios.h", "SIOCGSTAMP_OLD", 0, 0x8906, 0 },
{ "asm-generic/sockios.h", "SIOCSPGRP", 0, 0x8902, 0 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_BO_LIST", _IOC_READ|_IOC_WRITE, 0x6443, 0x18 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_CS", _IOC_READ|_IOC_WRITE, 0x6444, 0x18 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_CTX", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_FENCE_TO_HANDLE", _IOC_READ|_IOC_WRITE, 0x6454, 0x20 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_GEM_CREATE", _IOC_READ|_IOC_WRITE, 0x6440, 0x20 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_GEM_METADATA", _IOC_READ|_IOC_WRITE, 0x6446, 0x11c },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x6441, 0x08 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_GEM_OP", _IOC_READ|_IOC_WRITE, 0x6450, 0x10 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_GEM_USERPTR", _IOC_READ|_IOC_WRITE, 0x6451, 0x18 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_GEM_VA", _IOC_WRITE, 0x6448, 0x28 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_GEM_WAIT_IDLE", _IOC_READ|_IOC_WRITE, 0x6447, 0x10 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_INFO", _IOC_WRITE, 0x6445, 0x20 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_SCHED", _IOC_WRITE, 0x6455, 0x10 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_VM", _IOC_READ|_IOC_WRITE, 0x6453, 0x08 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_WAIT_CS", _IOC_READ|_IOC_WRITE, 0x6449, 0x20 },
{ "drm/amdgpu_drm.h", "DRM_IOCTL_AMDGPU_WAIT_FENCES", _IOC_READ|_IOC_WRITE, 0x6452, 0x18 },
{ "drm/armada_drm.h", "DRM_IOCTL_ARMADA_GEM_CREATE", _IOC_READ|_IOC_WRITE, 0x6440, 0x08 },
{ "drm/armada_drm.h", "DRM_IOCTL_ARMADA_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x6442, 0x20 },
{ "drm/armada_drm.h", "DRM_IOCTL_ARMADA_GEM_PWRITE", _IOC_WRITE, 0x6443, 0x14 },
{ "drm/drm.h", "DRM_IOCTL_ADD_BUFS", _IOC_READ|_IOC_WRITE, 0x6416, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_ADD_CTX", _IOC_READ|_IOC_WRITE, 0x6420, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_ADD_DRAW", _IOC_READ|_IOC_WRITE, 0x6427, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_ADD_MAP", _IOC_READ|_IOC_WRITE, 0x6415, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_AGP_ACQUIRE", _IOC_NONE, 0x6430, 0x00 },
{ "drm/drm.h", "DRM_IOCTL_AGP_ALLOC", _IOC_READ|_IOC_WRITE, 0x6434, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_AGP_BIND", _IOC_WRITE, 0x6436, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_AGP_ENABLE", _IOC_WRITE, 0x6432, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_AGP_FREE", _IOC_WRITE, 0x6435, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_AGP_INFO", _IOC_READ, 0x6433, 0x20 },
{ "drm/drm.h", "DRM_IOCTL_AGP_RELEASE", _IOC_NONE, 0x6431, 0x00 },
{ "drm/drm.h", "DRM_IOCTL_AGP_UNBIND", _IOC_WRITE, 0x6437, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_AUTH_MAGIC", _IOC_WRITE, 0x6411, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_BLOCK", _IOC_READ|_IOC_WRITE, 0x6412, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_CONTROL", _IOC_WRITE, 0x6414, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_CRTC_GET_SEQUENCE", _IOC_READ|_IOC_WRITE, 0x643b, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_CRTC_QUEUE_SEQUENCE", _IOC_READ|_IOC_WRITE, 0x643c, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_DMA", _IOC_READ|_IOC_WRITE, 0x6429, 0x28 },
{ "drm/drm.h", "DRM_IOCTL_DROP_MASTER", _IOC_NONE, 0x641f, 0x00 },
{ "drm/drm.h", "DRM_IOCTL_FINISH", _IOC_WRITE, 0x642c, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_FREE_BUFS", _IOC_WRITE, 0x641a, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_GEM_CLOSE", _IOC_WRITE, 0x6409, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_GEM_FLINK", _IOC_READ|_IOC_WRITE, 0x640a, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_GEM_OPEN", _IOC_READ|_IOC_WRITE, 0x640b, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_GET_CAP", _IOC_READ|_IOC_WRITE, 0x640c, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_GET_CLIENT", _IOC_READ|_IOC_WRITE, 0x6405, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_GET_CTX", _IOC_READ|_IOC_WRITE, 0x6423, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_GET_MAGIC", _IOC_READ, 0x6402, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_GET_MAP", _IOC_READ|_IOC_WRITE, 0x6404, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_GET_SAREA_CTX", _IOC_READ|_IOC_WRITE, 0x641d, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_GET_STATS", _IOC_READ, 0x6406, 0x7c },
{ "drm/drm.h", "DRM_IOCTL_GET_UNIQUE", _IOC_READ|_IOC_WRITE, 0x6401, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_INFO_BUFS", _IOC_READ|_IOC_WRITE, 0x6418, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_IRQ_BUSID", _IOC_READ|_IOC_WRITE, 0x6403, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_LOCK", _IOC_WRITE, 0x642a, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_MAP_BUFS", _IOC_READ|_IOC_WRITE, 0x6419, 0x0c },
{ "drm/drm.h", "DRM_IOCTL_MARK_BUFS", _IOC_WRITE, 0x6417, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_MODESET_CTL", _IOC_WRITE, 0x6408, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_MODE_ADDFB", _IOC_READ|_IOC_WRITE, 0x64ae, 0x1c },
{ "drm/drm.h", "DRM_IOCTL_MODE_ADDFB2", _IOC_READ|_IOC_WRITE, 0x64b8, 0x64 },
{ "drm/drm.h", "DRM_IOCTL_MODE_ATOMIC", _IOC_READ|_IOC_WRITE, 0x64bc, 0x38 },
{ "drm/drm.h", "DRM_IOCTL_MODE_ATTACHMODE", _IOC_READ|_IOC_WRITE, 0x64a8, 0x48 },
{ "drm/drm.h", "DRM_IOCTL_MODE_CLOSEFB", _IOC_READ|_IOC_WRITE, 0x64d0, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_MODE_CREATEPROPBLOB", _IOC_READ|_IOC_WRITE, 0x64bd, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_MODE_CREATE_DUMB", _IOC_READ|_IOC_WRITE, 0x64b2, 0x20 },
{ "drm/drm.h", "DRM_IOCTL_MODE_CREATE_LEASE", _IOC_READ|_IOC_WRITE, 0x64c6, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_MODE_CURSOR", _IOC_READ|_IOC_WRITE, 0x64a3, 0x1c },
{ "drm/drm.h", "DRM_IOCTL_MODE_CURSOR2", _IOC_READ|_IOC_WRITE, 0x64bb, 0x24 },
{ "drm/drm.h", "DRM_IOCTL_MODE_DESTROYPROPBLOB", _IOC_READ|_IOC_WRITE, 0x64be, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_MODE_DESTROY_DUMB", _IOC_READ|_IOC_WRITE, 0x64b4, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_MODE_DETACHMODE", _IOC_READ|_IOC_WRITE, 0x64a9, 0x48 },
{ "drm/drm.h", "DRM_IOCTL_MODE_DIRTYFB", _IOC_READ|_IOC_WRITE, 0x64b1, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETCONNECTOR", _IOC_READ|_IOC_WRITE, 0x64a7, 0x50 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETCRTC", _IOC_READ|_IOC_WRITE, 0x64a1, 0x68 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETENCODER", _IOC_READ|_IOC_WRITE, 0x64a6, 0x14 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETFB", _IOC_READ|_IOC_WRITE, 0x64ad, 0x1c },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETFB2", _IOC_READ|_IOC_WRITE, 0x64ce, 0x64 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETGAMMA", _IOC_READ|_IOC_WRITE, 0x64a4, 0x20 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETPLANE", _IOC_READ|_IOC_WRITE, 0x64b6, 0x20 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETPLANERESOURCES", _IOC_READ|_IOC_WRITE, 0x64b5, 0x0c },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETPROPBLOB", _IOC_READ|_IOC_WRITE, 0x64ac, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETPROPERTY", _IOC_READ|_IOC_WRITE, 0x64aa, 0x40 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GETRESOURCES", _IOC_READ|_IOC_WRITE, 0x64a0, 0x40 },
{ "drm/drm.h", "DRM_IOCTL_MODE_GET_LEASE", _IOC_READ|_IOC_WRITE, 0x64c8, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_MODE_LIST_LESSEES", _IOC_READ|_IOC_WRITE, 0x64c7, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_MODE_MAP_DUMB", _IOC_READ|_IOC_WRITE, 0x64b3, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_MODE_OBJ_GETPROPERTIES", _IOC_READ|_IOC_WRITE, 0x64b9, 0x1c },
{ "drm/drm.h", "DRM_IOCTL_MODE_OBJ_SETPROPERTY", _IOC_READ|_IOC_WRITE, 0x64ba, 0x14 },
{ "drm/drm.h", "DRM_IOCTL_MODE_PAGE_FLIP", _IOC_READ|_IOC_WRITE, 0x64b0, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_MODE_REVOKE_LEASE", _IOC_READ|_IOC_WRITE, 0x64c9, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_MODE_RMFB", _IOC_READ|_IOC_WRITE, 0x64af, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_MODE_SETCRTC", _IOC_READ|_IOC_WRITE, 0x64a2, 0x68 },
{ "drm/drm.h", "DRM_IOCTL_MODE_SETGAMMA", _IOC_READ|_IOC_WRITE, 0x64a5, 0x20 },
{ "drm/drm.h", "DRM_IOCTL_MODE_SETPLANE", _IOC_READ|_IOC_WRITE, 0x64b7, 0x30 },
{ "drm/drm.h", "DRM_IOCTL_MODE_SETPROPERTY", _IOC_READ|_IOC_WRITE, 0x64ab, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_MOD_CTX", _IOC_WRITE, 0x6422, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_NEW_CTX", _IOC_WRITE, 0x6425, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_PRIME_FD_TO_HANDLE", _IOC_READ|_IOC_WRITE, 0x642e, 0x0c },
{ "drm/drm.h", "DRM_IOCTL_PRIME_HANDLE_TO_FD", _IOC_READ|_IOC_WRITE, 0x642d, 0x0c },
{ "drm/drm.h", "DRM_IOCTL_RES_CTX", _IOC_READ|_IOC_WRITE, 0x6426, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_RM_CTX", _IOC_READ|_IOC_WRITE, 0x6421, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_RM_DRAW", _IOC_READ|_IOC_WRITE, 0x6428, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_RM_MAP", _IOC_WRITE, 0x641b, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_SET_CLIENT_CAP", _IOC_WRITE, 0x640d, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_SET_CLIENT_NAME", _IOC_READ|_IOC_WRITE, 0x64d1, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_SET_MASTER", _IOC_NONE, 0x641e, 0x00 },
{ "drm/drm.h", "DRM_IOCTL_SET_SAREA_CTX", _IOC_WRITE, 0x641c, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_SET_UNIQUE", _IOC_WRITE, 0x6410, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_SET_VERSION", _IOC_READ|_IOC_WRITE, 0x6407, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_SG_ALLOC", _IOC_READ|_IOC_WRITE, 0x6438, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_SG_FREE", _IOC_WRITE, 0x6439, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_SWITCH_CTX", _IOC_WRITE, 0x6424, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_CREATE", _IOC_READ|_IOC_WRITE, 0x64bf, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_DESTROY", _IOC_READ|_IOC_WRITE, 0x64c0, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_EVENTFD", _IOC_READ|_IOC_WRITE, 0x64cf, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_FD_TO_HANDLE", _IOC_READ|_IOC_WRITE, 0x64c2, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_HANDLE_TO_FD", _IOC_READ|_IOC_WRITE, 0x64c1, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_QUERY", _IOC_READ|_IOC_WRITE, 0x64cb, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_RESET", _IOC_READ|_IOC_WRITE, 0x64c4, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_SIGNAL", _IOC_READ|_IOC_WRITE, 0x64c5, 0x10 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_TIMELINE_SIGNAL", _IOC_READ|_IOC_WRITE, 0x64cd, 0x18 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_TIMELINE_WAIT", _IOC_READ|_IOC_WRITE, 0x64ca, 0x30 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_TRANSFER", _IOC_READ|_IOC_WRITE, 0x64cc, 0x20 },
{ "drm/drm.h", "DRM_IOCTL_SYNCOBJ_WAIT", _IOC_READ|_IOC_WRITE, 0x64c3, 0x28 },
{ "drm/drm.h", "DRM_IOCTL_UNBLOCK", _IOC_READ|_IOC_WRITE, 0x6413, 0x04 },
{ "drm/drm.h", "DRM_IOCTL_UNLOCK", _IOC_WRITE, 0x642b, 0x08 },
{ "drm/drm.h", "DRM_IOCTL_UPDATE_DRAW", _IOC_WRITE, 0x643f, 0x14 },
{ "drm/drm.h", "DRM_IOCTL_VERSION", _IOC_READ|_IOC_WRITE, 0x6400, 0x24 },
{ "drm/drm.h", "DRM_IOCTL_WAIT_VBLANK", _IOC_READ|_IOC_WRITE, 0x643a, 0x10 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_GEM_CPU_FINI", _IOC_WRITE, 0x6445, 0x08 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_GEM_CPU_PREP", _IOC_WRITE, 0x6444, 0x18 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6443, 0x10 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x48 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_GEM_USERPTR", _IOC_READ|_IOC_WRITE, 0x6448, 0x18 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_GEM_WAIT", _IOC_WRITE, 0x6449, 0x20 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_PM_QUERY_DOM", _IOC_READ|_IOC_WRITE, 0x644a, 0x48 },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_PM_QUERY_SIG", _IOC_READ|_IOC_WRITE, 0x644b, 0x4a },
{ "drm/etnaviv_drm.h", "DRM_IOCTL_ETNAVIV_WAIT_FENCE", _IOC_WRITE, 0x6447, 0x20 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_G2D_EXEC", _IOC_READ|_IOC_WRITE, 0x6462, 0x08 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_G2D_GET_VER", _IOC_READ|_IOC_WRITE, 0x6460, 0x08 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_G2D_SET_CMDLIST", _IOC_READ|_IOC_WRITE, 0x6461, 0x28 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_GEM_CREATE", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_GEM_GET", _IOC_READ|_IOC_WRITE, 0x6444, 0x10 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_GEM_MAP", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_IPP_COMMIT", _IOC_READ|_IOC_WRITE, 0x6483, 0x20 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_IPP_GET_CAPS", _IOC_READ|_IOC_WRITE, 0x6481, 0x18 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_IPP_GET_LIMITS", _IOC_READ|_IOC_WRITE, 0x6482, 0x20 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_IPP_GET_RESOURCES", _IOC_READ|_IOC_WRITE, 0x6480, 0x10 },
{ "drm/exynos_drm.h", "DRM_IOCTL_EXYNOS_VIDI_CONNECTION", _IOC_READ|_IOC_WRITE, 0x6447, 0x10 },
{ "drm/habanalabs_accel.h", "DRM_IOCTL_HL_CB", _IOC_READ|_IOC_WRITE, 0x6441, 0x18 },
{ "drm/habanalabs_accel.h", "DRM_IOCTL_HL_CS", _IOC_READ|_IOC_WRITE, 0x6442, 0x30 },
{ "drm/habanalabs_accel.h", "DRM_IOCTL_HL_DEBUG", _IOC_READ|_IOC_WRITE, 0x6445, 0x28 },
{ "drm/habanalabs_accel.h", "DRM_IOCTL_HL_INFO", _IOC_READ|_IOC_WRITE, 0x6440, 0x18 },
{ "drm/habanalabs_accel.h", "DRM_IOCTL_HL_MEMORY", _IOC_READ|_IOC_WRITE, 0x6444, 0x28 },
{ "drm/habanalabs_accel.h", "DRM_IOCTL_HL_WAIT_CS", _IOC_READ|_IOC_WRITE, 0x6443, 0x38 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_ALLOC", _IOC_READ|_IOC_WRITE, 0x6448, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_BATCHBUFFER", _IOC_WRITE, 0x6443, 0x18 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_CMDBUFFER", _IOC_WRITE, 0x644b, 0x18 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_DESTROY_HEAP", _IOC_WRITE, 0x644c, 0x04 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_FLIP", _IOC_NONE, 0x6442, 0x00 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_FLUSH", _IOC_NONE, 0x6441, 0x00 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_FREE", _IOC_WRITE, 0x6449, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_BUSY", _IOC_READ|_IOC_WRITE, 0x6457, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_CONTEXT_CREATE", _IOC_READ|_IOC_WRITE, 0x646d, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_CONTEXT_CREATE_EXT", _IOC_READ|_IOC_WRITE, 0x646d, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_CONTEXT_DESTROY", _IOC_WRITE, 0x646e, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_CONTEXT_GETPARAM", _IOC_READ|_IOC_WRITE, 0x6474, 0x18 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_CONTEXT_SETPARAM", _IOC_READ|_IOC_WRITE, 0x6475, 0x18 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_CREATE", _IOC_READ|_IOC_WRITE, 0x645b, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_CREATE_EXT", _IOC_READ|_IOC_WRITE, 0x647c, 0x18 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_ENTERVT", _IOC_NONE, 0x6459, 0x00 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_EXECBUFFER", _IOC_WRITE, 0x6454, 0x28 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_EXECBUFFER2", _IOC_WRITE, 0x6469, 0x40 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_EXECBUFFER2_WR", _IOC_READ|_IOC_WRITE, 0x6469, 0x40 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_GET_APERTURE", _IOC_READ, 0x6463, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_GET_CACHING", _IOC_READ|_IOC_WRITE, 0x6470, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_GET_TILING", _IOC_READ|_IOC_WRITE, 0x6462, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_INIT", _IOC_WRITE, 0x6453, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_LEAVEVT", _IOC_NONE, 0x645a, 0x00 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6466, 0x0c },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x645e, 0x28 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_GTT", _IOC_READ|_IOC_WRITE, 0x6464, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_MMAP_OFFSET", _IOC_READ|_IOC_WRITE, 0x6464, 0x20 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PIN", _IOC_READ|_IOC_WRITE, 0x6455, 0x18 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PREAD", _IOC_WRITE, 0x645c, 0x20 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_PWRITE", _IOC_WRITE, 0x645d, 0x20 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_SET_CACHING", _IOC_WRITE, 0x646f, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_SET_DOMAIN", _IOC_WRITE, 0x645f, 0x0c },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_SET_TILING", _IOC_READ|_IOC_WRITE, 0x6461, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_SW_FINISH", _IOC_WRITE, 0x6460, 0x04 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_THROTTLE", _IOC_NONE, 0x6458, 0x00 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_UNPIN", _IOC_WRITE, 0x6456, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_USERPTR", _IOC_READ|_IOC_WRITE, 0x6473, 0x18 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_VM_CREATE", _IOC_READ|_IOC_WRITE, 0x647a, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_VM_DESTROY", _IOC_WRITE, 0x647b, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GEM_WAIT", _IOC_READ|_IOC_WRITE, 0x646c, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GETPARAM", _IOC_READ|_IOC_WRITE, 0x6446, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GET_PIPE_FROM_CRTC_ID", _IOC_READ|_IOC_WRITE, 0x6465, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GET_RESET_STATS", _IOC_READ|_IOC_WRITE, 0x6472, 0x18 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GET_SPRITE_COLORKEY", _IOC_READ|_IOC_WRITE, 0x646a, 0x14 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_GET_VBLANK_PIPE", _IOC_READ, 0x644e, 0x04 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_HWS_ADDR", _IOC_WRITE, 0x6451, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_INIT", _IOC_WRITE, 0x6440, 0x44 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_INIT_HEAP", _IOC_WRITE, 0x644a, 0x0c },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_IRQ_EMIT", _IOC_READ|_IOC_WRITE, 0x6444, 0x04 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_IRQ_WAIT", _IOC_WRITE, 0x6445, 0x04 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_OVERLAY_ATTRS", _IOC_READ|_IOC_WRITE, 0x6468, 0x2c },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_OVERLAY_PUT_IMAGE", _IOC_WRITE, 0x6467, 0x2c },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_PERF_ADD_CONFIG", _IOC_WRITE, 0x6477, 0x48 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_PERF_OPEN", _IOC_WRITE, 0x6476, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_PERF_REMOVE_CONFIG", _IOC_WRITE, 0x6478, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_QUERY", _IOC_READ|_IOC_WRITE, 0x6479, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_REG_READ", _IOC_READ|_IOC_WRITE, 0x6471, 0x10 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_SETPARAM", _IOC_WRITE, 0x6447, 0x08 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_SET_SPRITE_COLORKEY", _IOC_READ|_IOC_WRITE, 0x646b, 0x14 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_SET_VBLANK_PIPE", _IOC_WRITE, 0x644d, 0x04 },
{ "drm/i915_drm.h", "DRM_IOCTL_I915_VBLANK_SWAP", _IOC_READ|_IOC_WRITE, 0x644f, 0x0c },
{ "drm/i915_drm.h", "I915_PERF_IOCTL_CONFIG", _IOC_NONE, 0x6902, 0x00 },
{ "drm/i915_drm.h", "I915_PERF_IOCTL_DISABLE", _IOC_NONE, 0x6901, 0x00 },
{ "drm/i915_drm.h", "I915_PERF_IOCTL_ENABLE", _IOC_NONE, 0x6900, 0x00 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_BO_CREATE", _IOC_READ|_IOC_WRITE, 0x6442, 0x18 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_BO_INFO", _IOC_READ|_IOC_WRITE, 0x6443, 0x20 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_BO_WAIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x18 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_METRIC_STREAMER_GET_DATA", _IOC_READ|_IOC_WRITE, 0x6449, 0x20 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_METRIC_STREAMER_GET_INFO", _IOC_READ|_IOC_WRITE, 0x644a, 0x20 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_METRIC_STREAMER_START", _IOC_READ|_IOC_WRITE, 0x6447, 0x1c },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_METRIC_STREAMER_STOP", _IOC_WRITE, 0x6448, 0x08 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_SET_PARAM", _IOC_WRITE, 0x6441, 0x10 },
{ "drm/ivpu_accel.h", "DRM_IOCTL_IVPU_SUBMIT", _IOC_WRITE, 0x6445, 0x1c },
{ "drm/lima_drm.h", "DRM_IOCTL_LIMA_CTX_CREATE", _IOC_READ, 0x6445, 0x08 },
{ "drm/lima_drm.h", "DRM_IOCTL_LIMA_CTX_FREE", _IOC_WRITE, 0x6446, 0x08 },
{ "drm/lima_drm.h", "DRM_IOCTL_LIMA_GEM_CREATE", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/lima_drm.h", "DRM_IOCTL_LIMA_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
{ "drm/lima_drm.h", "DRM_IOCTL_LIMA_GEM_SUBMIT", _IOC_WRITE, 0x6443, 0x30 },
{ "drm/lima_drm.h", "DRM_IOCTL_LIMA_GEM_WAIT", _IOC_WRITE, 0x6444, 0x10 },
{ "drm/lima_drm.h", "DRM_IOCTL_LIMA_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_CPU_FINI", _IOC_WRITE, 0x6445, 0x04 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_CPU_PREP", _IOC_WRITE, 0x6444, 0x18 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6443, 0x18 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x6448, 0x0c },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GEM_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6446, 0x48 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x18 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_SET_PARAM", _IOC_WRITE, 0x6441, 0x18 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_CLOSE", _IOC_WRITE, 0x644b, 0x04 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_NEW", _IOC_READ|_IOC_WRITE, 0x644a, 0x0c },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_SUBMITQUEUE_QUERY", _IOC_WRITE, 0x644c, 0x18 },
{ "drm/msm_drm.h", "DRM_IOCTL_MSM_WAIT_FENCE", _IOC_WRITE, 0x6447, 0x1c },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_CHANNEL_ALLOC", _IOC_READ|_IOC_WRITE, 0x6442, 0x58 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_CHANNEL_FREE", _IOC_WRITE, 0x6443, 0x04 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_EXEC", _IOC_READ|_IOC_WRITE, 0x6452, 0x28 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_GEM_CPU_FINI", _IOC_WRITE, 0x6483, 0x04 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_GEM_CPU_PREP", _IOC_WRITE, 0x6482, 0x08 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6484, 0x28 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6480, 0x30 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_GEM_PUSHBUF", _IOC_READ|_IOC_WRITE, 0x6481, 0x40 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_GETPARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_SVM_BIND", _IOC_READ|_IOC_WRITE, 0x6449, 0x40 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_SVM_INIT", _IOC_READ|_IOC_WRITE, 0x6448, 0x10 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_VM_BIND", _IOC_READ|_IOC_WRITE, 0x6451, 0x28 },
{ "drm/nouveau_drm.h", "DRM_IOCTL_NOUVEAU_VM_INIT", _IOC_READ|_IOC_WRITE, 0x6450, 0x10 },
{ "drm/omap_drm.h", "DRM_IOCTL_OMAP_GEM_CPU_FINI", _IOC_WRITE, 0x6445, 0x10 },
{ "drm/omap_drm.h", "DRM_IOCTL_OMAP_GEM_CPU_PREP", _IOC_WRITE, 0x6444, 0x08 },
{ "drm/omap_drm.h", "DRM_IOCTL_OMAP_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x6446, 0x18 },
{ "drm/omap_drm.h", "DRM_IOCTL_OMAP_GEM_NEW", _IOC_READ|_IOC_WRITE, 0x6443, 0x10 },
{ "drm/omap_drm.h", "DRM_IOCTL_OMAP_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/omap_drm.h", "DRM_IOCTL_OMAP_SET_PARAM", _IOC_WRITE, 0x6441, 0x10 },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_CREATE_BO", _IOC_READ|_IOC_WRITE, 0x6442, 0x18 },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_GET_BO_OFFSET", _IOC_READ|_IOC_WRITE, 0x6445, 0x10 },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6444, 0x10 },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_MADVISE", _IOC_READ|_IOC_WRITE, 0x6448, 0x0c },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_MMAP_BO", _IOC_READ|_IOC_WRITE, 0x6443, 0x10 },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_PERFCNT_DUMP", _IOC_WRITE, 0x6447, 0x08 },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_PERFCNT_ENABLE", _IOC_WRITE, 0x6446, 0x08 },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_SUBMIT", _IOC_WRITE, 0x6440, 0x28 },
{ "drm/panfrost_drm.h", "DRM_IOCTL_PANFROST_WAIT_BO", _IOC_WRITE, 0x6441, 0x10 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_CREATE_BO", _IOC_READ|_IOC_WRITE, 0x6441, 0x18 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_CREATE_CONTEXT", _IOC_READ|_IOC_WRITE, 0x6447, 0x28 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_CREATE_FREE_LIST", _IOC_READ|_IOC_WRITE, 0x6449, 0x20 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_CREATE_HWRT_DATASET", _IOC_READ|_IOC_WRITE, 0x644b, 0x88 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_CREATE_VM_CONTEXT", _IOC_READ|_IOC_WRITE, 0x6443, 0x08 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_DESTROY_CONTEXT", _IOC_WRITE, 0x6448, 0x08 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_DESTROY_FREE_LIST", _IOC_WRITE, 0x644a, 0x08 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_DESTROY_HWRT_DATASET", _IOC_WRITE, 0x644c, 0x08 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_DESTROY_VM_CONTEXT", _IOC_WRITE, 0x6444, 0x08 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_DEV_QUERY", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_GET_BO_MMAP_OFFSET", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_SUBMIT_JOBS", _IOC_WRITE, 0x644d, 0x10 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_VM_MAP", _IOC_WRITE, 0x6445, 0x28 },
{ "drm/pvr_drm.h", "DRM_IOCTL_PVR_VM_UNMAP", _IOC_WRITE, 0x6446, 0x18 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_ATTACH_SLICE_BO", _IOC_WRITE, 0x6443, 0x20 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_CREATE_BO", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_DETACH_SLICE_BO", _IOC_WRITE, 0x6448, 0x08 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_EXECUTE_BO", _IOC_WRITE, 0x6444, 0x10 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_MANAGE", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_MMAP_BO", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_PARTIAL_EXECUTE_BO", _IOC_WRITE, 0x6445, 0x10 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_PERF_STATS_BO", _IOC_READ|_IOC_WRITE, 0x6447, 0x10 },
{ "drm/qaic_accel.h", "DRM_IOCTL_QAIC_WAIT_BO", _IOC_WRITE, 0x6446, 0x10 },
{ "drm/qxl_drm.h", "DRM_IOCTL_QXL_ALLOC", _IOC_READ|_IOC_WRITE, 0x6440, 0x08 },
{ "drm/qxl_drm.h", "DRM_IOCTL_QXL_ALLOC_SURF", _IOC_READ|_IOC_WRITE, 0x6446, 0x18 },
{ "drm/qxl_drm.h", "DRM_IOCTL_QXL_CLIENTCAP", _IOC_WRITE, 0x6445, 0x08 },
{ "drm/qxl_drm.h", "DRM_IOCTL_QXL_EXECBUFFER", _IOC_WRITE, 0x6442, 0x10 },
{ "drm/qxl_drm.h", "DRM_IOCTL_QXL_GETPARAM", _IOC_READ|_IOC_WRITE, 0x6444, 0x10 },
{ "drm/qxl_drm.h", "DRM_IOCTL_QXL_MAP", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/qxl_drm.h", "DRM_IOCTL_QXL_UPDATE_AREA", _IOC_WRITE, 0x6443, 0x18 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_ALLOC", _IOC_READ|_IOC_WRITE, 0x6453, 0x10 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CLEAR", _IOC_WRITE, 0x6448, 0x18 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CMDBUF", _IOC_WRITE, 0x6450, 0x10 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CP_IDLE", _IOC_NONE, 0x6444, 0x00 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CP_INIT", _IOC_WRITE, 0x6440, 0x54 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CP_RESET", _IOC_NONE, 0x6443, 0x00 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CP_RESUME", _IOC_NONE, 0x6458, 0x00 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CP_START", _IOC_NONE, 0x6441, 0x00 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CP_STOP", _IOC_WRITE, 0x6442, 0x08 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_CS", _IOC_READ|_IOC_WRITE, 0x6466, 0x20 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_FLIP", _IOC_NONE, 0x6452, 0x00 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_FREE", _IOC_WRITE, 0x6454, 0x08 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_FULLSCREEN", _IOC_WRITE, 0x6446, 0x04 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_BUSY", _IOC_READ|_IOC_WRITE, 0x646a, 0x08 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_CREATE", _IOC_READ|_IOC_WRITE, 0x645d, 0x1c },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_GET_TILING", _IOC_READ|_IOC_WRITE, 0x6469, 0x0c },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_INFO", _IOC_READ|_IOC_WRITE, 0x645c, 0x18 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x645e, 0x20 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_OP", _IOC_READ|_IOC_WRITE, 0x646c, 0x10 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_PREAD", _IOC_READ|_IOC_WRITE, 0x6461, 0x20 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_PWRITE", _IOC_READ|_IOC_WRITE, 0x6462, 0x20 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_SET_DOMAIN", _IOC_READ|_IOC_WRITE, 0x6463, 0x0c },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_SET_TILING", _IOC_READ|_IOC_WRITE, 0x6468, 0x0c },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_USERPTR", _IOC_READ|_IOC_WRITE, 0x646d, 0x18 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_VA", _IOC_READ|_IOC_WRITE, 0x646b, 0x18 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GEM_WAIT_IDLE", _IOC_WRITE, 0x6464, 0x08 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_GETPARAM", _IOC_READ|_IOC_WRITE, 0x6451, 0x08 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_INDICES", _IOC_WRITE, 0x644a, 0x14 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_INDIRECT", _IOC_READ|_IOC_WRITE, 0x644d, 0x10 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_INFO", _IOC_READ|_IOC_WRITE, 0x6467, 0x10 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_INIT_HEAP", _IOC_WRITE, 0x6455, 0x0c },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_IRQ_EMIT", _IOC_READ|_IOC_WRITE, 0x6456, 0x04 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_IRQ_WAIT", _IOC_WRITE, 0x6457, 0x04 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_RESET", _IOC_NONE, 0x6445, 0x00 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_SETPARAM", _IOC_WRITE, 0x6459, 0x0c },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_STIPPLE", _IOC_WRITE, 0x644c, 0x04 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_SURF_ALLOC", _IOC_WRITE, 0x645a, 0x0c },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_SURF_FREE", _IOC_WRITE, 0x645b, 0x04 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_SWAP", _IOC_NONE, 0x6447, 0x00 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_TEXTURE", _IOC_READ|_IOC_WRITE, 0x644e, 0x18 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_VERTEX", _IOC_WRITE, 0x6449, 0x10 },
{ "drm/radeon_drm.h", "DRM_IOCTL_RADEON_VERTEX2", _IOC_WRITE, 0x644f, 0x18 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_CHANNEL_CLOSE", _IOC_READ|_IOC_WRITE, 0x6451, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_CHANNEL_MAP", _IOC_READ|_IOC_WRITE, 0x6452, 0x10 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_CHANNEL_OPEN", _IOC_READ|_IOC_WRITE, 0x6450, 0x18 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_CHANNEL_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6454, 0x40 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_CHANNEL_UNMAP", _IOC_READ|_IOC_WRITE, 0x6453, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_CLOSE_CHANNEL", _IOC_READ|_IOC_WRITE, 0x6446, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_GEM_CREATE", _IOC_READ|_IOC_WRITE, 0x6440, 0x10 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_GEM_GET_FLAGS", _IOC_READ|_IOC_WRITE, 0x644d, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_GEM_GET_TILING", _IOC_READ|_IOC_WRITE, 0x644b, 0x10 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_GEM_MMAP", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_GEM_SET_FLAGS", _IOC_READ|_IOC_WRITE, 0x644c, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_GEM_SET_TILING", _IOC_READ|_IOC_WRITE, 0x644a, 0x10 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_GET_SYNCPT", _IOC_READ|_IOC_WRITE, 0x6447, 0x10 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_GET_SYNCPT_BASE", _IOC_READ|_IOC_WRITE, 0x6449, 0x10 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_OPEN_CHANNEL", _IOC_READ|_IOC_WRITE, 0x6445, 0x10 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_SUBMIT", _IOC_READ|_IOC_WRITE, 0x6448, 0x58 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_SYNCPOINT_ALLOCATE", _IOC_READ|_IOC_WRITE, 0x6460, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_SYNCPOINT_FREE", _IOC_READ|_IOC_WRITE, 0x6461, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_SYNCPOINT_WAIT", _IOC_READ|_IOC_WRITE, 0x6462, 0x18 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_SYNCPT_INCR", _IOC_READ|_IOC_WRITE, 0x6443, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_SYNCPT_READ", _IOC_READ|_IOC_WRITE, 0x6442, 0x08 },
{ "drm/tegra_drm.h", "DRM_IOCTL_TEGRA_SYNCPT_WAIT", _IOC_READ|_IOC_WRITE, 0x6444, 0x10 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_CREATE_BO", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_GET_BO_OFFSET", _IOC_READ|_IOC_WRITE, 0x6445, 0x08 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6444, 0x10 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_MMAP_BO", _IOC_READ|_IOC_WRITE, 0x6443, 0x10 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_PERFMON_CREATE", _IOC_READ|_IOC_WRITE, 0x6448, 0x28 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_PERFMON_DESTROY", _IOC_READ|_IOC_WRITE, 0x6449, 0x04 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_PERFMON_GET_COUNTER", _IOC_READ|_IOC_WRITE, 0x644c, 0x168 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_PERFMON_GET_VALUES", _IOC_READ|_IOC_WRITE, 0x644a, 0x10 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_SUBMIT_CL", _IOC_READ|_IOC_WRITE, 0x6440, 0x48 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_SUBMIT_CPU", _IOC_WRITE, 0x644b, 0x18 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_SUBMIT_CSD", _IOC_WRITE, 0x6447, 0x54 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_SUBMIT_TFU", _IOC_WRITE, 0x6446, 0x58 },
{ "drm/v3d_drm.h", "DRM_IOCTL_V3D_WAIT_BO", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_CREATE_BO", _IOC_READ|_IOC_WRITE, 0x6443, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_CREATE_SHADER_BO", _IOC_READ|_IOC_WRITE, 0x6445, 0x18 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_GEM_MADVISE", _IOC_READ|_IOC_WRITE, 0x644b, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_GET_HANG_STATE", _IOC_READ|_IOC_WRITE, 0x6446, 0xa0 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_GET_PARAM", _IOC_READ|_IOC_WRITE, 0x6447, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_GET_TILING", _IOC_READ|_IOC_WRITE, 0x6449, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_LABEL_BO", _IOC_READ|_IOC_WRITE, 0x644a, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_MMAP_BO", _IOC_READ|_IOC_WRITE, 0x6444, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_PERFMON_CREATE", _IOC_READ|_IOC_WRITE, 0x644c, 0x18 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_PERFMON_DESTROY", _IOC_READ|_IOC_WRITE, 0x644d, 0x04 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_PERFMON_GET_VALUES", _IOC_READ|_IOC_WRITE, 0x644e, 0x0c },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_SET_TILING", _IOC_READ|_IOC_WRITE, 0x6448, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_SUBMIT_CL", _IOC_READ|_IOC_WRITE, 0x6440, 0xb0 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_WAIT_BO", _IOC_READ|_IOC_WRITE, 0x6442, 0x10 },
{ "drm/vc4_drm.h", "DRM_IOCTL_VC4_WAIT_SEQNO", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/vgem_drm.h", "DRM_IOCTL_VGEM_FENCE_ATTACH", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/vgem_drm.h", "DRM_IOCTL_VGEM_FENCE_SIGNAL", _IOC_WRITE, 0x6442, 0x08 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_CONTEXT_INIT", _IOC_READ|_IOC_WRITE, 0x644b, 0x10 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_EXECBUFFER", _IOC_READ|_IOC_WRITE, 0x6442, 0x40 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_GETPARAM", _IOC_READ|_IOC_WRITE, 0x6443, 0x10 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_GET_CAPS", _IOC_READ|_IOC_WRITE, 0x6449, 0x18 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_MAP", _IOC_READ|_IOC_WRITE, 0x6441, 0x10 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_RESOURCE_CREATE", _IOC_READ|_IOC_WRITE, 0x6444, 0x38 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_RESOURCE_CREATE_BLOB", _IOC_READ|_IOC_WRITE, 0x644a, 0x30 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_RESOURCE_INFO", _IOC_READ|_IOC_WRITE, 0x6445, 0x10 },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_TRANSFER_FROM_HOST", _IOC_READ|_IOC_WRITE, 0x6446, 0x2c },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_TRANSFER_TO_HOST", _IOC_READ|_IOC_WRITE, 0x6447, 0x2c },
{ "drm/virtgpu_drm.h", "DRM_IOCTL_VIRTGPU_WAIT", _IOC_READ|_IOC_WRITE, 0x6448, 0x08 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_DEVICE_QUERY", _IOC_READ|_IOC_WRITE, 0x6440, 0x28 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_EXEC", _IOC_WRITE, 0x6449, 0x38 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_EXEC_QUEUE_CREATE", _IOC_READ|_IOC_WRITE, 0x6446, 0x30 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_EXEC_QUEUE_DESTROY", _IOC_WRITE, 0x6447, 0x18 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_EXEC_QUEUE_GET_PROPERTY", _IOC_READ|_IOC_WRITE, 0x6448, 0x28 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_GEM_CREATE", _IOC_READ|_IOC_WRITE, 0x6441, 0x38 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_GEM_MMAP_OFFSET", _IOC_READ|_IOC_WRITE, 0x6442, 0x28 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_OBSERVATION", _IOC_WRITE, 0x644b, 0x20 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_VM_BIND", _IOC_WRITE, 0x6445, 0x88 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_VM_CREATE", _IOC_READ|_IOC_WRITE, 0x6443, 0x20 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_VM_DESTROY", _IOC_WRITE, 0x6444, 0x18 },
{ "drm/xe_drm.h", "DRM_IOCTL_XE_WAIT_USER_FENCE", _IOC_READ|_IOC_WRITE, 0x644a, 0x48 },
{ "drm/xe_drm.h", "DRM_XE_OBSERVATION_IOCTL_CONFIG", _IOC_NONE, 0x6902, 0x00 },
{ "drm/xe_drm.h", "DRM_XE_OBSERVATION_IOCTL_DISABLE", _IOC_NONE, 0x6901, 0x00 },
{ "drm/xe_drm.h", "DRM_XE_OBSERVATION_IOCTL_ENABLE", _IOC_NONE, 0x6900, 0x00 },
{ "drm/xe_drm.h", "DRM_XE_OBSERVATION_IOCTL_INFO", _IOC_NONE, 0x6904, 0x00 },
{ "drm/xe_drm.h", "DRM_XE_OBSERVATION_IOCTL_STATUS", _IOC_NONE, 0x6903, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_ASSIGN_MMIODEV", _IOC_WRITE, 0xa257, 0x68 },
{ "linux/acrn.h", "ACRN_IOCTL_ASSIGN_PCIDEV", _IOC_WRITE, 0xa255, 0x22 },
{ "linux/acrn.h", "ACRN_IOCTL_ATTACH_IOREQ_CLIENT", _IOC_NONE, 0xa233, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_CLEAR_VM_IOREQ", _IOC_NONE, 0xa235, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_CREATE_IOREQ_CLIENT", _IOC_NONE, 0xa232, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_CREATE_VDEV", _IOC_WRITE, 0xa259, 0xc0 },
{ "linux/acrn.h", "ACRN_IOCTL_CREATE_VM", _IOC_READ|_IOC_WRITE, 0xa210, 0x30 },
{ "linux/acrn.h", "ACRN_IOCTL_DEASSIGN_MMIODEV", _IOC_WRITE, 0xa258, 0x68 },
{ "linux/acrn.h", "ACRN_IOCTL_DEASSIGN_PCIDEV", _IOC_WRITE, 0xa256, 0x22 },
{ "linux/acrn.h", "ACRN_IOCTL_DESTROY_IOREQ_CLIENT", _IOC_NONE, 0xa234, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_DESTROY_VDEV", _IOC_WRITE, 0xa25a, 0xc0 },
{ "linux/acrn.h", "ACRN_IOCTL_DESTROY_VM", _IOC_NONE, 0xa211, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_INJECT_MSI", _IOC_WRITE, 0xa223, 0x10 },
{ "linux/acrn.h", "ACRN_IOCTL_IOEVENTFD", _IOC_WRITE, 0xa270, 0x20 },
{ "linux/acrn.h", "ACRN_IOCTL_IRQFD", _IOC_WRITE, 0xa271, 0x18 },
{ "linux/acrn.h", "ACRN_IOCTL_NOTIFY_REQUEST_FINISH", _IOC_WRITE, 0xa231, 0x08 },
{ "linux/acrn.h", "ACRN_IOCTL_PAUSE_VM", _IOC_NONE, 0xa213, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_PM_GET_CPU_STATE", _IOC_READ|_IOC_WRITE, 0xa260, 0x08 },
{ "linux/acrn.h", "ACRN_IOCTL_RESET_PTDEV_INTR", _IOC_WRITE, 0xa254, 0x14 },
{ "linux/acrn.h", "ACRN_IOCTL_RESET_VM", _IOC_NONE, 0xa215, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_SET_IRQLINE", _IOC_WRITE, 0xa225, 0x08 },
{ "linux/acrn.h", "ACRN_IOCTL_SET_MEMSEG", _IOC_WRITE, 0xa241, 0x20 },
{ "linux/acrn.h", "ACRN_IOCTL_SET_PTDEV_INTR", _IOC_WRITE, 0xa253, 0x14 },
{ "linux/acrn.h", "ACRN_IOCTL_SET_VCPU_REGS", _IOC_WRITE, 0xa216, 0x124 },
{ "linux/acrn.h", "ACRN_IOCTL_START_VM", _IOC_NONE, 0xa212, 0x00 },
{ "linux/acrn.h", "ACRN_IOCTL_UNSET_MEMSEG", _IOC_WRITE, 0xa242, 0x20 },
{ "linux/acrn.h", "ACRN_IOCTL_VM_INTR_MONITOR", _IOC_WRITE, 0xa224, 0x04 },
{ "linux/agpgart.h", "AGPIOC_ACQUIRE", _IOC_NONE, 0x4101, 0x00 },
{ "linux/agpgart.h", "AGPIOC_ALLOCATE", _IOC_READ|_IOC_WRITE, 0x4106, 0x04 },
{ "linux/agpgart.h", "AGPIOC_BIND", _IOC_WRITE, 0x4108, 0x04 },
{ "linux/agpgart.h", "AGPIOC_CHIPSET_FLUSH", _IOC_NONE, 0x410a, 0x00 },
{ "linux/agpgart.h", "AGPIOC_DEALLOCATE", _IOC_WRITE, 0x4107, 0x04 },
{ "linux/agpgart.h", "AGPIOC_INFO", _IOC_READ, 0x4100, 0x04 },
{ "linux/agpgart.h", "AGPIOC_PROTECT", _IOC_WRITE, 0x4105, 0x04 },
{ "linux/agpgart.h", "AGPIOC_RELEASE", _IOC_NONE, 0x4102, 0x00 },
{ "linux/agpgart.h", "AGPIOC_RESERVE", _IOC_WRITE, 0x4104, 0x04 },
{ "linux/agpgart.h", "AGPIOC_SETUP", _IOC_WRITE, 0x4103, 0x04 },
{ "linux/agpgart.h", "AGPIOC_UNBIND", _IOC_WRITE, 0x4109, 0x04 },
{ "linux/am437x-vpfe.h", "VIDIOC_AM437X_CCDC_CFG", _IOC_WRITE, 0x56c1, 0x04 },
{ "linux/android/binder.h", "BC_ACQUIRE", _IOC_WRITE, 0x6305, 0x04 },
{ "linux/android/binder.h", "BC_ACQUIRE_DONE", _IOC_WRITE, 0x6309, 0x10 },
{ "linux/android/binder.h", "BC_ACQUIRE_RESULT", _IOC_WRITE, 0x6302, 0x04 },
{ "linux/android/binder.h", "BC_ATTEMPT_ACQUIRE", _IOC_WRITE, 0x630a, 0x08 },
{ "linux/android/binder.h", "BC_CLEAR_DEATH_NOTIFICATION", _IOC_WRITE, 0x630f, 0x0c },
{ "linux/android/binder.h", "BC_CLEAR_FREEZE_NOTIFICATION", _IOC_WRITE, 0x6314, 0x0c },
{ "linux/android/binder.h", "BC_DEAD_BINDER_DONE", _IOC_WRITE, 0x6310, 0x08 },
{ "linux/android/binder.h", "BC_DECREFS", _IOC_WRITE, 0x6307, 0x04 },
{ "linux/android/binder.h", "BC_ENTER_LOOPER", _IOC_NONE, 0x630c, 0x00 },
{ "linux/android/binder.h", "BC_EXIT_LOOPER", _IOC_NONE, 0x630d, 0x00 },
{ "linux/android/binder.h", "BC_FREEZE_NOTIFICATION_DONE", _IOC_WRITE, 0x6315, 0x08 },
{ "linux/android/binder.h", "BC_FREE_BUFFER", _IOC_WRITE, 0x6303, 0x08 },
{ "linux/android/binder.h", "BC_INCREFS", _IOC_WRITE, 0x6304, 0x04 },
{ "linux/android/binder.h", "BC_INCREFS_DONE", _IOC_WRITE, 0x6308, 0x10 },
{ "linux/android/binder.h", "BC_REGISTER_LOOPER", _IOC_NONE, 0x630b, 0x00 },
{ "linux/android/binder.h", "BC_RELEASE", _IOC_WRITE, 0x6306, 0x04 },
{ "linux/android/binder.h", "BC_REPLY", _IOC_WRITE, 0x6301, 0x40 },
{ "linux/android/binder.h", "BC_REPLY_SG", _IOC_WRITE, 0x6312, 0x48 },
{ "linux/android/binder.h", "BC_REQUEST_DEATH_NOTIFICATION", _IOC_WRITE, 0x630e, 0x0c },
{ "linux/android/binder.h", "BC_TRANSACTION", _IOC_WRITE, 0x6300, 0x40 },
{ "linux/android/binder.h", "BC_TRANSACTION_SG", _IOC_WRITE, 0x6311, 0x48 },
{ "linux/android/binder.h", "BINDER_ENABLE_ONEWAY_SPAM_DETECTION", _IOC_WRITE, 0x6210, 0x04 },
{ "linux/android/binder.h", "BINDER_FREEZE", _IOC_WRITE, 0x620e, 0x0c },
{ "linux/android/binder.h", "BINDER_GET_EXTENDED_ERROR", _IOC_READ|_IOC_WRITE, 0x6211, 0x0c },
{ "linux/android/binder.h", "BINDER_GET_FROZEN_INFO", _IOC_READ|_IOC_WRITE, 0x620f, 0x0c },
{ "linux/android/binder.h", "BINDER_GET_NODE_DEBUG_INFO", _IOC_READ|_IOC_WRITE, 0x620b, 0x18 },
{ "linux/android/binder.h", "BINDER_GET_NODE_INFO_FOR_REF", _IOC_READ|_IOC_WRITE, 0x620c, 0x18 },
{ "linux/android/binder.h", "BINDER_SET_CONTEXT_MGR", _IOC_WRITE, 0x6207, 0x04 },
{ "linux/android/binder.h", "BINDER_SET_CONTEXT_MGR_EXT", _IOC_WRITE, 0x620d, 0x18 },
{ "linux/android/binder.h", "BINDER_SET_IDLE_PRIORITY", _IOC_WRITE, 0x6206, 0x04 },
{ "linux/android/binder.h", "BINDER_SET_IDLE_TIMEOUT", _IOC_WRITE, 0x6203, 0x08 },
{ "linux/android/binder.h", "BINDER_SET_MAX_THREADS", _IOC_WRITE, 0x6205, 0x04 },
{ "linux/android/binder.h", "BINDER_THREAD_EXIT", _IOC_WRITE, 0x6208, 0x04 },
{ "linux/android/binder.h", "BINDER_VERSION", _IOC_READ|_IOC_WRITE, 0x6209, 0x04 },
{ "linux/android/binder.h", "BINDER_WRITE_READ", _IOC_READ|_IOC_WRITE, 0x6201, 0x30 },
{ "linux/android/binder.h", "BR_ACQUIRE", _IOC_READ, 0x7208, 0x10 },
{ "linux/android/binder.h", "BR_ACQUIRE_RESULT", _IOC_READ, 0x7204, 0x04 },
{ "linux/android/binder.h", "BR_ATTEMPT_ACQUIRE", _IOC_READ, 0x720b, 0x14 },
{ "linux/android/binder.h", "BR_CLEAR_DEATH_NOTIFICATION_DONE", _IOC_READ, 0x7210, 0x08 },
{ "linux/android/binder.h", "BR_CLEAR_FREEZE_NOTIFICATION_DONE", _IOC_READ, 0x7216, 0x08 },
{ "linux/android/binder.h", "BR_DEAD_BINDER", _IOC_READ, 0x720f, 0x08 },
{ "linux/android/binder.h", "BR_DEAD_REPLY", _IOC_NONE, 0x7205, 0x00 },
{ "linux/android/binder.h", "BR_DECREFS", _IOC_READ, 0x720a, 0x10 },
{ "linux/android/binder.h", "BR_ERROR", _IOC_READ, 0x7200, 0x04 },
{ "linux/android/binder.h", "BR_FAILED_REPLY", _IOC_NONE, 0x7211, 0x00 },
{ "linux/android/binder.h", "BR_FINISHED", _IOC_NONE, 0x720e, 0x00 },
{ "linux/android/binder.h", "BR_FROZEN_BINDER", _IOC_READ, 0x7215, 0x10 },
{ "linux/android/binder.h", "BR_FROZEN_REPLY", _IOC_NONE, 0x7212, 0x00 },
{ "linux/android/binder.h", "BR_INCREFS", _IOC_READ, 0x7207, 0x10 },
{ "linux/android/binder.h", "BR_NOOP", _IOC_NONE, 0x720c, 0x00 },
{ "linux/android/binder.h", "BR_OK", _IOC_NONE, 0x7201, 0x00 },
{ "linux/android/binder.h", "BR_ONEWAY_SPAM_SUSPECT", _IOC_NONE, 0x7213, 0x00 },
{ "linux/android/binder.h", "BR_RELEASE", _IOC_READ, 0x7209, 0x10 },
{ "linux/android/binder.h", "BR_REPLY", _IOC_READ, 0x7203, 0x40 },
{ "linux/android/binder.h", "BR_SPAWN_LOOPER", _IOC_NONE, 0x720d, 0x00 },
{ "linux/android/binder.h", "BR_TRANSACTION", _IOC_READ, 0x7202, 0x40 },
{ "linux/android/binder.h", "BR_TRANSACTION_COMPLETE", _IOC_NONE, 0x7206, 0x00 },
{ "linux/android/binder.h", "BR_TRANSACTION_PENDING_FROZEN", _IOC_NONE, 0x7214, 0x00 },
{ "linux/android/binder.h", "BR_TRANSACTION_SEC_CTX", _IOC_READ, 0x7202, 0x48 },
{ "linux/android/binderfs.h", "BINDER_CTL_ADD", _IOC_READ|_IOC_WRITE, 0x6201, 0x108 },
{ "linux/apm_bios.h", "APM_IOC_STANDBY", _IOC_NONE, 0x4101, 0x00 },
{ "linux/apm_bios.h", "APM_IOC_SUSPEND", _IOC_NONE, 0x4102, 0x00 },
{ "linux/arcfb.h", "FBIO_GETCONTROL2", _IOC_READ, 0x4689, 0x04 },
{ "linux/arcfb.h", "FBIO_WAITEVENT", _IOC_NONE, 0x4688, 0x00 },
{ "linux/aspeed-lpc-ctrl.h", "ASPEED_LPC_CTRL_IOCTL_GET_SIZE", _IOC_READ|_IOC_WRITE, 0xb200, 0x10 },
{ "linux/aspeed-lpc-ctrl.h", "ASPEED_LPC_CTRL_IOCTL_MAP", _IOC_WRITE, 0xb201, 0x10 },
{ "linux/aspeed-p2a-ctrl.h", "ASPEED_P2A_CTRL_IOCTL_GET_MEMORY_CONFIG", _IOC_READ|_IOC_WRITE, 0xb301, 0x10 },
{ "linux/aspeed-p2a-ctrl.h", "ASPEED_P2A_CTRL_IOCTL_SET_WINDOW", _IOC_WRITE, 0xb300, 0x10 },
{ "linux/atm_eni.h", "ENI_MEMDUMP", _IOC_WRITE, 0x6160, 0x0c },
{ "linux/atm_eni.h", "ENI_SETMULT", _IOC_WRITE, 0x6167, 0x0c },
{ "linux/atm_he.h", "HE_GET_REG", _IOC_WRITE, 0x6160, 0x0c },
{ "linux/atm_idt77105.h", "IDT77105_GETSTAT", _IOC_WRITE, 0x6132, 0x0c },
{ "linux/atm_idt77105.h", "IDT77105_GETSTATZ", _IOC_WRITE, 0x6133, 0x0c },
{ "linux/atm_nicstar.h", "NS_ADJBUFLEV", _IOC_NONE, 0x6163, 0x00 },
{ "linux/atm_nicstar.h", "NS_GETPSTAT", _IOC_READ|_IOC_WRITE, 0x6161, 0x0c },
{ "linux/atm_nicstar.h", "NS_SETBUFLEV", _IOC_WRITE, 0x6162, 0x0c },
{ "linux/atm_tcp.h", "ATMTCP_CREATE", _IOC_NONE, 0x618e, 0x00 },
{ "linux/atm_tcp.h", "ATMTCP_REMOVE", _IOC_NONE, 0x618f, 0x00 },
{ "linux/atm_tcp.h", "SIOCSIFATMTCP", _IOC_NONE, 0x6180, 0x00 },
{ "linux/atm_zatm.h", "ZATM_GETPOOL", _IOC_WRITE, 0x6161, 0x0c },
{ "linux/atm_zatm.h", "ZATM_GETPOOLZ", _IOC_WRITE, 0x6162, 0x0c },
{ "linux/atm_zatm.h", "ZATM_SETPOOL", _IOC_WRITE, 0x6163, 0x0c },
{ "linux/atmarp.h", "ATMARPD_CTRL", _IOC_NONE, 0x61e1, 0x00 },
{ "linux/atmarp.h", "ATMARP_ENCAP", _IOC_NONE, 0x61e5, 0x00 },
{ "linux/atmarp.h", "ATMARP_MKIP", _IOC_NONE, 0x61e2, 0x00 },
{ "linux/atmarp.h", "ATMARP_SETENTRY", _IOC_NONE, 0x61e3, 0x00 },
{ "linux/atmbr2684.h", "BR2684_SETFILT", _IOC_WRITE, 0x6190, 0x1c },
{ "linux/atmclip.h", "SIOCMKCLIP", _IOC_NONE, 0x61e0, 0x00 },
{ "linux/atmdev.h", "ATM_ADDADDR", _IOC_WRITE, 0x6188, 0x0c },
{ "linux/atmdev.h", "ATM_ADDLECSADDR", _IOC_WRITE, 0x618e, 0x0c },
{ "linux/atmdev.h", "ATM_ADDPARTY", _IOC_WRITE, 0x61f4, 0x08 },
{ "linux/atmdev.h", "ATM_DELADDR", _IOC_WRITE, 0x6189, 0x0c },
{ "linux/atmdev.h", "ATM_DELLECSADDR", _IOC_WRITE, 0x618f, 0x0c },
{ "linux/atmdev.h", "ATM_DROPPARTY", _IOC_WRITE, 0x61f5, 0x04 },
{ "linux/atmdev.h", "ATM_GETADDR", _IOC_WRITE, 0x6186, 0x0c },
{ "linux/atmdev.h", "ATM_GETCIRANGE", _IOC_WRITE, 0x618a, 0x0c },
{ "linux/atmdev.h", "ATM_GETESI", _IOC_WRITE, 0x6185, 0x0c },
{ "linux/atmdev.h", "ATM_GETLECSADDR", _IOC_WRITE, 0x6190, 0x0c },
{ "linux/atmdev.h", "ATM_GETLINKRATE", _IOC_WRITE, 0x6181, 0x0c },
{ "linux/atmdev.h", "ATM_GETLOOP", _IOC_WRITE, 0x6152, 0x0c },
{ "linux/atmdev.h", "ATM_GETNAMES", _IOC_WRITE, 0x6183, 0x08 },
{ "linux/atmdev.h", "ATM_GETSTAT", _IOC_WRITE, 0x6150, 0x0c },
{ "linux/atmdev.h", "ATM_GETSTATZ", _IOC_WRITE, 0x6151, 0x0c },
{ "linux/atmdev.h", "ATM_GETTYPE", _IOC_WRITE, 0x6184, 0x0c },
{ "linux/atmdev.h", "ATM_NEWBACKENDIF", _IOC_WRITE, 0x61f3, 0x02 },
{ "linux/atmdev.h", "ATM_QUERYLOOP", _IOC_WRITE, 0x6154, 0x0c },
{ "linux/atmdev.h", "ATM_RSTADDR", _IOC_WRITE, 0x6187, 0x0c },
{ "linux/atmdev.h", "ATM_SETBACKEND", _IOC_WRITE, 0x61f2, 0x02 },
{ "linux/atmdev.h", "ATM_SETCIRANGE", _IOC_WRITE, 0x618b, 0x0c },
{ "linux/atmdev.h", "ATM_SETESI", _IOC_WRITE, 0x618c, 0x0c },
{ "linux/atmdev.h", "ATM_SETESIF", _IOC_WRITE, 0x618d, 0x0c },
{ "linux/atmdev.h", "ATM_SETLOOP", _IOC_WRITE, 0x6153, 0x0c },
{ "linux/atmdev.h", "ATM_SETSC", _IOC_WRITE, 0x61f1, 0x04 },
{ "linux/atmlec.h", "ATMLEC_CTRL", _IOC_NONE, 0x61d0, 0x00 },
{ "linux/atmlec.h", "ATMLEC_DATA", _IOC_NONE, 0x61d1, 0x00 },
{ "linux/atmlec.h", "ATMLEC_MCAST", _IOC_NONE, 0x61d2, 0x00 },
{ "linux/atmmpc.h", "ATMMPC_CTRL", _IOC_NONE, 0x61d8, 0x00 },
{ "linux/atmmpc.h", "ATMMPC_DATA", _IOC_NONE, 0x61d9, 0x00 },
{ "linux/atmsvc.h", "ATMSIGD_CTRL", _IOC_NONE, 0x61f0, 0x00 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_ASKUMOUNT", _IOC_READ|_IOC_WRITE, 0x937d, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_CATATONIC", _IOC_READ|_IOC_WRITE, 0x9379, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_CLOSEMOUNT", _IOC_READ|_IOC_WRITE, 0x9375, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_EXPIRE", _IOC_READ|_IOC_WRITE, 0x937c, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_FAIL", _IOC_READ|_IOC_WRITE, 0x9377, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_ISMOUNTPOINT", _IOC_READ|_IOC_WRITE, 0x937e, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_OPENMOUNT", _IOC_READ|_IOC_WRITE, 0x9374, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_PROTOSUBVER", _IOC_READ|_IOC_WRITE, 0x9373, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_PROTOVER", _IOC_READ|_IOC_WRITE, 0x9372, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_READY", _IOC_READ|_IOC_WRITE, 0x9376, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_REQUESTER", _IOC_READ|_IOC_WRITE, 0x937b, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_SETPIPEFD", _IOC_READ|_IOC_WRITE, 0x9378, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_TIMEOUT", _IOC_READ|_IOC_WRITE, 0x937a, 0x18 },
{ "linux/auto_dev-ioctl.h", "AUTOFS_DEV_IOCTL_VERSION", _IOC_READ|_IOC_WRITE, 0x9371, 0x18 },
{ "linux/auto_fs.h", "AUTOFS_IOC_ASKUMOUNT", _IOC_READ, 0x9370, 0x04 },
{ "linux/auto_fs.h", "AUTOFS_IOC_CATATONIC", _IOC_NONE, 0x9362, 0x00 },
{ "linux/auto_fs.h", "AUTOFS_IOC_EXPIRE", _IOC_READ, 0x9365, 0x10c },
{ "linux/auto_fs.h", "AUTOFS_IOC_EXPIRE_MULTI", _IOC_WRITE, 0x9366, 0x04 },
{ "linux/auto_fs.h", "AUTOFS_IOC_FAIL", _IOC_NONE, 0x9361, 0x00 },
{ "linux/auto_fs.h", "AUTOFS_IOC_PROTOSUBVER", _IOC_READ, 0x9367, 0x04 },
{ "linux/auto_fs.h", "AUTOFS_IOC_PROTOVER", _IOC_READ, 0x9363, 0x04 },
{ "linux/auto_fs.h", "AUTOFS_IOC_READY", _IOC_NONE, 0x9360, 0x00 },
{ "linux/auto_fs.h", "AUTOFS_IOC_SETTIMEOUT32", _IOC_READ|_IOC_WRITE, 0x9364, 0x04 },
{ "linux/blkdev.h", "BLOCK_URING_CMD_DISCARD", _IOC_NONE, 0x1200, 0x00 },
{ "linux/blkpg.h", "BLKPG", _IOC_NONE, 0x1269, 0x00 },
{ "linux/blkzoned.h", "BLKCLOSEZONE", _IOC_WRITE, 0x1287, 0x10 },
{ "linux/blkzoned.h", "BLKFINISHZONE", _IOC_WRITE, 0x1288, 0x10 },
{ "linux/blkzoned.h", "BLKGETNRZONES", _IOC_READ, 0x1285, 0x04 },
{ "linux/blkzoned.h", "BLKGETZONESZ", _IOC_READ, 0x1284, 0x04 },
{ "linux/blkzoned.h", "BLKOPENZONE", _IOC_WRITE, 0x1286, 0x10 },
{ "linux/blkzoned.h", "BLKREPORTZONE", _IOC_READ|_IOC_WRITE, 0x1282, 0x10 },
{ "linux/blkzoned.h", "BLKRESETZONE", _IOC_WRITE, 0x1283, 0x10 },
{ "linux/bt-bmc.h", "BT_BMC_IOCTL_SMS_ATN", _IOC_NONE, 0xb100, 0x00 },
{ "linux/btrfs.h", "BTRFS_IOC_ADD_DEV", _IOC_WRITE, 0x940a, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_BALANCE", _IOC_WRITE, 0x940c, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_BALANCE_CTL", _IOC_WRITE, 0x9421, 0x04 },
{ "linux/btrfs.h", "BTRFS_IOC_BALANCE_PROGRESS", _IOC_READ, 0x9422, 0x400 },
{ "linux/btrfs.h", "BTRFS_IOC_BALANCE_V2", _IOC_READ|_IOC_WRITE, 0x9420, 0x400 },
{ "linux/btrfs.h", "BTRFS_IOC_CLONE", _IOC_WRITE, 0x9409, 0x04 },
{ "linux/btrfs.h", "BTRFS_IOC_CLONE_RANGE", _IOC_WRITE, 0x940d, 0x20 },
{ "linux/btrfs.h", "BTRFS_IOC_DEFAULT_SUBVOL", _IOC_WRITE, 0x9413, 0x08 },
{ "linux/btrfs.h", "BTRFS_IOC_DEFRAG", _IOC_WRITE, 0x9402, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_DEFRAG_RANGE", _IOC_WRITE, 0x9410, 0x30 },
{ "linux/btrfs.h", "BTRFS_IOC_DEVICES_READY", _IOC_READ, 0x9427, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_DEV_INFO", _IOC_READ|_IOC_WRITE, 0x941e, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_DEV_REPLACE", _IOC_READ|_IOC_WRITE, 0x9435, 0xa22 },
{ "linux/btrfs.h", "BTRFS_IOC_ENCODED_READ", _IOC_READ, 0x9440, 0x78 },
{ "linux/btrfs.h", "BTRFS_IOC_ENCODED_WRITE", _IOC_WRITE, 0x9440, 0x78 },
{ "linux/btrfs.h", "BTRFS_IOC_FILE_EXTENT_SAME", _IOC_READ|_IOC_WRITE, 0x9436, 0x18 },
{ "linux/btrfs.h", "BTRFS_IOC_FORGET_DEV", _IOC_WRITE, 0x9405, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_FS_INFO", _IOC_READ, 0x941f, 0x400 },
{ "linux/btrfs.h", "BTRFS_IOC_GET_DEV_STATS", _IOC_READ|_IOC_WRITE, 0x9434, 0x408 },
{ "linux/btrfs.h", "BTRFS_IOC_GET_FEATURES", _IOC_READ, 0x9439, 0x18 },
{ "linux/btrfs.h", "BTRFS_IOC_GET_SUBVOL_INFO", _IOC_READ, 0x943c, 0x1e8 },
{ "linux/btrfs.h", "BTRFS_IOC_GET_SUBVOL_ROOTREF", _IOC_READ|_IOC_WRITE, 0x943d, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_GET_SUPPORTED_FEATURES", _IOC_READ, 0x9439, 0x48 },
{ "linux/btrfs.h", "BTRFS_IOC_INO_LOOKUP", _IOC_READ|_IOC_WRITE, 0x9412, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_INO_LOOKUP_USER", _IOC_READ|_IOC_WRITE, 0x943e, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_INO_PATHS", _IOC_READ|_IOC_WRITE, 0x9423, 0x38 },
{ "linux/btrfs.h", "BTRFS_IOC_LOGICAL_INO", _IOC_READ|_IOC_WRITE, 0x9424, 0x38 },
{ "linux/btrfs.h", "BTRFS_IOC_LOGICAL_INO_V2", _IOC_READ|_IOC_WRITE, 0x943b, 0x38 },
{ "linux/btrfs.h", "BTRFS_IOC_QGROUP_ASSIGN", _IOC_WRITE, 0x9429, 0x18 },
{ "linux/btrfs.h", "BTRFS_IOC_QGROUP_CREATE", _IOC_WRITE, 0x942a, 0x10 },
{ "linux/btrfs.h", "BTRFS_IOC_QGROUP_LIMIT", _IOC_READ, 0x942b, 0x30 },
{ "linux/btrfs.h", "BTRFS_IOC_QUOTA_CTL", _IOC_READ|_IOC_WRITE, 0x9428, 0x10 },
{ "linux/btrfs.h", "BTRFS_IOC_QUOTA_RESCAN", _IOC_WRITE, 0x942c, 0x40 },
{ "linux/btrfs.h", "BTRFS_IOC_QUOTA_RESCAN_STATUS", _IOC_READ, 0x942d, 0x40 },
{ "linux/btrfs.h", "BTRFS_IOC_QUOTA_RESCAN_WAIT", _IOC_NONE, 0x942e, 0x00 },
{ "linux/btrfs.h", "BTRFS_IOC_RESIZE", _IOC_WRITE, 0x9403, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_RM_DEV", _IOC_WRITE, 0x940b, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_RM_DEV_V2", _IOC_WRITE, 0x943a, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_SCAN_DEV", _IOC_WRITE, 0x9404, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_SCRUB", _IOC_READ|_IOC_WRITE, 0x941b, 0x400 },
{ "linux/btrfs.h", "BTRFS_IOC_SCRUB_CANCEL", _IOC_NONE, 0x941c, 0x00 },
{ "linux/btrfs.h", "BTRFS_IOC_SCRUB_PROGRESS", _IOC_READ|_IOC_WRITE, 0x941d, 0x400 },
{ "linux/btrfs.h", "BTRFS_IOC_SEND", _IOC_WRITE, 0x9426, 0x44 },
{ "linux/btrfs.h", "BTRFS_IOC_SET_FEATURES", _IOC_WRITE, 0x9439, 0x30 },
{ "linux/btrfs.h", "BTRFS_IOC_SET_RECEIVED_SUBVOL", _IOC_READ|_IOC_WRITE, 0x9425, 0xc0 },
{ "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE", _IOC_WRITE, 0x9401, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_SNAP_CREATE_V2", _IOC_WRITE, 0x9417, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY", _IOC_WRITE, 0x940f, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_SNAP_DESTROY_V2", _IOC_WRITE, 0x943f, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_SPACE_INFO", _IOC_READ|_IOC_WRITE, 0x9414, 0x10 },
{ "linux/btrfs.h", "BTRFS_IOC_START_SYNC", _IOC_READ, 0x9418, 0x08 },
{ "linux/btrfs.h", "BTRFS_IOC_SUBVOL_CREATE", _IOC_WRITE, 0x940e, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_SUBVOL_CREATE_V2", _IOC_WRITE, 0x9418, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_SUBVOL_GETFLAGS", _IOC_READ, 0x9419, 0x08 },
{ "linux/btrfs.h", "BTRFS_IOC_SUBVOL_SETFLAGS", _IOC_WRITE, 0x941a, 0x08 },
{ "linux/btrfs.h", "BTRFS_IOC_SUBVOL_SYNC_WAIT", _IOC_WRITE, 0x9441, 0x10 },
{ "linux/btrfs.h", "BTRFS_IOC_SYNC", _IOC_NONE, 0x9408, 0x00 },
{ "linux/btrfs.h", "BTRFS_IOC_TRANS_END", _IOC_NONE, 0x9407, 0x00 },
{ "linux/btrfs.h", "BTRFS_IOC_TRANS_START", _IOC_NONE, 0x9406, 0x00 },
{ "linux/btrfs.h", "BTRFS_IOC_TREE_SEARCH", _IOC_READ|_IOC_WRITE, 0x9411, 0x1000 },
{ "linux/btrfs.h", "BTRFS_IOC_TREE_SEARCH_V2", _IOC_READ|_IOC_WRITE, 0x9411, 0x70 },
{ "linux/btrfs.h", "BTRFS_IOC_WAIT_SYNC", _IOC_WRITE, 0x9416, 0x08 },
{ "linux/cachefiles.h", "CACHEFILES_IOC_READ_COMPLETE", _IOC_WRITE, 0x9801, 0x04 },
{ "linux/capi.h", "CAPI_CLR_FLAGS", _IOC_READ, 0x4325, 0x04 },
{ "linux/capi.h", "CAPI_GET_ERRCODE", _IOC_READ, 0x4321, 0x02 },
{ "linux/capi.h", "CAPI_GET_FLAGS", _IOC_READ, 0x4323, 0x04 },
{ "linux/capi.h", "CAPI_GET_MANUFACTURER", _IOC_READ|_IOC_WRITE, 0x4306, 0x04 },
{ "linux/capi.h", "CAPI_GET_PROFILE", _IOC_READ|_IOC_WRITE, 0x4309, 0x40 },
{ "linux/capi.h", "CAPI_GET_SERIAL", _IOC_READ|_IOC_WRITE, 0x4308, 0x04 },
{ "linux/capi.h", "CAPI_GET_VERSION", _IOC_READ|_IOC_WRITE, 0x4307, 0x10 },
{ "linux/capi.h", "CAPI_INSTALLED", _IOC_READ, 0x4322, 0x02 },
{ "linux/capi.h", "CAPI_MANUFACTURER_CMD", _IOC_READ|_IOC_WRITE, 0x4320, 0x08 },
{ "linux/capi.h", "CAPI_NCCI_GETUNIT", _IOC_READ, 0x4327, 0x04 },
{ "linux/capi.h", "CAPI_NCCI_OPENCOUNT", _IOC_READ, 0x4326, 0x04 },
{ "linux/capi.h", "CAPI_REGISTER", _IOC_WRITE, 0x4301, 0x0c },
{ "linux/capi.h", "CAPI_SET_FLAGS", _IOC_READ, 0x4324, 0x04 },
{ "linux/cciss_ioctl.h", "CCISS_BIG_PASSTHRU", _IOC_READ|_IOC_WRITE, 0x4212, 0x58 },
{ "linux/cciss_ioctl.h", "CCISS_DEREGDISK", _IOC_NONE, 0x420c, 0x00 },
{ "linux/cciss_ioctl.h", "CCISS_GETBUSTYPES", _IOC_READ, 0x4207, 0x04 },
{ "linux/cciss_ioctl.h", "CCISS_GETDRIVVER", _IOC_READ, 0x4209, 0x04 },
{ "linux/cciss_ioctl.h", "CCISS_GETFIRMVER", _IOC_READ, 0x4208, 0x04 },
{ "linux/cciss_ioctl.h", "CCISS_GETHEARTBEAT", _IOC_READ, 0x4206, 0x04 },
{ "linux/cciss_ioctl.h", "CCISS_GETINTINFO", _IOC_READ, 0x4202, 0x08 },
{ "linux/cciss_ioctl.h", "CCISS_GETLUNINFO", _IOC_READ, 0x4211, 0x0c },
{ "linux/cciss_ioctl.h", "CCISS_GETNODENAME", _IOC_READ, 0x4204, 0x10 },
{ "linux/cciss_ioctl.h", "CCISS_GETPCIINFO", _IOC_READ, 0x4201, 0x08 },
{ "linux/cciss_ioctl.h", "CCISS_PASSTHRU", _IOC_READ|_IOC_WRITE, 0x420b, 0x52 },
{ "linux/cciss_ioctl.h", "CCISS_REGNEWD", _IOC_NONE, 0x420e, 0x00 },
{ "linux/cciss_ioctl.h", "CCISS_REGNEWDISK", _IOC_WRITE, 0x420d, 0x04 },
{ "linux/cciss_ioctl.h", "CCISS_RESCANDISK", _IOC_NONE, 0x4210, 0x00 },
{ "linux/cciss_ioctl.h", "CCISS_REVALIDVOLS", _IOC_NONE, 0x420a, 0x00 },
{ "linux/cciss_ioctl.h", "CCISS_SETINTINFO", _IOC_WRITE, 0x4203, 0x08 },
{ "linux/cciss_ioctl.h", "CCISS_SETNODENAME", _IOC_WRITE, 0x4205, 0x10 },
{ "linux/cdrom.h", "CDROMAUDIOBUFSIZ", 0, 0x5382, 0 },
{ "linux/cdrom.h", "CDROMCLOSETRAY", 0, 0x5319, 0 },
{ "linux/cdrom.h", "CDROMEJECT", 0, 0x5309, 0 },
{ "linux/cdrom.h", "CDROMEJECT_SW", 0, 0x530f, 0 },
{ "linux/cdrom.h", "CDROMGETSPINDOWN", 0, 0x531d, 0 },
{ "linux/cdrom.h", "CDROMMULTISESSION", 0, 0x5310, 0 },
{ "linux/cdrom.h", "CDROMPAUSE", 0, 0x5301, 0 },
{ "linux/cdrom.h", "CDROMPLAYBLK", 0, 0x5317, 0 },
{ "linux/cdrom.h", "CDROMPLAYMSF", 0, 0x5303, 0 },
{ "linux/cdrom.h", "CDROMPLAYTRKIND", 0, 0x5304, 0 },
{ "linux/cdrom.h", "CDROMREADALL", 0, 0x5318, 0 },
{ "linux/cdrom.h", "CDROMREADAUDIO", 0, 0x530e, 0 },
{ "linux/cdrom.h", "CDROMREADCOOKED", 0, 0x5315, 0 },
{ "linux/cdrom.h", "CDROMREADMODE1", 0, 0x530d, 0 },
{ "linux/cdrom.h", "CDROMREADMODE2", 0, 0x530c, 0 },
{ "linux/cdrom.h", "CDROMREADRAW", 0, 0x5314, 0 },
{ "linux/cdrom.h", "CDROMREADTOCENTRY", 0, 0x5306, 0 },
{ "linux/cdrom.h", "CDROMREADTOCHDR", 0, 0x5305, 0 },
{ "linux/cdrom.h", "CDROMRESET", 0, 0x5312, 0 },
{ "linux/cdrom.h", "CDROMRESUME", 0, 0x5302, 0 },
{ "linux/cdrom.h", "CDROMSEEK", 0, 0x5316, 0 },
{ "linux/cdrom.h", "CDROMSETSPINDOWN", 0, 0x531e, 0 },
{ "linux/cdrom.h", "CDROMSTART", 0, 0x5308, 0 },
{ "linux/cdrom.h", "CDROMSTOP", 0, 0x5307, 0 },
{ "linux/cdrom.h", "CDROMSUBCHNL", 0, 0x530b, 0 },
{ "linux/cdrom.h", "CDROMVOLCTRL", 0, 0x530a, 0 },
{ "linux/cdrom.h", "CDROMVOLREAD", 0, 0x5313, 0 },
{ "linux/cdrom.h", "CDROM_CHANGER_NSLOTS", 0, 0x5328, 0 },
{ "linux/cdrom.h", "CDROM_CLEAR_OPTIONS", 0, 0x5321, 0 },
{ "linux/cdrom.h", "CDROM_DEBUG", 0, 0x5330, 0 },
{ "linux/cdrom.h", "CDROM_DISC_STATUS", 0, 0x5327, 0 },
{ "linux/cdrom.h", "CDROM_DRIVE_STATUS", 0, 0x5326, 0 },
{ "linux/cdrom.h", "CDROM_GET_CAPABILITY", 0, 0x5331, 0 },
{ "linux/cdrom.h", "CDROM_GET_MCN", 0, 0x5311, 0 },
{ "linux/cdrom.h", "CDROM_LAST_WRITTEN", 0, 0x5395, 0 },
{ "linux/cdrom.h", "CDROM_LOCKDOOR", 0, 0x5329, 0 },
{ "linux/cdrom.h", "CDROM_MEDIA_CHANGED", 0, 0x5325, 0 },
{ "linux/cdrom.h", "CDROM_NEXT_WRITABLE", 0, 0x5394, 0 },
{ "linux/cdrom.h", "CDROM_SELECT_DISC", 0, 0x5323, 0 },
{ "linux/cdrom.h", "CDROM_SELECT_SPEED", 0, 0x5322, 0 },
{ "linux/cdrom.h", "CDROM_SEND_PACKET", 0, 0x5393, 0 },
{ "linux/cdrom.h", "CDROM_SET_OPTIONS", 0, 0x5320, 0 },
{ "linux/cdrom.h", "CDROM_TIMED_MEDIA_CHANGE", 0, 0x5396, 0 },
{ "linux/cdrom.h", "DVD_AUTH", 0, 0x5392, 0 },
{ "linux/cdrom.h", "DVD_READ_STRUCT", 0, 0x5390, 0 },
{ "linux/cdrom.h", "DVD_WRITE_STRUCT", 0, 0x5391, 0 },
{ "linux/cec.h", "CEC_ADAP_G_CAPS", _IOC_READ|_IOC_WRITE, 0x6100, 0x4c },
{ "linux/cec.h", "CEC_ADAP_G_CONNECTOR_INFO", _IOC_READ, 0x610a, 0x44 },
{ "linux/cec.h", "CEC_ADAP_G_LOG_ADDRS", _IOC_READ, 0x6103, 0x5c },
{ "linux/cec.h", "CEC_ADAP_G_PHYS_ADDR", _IOC_READ, 0x6101, 0x02 },
{ "linux/cec.h", "CEC_ADAP_S_LOG_ADDRS", _IOC_READ|_IOC_WRITE, 0x6104, 0x5c },
{ "linux/cec.h", "CEC_ADAP_S_PHYS_ADDR", _IOC_WRITE, 0x6102, 0x02 },
{ "linux/cec.h", "CEC_DQEVENT", _IOC_READ|_IOC_WRITE, 0x6107, 0x50 },
{ "linux/cec.h", "CEC_G_MODE", _IOC_READ, 0x6108, 0x04 },
{ "linux/cec.h", "CEC_RECEIVE", _IOC_READ|_IOC_WRITE, 0x6106, 0x38 },
{ "linux/cec.h", "CEC_S_MODE", _IOC_WRITE, 0x6109, 0x04 },
{ "linux/cec.h", "CEC_TRANSMIT", _IOC_READ|_IOC_WRITE, 0x6105, 0x38 },
{ "linux/chio.h", "CHIOEXCHANGE", _IOC_WRITE, 0x6302, 0x1c },
{ "linux/chio.h", "CHIOGELEM", _IOC_WRITE, 0x6310, 0x6c },
{ "linux/chio.h", "CHIOGPARAMS", _IOC_READ, 0x6306, 0x14 },
{ "linux/chio.h", "CHIOGPICKER", _IOC_READ, 0x6304, 0x04 },
{ "linux/chio.h", "CHIOGSTATUS", _IOC_WRITE, 0x6308, 0x08 },
{ "linux/chio.h", "CHIOGVPARAMS", _IOC_READ, 0x6313, 0x70 },
{ "linux/chio.h", "CHIOINITELEM", _IOC_NONE, 0x6311, 0x00 },
{ "linux/chio.h", "CHIOMOVE", _IOC_WRITE, 0x6301, 0x14 },
{ "linux/chio.h", "CHIOPOSITION", _IOC_WRITE, 0x6303, 0x0c },
{ "linux/chio.h", "CHIOSPICKER", _IOC_WRITE, 0x6305, 0x04 },
{ "linux/chio.h", "CHIOSVOLTAG", _IOC_WRITE, 0x6312, 0x30 },
{ "linux/coda.h", "CIOC_KERNEL_VERSION", _IOC_READ|_IOC_WRITE, 0x630a, 0x04 },
{ "linux/comedi.h", "COMEDI_BUFCONFIG", _IOC_READ, 0x640d, 0x20 },
{ "linux/comedi.h", "COMEDI_BUFINFO", _IOC_READ|_IOC_WRITE, 0x640e, 0x2c },
{ "linux/comedi.h", "COMEDI_CANCEL", _IOC_NONE, 0x6407, 0x00 },
{ "linux/comedi.h", "COMEDI_CHANINFO", _IOC_READ, 0x6403, 0x20 },
{ "linux/comedi.h", "COMEDI_CMD", _IOC_READ, 0x6409, 0x40 },
{ "linux/comedi.h", "COMEDI_CMDTEST", _IOC_READ, 0x640a, 0x40 },
{ "linux/comedi.h", "COMEDI_DEVCONFIG", _IOC_WRITE, 0x6400, 0x94 },
{ "linux/comedi.h", "COMEDI_DEVINFO", _IOC_READ, 0x6401, 0xb0 },
{ "linux/comedi.h", "COMEDI_INSN", _IOC_READ, 0x640c, 0x20 },
{ "linux/comedi.h", "COMEDI_INSNLIST", _IOC_READ, 0x640b, 0x08 },
{ "linux/comedi.h", "COMEDI_LOCK", _IOC_NONE, 0x6405, 0x00 },
{ "linux/comedi.h", "COMEDI_POLL", _IOC_NONE, 0x640f, 0x00 },
{ "linux/comedi.h", "COMEDI_RANGEINFO", _IOC_READ, 0x6408, 0x08 },
{ "linux/comedi.h", "COMEDI_SETRSUBD", _IOC_NONE, 0x6410, 0x00 },
{ "linux/comedi.h", "COMEDI_SETWSUBD", _IOC_NONE, 0x6411, 0x00 },
{ "linux/comedi.h", "COMEDI_SUBDINFO", _IOC_READ, 0x6402, 0x48 },
{ "linux/comedi.h", "COMEDI_UNLOCK", _IOC_NONE, 0x6406, 0x00 },
{ "linux/counter.h", "COUNTER_ADD_WATCH_IOCTL", _IOC_WRITE, 0x3e00, 0x06 },
{ "linux/counter.h", "COUNTER_DISABLE_EVENTS_IOCTL", _IOC_NONE, 0x3e02, 0x00 },
{ "linux/counter.h", "COUNTER_ENABLE_EVENTS_IOCTL", _IOC_NONE, 0x3e01, 0x00 },
{ "linux/cxl_mem.h", "CXL_MEM_QUERY_COMMANDS", _IOC_READ, 0xce01, 0x08 },
{ "linux/cxl_mem.h", "CXL_MEM_SEND_COMMAND", _IOC_READ|_IOC_WRITE, 0xce02, 0x30 },
{ "linux/dm-ioctl.h", "DM_DEV_ARM_POLL", _IOC_READ|_IOC_WRITE, 0xfd10, 0x138 },
{ "linux/dm-ioctl.h", "DM_DEV_CREATE", _IOC_READ|_IOC_WRITE, 0xfd03, 0x138 },
{ "linux/dm-ioctl.h", "DM_DEV_REMOVE", _IOC_READ|_IOC_WRITE, 0xfd04, 0x138 },
{ "linux/dm-ioctl.h", "DM_DEV_RENAME", _IOC_READ|_IOC_WRITE, 0xfd05, 0x138 },
{ "linux/dm-ioctl.h", "DM_DEV_SET_GEOMETRY", _IOC_READ|_IOC_WRITE, 0xfd0f, 0x138 },
{ "linux/dm-ioctl.h", "DM_DEV_STATUS", _IOC_READ|_IOC_WRITE, 0xfd07, 0x138 },
{ "linux/dm-ioctl.h", "DM_DEV_SUSPEND", _IOC_READ|_IOC_WRITE, 0xfd06, 0x138 },
{ "linux/dm-ioctl.h", "DM_DEV_WAIT", _IOC_READ|_IOC_WRITE, 0xfd08, 0x138 },
{ "linux/dm-ioctl.h", "DM_GET_TARGET_VERSION", _IOC_READ|_IOC_WRITE, 0xfd11, 0x138 },
{ "linux/dm-ioctl.h", "DM_LIST_DEVICES", _IOC_READ|_IOC_WRITE, 0xfd02, 0x138 },
{ "linux/dm-ioctl.h", "DM_LIST_VERSIONS", _IOC_READ|_IOC_WRITE, 0xfd0d, 0x138 },
{ "linux/dm-ioctl.h", "DM_REMOVE_ALL", _IOC_READ|_IOC_WRITE, 0xfd01, 0x138 },
{ "linux/dm-ioctl.h", "DM_TABLE_CLEAR", _IOC_READ|_IOC_WRITE, 0xfd0a, 0x138 },
{ "linux/dm-ioctl.h", "DM_TABLE_DEPS", _IOC_READ|_IOC_WRITE, 0xfd0b, 0x138 },
{ "linux/dm-ioctl.h", "DM_TABLE_LOAD", _IOC_READ|_IOC_WRITE, 0xfd09, 0x138 },
{ "linux/dm-ioctl.h", "DM_TABLE_STATUS", _IOC_READ|_IOC_WRITE, 0xfd0c, 0x138 },
{ "linux/dm-ioctl.h", "DM_TARGET_MSG", _IOC_READ|_IOC_WRITE, 0xfd0e, 0x138 },
{ "linux/dm-ioctl.h", "DM_VERSION", _IOC_READ|_IOC_WRITE, 0xfd00, 0x138 },
{ "linux/dma-buf.h", "DMA_BUF_IOCTL_EXPORT_SYNC_FILE", _IOC_READ|_IOC_WRITE, 0x6202, 0x08 },
{ "linux/dma-buf.h", "DMA_BUF_IOCTL_IMPORT_SYNC_FILE", _IOC_WRITE, 0x6203, 0x08 },
{ "linux/dma-buf.h", "DMA_BUF_IOCTL_SYNC", _IOC_WRITE, 0x6200, 0x08 },
{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_A", _IOC_WRITE, 0x6201, 0x04 },
{ "linux/dma-buf.h", "DMA_BUF_SET_NAME_B", _IOC_WRITE, 0x6201, 0x08 },
{ "linux/dma-heap.h", "DMA_HEAP_IOCTL_ALLOC", _IOC_READ|_IOC_WRITE, 0x4800, 0x18 },
{ "linux/dvb/audio.h", "AUDIO_BILINGUAL_CHANNEL_SELECT", _IOC_NONE, 0x6f14, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_CHANNEL_SELECT", _IOC_NONE, 0x6f09, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_CLEAR_BUFFER", _IOC_NONE, 0x6f0c, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_CONTINUE", _IOC_NONE, 0x6f04, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_GET_CAPABILITIES", _IOC_READ, 0x6f0b, 0x04 },
{ "linux/dvb/audio.h", "AUDIO_GET_STATUS", _IOC_READ, 0x6f0a, 0x20 },
{ "linux/dvb/audio.h", "AUDIO_PAUSE", _IOC_NONE, 0x6f03, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_PLAY", _IOC_NONE, 0x6f02, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_SELECT_SOURCE", _IOC_NONE, 0x6f05, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_SET_AV_SYNC", _IOC_NONE, 0x6f07, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_SET_BYPASS_MODE", _IOC_NONE, 0x6f08, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_SET_ID", _IOC_NONE, 0x6f0d, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_SET_MIXER", _IOC_WRITE, 0x6f0e, 0x08 },
{ "linux/dvb/audio.h", "AUDIO_SET_MUTE", _IOC_NONE, 0x6f06, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_SET_STREAMTYPE", _IOC_NONE, 0x6f0f, 0x00 },
{ "linux/dvb/audio.h", "AUDIO_STOP", _IOC_NONE, 0x6f01, 0x00 },
{ "linux/dvb/ca.h", "CA_GET_CAP", _IOC_READ, 0x6f81, 0x10 },
{ "linux/dvb/ca.h", "CA_GET_DESCR_INFO", _IOC_READ, 0x6f83, 0x08 },
{ "linux/dvb/ca.h", "CA_GET_MSG", _IOC_READ, 0x6f84, 0x10c },
{ "linux/dvb/ca.h", "CA_GET_SLOT_INFO", _IOC_READ, 0x6f82, 0x0c },
{ "linux/dvb/ca.h", "CA_RESET", _IOC_NONE, 0x6f80, 0x00 },
{ "linux/dvb/ca.h", "CA_SEND_MSG", _IOC_WRITE, 0x6f85, 0x10c },
{ "linux/dvb/ca.h", "CA_SET_DESCR", _IOC_WRITE, 0x6f86, 0x10 },
{ "linux/dvb/dmx.h", "DMX_ADD_PID", _IOC_WRITE, 0x6f33, 0x02 },
{ "linux/dvb/dmx.h", "DMX_DQBUF", _IOC_READ|_IOC_WRITE, 0x6f40, 0x18 },
{ "linux/dvb/dmx.h", "DMX_EXPBUF", _IOC_READ|_IOC_WRITE, 0x6f3e, 0x0c },
{ "linux/dvb/dmx.h", "DMX_GET_PES_PIDS", _IOC_READ, 0x6f2f, 0x0a },
{ "linux/dvb/dmx.h", "DMX_GET_STC", _IOC_READ|_IOC_WRITE, 0x6f32, 0x10 },
{ "linux/dvb/dmx.h", "DMX_QBUF", _IOC_READ|_IOC_WRITE, 0x6f3f, 0x18 },
{ "linux/dvb/dmx.h", "DMX_QUERYBUF", _IOC_READ|_IOC_WRITE, 0x6f3d, 0x18 },
{ "linux/dvb/dmx.h", "DMX_REMOVE_PID", _IOC_WRITE, 0x6f34, 0x02 },
{ "linux/dvb/dmx.h", "DMX_REQBUFS", _IOC_READ|_IOC_WRITE, 0x6f3c, 0x08 },
{ "linux/dvb/dmx.h", "DMX_SET_BUFFER_SIZE", _IOC_NONE, 0x6f2d, 0x00 },
{ "linux/dvb/dmx.h", "DMX_SET_FILTER", _IOC_WRITE, 0x6f2b, 0x3a },
{ "linux/dvb/dmx.h", "DMX_SET_PES_FILTER", _IOC_WRITE, 0x6f2c, 0x12 },
{ "linux/dvb/dmx.h", "DMX_START", _IOC_NONE, 0x6f29, 0x00 },
{ "linux/dvb/dmx.h", "DMX_STOP", _IOC_NONE, 0x6f2a, 0x00 },
{ "linux/dvb/frontend.h", "FE_DISEQC_RECV_SLAVE_REPLY", _IOC_READ, 0x6f40, 0x0a },
{ "linux/dvb/frontend.h", "FE_DISEQC_RESET_OVERLOAD", _IOC_NONE, 0x6f3e, 0x00 },
{ "linux/dvb/frontend.h", "FE_DISEQC_SEND_BURST", _IOC_NONE, 0x6f41, 0x00 },
{ "linux/dvb/frontend.h", "FE_DISEQC_SEND_MASTER_CMD", _IOC_WRITE, 0x6f3f, 0x07 },
{ "linux/dvb/frontend.h", "FE_DISHNETWORK_SEND_LEGACY_CMD", _IOC_NONE, 0x6f50, 0x00 },
{ "linux/dvb/frontend.h", "FE_ENABLE_HIGH_LNB_VOLTAGE", _IOC_NONE, 0x6f44, 0x00 },
{ "linux/dvb/frontend.h", "FE_GET_EVENT", _IOC_READ, 0x6f4e, 0x28 },
{ "linux/dvb/frontend.h", "FE_GET_FRONTEND", _IOC_READ, 0x6f4d, 0x24 },
{ "linux/dvb/frontend.h", "FE_GET_INFO", _IOC_READ, 0x6f3d, 0xa8 },
{ "linux/dvb/frontend.h", "FE_GET_PROPERTY", _IOC_READ, 0x6f53, 0x08 },
{ "linux/dvb/frontend.h", "FE_READ_BER", _IOC_READ, 0x6f46, 0x04 },
{ "linux/dvb/frontend.h", "FE_READ_SIGNAL_STRENGTH", _IOC_READ, 0x6f47, 0x02 },
{ "linux/dvb/frontend.h", "FE_READ_SNR", _IOC_READ, 0x6f48, 0x02 },
{ "linux/dvb/frontend.h", "FE_READ_STATUS", _IOC_READ, 0x6f45, 0x04 },
{ "linux/dvb/frontend.h", "FE_READ_UNCORRECTED_BLOCKS", _IOC_READ, 0x6f49, 0x04 },
{ "linux/dvb/frontend.h", "FE_SET_FRONTEND", _IOC_WRITE, 0x6f4c, 0x24 },
{ "linux/dvb/frontend.h", "FE_SET_FRONTEND_TUNE_MODE", _IOC_NONE, 0x6f51, 0x00 },
{ "linux/dvb/frontend.h", "FE_SET_PROPERTY", _IOC_WRITE, 0x6f52, 0x08 },
{ "linux/dvb/frontend.h", "FE_SET_TONE", _IOC_NONE, 0x6f42, 0x00 },
{ "linux/dvb/frontend.h", "FE_SET_VOLTAGE", _IOC_NONE, 0x6f43, 0x00 },
{ "linux/dvb/net.h", "NET_ADD_IF", _IOC_READ|_IOC_WRITE, 0x6f34, 0x06 },
{ "linux/dvb/net.h", "NET_GET_IF", _IOC_READ|_IOC_WRITE, 0x6f36, 0x06 },
{ "linux/dvb/net.h", "NET_REMOVE_IF", _IOC_NONE, 0x6f35, 0x00 },
{ "linux/dvb/osd.h", "OSD_GET_CAPABILITY", _IOC_READ, 0x6fa1, 0x08 },
{ "linux/dvb/osd.h", "OSD_SEND_CMD", _IOC_WRITE, 0x6fa0, 0x1c },
{ "linux/dvb/video.h", "VIDEO_CLEAR_BUFFER", _IOC_NONE, 0x6f22, 0x00 },
{ "linux/dvb/video.h", "VIDEO_COMMAND", _IOC_READ|_IOC_WRITE, 0x6f3b, 0x48 },
{ "linux/dvb/video.h", "VIDEO_CONTINUE", _IOC_NONE, 0x6f18, 0x00 },
{ "linux/dvb/video.h", "VIDEO_FAST_FORWARD", _IOC_NONE, 0x6f1f, 0x00 },
{ "linux/dvb/video.h", "VIDEO_FREEZE", _IOC_NONE, 0x6f17, 0x00 },
{ "linux/dvb/video.h", "VIDEO_GET_CAPABILITIES", _IOC_READ, 0x6f21, 0x04 },
{ "linux/dvb/video.h", "VIDEO_GET_EVENT", _IOC_READ, 0x6f1c, 0x14 },
{ "linux/dvb/video.h", "VIDEO_GET_FRAME_COUNT", _IOC_READ, 0x6f3a, 0x08 },
{ "linux/dvb/video.h", "VIDEO_GET_PTS", _IOC_READ, 0x6f39, 0x08 },
{ "linux/dvb/video.h", "VIDEO_GET_SIZE", _IOC_READ, 0x6f37, 0x0c },
{ "linux/dvb/video.h", "VIDEO_GET_STATUS", _IOC_READ, 0x6f1b, 0x14 },
{ "linux/dvb/video.h", "VIDEO_PLAY", _IOC_NONE, 0x6f16, 0x00 },
{ "linux/dvb/video.h", "VIDEO_SELECT_SOURCE", _IOC_NONE, 0x6f19, 0x00 },
{ "linux/dvb/video.h", "VIDEO_SET_BLANK", _IOC_NONE, 0x6f1a, 0x00 },
{ "linux/dvb/video.h", "VIDEO_SET_DISPLAY_FORMAT", _IOC_NONE, 0x6f1d, 0x00 },
{ "linux/dvb/video.h", "VIDEO_SET_FORMAT", _IOC_NONE, 0x6f25, 0x00 },
{ "linux/dvb/video.h", "VIDEO_SET_STREAMTYPE", _IOC_NONE, 0x6f24, 0x00 },
{ "linux/dvb/video.h", "VIDEO_SLOWMOTION", _IOC_NONE, 0x6f20, 0x00 },
{ "linux/dvb/video.h", "VIDEO_STILLPICTURE", _IOC_WRITE, 0x6f1e, 0x08 },
{ "linux/dvb/video.h", "VIDEO_STOP", _IOC_NONE, 0x6f15, 0x00 },
{ "linux/dvb/video.h", "VIDEO_TRY_COMMAND", _IOC_READ|_IOC_WRITE, 0x6f3c, 0x48 },
{ "linux/eventpoll.h", "EPIOCGPARAMS", _IOC_READ, 0x8a02, 0x08 },
{ "linux/eventpoll.h", "EPIOCSPARAMS", _IOC_WRITE, 0x8a01, 0x08 },
{ "linux/exfat.h", "EXFAT_IOC_SHUTDOWN", _IOC_READ, 0x587d, 0x04 },
{ "linux/ext4.h", "EXT4_IOC32_GETRSVSZ", _IOC_READ, 0x6605, 0x04 },
{ "linux/ext4.h", "EXT4_IOC32_GETVERSION", _IOC_READ, 0x6603, 0x04 },
{ "linux/ext4.h", "EXT4_IOC32_GROUP_EXTEND", _IOC_WRITE, 0x6607, 0x04 },
{ "linux/ext4.h", "EXT4_IOC32_SETRSVSZ", _IOC_WRITE, 0x6606, 0x04 },
{ "linux/ext4.h", "EXT4_IOC32_SETVERSION", _IOC_WRITE, 0x6604, 0x04 },
{ "linux/ext4.h", "EXT4_IOC_ALLOC_DA_BLKS", _IOC_NONE, 0x660c, 0x00 },
{ "linux/ext4.h", "EXT4_IOC_CHECKPOINT", _IOC_WRITE, 0x662b, 0x04 },
{ "linux/ext4.h", "EXT4_IOC_CLEAR_ES_CACHE", _IOC_NONE, 0x6628, 0x00 },
{ "linux/ext4.h", "EXT4_IOC_GETFSUUID", _IOC_READ, 0x662c, 0x08 },
{ "linux/ext4.h", "EXT4_IOC_GETSTATE", _IOC_WRITE, 0x6629, 0x04 },
{ "linux/ext4.h", "EXT4_IOC_GET_ES_CACHE", _IOC_READ|_IOC_WRITE, 0x662a, 0x20 },
{ "linux/ext4.h", "EXT4_IOC_GROUP_ADD", _IOC_WRITE, 0x6608, 0x24 },
{ "linux/ext4.h", "EXT4_IOC_MIGRATE", _IOC_NONE, 0x6609, 0x00 },
{ "linux/ext4.h", "EXT4_IOC_MOVE_EXT", _IOC_READ|_IOC_WRITE, 0x660f, 0x28 },
{ "linux/ext4.h", "EXT4_IOC_PRECACHE_EXTENTS", _IOC_NONE, 0x6612, 0x00 },
{ "linux/ext4.h", "EXT4_IOC_RESIZE_FS", _IOC_WRITE, 0x6610, 0x08 },
{ "linux/ext4.h", "EXT4_IOC_SETFSUUID", _IOC_WRITE, 0x662c, 0x08 },
{ "linux/ext4.h", "EXT4_IOC_SHUTDOWN", _IOC_READ, 0x587d, 0x04 },
{ "linux/ext4.h", "EXT4_IOC_SWAP_BOOT", _IOC_NONE, 0x6611, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_ABORT_ATOMIC_WRITE", _IOC_NONE, 0xf505, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_COMMIT_ATOMIC_WRITE", _IOC_NONE, 0xf502, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_COMPRESS_FILE", _IOC_NONE, 0xf518, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_DECOMPRESS_FILE", _IOC_NONE, 0xf517, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_DEFRAGMENT", _IOC_READ|_IOC_WRITE, 0xf508, 0x10 },
{ "linux/f2fs.h", "F2FS_IOC_FLUSH_DEVICE", _IOC_WRITE, 0xf50a, 0x08 },
{ "linux/f2fs.h", "F2FS_IOC_GARBAGE_COLLECT", _IOC_WRITE, 0xf506, 0x04 },
{ "linux/f2fs.h", "F2FS_IOC_GARBAGE_COLLECT_RANGE", _IOC_WRITE, 0xf50b, 0x14 },
{ "linux/f2fs.h", "F2FS_IOC_GET_COMPRESS_BLOCKS", _IOC_READ, 0xf511, 0x08 },
{ "linux/f2fs.h", "F2FS_IOC_GET_COMPRESS_OPTION", _IOC_READ, 0xf515, 0x02 },
{ "linux/f2fs.h", "F2FS_IOC_GET_DEV_ALIAS_FILE", _IOC_READ, 0xf51a, 0x04 },
{ "linux/f2fs.h", "F2FS_IOC_GET_FEATURES", _IOC_READ, 0xf50c, 0x04 },
{ "linux/f2fs.h", "F2FS_IOC_GET_PIN_FILE", _IOC_READ, 0xf50e, 0x04 },
{ "linux/f2fs.h", "F2FS_IOC_MOVE_RANGE", _IOC_READ|_IOC_WRITE, 0xf509, 0x1c },
{ "linux/f2fs.h", "F2FS_IOC_PRECACHE_EXTENTS", _IOC_NONE, 0xf50f, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_RELEASE_COMPRESS_BLOCKS", _IOC_READ, 0xf512, 0x08 },
{ "linux/f2fs.h", "F2FS_IOC_RELEASE_VOLATILE_WRITE", _IOC_NONE, 0xf504, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_RESERVE_COMPRESS_BLOCKS", _IOC_READ, 0xf513, 0x08 },
{ "linux/f2fs.h", "F2FS_IOC_RESIZE_FS", _IOC_WRITE, 0xf510, 0x08 },
{ "linux/f2fs.h", "F2FS_IOC_SEC_TRIM_FILE", _IOC_WRITE, 0xf514, 0x18 },
{ "linux/f2fs.h", "F2FS_IOC_SET_COMPRESS_OPTION", _IOC_WRITE, 0xf516, 0x02 },
{ "linux/f2fs.h", "F2FS_IOC_SET_PIN_FILE", _IOC_WRITE, 0xf50d, 0x04 },
{ "linux/f2fs.h", "F2FS_IOC_SHUTDOWN", _IOC_READ, 0x587d, 0x04 },
{ "linux/f2fs.h", "F2FS_IOC_START_ATOMIC_REPLACE", _IOC_NONE, 0xf519, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_START_ATOMIC_WRITE", _IOC_NONE, 0xf501, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_START_VOLATILE_WRITE", _IOC_NONE, 0xf503, 0x00 },
{ "linux/f2fs.h", "F2FS_IOC_WRITE_CHECKPOINT", _IOC_NONE, 0xf507, 0x00 },
{ "linux/fb.h", "FBIOBLANK", 0, 0x4611, 0 },
{ "linux/fb.h", "FBIOGETCMAP", 0, 0x4604, 0 },
{ "linux/fb.h", "FBIOGET_CON2FBMAP", 0, 0x460F, 0 },
{ "linux/fb.h", "FBIOGET_DISPINFO", 0, 0x4618, 0 },
{ "linux/fb.h", "FBIOGET_FSCREENINFO", 0, 0x4602, 0 },
{ "linux/fb.h", "FBIOGET_GLYPH", 0, 0x4615, 0 },
{ "linux/fb.h", "FBIOGET_HWCINFO", 0, 0x4616, 0 },
{ "linux/fb.h", "FBIOGET_VBLANK", _IOC_READ, 0x4612, 0x20 },
{ "linux/fb.h", "FBIOGET_VSCREENINFO", 0, 0x4600, 0 },
{ "linux/fb.h", "FBIOPAN_DISPLAY", 0, 0x4606, 0 },
{ "linux/fb.h", "FBIOPUTCMAP", 0, 0x4605, 0 },
{ "linux/fb.h", "FBIOPUT_CON2FBMAP", 0, 0x4610, 0 },
{ "linux/fb.h", "FBIOPUT_MODEINFO", 0, 0x4617, 0 },
{ "linux/fb.h", "FBIOPUT_VSCREENINFO", 0, 0x4601, 0 },
{ "linux/fb.h", "FBIO_ALLOC", 0, 0x4613, 0 },
{ "linux/fb.h", "FBIO_CURSOR", _IOC_READ|_IOC_WRITE, 0x4608, 0x44 },
{ "linux/fb.h", "FBIO_FREE", 0, 0x4614, 0 },
{ "linux/fb.h", "FBIO_WAITFORVSYNC", _IOC_WRITE, 0x4620, 0x04 },
{ "linux/fd.h", "FDCLRPRM", _IOC_NONE, 0x0241, 0x00 },
{ "linux/fd.h", "FDDEFPRM", _IOC_WRITE, 0x0243, 0x1c },
{ "linux/fd.h", "FDEJECT", _IOC_NONE, 0x025a, 0x00 },
{ "linux/fd.h", "FDFLUSH", _IOC_NONE, 0x024b, 0x00 },
{ "linux/fd.h", "FDFMTBEG", _IOC_NONE, 0x0247, 0x00 },
{ "linux/fd.h", "FDFMTEND", _IOC_NONE, 0x0249, 0x00 },
{ "linux/fd.h", "FDFMTTRK", _IOC_WRITE, 0x0248, 0x0c },
{ "linux/fd.h", "FDGETDRVPRM", _IOC_READ, 0x0211, 0x52 },
{ "linux/fd.h", "FDGETDRVSTAT", _IOC_READ, 0x0212, 0x34 },
{ "linux/fd.h", "FDGETDRVTYP", _IOC_READ, 0x020f, 0x10 },
{ "linux/fd.h", "FDGETFDCSTAT", _IOC_READ, 0x0215, 0x1c },
{ "linux/fd.h", "FDGETMAXERRS", _IOC_READ, 0x020e, 0x14 },
{ "linux/fd.h", "FDGETPRM", _IOC_READ, 0x0204, 0x1c },
{ "linux/fd.h", "FDMSGOFF", _IOC_NONE, 0x0246, 0x00 },
{ "linux/fd.h", "FDMSGON", _IOC_NONE, 0x0245, 0x00 },
{ "linux/fd.h", "FDPOLLDRVSTAT", _IOC_READ, 0x0213, 0x34 },
{ "linux/fd.h", "FDRAWCMD", _IOC_NONE, 0x0258, 0x00 },
{ "linux/fd.h", "FDRESET", _IOC_NONE, 0x0254, 0x00 },
{ "linux/fd.h", "FDSETDRVPRM", _IOC_WRITE, 0x0290, 0x52 },
{ "linux/fd.h", "FDSETEMSGTRESH", _IOC_NONE, 0x024a, 0x00 },
{ "linux/fd.h", "FDSETMAXERRS", _IOC_WRITE, 0x024c, 0x14 },
{ "linux/fd.h", "FDSETPRM", _IOC_WRITE, 0x0242, 0x1c },
{ "linux/fd.h", "FDTWADDLE", _IOC_NONE, 0x0259, 0x00 },
{ "linux/fd.h", "FDWERRORCLR", _IOC_NONE, 0x0256, 0x00 },
{ "linux/fd.h", "FDWERRORGET", _IOC_READ, 0x0217, 0x18 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_ADD_DESCRIPTOR", _IOC_READ|_IOC_WRITE, 0x2306, 0x18 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_ALLOCATE", _IOC_READ|_IOC_WRITE, 0x2302, 0x20 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_ALLOCATE_ISO_RESOURCE", _IOC_READ|_IOC_WRITE, 0x230d, 0x18 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_ALLOCATE_ISO_RESOURCE_ONCE", _IOC_WRITE, 0x230f, 0x18 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_CREATE_ISO_CONTEXT", _IOC_READ|_IOC_WRITE, 0x2308, 0x1c },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_DEALLOCATE", _IOC_WRITE, 0x2303, 0x04 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_DEALLOCATE_ISO_RESOURCE", _IOC_WRITE, 0x230e, 0x04 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_DEALLOCATE_ISO_RESOURCE_ONCE", _IOC_WRITE, 0x2310, 0x18 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_FLUSH_ISO", _IOC_WRITE, 0x2318, 0x04 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_GET_CYCLE_TIMER", _IOC_READ, 0x230c, 0x0c },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_GET_CYCLE_TIMER2", _IOC_READ|_IOC_WRITE, 0x2314, 0x14 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_GET_INFO", _IOC_READ|_IOC_WRITE, 0x2300, 0x24 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_GET_SPEED", _IOC_NONE, 0x2311, 0x00 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_INITIATE_BUS_RESET", _IOC_WRITE, 0x2305, 0x04 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_QUEUE_ISO", _IOC_READ|_IOC_WRITE, 0x2309, 0x18 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_RECEIVE_PHY_PACKETS", _IOC_WRITE, 0x2316, 0x08 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_REMOVE_DESCRIPTOR", _IOC_WRITE, 0x2307, 0x04 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_SEND_BROADCAST_REQUEST", _IOC_WRITE, 0x2312, 0x24 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_SEND_PHY_PACKET", _IOC_READ|_IOC_WRITE, 0x2315, 0x14 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_SEND_REQUEST", _IOC_WRITE, 0x2301, 0x24 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_SEND_RESPONSE", _IOC_WRITE, 0x2304, 0x14 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_SEND_STREAM_PACKET", _IOC_WRITE, 0x2313, 0x28 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_SET_ISO_CHANNELS", _IOC_WRITE, 0x2317, 0x0c },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_START_ISO", _IOC_WRITE, 0x230a, 0x10 },
{ "linux/firewire-cdev.h", "FW_CDEV_IOC_STOP_ISO", _IOC_WRITE, 0x230b, 0x04 },
{ "linux/fpga-dfl.h", "DFL_FPGA_CHECK_EXTENSION", _IOC_NONE, 0xb601, 0x00 },
{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_GET_IRQ_NUM", _IOC_READ, 0xb683, 0x04 },
{ "linux/fpga-dfl.h", "DFL_FPGA_FME_ERR_SET_IRQ", _IOC_WRITE, 0xb684, 0x08 },
{ "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_ASSIGN", _IOC_WRITE, 0xb682, 0x04 },
{ "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_PR", _IOC_NONE, 0xb680, 0x00 },
{ "linux/fpga-dfl.h", "DFL_FPGA_FME_PORT_RELEASE", _IOC_WRITE, 0xb681, 0x04 },
{ "linux/fpga-dfl.h", "DFL_FPGA_GET_API_VERSION", _IOC_NONE, 0xb600, 0x00 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_MAP", _IOC_NONE, 0xb643, 0x00 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_DMA_UNMAP", _IOC_NONE, 0xb644, 0x00 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_GET_IRQ_NUM", _IOC_READ, 0xb645, 0x04 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_ERR_SET_IRQ", _IOC_WRITE, 0xb646, 0x08 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_INFO", _IOC_NONE, 0xb641, 0x00 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_GET_REGION_INFO", _IOC_NONE, 0xb642, 0x00 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_RESET", _IOC_NONE, 0xb640, 0x00 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_GET_IRQ_NUM", _IOC_READ, 0xb647, 0x04 },
{ "linux/fpga-dfl.h", "DFL_FPGA_PORT_UINT_SET_IRQ", _IOC_WRITE, 0xb648, 0x08 },
{ "linux/fs.h", "BLKALIGNOFF", _IOC_NONE, 0x127a, 0x00 },
{ "linux/fs.h", "BLKBSZGET", _IOC_READ, 0x1270, 0x04 },
{ "linux/fs.h", "BLKBSZSET", _IOC_WRITE, 0x1271, 0x04 },
{ "linux/fs.h", "BLKDISCARD", _IOC_NONE, 0x1277, 0x00 },
{ "linux/fs.h", "BLKDISCARDZEROES", _IOC_NONE, 0x127c, 0x00 },
{ "linux/fs.h", "BLKFLSBUF", _IOC_NONE, 0x1261, 0x00 },
{ "linux/fs.h", "BLKFRAGET", _IOC_NONE, 0x1265, 0x00 },
{ "linux/fs.h", "BLKFRASET", _IOC_NONE, 0x1264, 0x00 },
{ "linux/fs.h", "BLKGETDISKSEQ", _IOC_READ, 0x1280, 0x08 },
{ "linux/fs.h", "BLKGETSIZE", _IOC_NONE, 0x1260, 0x00 },
{ "linux/fs.h", "BLKGETSIZE64", _IOC_READ, 0x1272, 0x04 },
{ "linux/fs.h", "BLKIOMIN", _IOC_NONE, 0x1278, 0x00 },
{ "linux/fs.h", "BLKIOOPT", _IOC_NONE, 0x1279, 0x00 },
{ "linux/fs.h", "BLKPBSZGET", _IOC_NONE, 0x127b, 0x00 },
{ "linux/fs.h", "BLKRAGET", _IOC_NONE, 0x1263, 0x00 },
{ "linux/fs.h", "BLKRASET", _IOC_NONE, 0x1262, 0x00 },
{ "linux/fs.h", "BLKROGET", _IOC_NONE, 0x125e, 0x00 },
{ "linux/fs.h", "BLKROSET", _IOC_NONE, 0x125d, 0x00 },
{ "linux/fs.h", "BLKROTATIONAL", _IOC_NONE, 0x127e, 0x00 },
{ "linux/fs.h", "BLKRRPART", _IOC_NONE, 0x125f, 0x00 },
{ "linux/fs.h", "BLKSECDISCARD", _IOC_NONE, 0x127d, 0x00 },
{ "linux/fs.h", "BLKSECTGET", _IOC_NONE, 0x1267, 0x00 },
{ "linux/fs.h", "BLKSECTSET", _IOC_NONE, 0x1266, 0x00 },
{ "linux/fs.h", "BLKSSZGET", _IOC_NONE, 0x1268, 0x00 },
{ "linux/fs.h", "BLKTRACESETUP", _IOC_READ|_IOC_WRITE, 0x1273, 0x3e },
{ "linux/fs.h", "BLKTRACESTART", _IOC_NONE, 0x1274, 0x00 },
{ "linux/fs.h", "BLKTRACESTOP", _IOC_NONE, 0x1275, 0x00 },
{ "linux/fs.h", "BLKTRACETEARDOWN", _IOC_NONE, 0x1276, 0x00 },
{ "linux/fs.h", "BLKZEROOUT", _IOC_NONE, 0x127f, 0x00 },
{ "linux/fs.h", "FIBMAP", _IOC_NONE, 0x0001, 0x00 },
{ "linux/fs.h", "FICLONE", _IOC_WRITE, 0x9409, 0x04 },
{ "linux/fs.h", "FICLONERANGE", _IOC_WRITE, 0x940d, 0x20 },
{ "linux/fs.h", "FIDEDUPERANGE", _IOC_READ|_IOC_WRITE, 0x9436, 0x18 },
{ "linux/fs.h", "FIFREEZE", _IOC_READ|_IOC_WRITE, 0x5877, 0x04 },
{ "linux/fs.h", "FIGETBSZ", _IOC_NONE, 0x0002, 0x00 },
{ "linux/fs.h", "FITHAW", _IOC_READ|_IOC_WRITE, 0x5878, 0x04 },
{ "linux/fs.h", "FITRIM", _IOC_READ|_IOC_WRITE, 0x5879, 0x18 },
{ "linux/fs.h", "FS_IOC32_GETFLAGS", _IOC_READ, 0x6601, 0x04 },
{ "linux/fs.h", "FS_IOC32_GETVERSION", _IOC_READ, 0x7601, 0x04 },
{ "linux/fs.h", "FS_IOC32_SETFLAGS", _IOC_WRITE, 0x6602, 0x04 },
{ "linux/fs.h", "FS_IOC32_SETVERSION", _IOC_WRITE, 0x7602, 0x04 },
{ "linux/fs.h", "FS_IOC_FIEMAP", _IOC_READ|_IOC_WRITE, 0x660b, 0x20 },
{ "linux/fs.h", "FS_IOC_FSGETXATTR", _IOC_READ, 0x581f, 0x1c },
{ "linux/fs.h", "FS_IOC_FSSETXATTR", _IOC_WRITE, 0x5820, 0x1c },
{ "linux/fs.h", "FS_IOC_GETFSLABEL", _IOC_READ, 0x9431, 0x100 },
{ "linux/fs.h", "FS_IOC_GETFSSYSFSPATH", _IOC_READ, 0x1501, 0x81 },
{ "linux/fs.h", "FS_IOC_GETFSUUID", _IOC_READ, 0x1500, 0x11 },
{ "linux/fs.h", "FS_IOC_SETFSLABEL", _IOC_WRITE, 0x9432, 0x100 },
{ "linux/fs.h", "PAGEMAP_SCAN", _IOC_READ|_IOC_WRITE, 0x6610, 0x60 },
{ "linux/fs.h", "PROCMAP_QUERY", _IOC_READ|_IOC_WRITE, 0x6611, 0x68 },
{ "linux/fscrypt.h", "FS_IOC_ADD_ENCRYPTION_KEY", _IOC_READ|_IOC_WRITE, 0x6617, 0x50 },
{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_KEY_STATUS", _IOC_READ|_IOC_WRITE, 0x661a, 0x80 },
{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_NONCE", _IOC_READ, 0x661b, 0x10 },
{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY", _IOC_WRITE, 0x6615, 0x0c },
{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_POLICY_EX", _IOC_READ|_IOC_WRITE, 0x6616, 0x09 },
{ "linux/fscrypt.h", "FS_IOC_GET_ENCRYPTION_PWSALT", _IOC_WRITE, 0x6614, 0x10 },
{ "linux/fscrypt.h", "FS_IOC_REMOVE_ENCRYPTION_KEY", _IOC_READ|_IOC_WRITE, 0x6618, 0x40 },
{ "linux/fscrypt.h", "FS_IOC_REMOVE_ENCRYPTION_KEY_ALL_USERS", _IOC_READ|_IOC_WRITE, 0x6619, 0x40 },
{ "linux/fscrypt.h", "FS_IOC_SET_ENCRYPTION_POLICY", _IOC_READ, 0x6613, 0x0c },
{ "linux/fsi.h", "FSI_SBEFIFO_CMD_TIMEOUT_SECONDS", _IOC_WRITE, 0x7301, 0x04 },
{ "linux/fsi.h", "FSI_SBEFIFO_READ_TIMEOUT_SECONDS", _IOC_WRITE, 0x7300, 0x04 },
{ "linux/fsi.h", "FSI_SCOM_CHECK", _IOC_READ, 0x7300, 0x04 },
{ "linux/fsi.h", "FSI_SCOM_READ", _IOC_READ|_IOC_WRITE, 0x7301, 0x1e },
{ "linux/fsi.h", "FSI_SCOM_RESET", _IOC_WRITE, 0x7303, 0x04 },
{ "linux/fsi.h", "FSI_SCOM_WRITE", _IOC_READ|_IOC_WRITE, 0x7302, 0x1e },
{ "linux/fsl-diu-fb.h", "MFB_GET_ALPHA", _IOC_READ, 0x4d00, 0x01 },
{ "linux/fsl-diu-fb.h", "MFB_GET_AOID", _IOC_READ, 0x4d04, 0x08 },
{ "linux/fsl-diu-fb.h", "MFB_GET_GAMMA", _IOC_READ, 0x4d01, 0x01 },
{ "linux/fsl-diu-fb.h", "MFB_GET_PIXFMT", _IOC_READ, 0x4d08, 0x04 },
{ "linux/fsl-diu-fb.h", "MFB_SET_ALPHA", _IOC_WRITE, 0x4d00, 0x01 },
{ "linux/fsl-diu-fb.h", "MFB_SET_AOID", _IOC_WRITE, 0x4d04, 0x08 },
{ "linux/fsl-diu-fb.h", "MFB_SET_BRIGHTNESS", _IOC_WRITE, 0x4d03, 0x01 },
{ "linux/fsl-diu-fb.h", "MFB_SET_CHROMA_KEY", _IOC_WRITE, 0x4d01, 0x0a },
{ "linux/fsl-diu-fb.h", "MFB_SET_GAMMA", _IOC_WRITE, 0x4d01, 0x01 },
{ "linux/fsl-diu-fb.h", "MFB_SET_PIXFMT", _IOC_WRITE, 0x4d08, 0x04 },
{ "linux/fsl_hypervisor.h", "FSL_HV_IOCTL_DOORBELL", _IOC_READ|_IOC_WRITE, 0xaf06, 0x08 },
{ "linux/fsl_hypervisor.h", "FSL_HV_IOCTL_GETPROP", _IOC_READ|_IOC_WRITE, 0xaf07, 0x28 },
{ "linux/fsl_hypervisor.h", "FSL_HV_IOCTL_MEMCPY", _IOC_READ|_IOC_WRITE, 0xaf05, 0x28 },
{ "linux/fsl_hypervisor.h", "FSL_HV_IOCTL_PARTITION_GET_STATUS", _IOC_READ|_IOC_WRITE, 0xaf02, 0x0c },
{ "linux/fsl_hypervisor.h", "FSL_HV_IOCTL_PARTITION_RESTART", _IOC_READ|_IOC_WRITE, 0xaf01, 0x08 },
{ "linux/fsl_hypervisor.h", "FSL_HV_IOCTL_PARTITION_START", _IOC_READ|_IOC_WRITE, 0xaf03, 0x10 },
{ "linux/fsl_hypervisor.h", "FSL_HV_IOCTL_PARTITION_STOP", _IOC_READ|_IOC_WRITE, 0xaf04, 0x08 },
{ "linux/fsl_hypervisor.h", "FSL_HV_IOCTL_SETPROP", _IOC_READ|_IOC_WRITE, 0xaf08, 0x28 },
{ "linux/fsl_mc.h", "FSL_MC_SEND_MC_COMMAND", _IOC_READ|_IOC_WRITE, 0x52e0, 0x40 },
{ "linux/fsmap.h", "FS_IOC_GETFSMAP", _IOC_READ|_IOC_WRITE, 0x583b, 0xc0 },
{ "linux/fsverity.h", "FS_IOC_ENABLE_VERITY", _IOC_WRITE, 0x6685, 0x80 },
{ "linux/fsverity.h", "FS_IOC_MEASURE_VERITY", _IOC_READ|_IOC_WRITE, 0x6686, 0x04 },
{ "linux/fsverity.h", "FS_IOC_READ_VERITY_METADATA", _IOC_READ|_IOC_WRITE, 0x6687, 0x28 },
{ "linux/fuse.h", "FUSE_DEV_IOC_BACKING_CLOSE", _IOC_WRITE, 0xe502, 0x04 },
{ "linux/fuse.h", "FUSE_DEV_IOC_BACKING_OPEN", _IOC_WRITE, 0xe501, 0x10 },
{ "linux/fuse.h", "FUSE_DEV_IOC_CLONE", _IOC_READ, 0xe500, 0x04 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_EXECUTE_DDCB", _IOC_READ|_IOC_WRITE, 0xa532, 0xe8 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_EXECUTE_RAW_DDCB", _IOC_READ|_IOC_WRITE, 0xa533, 0xe8 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_GET_CARD_STATE", _IOC_READ, 0xa524, 0x04 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_PIN_MEM", _IOC_READ|_IOC_WRITE, 0xa528, 0x20 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_READ_REG16", _IOC_READ, 0xa522, 0x10 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_READ_REG32", _IOC_READ, 0xa520, 0x10 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_READ_REG64", _IOC_READ, 0xa51e, 0x10 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_SLU_READ", _IOC_READ|_IOC_WRITE, 0xa551, 0x38 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_SLU_UPDATE", _IOC_READ|_IOC_WRITE, 0xa550, 0x38 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_UNPIN_MEM", _IOC_READ|_IOC_WRITE, 0xa529, 0x20 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG16", _IOC_WRITE, 0xa523, 0x10 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG32", _IOC_WRITE, 0xa521, 0x10 },
{ "linux/genwqe/genwqe_card.h", "GENWQE_WRITE_REG64", _IOC_WRITE, 0xa51f, 0x10 },
{ "linux/gpio.h", "GPIOHANDLE_GET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb408, 0x40 },
{ "linux/gpio.h", "GPIOHANDLE_SET_CONFIG_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40a, 0x54 },
{ "linux/gpio.h", "GPIOHANDLE_SET_LINE_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb409, 0x40 },
{ "linux/gpio.h", "GPIO_GET_CHIPINFO_IOCTL", _IOC_READ, 0xb401, 0x44 },
{ "linux/gpio.h", "GPIO_GET_LINEEVENT_IOCTL", _IOC_READ|_IOC_WRITE, 0xb404, 0x30 },
{ "linux/gpio.h", "GPIO_GET_LINEHANDLE_IOCTL", _IOC_READ|_IOC_WRITE, 0xb403, 0x16c },
{ "linux/gpio.h", "GPIO_GET_LINEINFO_IOCTL", _IOC_READ|_IOC_WRITE, 0xb402, 0x48 },
{ "linux/gpio.h", "GPIO_GET_LINEINFO_UNWATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40c, 0x04 },
{ "linux/gpio.h", "GPIO_GET_LINEINFO_WATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40b, 0x48 },
{ "linux/gpio.h", "GPIO_V2_GET_LINEINFO_IOCTL", _IOC_READ|_IOC_WRITE, 0xb405, 0x100 },
{ "linux/gpio.h", "GPIO_V2_GET_LINEINFO_WATCH_IOCTL", _IOC_READ|_IOC_WRITE, 0xb406, 0x100 },
{ "linux/gpio.h", "GPIO_V2_GET_LINE_IOCTL", _IOC_READ|_IOC_WRITE, 0xb407, 0x250 },
{ "linux/gpio.h", "GPIO_V2_LINE_GET_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40e, 0x10 },
{ "linux/gpio.h", "GPIO_V2_LINE_SET_CONFIG_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40d, 0x110 },
{ "linux/gpio.h", "GPIO_V2_LINE_SET_VALUES_IOCTL", _IOC_READ|_IOC_WRITE, 0xb40f, 0x10 },
{ "linux/gsmmux.h", "GSMIOC_DISABLE_NET", _IOC_NONE, 0x4703, 0x00 },
{ "linux/gsmmux.h", "GSMIOC_ENABLE_NET", _IOC_WRITE, 0x4702, 0x34 },
{ "linux/gsmmux.h", "GSMIOC_GETCONF", _IOC_READ, 0x4700, 0x4c },
{ "linux/gsmmux.h", "GSMIOC_GETCONF_DLCI", _IOC_READ|_IOC_WRITE, 0x4707, 0x38 },
{ "linux/gsmmux.h", "GSMIOC_GETCONF_EXT", _IOC_READ, 0x4705, 0x20 },
{ "linux/gsmmux.h", "GSMIOC_GETFIRST", _IOC_READ, 0x4704, 0x04 },
{ "linux/gsmmux.h", "GSMIOC_SETCONF", _IOC_WRITE, 0x4701, 0x4c },
{ "linux/gsmmux.h", "GSMIOC_SETCONF_DLCI", _IOC_WRITE, 0x4708, 0x38 },
{ "linux/gsmmux.h", "GSMIOC_SETCONF_EXT", _IOC_WRITE, 0x4706, 0x20 },
{ "linux/hdreg.h", "HDIO_DRIVE_CMD", 0, 0x031f, 0 },
{ "linux/hdreg.h", "HDIO_DRIVE_RESET", 0, 0x031c, 0 },
{ "linux/hdreg.h", "HDIO_DRIVE_TASK", 0, 0x031e, 0 },
{ "linux/hdreg.h", "HDIO_DRIVE_TASKFILE", 0, 0x031d, 0 },
{ "linux/hdreg.h", "HDIO_GETGEO", 0, 0x0301, 0 },
{ "linux/hdreg.h", "HDIO_GET_32BIT", 0, 0x0309, 0 },
{ "linux/hdreg.h", "HDIO_GET_ACOUSTIC", 0, 0x030f, 0 },
{ "linux/hdreg.h", "HDIO_GET_ADDRESS", 0, 0x0310, 0 },
{ "linux/hdreg.h", "HDIO_GET_BUSSTATE", 0, 0x031a, 0 },
{ "linux/hdreg.h", "HDIO_GET_DMA", 0, 0x030b, 0 },
{ "linux/hdreg.h", "HDIO_GET_IDENTITY", 0, 0x030d, 0 },
{ "linux/hdreg.h", "HDIO_GET_KEEPSETTINGS", 0, 0x0308, 0 },
{ "linux/hdreg.h", "HDIO_GET_MULTCOUNT", 0, 0x0304, 0 },
{ "linux/hdreg.h", "HDIO_GET_NICE", 0, 0x030c, 0 },
{ "linux/hdreg.h", "HDIO_GET_NOWERR", 0, 0x030a, 0 },
{ "linux/hdreg.h", "HDIO_GET_QDMA", 0, 0x0305, 0 },
{ "linux/hdreg.h", "HDIO_GET_UNMASKINTR", 0, 0x0302, 0 },
{ "linux/hdreg.h", "HDIO_GET_WCACHE", 0, 0x030e, 0 },
{ "linux/hdreg.h", "HDIO_OBSOLETE_IDENTITY", 0, 0x0307, 0 },
{ "linux/hdreg.h", "HDIO_SCAN_HWIF", 0, 0x0328, 0 },
{ "linux/hdreg.h", "HDIO_SET_32BIT", 0, 0x0324, 0 },
{ "linux/hdreg.h", "HDIO_SET_ACOUSTIC", 0, 0x032c, 0 },
{ "linux/hdreg.h", "HDIO_SET_ADDRESS", 0, 0x032f, 0 },
{ "linux/hdreg.h", "HDIO_SET_BUSSTATE", 0, 0x032d, 0 },
{ "linux/hdreg.h", "HDIO_SET_DMA", 0, 0x0326, 0 },
{ "linux/hdreg.h", "HDIO_SET_KEEPSETTINGS", 0, 0x0323, 0 },
{ "linux/hdreg.h", "HDIO_SET_MULTCOUNT", 0, 0x0321, 0 },
{ "linux/hdreg.h", "HDIO_SET_NICE", 0, 0x0329, 0 },
{ "linux/hdreg.h", "HDIO_SET_NOWERR", 0, 0x0325, 0 },
{ "linux/hdreg.h", "HDIO_SET_PIO_MODE", 0, 0x0327, 0 },
{ "linux/hdreg.h", "HDIO_SET_QDMA", 0, 0x032e, 0 },
{ "linux/hdreg.h", "HDIO_SET_UNMASKINTR", 0, 0x0322, 0 },
{ "linux/hdreg.h", "HDIO_SET_WCACHE", 0, 0x032b, 0 },
{ "linux/hdreg.h", "HDIO_SET_XFER", 0, 0x0306, 0 },
{ "linux/hdreg.h", "HDIO_TRISTATE_HWIF", 0, 0x031b, 0 },
{ "linux/hdreg.h", "HDIO_UNREGISTER_HWIF", 0, 0x032a, 0 },
{ "linux/hid-roccat.h", "ROCCATIOCGREPSIZE", _IOC_READ, 0x48f1, 0x04 },
{ "linux/hiddev.h", "HIDIOCAPPLICATION", _IOC_NONE, 0x4802, 0x00 },
{ "linux/hiddev.h", "HIDIOCGCOLLECTIONINDEX", _IOC_WRITE, 0x4810, 0x18 },
{ "linux/hiddev.h", "HIDIOCGCOLLECTIONINFO", _IOC_READ|_IOC_WRITE, 0x4811, 0x10 },
{ "linux/hiddev.h", "HIDIOCGDEVINFO", _IOC_READ, 0x4803, 0x1a },
{ "linux/hiddev.h", "HIDIOCGFIELDINFO", _IOC_READ|_IOC_WRITE, 0x480a, 0x38 },
{ "linux/hiddev.h", "HIDIOCGFLAG", _IOC_READ, 0x480e, 0x04 },
{ "linux/hiddev.h", "HIDIOCGREPORT", _IOC_WRITE, 0x4807, 0x0c },
{ "linux/hiddev.h", "HIDIOCGREPORTINFO", _IOC_READ|_IOC_WRITE, 0x4809, 0x0c },
{ "linux/hiddev.h", "HIDIOCGSTRING", _IOC_READ, 0x4804, 0x104 },
{ "linux/hiddev.h", "HIDIOCGUCODE", _IOC_READ|_IOC_WRITE, 0x480d, 0x18 },
{ "linux/hiddev.h", "HIDIOCGUSAGE", _IOC_READ|_IOC_WRITE, 0x480b, 0x18 },
{ "linux/hiddev.h", "HIDIOCGUSAGES", _IOC_READ|_IOC_WRITE, 0x4813, 0x101c },
{ "linux/hiddev.h", "HIDIOCGVERSION", _IOC_READ, 0x4801, 0x04 },
{ "linux/hiddev.h", "HIDIOCINITREPORT", _IOC_NONE, 0x4805, 0x00 },
{ "linux/hiddev.h", "HIDIOCSFLAG", _IOC_WRITE, 0x480f, 0x04 },
{ "linux/hiddev.h", "HIDIOCSREPORT", _IOC_WRITE, 0x4808, 0x0c },
{ "linux/hiddev.h", "HIDIOCSUSAGE", _IOC_WRITE, 0x480c, 0x18 },
{ "linux/hiddev.h", "HIDIOCSUSAGES", _IOC_WRITE, 0x4814, 0x101c },
{ "linux/hidraw.h", "HIDIOCGRAWINFO", _IOC_READ, 0x4803, 0x08 },
{ "linux/hidraw.h", "HIDIOCGRDESC", _IOC_READ, 0x4802, 0x1004 },
{ "linux/hidraw.h", "HIDIOCGRDESCSIZE", _IOC_READ, 0x4801, 0x04 },
{ "linux/hidraw.h", "HIDIOCREVOKE", _IOC_WRITE, 0x480d, 0x04 },
{ "linux/hpet.h", "HPET_DPI", _IOC_NONE, 0x6805, 0x00 },
{ "linux/hpet.h", "HPET_EPI", _IOC_NONE, 0x6804, 0x00 },
{ "linux/hpet.h", "HPET_IE_OFF", _IOC_NONE, 0x6802, 0x00 },
{ "linux/hpet.h", "HPET_IE_ON", _IOC_NONE, 0x6801, 0x00 },
{ "linux/hpet.h", "HPET_INFO", _IOC_READ, 0x6803, 0x0c },
{ "linux/hpet.h", "HPET_IRQFREQ", _IOC_WRITE, 0x6806, 0x04 },
{ "linux/hsi/cs-protocol.h", "CS_CONFIG_BUFS", _IOC_WRITE, 0x431f, 0x20 },
{ "linux/hsi/cs-protocol.h", "CS_GET_IF_VERSION", _IOC_READ, 0x431e, 0x04 },
{ "linux/hsi/cs-protocol.h", "CS_GET_STATE", _IOC_READ, 0x4315, 0x04 },
{ "linux/hsi/cs-protocol.h", "CS_SET_WAKELINE", _IOC_WRITE, 0x4317, 0x04 },
{ "linux/hsi/hsi_char.h", "HSC_GET_RX", _IOC_WRITE, 0x6b14, 0x0c },
{ "linux/hsi/hsi_char.h", "HSC_GET_TX", _IOC_WRITE, 0x6b16, 0x10 },
{ "linux/hsi/hsi_char.h", "HSC_RESET", _IOC_NONE, 0x6b10, 0x00 },
{ "linux/hsi/hsi_char.h", "HSC_SEND_BREAK", _IOC_NONE, 0x6b12, 0x00 },
{ "linux/hsi/hsi_char.h", "HSC_SET_PM", _IOC_NONE, 0x6b11, 0x00 },
{ "linux/hsi/hsi_char.h", "HSC_SET_RX", _IOC_WRITE, 0x6b13, 0x0c },
{ "linux/hsi/hsi_char.h", "HSC_SET_TX", _IOC_WRITE, 0x6b15, 0x10 },
{ "linux/i2o-dev.h", "I2OEVTGET", _IOC_READ, 0x690b, 0x68 },
{ "linux/i2o-dev.h", "I2OEVTREG", _IOC_WRITE, 0x690a, 0x0c },
{ "linux/i2o-dev.h", "I2OGETIOPS", _IOC_READ, 0x6900, 0x20 },
{ "linux/i2o-dev.h", "I2OHRTGET", _IOC_READ|_IOC_WRITE, 0x6901, 0x0c },
{ "linux/i2o-dev.h", "I2OHTML", _IOC_READ|_IOC_WRITE, 0x6909, 0x1c },
{ "linux/i2o-dev.h", "I2OLCTGET", _IOC_READ|_IOC_WRITE, 0x6902, 0x0c },
{ "linux/i2o-dev.h", "I2OPARMGET", _IOC_READ|_IOC_WRITE, 0x6904, 0x18 },
{ "linux/i2o-dev.h", "I2OPARMSET", _IOC_READ|_IOC_WRITE, 0x6903, 0x18 },
{ "linux/i2o-dev.h", "I2OPASSTHRU32", _IOC_READ, 0x690c, 0x08 },
{ "linux/i2o-dev.h", "I2OSWDEL", _IOC_READ|_IOC_WRITE, 0x6907, 0x1a },
{ "linux/i2o-dev.h", "I2OSWDL", _IOC_READ|_IOC_WRITE, 0x6905, 0x1a },
{ "linux/i2o-dev.h", "I2OSWUL", _IOC_READ|_IOC_WRITE, 0x6906, 0x1a },
{ "linux/i2o-dev.h", "I2OVALIDATE", _IOC_READ, 0x6908, 0x04 },
{ "linux/i8k.h", "I8K_BIOS_VERSION", _IOC_READ, 0x6980, 0x04 },
{ "linux/i8k.h", "I8K_FN_STATUS", _IOC_READ, 0x6983, 0x04 },
{ "linux/i8k.h", "I8K_GET_FAN", _IOC_READ|_IOC_WRITE, 0x6986, 0x04 },
{ "linux/i8k.h", "I8K_GET_SPEED", _IOC_READ|_IOC_WRITE, 0x6985, 0x04 },
{ "linux/i8k.h", "I8K_GET_TEMP", _IOC_READ, 0x6984, 0x04 },
{ "linux/i8k.h", "I8K_MACHINE_ID", _IOC_READ, 0x6981, 0x04 },
{ "linux/i8k.h", "I8K_POWER_STATUS", _IOC_READ, 0x6982, 0x04 },
{ "linux/i8k.h", "I8K_SET_FAN", _IOC_READ|_IOC_WRITE, 0x6987, 0x04 },
{ "linux/if_pppox.h", "PPPOEIOCDFWD", _IOC_NONE, 0xb101, 0x00 },
{ "linux/if_pppox.h", "PPPOEIOCSFWD", _IOC_WRITE, 0xb100, 0x04 },
{ "linux/if_tun.h", "TUNATTACHFILTER", _IOC_WRITE, 0x54d5, 0x06 },
{ "linux/if_tun.h", "TUNDETACHFILTER", _IOC_WRITE, 0x54d6, 0x06 },
{ "linux/if_tun.h", "TUNGETDEVNETNS", _IOC_NONE, 0x54e3, 0x00 },
{ "linux/if_tun.h", "TUNGETFEATURES", _IOC_READ, 0x54cf, 0x04 },
{ "linux/if_tun.h", "TUNGETFILTER", _IOC_READ, 0x54db, 0x06 },
{ "linux/if_tun.h", "TUNGETIFF", _IOC_READ, 0x54d2, 0x04 },
{ "linux/if_tun.h", "TUNGETSNDBUF", _IOC_READ, 0x54d3, 0x04 },
{ "linux/if_tun.h", "TUNGETVNETBE", _IOC_READ, 0x54df, 0x04 },
{ "linux/if_tun.h", "TUNGETVNETHDRSZ", _IOC_READ, 0x54d7, 0x04 },
{ "linux/if_tun.h", "TUNGETVNETLE", _IOC_READ, 0x54dd, 0x04 },
{ "linux/if_tun.h", "TUNSETCARRIER", _IOC_WRITE, 0x54e2, 0x04 },
{ "linux/if_tun.h", "TUNSETDEBUG", _IOC_WRITE, 0x54c9, 0x04 },
{ "linux/if_tun.h", "TUNSETFILTEREBPF", _IOC_READ, 0x54e1, 0x04 },
{ "linux/if_tun.h", "TUNSETGROUP", _IOC_WRITE, 0x54ce, 0x04 },
{ "linux/if_tun.h", "TUNSETIFF", _IOC_WRITE, 0x54ca, 0x04 },
{ "linux/if_tun.h", "TUNSETIFINDEX", _IOC_WRITE, 0x54da, 0x04 },
{ "linux/if_tun.h", "TUNSETLINK", _IOC_WRITE, 0x54cd, 0x04 },
{ "linux/if_tun.h", "TUNSETNOCSUM", _IOC_WRITE, 0x54c8, 0x04 },
{ "linux/if_tun.h", "TUNSETOFFLOAD", _IOC_WRITE, 0x54d0, 0x04 },
{ "linux/if_tun.h", "TUNSETOWNER", _IOC_WRITE, 0x54cc, 0x04 },
{ "linux/if_tun.h", "TUNSETPERSIST", _IOC_WRITE, 0x54cb, 0x04 },
{ "linux/if_tun.h", "TUNSETQUEUE", _IOC_WRITE, 0x54d9, 0x04 },
{ "linux/if_tun.h", "TUNSETSNDBUF", _IOC_WRITE, 0x54d4, 0x04 },
{ "linux/if_tun.h", "TUNSETSTEERINGEBPF", _IOC_READ, 0x54e0, 0x04 },
{ "linux/if_tun.h", "TUNSETTXFILTER", _IOC_WRITE, 0x54d1, 0x04 },
{ "linux/if_tun.h", "TUNSETVNETBE", _IOC_WRITE, 0x54de, 0x04 },
{ "linux/if_tun.h", "TUNSETVNETHDRSZ", _IOC_WRITE, 0x54d8, 0x04 },
{ "linux/if_tun.h", "TUNSETVNETLE", _IOC_WRITE, 0x54dc, 0x04 },
{ "linux/iio/buffer.h", "IIO_BUFFER_DMABUF_ATTACH_IOCTL", _IOC_WRITE, 0x6992, 0x04 },
{ "linux/iio/buffer.h", "IIO_BUFFER_DMABUF_DETACH_IOCTL", _IOC_WRITE, 0x6993, 0x04 },
{ "linux/iio/buffer.h", "IIO_BUFFER_DMABUF_ENQUEUE_IOCTL", _IOC_WRITE, 0x6994, 0x10 },
{ "linux/iio/buffer.h", "IIO_BUFFER_GET_FD_IOCTL", _IOC_READ|_IOC_WRITE, 0x6991, 0x04 },
{ "linux/iio/events.h", "IIO_GET_EVENT_FD_IOCTL", _IOC_READ, 0x6990, 0x04 },
{ "linux/inotify.h", "INOTIFY_IOC_SETNEXTWD", _IOC_WRITE, 0x4900, 0x04 },
{ "linux/input.h", "EVIOCGEFFECTS", _IOC_READ, 0x4584, 0x04 },
{ "linux/input.h", "EVIOCGID", _IOC_READ, 0x4502, 0x08 },
{ "linux/input.h", "EVIOCGKEYCODE", _IOC_READ, 0x4504, 0x08 },
{ "linux/input.h", "EVIOCGKEYCODE_V2", _IOC_READ, 0x4504, 0x28 },
{ "linux/input.h", "EVIOCGMASK", _IOC_READ, 0x4592, 0x10 },
{ "linux/input.h", "EVIOCGRAB", _IOC_WRITE, 0x4590, 0x04 },
{ "linux/input.h", "EVIOCGREP", _IOC_READ, 0x4503, 0x08 },
{ "linux/input.h", "EVIOCGVERSION", _IOC_READ, 0x4501, 0x04 },
{ "linux/input.h", "EVIOCREVOKE", _IOC_WRITE, 0x4591, 0x04 },
{ "linux/input.h", "EVIOCRMFF", _IOC_WRITE, 0x4581, 0x04 },
{ "linux/input.h", "EVIOCSCLOCKID", _IOC_WRITE, 0x45a0, 0x04 },
{ "linux/input.h", "EVIOCSFF", _IOC_WRITE, 0x4580, 0x28 },
{ "linux/input.h", "EVIOCSKEYCODE", _IOC_WRITE, 0x4504, 0x08 },
{ "linux/input.h", "EVIOCSKEYCODE_V2", _IOC_WRITE, 0x4504, 0x28 },
{ "linux/input.h", "EVIOCSMASK", _IOC_WRITE, 0x4593, 0x10 },
{ "linux/input.h", "EVIOCSREP", _IOC_WRITE, 0x4503, 0x08 },
{ "linux/iommufd.h", "IOMMU_DESTROY", _IOC_NONE, 0x3b80, 0x00 },
{ "linux/iommufd.h", "IOMMU_FAULT_QUEUE_ALLOC", _IOC_NONE, 0x3b8e, 0x00 },
{ "linux/iommufd.h", "IOMMU_GET_HW_INFO", _IOC_NONE, 0x3b8a, 0x00 },
{ "linux/iommufd.h", "IOMMU_HWPT_ALLOC", _IOC_NONE, 0x3b89, 0x00 },
{ "linux/iommufd.h", "IOMMU_HWPT_GET_DIRTY_BITMAP", _IOC_NONE, 0x3b8c, 0x00 },
{ "linux/iommufd.h", "IOMMU_HWPT_INVALIDATE", _IOC_NONE, 0x3b8d, 0x00 },
{ "linux/iommufd.h", "IOMMU_HWPT_SET_DIRTY_TRACKING", _IOC_NONE, 0x3b8b, 0x00 },
{ "linux/iommufd.h", "IOMMU_IOAS_ALLOC", _IOC_NONE, 0x3b81, 0x00 },
{ "linux/iommufd.h", "IOMMU_IOAS_ALLOW_IOVAS", _IOC_NONE, 0x3b82, 0x00 },
{ "linux/iommufd.h", "IOMMU_IOAS_CHANGE_PROCESS", _IOC_NONE, 0x3b92, 0x00 },
{ "linux/iommufd.h", "IOMMU_IOAS_COPY", _IOC_NONE, 0x3b83, 0x00 },
{ "linux/iommufd.h", "IOMMU_IOAS_IOVA_RANGES", _IOC_NONE, 0x3b84, 0x00 },
{ "linux/iommufd.h", "IOMMU_IOAS_MAP", _IOC_NONE, 0x3b85, 0x00 },
{ "linux/iommufd.h", "IOMMU_IOAS_MAP_FILE", _IOC_NONE, 0x3b8f, 0x00 },
{ "linux/iommufd.h", "IOMMU_IOAS_UNMAP", _IOC_NONE, 0x3b86, 0x00 },
{ "linux/iommufd.h", "IOMMU_OPTION", _IOC_NONE, 0x3b87, 0x00 },
{ "linux/iommufd.h", "IOMMU_VDEVICE_ALLOC", _IOC_NONE, 0x3b91, 0x00 },
{ "linux/iommufd.h", "IOMMU_VFIO_IOAS", _IOC_NONE, 0x3b88, 0x00 },
{ "linux/iommufd.h", "IOMMU_VIOMMU_ALLOC", _IOC_NONE, 0x3b90, 0x00 },
{ "linux/ipmi.h", "IPMICTL_GET_MAINTENANCE_MODE_CMD", _IOC_READ, 0x691e, 0x04 },
{ "linux/ipmi.h", "IPMICTL_GET_MY_ADDRESS_CMD", _IOC_READ, 0x6912, 0x04 },
{ "linux/ipmi.h", "IPMICTL_GET_MY_CHANNEL_ADDRESS_CMD", _IOC_READ, 0x6919, 0x04 },
{ "linux/ipmi.h", "IPMICTL_GET_MY_CHANNEL_LUN_CMD", _IOC_READ, 0x691b, 0x04 },
{ "linux/ipmi.h", "IPMICTL_GET_MY_LUN_CMD", _IOC_READ, 0x6914, 0x04 },
{ "linux/ipmi.h", "IPMICTL_GET_TIMING_PARMS_CMD", _IOC_READ, 0x6917, 0x08 },
{ "linux/ipmi.h", "IPMICTL_RECEIVE_MSG", _IOC_READ|_IOC_WRITE, 0x690c, 0x18 },
{ "linux/ipmi.h", "IPMICTL_RECEIVE_MSG_TRUNC", _IOC_READ|_IOC_WRITE, 0x690b, 0x18 },
{ "linux/ipmi.h", "IPMICTL_REGISTER_FOR_CMD", _IOC_READ, 0x690e, 0x02 },
{ "linux/ipmi.h", "IPMICTL_REGISTER_FOR_CMD_CHANS", _IOC_READ, 0x691c, 0x0c },
{ "linux/ipmi.h", "IPMICTL_SEND_COMMAND", _IOC_READ, 0x690d, 0x14 },
{ "linux/ipmi.h", "IPMICTL_SEND_COMMAND_SETTIME", _IOC_READ, 0x6915, 0x1c },
{ "linux/ipmi.h", "IPMICTL_SET_GETS_EVENTS_CMD", _IOC_READ, 0x6910, 0x04 },
{ "linux/ipmi.h", "IPMICTL_SET_MAINTENANCE_MODE_CMD", _IOC_WRITE, 0x691f, 0x04 },
{ "linux/ipmi.h", "IPMICTL_SET_MY_ADDRESS_CMD", _IOC_READ, 0x6911, 0x04 },
{ "linux/ipmi.h", "IPMICTL_SET_MY_CHANNEL_ADDRESS_CMD", _IOC_READ, 0x6918, 0x04 },
{ "linux/ipmi.h", "IPMICTL_SET_MY_CHANNEL_LUN_CMD", _IOC_READ, 0x691a, 0x04 },
{ "linux/ipmi.h", "IPMICTL_SET_MY_LUN_CMD", _IOC_READ, 0x6913, 0x04 },
{ "linux/ipmi.h", "IPMICTL_SET_TIMING_PARMS_CMD", _IOC_READ, 0x6916, 0x08 },
{ "linux/ipmi.h", "IPMICTL_UNREGISTER_FOR_CMD", _IOC_READ, 0x690f, 0x02 },
{ "linux/ipmi.h", "IPMICTL_UNREGISTER_FOR_CMD_CHANS", _IOC_READ, 0x691d, 0x0c },
{ "linux/ipmi_bmc.h", "IPMI_BMC_IOCTL_CLEAR_SMS_ATN", _IOC_NONE, 0xb101, 0x00 },
{ "linux/ipmi_bmc.h", "IPMI_BMC_IOCTL_FORCE_ABORT", _IOC_NONE, 0xb102, 0x00 },
{ "linux/ipmi_bmc.h", "IPMI_BMC_IOCTL_SET_SMS_ATN", _IOC_NONE, 0xb100, 0x00 },
{ "linux/isst_if.h", "ISST_IF_CLOS_ASSOC", _IOC_READ|_IOC_WRITE, 0xfe08, 0x04 },
{ "linux/isst_if.h", "ISST_IF_CLOS_PARAM", _IOC_READ|_IOC_WRITE, 0xfe07, 0x04 },
{ "linux/isst_if.h", "ISST_IF_CORE_POWER_STATE", _IOC_READ|_IOC_WRITE, 0xfe06, 0x04 },
{ "linux/isst_if.h", "ISST_IF_COUNT_TPMI_INSTANCES", _IOC_READ, 0xfe05, 0x04 },
{ "linux/isst_if.h", "ISST_IF_GET_BASE_FREQ_CPU_MASK", _IOC_READ, 0xfe0f, 0x04 },
{ "linux/isst_if.h", "ISST_IF_GET_BASE_FREQ_INFO", _IOC_READ, 0xfe0e, 0x04 },
{ "linux/isst_if.h", "ISST_IF_GET_PERF_LEVEL_CPU_MASK", _IOC_READ, 0xfe0d, 0x04 },
{ "linux/isst_if.h", "ISST_IF_GET_PERF_LEVEL_INFO", _IOC_READ, 0xfe0c, 0x04 },
{ "linux/isst_if.h", "ISST_IF_GET_PHY_ID", _IOC_READ|_IOC_WRITE, 0xfe01, 0x04 },
{ "linux/isst_if.h", "ISST_IF_GET_PLATFORM_INFO", _IOC_READ, 0xfe00, 0x04 },
{ "linux/isst_if.h", "ISST_IF_GET_TURBO_FREQ_INFO", _IOC_READ, 0xfe10, 0x04 },
{ "linux/isst_if.h", "ISST_IF_IO_CMD", _IOC_WRITE, 0xfe02, 0x04 },
{ "linux/isst_if.h", "ISST_IF_MBOX_COMMAND", _IOC_READ|_IOC_WRITE, 0xfe03, 0x04 },
{ "linux/isst_if.h", "ISST_IF_MSR_COMMAND", _IOC_READ|_IOC_WRITE, 0xfe04, 0x04 },
{ "linux/isst_if.h", "ISST_IF_PERF_LEVELS", _IOC_READ|_IOC_WRITE, 0xfe09, 0x04 },
{ "linux/isst_if.h", "ISST_IF_PERF_SET_FEATURE", _IOC_WRITE, 0xfe0b, 0x04 },
{ "linux/isst_if.h", "ISST_IF_PERF_SET_LEVEL", _IOC_WRITE, 0xfe0a, 0x04 },
{ "linux/ivtv.h", "IVTV_IOC_DMA_FRAME", _IOC_WRITE, 0x56c0, 0x38 },
{ "linux/ivtv.h", "IVTV_IOC_PASSTHROUGH_MODE", _IOC_WRITE, 0x56c1, 0x04 },
{ "linux/ivtvfb.h", "IVTVFB_IOC_DMA_FRAME", _IOC_WRITE, 0x56c0, 0x0c },
{ "linux/joystick.h", "JSIOCGAXES", _IOC_READ, 0x6a11, 0x01 },
{ "linux/joystick.h", "JSIOCGAXMAP", _IOC_READ, 0x6a32, 0x40 },
{ "linux/joystick.h", "JSIOCGBTNMAP", _IOC_READ, 0x6a34, 0x400 },
{ "linux/joystick.h", "JSIOCGBUTTONS", _IOC_READ, 0x6a12, 0x01 },
{ "linux/joystick.h", "JSIOCGCORR", _IOC_READ, 0x6a22, 0x24 },
{ "linux/joystick.h", "JSIOCGVERSION", _IOC_READ, 0x6a01, 0x04 },
{ "linux/joystick.h", "JSIOCSAXMAP", _IOC_WRITE, 0x6a31, 0x40 },
{ "linux/joystick.h", "JSIOCSBTNMAP", _IOC_WRITE, 0x6a33, 0x400 },
{ "linux/joystick.h", "JSIOCSCORR", _IOC_WRITE, 0x6a21, 0x24 },
{ "linux/kcov.h", "KCOV_DISABLE", _IOC_NONE, 0x6365, 0x00 },
{ "linux/kcov.h", "KCOV_ENABLE", _IOC_NONE, 0x6364, 0x00 },
{ "linux/kcov.h", "KCOV_INIT_TRACE", _IOC_READ, 0x6301, 0x04 },
{ "linux/kcov.h", "KCOV_REMOTE_ENABLE", _IOC_WRITE, 0x6366, 0x18 },
{ "linux/kd.h", "GIO_CMAP", 0, 0x4B70, 0 },
{ "linux/kd.h", "GIO_FONT", 0, 0x4B60, 0 },
{ "linux/kd.h", "GIO_FONTX", 0, 0x4B6B, 0 },
{ "linux/kd.h", "GIO_SCRNMAP", 0, 0x4B40, 0 },
{ "linux/kd.h", "GIO_UNIMAP", 0, 0x4B66, 0 },
{ "linux/kd.h", "GIO_UNISCRNMAP", 0, 0x4B69, 0 },
{ "linux/kd.h", "KDADDIO", 0, 0x4B34, 0 },
{ "linux/kd.h", "KDDELIO", 0, 0x4B35, 0 },
{ "linux/kd.h", "KDDISABIO", 0, 0x4B37, 0 },
{ "linux/kd.h", "KDENABIO", 0, 0x4B36, 0 },
{ "linux/kd.h", "KDFONTOP", 0, 0x4B72, 0 },
{ "linux/kd.h", "KDGETKEYCODE", 0, 0x4B4C, 0 },
{ "linux/kd.h", "KDGETLED", 0, 0x4B31, 0 },
{ "linux/kd.h", "KDGETMODE", 0, 0x4B3B, 0 },
{ "linux/kd.h", "KDGKBDIACR", 0, 0x4B4A, 0 },
{ "linux/kd.h", "KDGKBDIACRUC", 0, 0x4BFA, 0 },
{ "linux/kd.h", "KDGKBENT", 0, 0x4B46, 0 },
{ "linux/kd.h", "KDGKBLED", 0, 0x4B64, 0 },
{ "linux/kd.h", "KDGKBMETA", 0, 0x4B62, 0 },
{ "linux/kd.h", "KDGKBMODE", 0, 0x4B44, 0 },
{ "linux/kd.h", "KDGKBSENT", 0, 0x4B48, 0 },
{ "linux/kd.h", "KDGKBTYPE", 0, 0x4B33, 0 },
{ "linux/kd.h", "KDKBDREP", 0, 0x4B52, 0 },
{ "linux/kd.h", "KDMAPDISP", 0, 0x4B3C, 0 },
{ "linux/kd.h", "KDMKTONE", 0, 0x4B30, 0 },
{ "linux/kd.h", "KDSETKEYCODE", 0, 0x4B4D, 0 },
{ "linux/kd.h", "KDSETLED", 0, 0x4B32, 0 },
{ "linux/kd.h", "KDSETMODE", 0, 0x4B3A, 0 },
{ "linux/kd.h", "KDSIGACCEPT", 0, 0x4B4E, 0 },
{ "linux/kd.h", "KDSKBDIACR", 0, 0x4B4B, 0 },
{ "linux/kd.h", "KDSKBDIACRUC", 0, 0x4BFB, 0 },
{ "linux/kd.h", "KDSKBENT", 0, 0x4B47, 0 },
{ "linux/kd.h", "KDSKBLED", 0, 0x4B65, 0 },
{ "linux/kd.h", "KDSKBMETA", 0, 0x4B63, 0 },
{ "linux/kd.h", "KDSKBMODE", 0, 0x4B45, 0 },
{ "linux/kd.h", "KDSKBSENT", 0, 0x4B49, 0 },
{ "linux/kd.h", "KDUNMAPDISP", 0, 0x4B3D, 0 },
{ "linux/kd.h", "KIOCSOUND", 0, 0x4B2F, 0 },
{ "linux/kd.h", "PIO_CMAP", 0, 0x4B71, 0 },
{ "linux/kd.h", "PIO_FONT", 0, 0x4B61, 0 },
{ "linux/kd.h", "PIO_FONTRESET", 0, 0x4B6D, 0 },
{ "linux/kd.h", "PIO_FONTX", 0, 0x4B6C, 0 },
{ "linux/kd.h", "PIO_SCRNMAP", 0, 0x4B41, 0 },
{ "linux/kd.h", "PIO_UNIMAP", 0, 0x4B67, 0 },
{ "linux/kd.h", "PIO_UNIMAPCLR", 0, 0x4B68, 0 },
{ "linux/kd.h", "PIO_UNISCRNMAP", 0, 0x4B6A, 0 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_ACQUIRE_VM", _IOC_WRITE, 0x4b15, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_MEMORY_OF_GPU", _IOC_READ|_IOC_WRITE, 0x4b16, 0x28 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_ALLOC_QUEUE_GWS", _IOC_READ|_IOC_WRITE, 0x4b1e, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_AVAILABLE_MEMORY", _IOC_READ|_IOC_WRITE, 0x4b23, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_EVENT", _IOC_READ|_IOC_WRITE, 0x4b08, 0x20 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_CREATE_QUEUE", _IOC_READ|_IOC_WRITE, 0x4b02, 0x60 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_CRIU_OP", _IOC_READ|_IOC_WRITE, 0x4b22, 0x34 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_ADDRESS_WATCH_DEPRECATED", _IOC_WRITE, 0x4b0f, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_REGISTER_DEPRECATED", _IOC_WRITE, 0x4b0d, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_TRAP", _IOC_READ|_IOC_WRITE, 0x4b26, 0x20 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_UNREGISTER_DEPRECATED", _IOC_WRITE, 0x4b0e, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_DBG_WAVE_CONTROL_DEPRECATED", _IOC_WRITE, 0x4b10, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_DESTROY_EVENT", _IOC_WRITE, 0x4b09, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_DESTROY_QUEUE", _IOC_READ|_IOC_WRITE, 0x4b03, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_EXPORT_DMABUF", _IOC_READ|_IOC_WRITE, 0x4b24, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_FREE_MEMORY_OF_GPU", _IOC_WRITE, 0x4b17, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_GET_CLOCK_COUNTERS", _IOC_READ|_IOC_WRITE, 0x4b05, 0x28 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_GET_DMABUF_INFO", _IOC_READ|_IOC_WRITE, 0x4b1c, 0x20 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_GET_PROCESS_APERTURES", _IOC_READ, 0x4b06, 0x190 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_GET_PROCESS_APERTURES_NEW", _IOC_READ|_IOC_WRITE, 0x4b14, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_GET_QUEUE_WAVE_STATE", _IOC_READ|_IOC_WRITE, 0x4b1b, 0x18 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_GET_TILE_CONFIG", _IOC_READ|_IOC_WRITE, 0x4b12, 0x28 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_GET_VERSION", _IOC_READ, 0x4b01, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_IMPORT_DMABUF", _IOC_READ|_IOC_WRITE, 0x4b1d, 0x18 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_MAP_MEMORY_TO_GPU", _IOC_READ|_IOC_WRITE, 0x4b18, 0x18 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_RESET_EVENT", _IOC_WRITE, 0x4b0b, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_RUNTIME_ENABLE", _IOC_READ|_IOC_WRITE, 0x4b25, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_CU_MASK", _IOC_WRITE, 0x4b1a, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_EVENT", _IOC_WRITE, 0x4b0a, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_MEMORY_POLICY", _IOC_WRITE, 0x4b04, 0x20 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_SCRATCH_BACKING_VA", _IOC_READ|_IOC_WRITE, 0x4b11, 0x10 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_TRAP_HANDLER", _IOC_WRITE, 0x4b13, 0x18 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SET_XNACK_MODE", _IOC_READ|_IOC_WRITE, 0x4b21, 0x04 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SMI_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b1f, 0x08 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_SVM", _IOC_READ|_IOC_WRITE, 0x4b20, 0x18 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_UNMAP_MEMORY_FROM_GPU", _IOC_READ|_IOC_WRITE, 0x4b19, 0x18 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_UPDATE_QUEUE", _IOC_WRITE, 0x4b07, 0x18 },
{ "linux/kfd_ioctl.h", "AMDKFD_IOC_WAIT_EVENTS", _IOC_READ|_IOC_WRITE, 0x4b0c, 0x18 },
{ "linux/lirc.h", "LIRC_GET_FEATURES", _IOC_READ, 0x6900, 0x04 },
{ "linux/lirc.h", "LIRC_GET_LENGTH", _IOC_READ, 0x690f, 0x04 },
{ "linux/lirc.h", "LIRC_GET_MAX_TIMEOUT", _IOC_READ, 0x6909, 0x04 },
{ "linux/lirc.h", "LIRC_GET_MIN_TIMEOUT", _IOC_READ, 0x6908, 0x04 },
{ "linux/lirc.h", "LIRC_GET_REC_MODE", _IOC_READ, 0x6902, 0x04 },
{ "linux/lirc.h", "LIRC_GET_REC_RESOLUTION", _IOC_READ, 0x6907, 0x04 },
{ "linux/lirc.h", "LIRC_GET_REC_TIMEOUT", _IOC_READ, 0x6924, 0x04 },
{ "linux/lirc.h", "LIRC_GET_SEND_MODE", _IOC_READ, 0x6901, 0x04 },
{ "linux/lirc.h", "LIRC_SET_MEASURE_CARRIER_MODE", _IOC_WRITE, 0x691d, 0x04 },
{ "linux/lirc.h", "LIRC_SET_REC_CARRIER", _IOC_WRITE, 0x6914, 0x04 },
{ "linux/lirc.h", "LIRC_SET_REC_CARRIER_RANGE", _IOC_WRITE, 0x691f, 0x04 },
{ "linux/lirc.h", "LIRC_SET_REC_MODE", _IOC_WRITE, 0x6912, 0x04 },
{ "linux/lirc.h", "LIRC_SET_REC_TIMEOUT", _IOC_WRITE, 0x6918, 0x04 },
{ "linux/lirc.h", "LIRC_SET_REC_TIMEOUT_REPORTS", _IOC_WRITE, 0x6919, 0x04 },
{ "linux/lirc.h", "LIRC_SET_SEND_CARRIER", _IOC_WRITE, 0x6913, 0x04 },
{ "linux/lirc.h", "LIRC_SET_SEND_DUTY_CYCLE", _IOC_WRITE, 0x6915, 0x04 },
{ "linux/lirc.h", "LIRC_SET_SEND_MODE", _IOC_WRITE, 0x6911, 0x04 },
{ "linux/lirc.h", "LIRC_SET_TRANSMITTER_MASK", _IOC_WRITE, 0x6917, 0x04 },
{ "linux/lirc.h", "LIRC_SET_WIDEBAND_RECEIVER", _IOC_WRITE, 0x6923, 0x04 },
{ "linux/loadpin.h", "LOADPIN_IOC_SET_TRUSTED_VERITY_DIGESTS", _IOC_WRITE, 0x4c00, 0x04 },
{ "linux/loop.h", "LOOP_CHANGE_FD", 0, 0x4C06, 0 },
{ "linux/loop.h", "LOOP_CLR_FD", 0, 0x4C01, 0 },
{ "linux/loop.h", "LOOP_CONFIGURE", 0, 0x4C0A, 0 },
{ "linux/loop.h", "LOOP_CTL_ADD", 0, 0x4C80, 0 },
{ "linux/loop.h", "LOOP_CTL_GET_FREE", 0, 0x4C82, 0 },
{ "linux/loop.h", "LOOP_CTL_REMOVE", 0, 0x4C81, 0 },
{ "linux/loop.h", "LOOP_GET_STATUS", 0, 0x4C03, 0 },
{ "linux/loop.h", "LOOP_GET_STATUS64", 0, 0x4C05, 0 },
{ "linux/loop.h", "LOOP_SET_BLOCK_SIZE", 0, 0x4C09, 0 },
{ "linux/loop.h", "LOOP_SET_CAPACITY", 0, 0x4C07, 0 },
{ "linux/loop.h", "LOOP_SET_DIRECT_IO", 0, 0x4C08, 0 },
{ "linux/loop.h", "LOOP_SET_FD", 0, 0x4C00, 0 },
{ "linux/loop.h", "LOOP_SET_STATUS", 0, 0x4C02, 0 },
{ "linux/loop.h", "LOOP_SET_STATUS64", 0, 0x4C04, 0 },
{ "linux/lp.h", "LPSETTIMEOUT_NEW", _IOC_WRITE, 0x060f, 0x10 },
{ "linux/mISDNif.h", "IMADDTIMER", _IOC_READ, 0x4940, 0x04 },
{ "linux/mISDNif.h", "IMCLEAR_L2", _IOC_READ, 0x4946, 0x04 },
{ "linux/mISDNif.h", "IMCTRLREQ", _IOC_READ, 0x4945, 0x04 },
{ "linux/mISDNif.h", "IMDELTIMER", _IOC_READ, 0x4941, 0x04 },
{ "linux/mISDNif.h", "IMGETCOUNT", _IOC_READ, 0x4943, 0x04 },
{ "linux/mISDNif.h", "IMGETDEVINFO", _IOC_READ, 0x4944, 0x04 },
{ "linux/mISDNif.h", "IMGETVERSION", _IOC_READ, 0x4942, 0x04 },
{ "linux/mISDNif.h", "IMHOLD_L1", _IOC_READ, 0x4948, 0x04 },
{ "linux/mISDNif.h", "IMSETDEVNAME", _IOC_READ, 0x4947, 0x18 },
{ "linux/map_benchmark.h", "DMA_MAP_BENCHMARK", _IOC_READ|_IOC_WRITE, 0x6401, 0x3c },
{ "linux/matroxfb.h", "MATROXFB_GET_ALL_OUTPUTS", _IOC_READ, 0x6efb, 0x04 },
{ "linux/matroxfb.h", "MATROXFB_GET_AVAILABLE_OUTPUTS", _IOC_READ, 0x6ef9, 0x04 },
{ "linux/matroxfb.h", "MATROXFB_GET_OUTPUT_CONNECTION", _IOC_READ, 0x6ef8, 0x04 },
{ "linux/matroxfb.h", "MATROXFB_GET_OUTPUT_MODE", _IOC_READ|_IOC_WRITE, 0x6efa, 0x04 },
{ "linux/matroxfb.h", "MATROXFB_SET_OUTPUT_CONNECTION", _IOC_WRITE, 0x6ef8, 0x04 },
{ "linux/matroxfb.h", "MATROXFB_SET_OUTPUT_MODE", _IOC_WRITE, 0x6efa, 0x04 },
{ "linux/media.h", "MEDIA_IOC_DEVICE_INFO", _IOC_READ|_IOC_WRITE, 0x7c00, 0x100 },
{ "linux/media.h", "MEDIA_IOC_ENUM_ENTITIES", _IOC_READ|_IOC_WRITE, 0x7c01, 0x100 },
{ "linux/media.h", "MEDIA_IOC_ENUM_LINKS", _IOC_READ|_IOC_WRITE, 0x7c02, 0x1c },
{ "linux/media.h", "MEDIA_IOC_G_TOPOLOGY", _IOC_READ|_IOC_WRITE, 0x7c04, 0x48 },
{ "linux/media.h", "MEDIA_IOC_REQUEST_ALLOC", _IOC_READ, 0x7c05, 0x04 },
{ "linux/media.h", "MEDIA_IOC_SETUP_LINK", _IOC_READ|_IOC_WRITE, 0x7c03, 0x30 },
{ "linux/media.h", "MEDIA_REQUEST_IOC_QUEUE", _IOC_NONE, 0x7c80, 0x00 },
{ "linux/media.h", "MEDIA_REQUEST_IOC_REINIT", _IOC_NONE, 0x7c81, 0x00 },
{ "linux/mei.h", "IOCTL_MEI_CONNECT_CLIENT", _IOC_READ|_IOC_WRITE, 0x4801, 0x10 },
{ "linux/mei.h", "IOCTL_MEI_CONNECT_CLIENT_VTAG", _IOC_READ|_IOC_WRITE, 0x4804, 0x14 },
{ "linux/mei.h", "IOCTL_MEI_NOTIFY_GET", _IOC_READ, 0x4803, 0x04 },
{ "linux/mei.h", "IOCTL_MEI_NOTIFY_SET", _IOC_WRITE, 0x4802, 0x04 },
{ "linux/misc/bcm_vk.h", "VK_IOCTL_LOAD_IMAGE", _IOC_WRITE, 0x5e02, 0x44 },
{ "linux/misc/bcm_vk.h", "VK_IOCTL_RESET", _IOC_WRITE, 0x5e04, 0x08 },
{ "linux/mmc/ioctl.h", "MMC_IOC_CMD", _IOC_READ|_IOC_WRITE, 0xb300, 0x48 },
{ "linux/mmc/ioctl.h", "MMC_IOC_MULTI_CMD", _IOC_READ|_IOC_WRITE, 0xb301, 0x08 },
{ "linux/mmtimer.h", "MMTIMER_GETBITS", _IOC_NONE, 0x6d04, 0x00 },
{ "linux/mmtimer.h", "MMTIMER_GETCOUNTER", _IOC_READ, 0x6d09, 0x04 },
{ "linux/mmtimer.h", "MMTIMER_GETFREQ", _IOC_READ, 0x6d02, 0x04 },
{ "linux/mmtimer.h", "MMTIMER_GETOFFSET", _IOC_NONE, 0x6d00, 0x00 },
{ "linux/mmtimer.h", "MMTIMER_GETRES", _IOC_READ, 0x6d01, 0x04 },
{ "linux/mmtimer.h", "MMTIMER_MMAPAVAIL", _IOC_NONE, 0x6d06, 0x00 },
{ "linux/msdos_fs.h", "FAT_IOCTL_GET_ATTRIBUTES", _IOC_READ, 0x7210, 0x04 },
{ "linux/msdos_fs.h", "FAT_IOCTL_GET_VOLUME_ID", _IOC_READ, 0x7213, 0x04 },
{ "linux/msdos_fs.h", "FAT_IOCTL_SET_ATTRIBUTES", _IOC_WRITE, 0x7211, 0x04 },
{ "linux/msdos_fs.h", "VFAT_IOCTL_READDIR_BOTH", _IOC_READ, 0x7201, 0x214 },
{ "linux/msdos_fs.h", "VFAT_IOCTL_READDIR_SHORT", _IOC_READ, 0x7202, 0x214 },
{ "linux/mtio.h", "MTIOCGET", _IOC_READ, 0x6d02, 0x1c },
{ "linux/mtio.h", "MTIOCPOS", _IOC_READ, 0x6d03, 0x04 },
{ "linux/mtio.h", "MTIOCTOP", _IOC_WRITE, 0x6d01, 0x06 },
{ "linux/nbd.h", "NBD_CLEAR_QUE", _IOC_NONE, 0xab05, 0x00 },
{ "linux/nbd.h", "NBD_CLEAR_SOCK", _IOC_NONE, 0xab04, 0x00 },
{ "linux/nbd.h", "NBD_DISCONNECT", _IOC_NONE, 0xab08, 0x00 },
{ "linux/nbd.h", "NBD_DO_IT", _IOC_NONE, 0xab03, 0x00 },
{ "linux/nbd.h", "NBD_PRINT_DEBUG", _IOC_NONE, 0xab06, 0x00 },
{ "linux/nbd.h", "NBD_SET_BLKSIZE", _IOC_NONE, 0xab01, 0x00 },
{ "linux/nbd.h", "NBD_SET_FLAGS", _IOC_NONE, 0xab0a, 0x00 },
{ "linux/nbd.h", "NBD_SET_SIZE", _IOC_NONE, 0xab02, 0x00 },
{ "linux/nbd.h", "NBD_SET_SIZE_BLOCKS", _IOC_NONE, 0xab07, 0x00 },
{ "linux/nbd.h", "NBD_SET_SOCK", _IOC_NONE, 0xab00, 0x00 },
{ "linux/nbd.h", "NBD_SET_TIMEOUT", _IOC_NONE, 0xab09, 0x00 },
{ "linux/ndctl.h", "ND_IOCTL_ARS_CAP", _IOC_READ|_IOC_WRITE, 0x4e01, 0x20 },
{ "linux/ndctl.h", "ND_IOCTL_ARS_START", _IOC_READ|_IOC_WRITE, 0x4e02, 0x20 },
{ "linux/ndctl.h", "ND_IOCTL_ARS_STATUS", _IOC_READ|_IOC_WRITE, 0x4e03, 0x30 },
{ "linux/ndctl.h", "ND_IOCTL_CALL", _IOC_READ|_IOC_WRITE, 0x4e0a, 0x40 },
{ "linux/ndctl.h", "ND_IOCTL_CLEAR_ERROR", _IOC_READ|_IOC_WRITE, 0x4e04, 0x20 },
{ "linux/ndctl.h", "ND_IOCTL_DIMM_FLAGS", _IOC_READ|_IOC_WRITE, 0x4e03, 0x08 },
{ "linux/ndctl.h", "ND_IOCTL_GET_CONFIG_DATA", _IOC_READ|_IOC_WRITE, 0x4e05, 0x0c },
{ "linux/ndctl.h", "ND_IOCTL_GET_CONFIG_SIZE", _IOC_READ|_IOC_WRITE, 0x4e04, 0x0c },
{ "linux/ndctl.h", "ND_IOCTL_SET_CONFIG_DATA", _IOC_READ|_IOC_WRITE, 0x4e06, 0x08 },
{ "linux/ndctl.h", "ND_IOCTL_VENDOR", _IOC_READ|_IOC_WRITE, 0x4e09, 0x08 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_CHANGE_CPMODE", _IOC_WRITE, 0x6e80, 0x10 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_CLEAN_SEGMENTS", _IOC_WRITE, 0x6e88, 0x78 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_DELETE_CHECKPOINT", _IOC_WRITE, 0x6e81, 0x08 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_GET_BDESCS", _IOC_READ|_IOC_WRITE, 0x6e87, 0x18 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_GET_CPINFO", _IOC_READ, 0x6e82, 0x18 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_GET_CPSTAT", _IOC_READ, 0x6e83, 0x18 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_GET_SUINFO", _IOC_READ, 0x6e84, 0x18 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_GET_SUSTAT", _IOC_READ, 0x6e85, 0x30 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_GET_VINFO", _IOC_READ|_IOC_WRITE, 0x6e86, 0x18 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_RESIZE", _IOC_WRITE, 0x6e8b, 0x08 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_SET_ALLOC_RANGE", _IOC_WRITE, 0x6e8c, 0x10 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_SET_SUINFO", _IOC_WRITE, 0x6e8d, 0x18 },
{ "linux/nilfs2_api.h", "NILFS_IOCTL_SYNC", _IOC_READ, 0x6e8a, 0x08 },
{ "linux/nitro_enclaves.h", "NE_ADD_VCPU", _IOC_READ|_IOC_WRITE, 0xae21, 0x04 },
{ "linux/nitro_enclaves.h", "NE_CREATE_VM", _IOC_READ, 0xae20, 0x08 },
{ "linux/nitro_enclaves.h", "NE_GET_IMAGE_LOAD_INFO", _IOC_READ|_IOC_WRITE, 0xae22, 0x10 },
{ "linux/nitro_enclaves.h", "NE_SET_USER_MEMORY_REGION", _IOC_WRITE, 0xae23, 0x18 },
{ "linux/nitro_enclaves.h", "NE_START_ENCLAVE", _IOC_READ|_IOC_WRITE, 0xae24, 0x10 },
{ "linux/nsfs.h", "NS_GET_MNTNS_ID", _IOC_READ, 0xb705, 0x08 },
{ "linux/nsfs.h", "NS_GET_NSTYPE", _IOC_NONE, 0xb703, 0x00 },
{ "linux/nsfs.h", "NS_GET_OWNER_UID", _IOC_NONE, 0xb704, 0x00 },
{ "linux/nsfs.h", "NS_GET_PARENT", _IOC_NONE, 0xb702, 0x00 },
{ "linux/nsfs.h", "NS_GET_PID_FROM_PIDNS", _IOC_READ, 0xb706, 0x04 },
{ "linux/nsfs.h", "NS_GET_PID_IN_PIDNS", _IOC_READ, 0xb708, 0x04 },
{ "linux/nsfs.h", "NS_GET_TGID_FROM_PIDNS", _IOC_READ, 0xb707, 0x04 },
{ "linux/nsfs.h", "NS_GET_TGID_IN_PIDNS", _IOC_READ, 0xb709, 0x04 },
{ "linux/nsfs.h", "NS_GET_USERNS", _IOC_NONE, 0xb701, 0x00 },
{ "linux/nsfs.h", "NS_MNT_GET_INFO", _IOC_READ, 0xb70a, 0x10 },
{ "linux/nsfs.h", "NS_MNT_GET_NEXT", _IOC_READ, 0xb70b, 0x10 },
{ "linux/nsfs.h", "NS_MNT_GET_PREV", _IOC_READ, 0xb70c, 0x10 },
{ "linux/nsm.h", "NSM_IOCTL_RAW", _IOC_READ|_IOC_WRITE, 0x0a00, 0x20 },
{ "linux/ntsync.h", "NTSYNC_IOC_CREATE_SEM", _IOC_READ|_IOC_WRITE, 0x4e80, 0x0c },
{ "linux/ntsync.h", "NTSYNC_IOC_SEM_POST", _IOC_READ|_IOC_WRITE, 0x4e81, 0x04 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_ADMIN64_CMD", _IOC_READ|_IOC_WRITE, 0x4e47, 0x50 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_ADMIN_CMD", _IOC_READ|_IOC_WRITE, 0x4e41, 0x48 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_ID", _IOC_NONE, 0x4e40, 0x00 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_IO64_CMD", _IOC_READ|_IOC_WRITE, 0x4e48, 0x50 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_IO64_CMD_VEC", _IOC_READ|_IOC_WRITE, 0x4e49, 0x50 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_IO_CMD", _IOC_READ|_IOC_WRITE, 0x4e43, 0x48 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_RESCAN", _IOC_NONE, 0x4e46, 0x00 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_RESET", _IOC_NONE, 0x4e44, 0x00 },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_SUBMIT_IO", _IOC_WRITE, 0x4e42, 0x2c },
{ "linux/nvme_ioctl.h", "NVME_IOCTL_SUBSYS_RESET", _IOC_NONE, 0x4e45, 0x00 },
{ "linux/nvme_ioctl.h", "NVME_URING_CMD_ADMIN", _IOC_READ|_IOC_WRITE, 0x4e82, 0x48 },
{ "linux/nvme_ioctl.h", "NVME_URING_CMD_ADMIN_VEC", _IOC_READ|_IOC_WRITE, 0x4e83, 0x48 },
{ "linux/nvme_ioctl.h", "NVME_URING_CMD_IO", _IOC_READ|_IOC_WRITE, 0x4e80, 0x48 },
{ "linux/nvme_ioctl.h", "NVME_URING_CMD_IO_VEC", _IOC_READ|_IOC_WRITE, 0x4e81, 0x48 },
{ "linux/nvram.h", "NVRAM_INIT", _IOC_NONE, 0x7040, 0x00 },
{ "linux/nvram.h", "NVRAM_SETCKS", _IOC_NONE, 0x7041, 0x00 },
{ "linux/omap3isp.h", "VIDIOC_OMAP3ISP_AEWB_CFG", _IOC_READ|_IOC_WRITE, 0x56c3, 0x1e },
{ "linux/omap3isp.h", "VIDIOC_OMAP3ISP_AF_CFG", _IOC_READ|_IOC_WRITE, 0x56c5, 0x4a },
{ "linux/omap3isp.h", "VIDIOC_OMAP3ISP_CCDC_CFG", _IOC_READ|_IOC_WRITE, 0x56c1, 0x20 },
{ "linux/omap3isp.h", "VIDIOC_OMAP3ISP_HIST_CFG", _IOC_READ|_IOC_WRITE, 0x56c4, 0x30 },
{ "linux/omap3isp.h", "VIDIOC_OMAP3ISP_PRV_CFG", _IOC_READ|_IOC_WRITE, 0x56c2, 0x3c },
{ "linux/omap3isp.h", "VIDIOC_OMAP3ISP_STAT_EN", _IOC_READ|_IOC_WRITE, 0x56c7, 0x04 },
{ "linux/omap3isp.h", "VIDIOC_OMAP3ISP_STAT_REQ_TIME32", _IOC_READ|_IOC_WRITE, 0x56c6, 0x16 },
{ "linux/omapfb.h", "OMAPFB_CTRL_TEST", _IOC_WRITE, 0x4f2e, 0x04 },
{ "linux/omapfb.h", "OMAPFB_GET_CAPS", _IOC_READ, 0x4f2a, 0x0c },
{ "linux/omapfb.h", "OMAPFB_GET_COLOR_KEY", _IOC_WRITE, 0x4f33, 0x0c },
{ "linux/omapfb.h", "OMAPFB_GET_DISPLAY_INFO", _IOC_READ, 0x4f3f, 0x20 },
{ "linux/omapfb.h", "OMAPFB_GET_OVERLAY_COLORMODE", _IOC_READ, 0x4f3b, 0x3a },
{ "linux/omapfb.h", "OMAPFB_GET_UPDATE_MODE", _IOC_WRITE, 0x4f2b, 0x04 },
{ "linux/omapfb.h", "OMAPFB_GET_VRAM_INFO", _IOC_READ, 0x4f3d, 0x20 },
{ "linux/omapfb.h", "OMAPFB_LCD_TEST", _IOC_WRITE, 0x4f2d, 0x04 },
{ "linux/omapfb.h", "OMAPFB_MEMORY_READ", _IOC_READ, 0x4f3a, 0x10 },
{ "linux/omapfb.h", "OMAPFB_MIRROR", _IOC_WRITE, 0x4f1f, 0x04 },
{ "linux/omapfb.h", "OMAPFB_QUERY_MEM", _IOC_WRITE, 0x4f38, 0x08 },
{ "linux/omapfb.h", "OMAPFB_QUERY_PLANE", _IOC_WRITE, 0x4f35, 0x44 },
{ "linux/omapfb.h", "OMAPFB_SETUP_MEM", _IOC_WRITE, 0x4f37, 0x08 },
{ "linux/omapfb.h", "OMAPFB_SETUP_PLANE", _IOC_WRITE, 0x4f34, 0x44 },
{ "linux/omapfb.h", "OMAPFB_SET_COLOR_KEY", _IOC_WRITE, 0x4f32, 0x0c },
{ "linux/omapfb.h", "OMAPFB_SET_TEARSYNC", _IOC_WRITE, 0x4f3e, 0x08 },
{ "linux/omapfb.h", "OMAPFB_SET_UPDATE_MODE", _IOC_WRITE, 0x4f28, 0x04 },
{ "linux/omapfb.h", "OMAPFB_SYNC_GFX", _IOC_NONE, 0x4f25, 0x00 },
{ "linux/omapfb.h", "OMAPFB_UPDATE_WINDOW", _IOC_WRITE, 0x4f36, 0x44 },
{ "linux/omapfb.h", "OMAPFB_UPDATE_WINDOW_OLD", _IOC_WRITE, 0x4f2f, 0x14 },
{ "linux/omapfb.h", "OMAPFB_VSYNC", _IOC_NONE, 0x4f26, 0x00 },
{ "linux/omapfb.h", "OMAPFB_WAITFORGO", _IOC_NONE, 0x4f3c, 0x00 },
{ "linux/omapfb.h", "OMAPFB_WAITFORVSYNC", _IOC_NONE, 0x4f39, 0x00 },
{ "linux/pcitest.h", "PCITEST_BAR", _IOC_NONE, 0x5001, 0x00 },
{ "linux/pcitest.h", "PCITEST_CLEAR_IRQ", _IOC_NONE, 0x5010, 0x00 },
{ "linux/pcitest.h", "PCITEST_COPY", _IOC_WRITE, 0x5006, 0x04 },
{ "linux/pcitest.h", "PCITEST_GET_IRQTYPE", _IOC_NONE, 0x5009, 0x00 },
{ "linux/pcitest.h", "PCITEST_INTX_IRQ", _IOC_NONE, 0x5002, 0x00 },
{ "linux/pcitest.h", "PCITEST_MSI", _IOC_WRITE, 0x5003, 0x04 },
{ "linux/pcitest.h", "PCITEST_MSIX", _IOC_WRITE, 0x5007, 0x04 },
{ "linux/pcitest.h", "PCITEST_READ", _IOC_WRITE, 0x5005, 0x04 },
{ "linux/pcitest.h", "PCITEST_SET_IRQTYPE", _IOC_WRITE, 0x5008, 0x04 },
{ "linux/pcitest.h", "PCITEST_WRITE", _IOC_WRITE, 0x5004, 0x04 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_DISABLE", _IOC_NONE, 0x2401, 0x00 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_ENABLE", _IOC_NONE, 0x2400, 0x00 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_ID", _IOC_READ, 0x2407, 0x04 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_MODIFY_ATTRIBUTES", _IOC_WRITE, 0x240b, 0x04 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_PAUSE_OUTPUT", _IOC_WRITE, 0x2409, 0x04 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_PERIOD", _IOC_WRITE, 0x2404, 0x08 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_QUERY_BPF", _IOC_READ|_IOC_WRITE, 0x240a, 0x04 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_REFRESH", _IOC_NONE, 0x2402, 0x00 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_RESET", _IOC_NONE, 0x2403, 0x00 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_SET_BPF", _IOC_WRITE, 0x2408, 0x04 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_SET_FILTER", _IOC_WRITE, 0x2406, 0x04 },
{ "linux/perf_event.h", "PERF_EVENT_IOC_SET_OUTPUT", _IOC_NONE, 0x2405, 0x00 },
{ "linux/pfrut.h", "PFRT_LOG_IOC_GET_DATA_INFO", _IOC_READ, 0xee08, 0x3c },
{ "linux/pfrut.h", "PFRT_LOG_IOC_GET_INFO", _IOC_READ, 0xee07, 0x0c },
{ "linux/pfrut.h", "PFRT_LOG_IOC_SET_INFO", _IOC_WRITE, 0xee06, 0x0c },
{ "linux/pfrut.h", "PFRU_IOC_ACTIVATE", _IOC_WRITE, 0xee03, 0x04 },
{ "linux/pfrut.h", "PFRU_IOC_QUERY_CAP", _IOC_READ, 0xee05, 0x5c },
{ "linux/pfrut.h", "PFRU_IOC_SET_REV", _IOC_WRITE, 0xee01, 0x04 },
{ "linux/pfrut.h", "PFRU_IOC_STAGE", _IOC_WRITE, 0xee02, 0x04 },
{ "linux/pfrut.h", "PFRU_IOC_STAGE_ACTIVATE", _IOC_WRITE, 0xee04, 0x04 },
{ "linux/phantom.h", "PHN_GETREG", _IOC_READ|_IOC_WRITE, 0x7005, 0x08 },
{ "linux/phantom.h", "PHN_GETREGS", _IOC_READ|_IOC_WRITE, 0x7007, 0x28 },
{ "linux/phantom.h", "PHN_GET_REG", _IOC_READ|_IOC_WRITE, 0x7000, 0x04 },
{ "linux/phantom.h", "PHN_GET_REGS", _IOC_READ|_IOC_WRITE, 0x7002, 0x04 },
{ "linux/phantom.h", "PHN_NOT_OH", _IOC_NONE, 0x7004, 0x00 },
{ "linux/phantom.h", "PHN_SETREG", _IOC_WRITE, 0x7006, 0x08 },
{ "linux/phantom.h", "PHN_SETREGS", _IOC_WRITE, 0x7008, 0x28 },
{ "linux/phantom.h", "PHN_SET_REG", _IOC_WRITE, 0x7001, 0x04 },
{ "linux/phantom.h", "PHN_SET_REGS", _IOC_WRITE, 0x7003, 0x04 },
{ "linux/pidfd.h", "PIDFD_GET_CGROUP_NAMESPACE", _IOC_NONE, 0xff01, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_INFO", _IOC_READ|_IOC_WRITE, 0xff0b, 0x40 },
{ "linux/pidfd.h", "PIDFD_GET_IPC_NAMESPACE", _IOC_NONE, 0xff02, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_MNT_NAMESPACE", _IOC_NONE, 0xff03, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_NET_NAMESPACE", _IOC_NONE, 0xff04, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_PID_FOR_CHILDREN_NAMESPACE", _IOC_NONE, 0xff06, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_PID_NAMESPACE", _IOC_NONE, 0xff05, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_TIME_FOR_CHILDREN_NAMESPACE", _IOC_NONE, 0xff08, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_TIME_NAMESPACE", _IOC_NONE, 0xff07, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_USER_NAMESPACE", _IOC_NONE, 0xff09, 0x00 },
{ "linux/pidfd.h", "PIDFD_GET_UTS_NAMESPACE", _IOC_NONE, 0xff0a, 0x00 },
{ "linux/pktcdvd.h", "PACKET_CTRL_CMD", _IOC_READ|_IOC_WRITE, 0x5801, 0x18 },
{ "linux/platform_data/cros_ec_chardev.h", "CROS_EC_DEV_IOCEVENTMASK", _IOC_NONE, 0xec02, 0x00 },
{ "linux/platform_data/cros_ec_chardev.h", "CROS_EC_DEV_IOCRDMEM", _IOC_READ|_IOC_WRITE, 0xec01, 0x108 },
{ "linux/platform_data/cros_ec_chardev.h", "CROS_EC_DEV_IOCXCMD", _IOC_READ|_IOC_WRITE, 0xec00, 0x14 },
{ "linux/platform_data/media/si4713.h", "SI4713_IOC_MEASURE_RNL", _IOC_READ|_IOC_WRITE, 0x56c0, 0x1c },
{ "linux/pmu.h", "PMU_IOC_CAN_SLEEP", _IOC_READ, 0x4205, 0x04 },
{ "linux/pmu.h", "PMU_IOC_GET_BACKLIGHT", _IOC_READ, 0x4201, 0x04 },
{ "linux/pmu.h", "PMU_IOC_GET_MODEL", _IOC_READ, 0x4203, 0x04 },
{ "linux/pmu.h", "PMU_IOC_GRAB_BACKLIGHT", _IOC_READ, 0x4206, 0x04 },
{ "linux/pmu.h", "PMU_IOC_HAS_ADB", _IOC_READ, 0x4204, 0x04 },
{ "linux/pmu.h", "PMU_IOC_SET_BACKLIGHT", _IOC_WRITE, 0x4202, 0x04 },
{ "linux/pmu.h", "PMU_IOC_SLEEP", _IOC_NONE, 0x4200, 0x00 },
{ "linux/ppdev.h", "PPCLAIM", _IOC_NONE, 0x708b, 0x00 },
{ "linux/ppdev.h", "PPCLRIRQ", _IOC_READ, 0x7093, 0x04 },
{ "linux/ppdev.h", "PPDATADIR", _IOC_WRITE, 0x7090, 0x04 },
{ "linux/ppdev.h", "PPEXCL", _IOC_NONE, 0x708f, 0x00 },
{ "linux/ppdev.h", "PPFCONTROL", _IOC_WRITE, 0x708e, 0x02 },
{ "linux/ppdev.h", "PPGETFLAGS", _IOC_READ, 0x709a, 0x04 },
{ "linux/ppdev.h", "PPGETMODE", _IOC_READ, 0x7098, 0x04 },
{ "linux/ppdev.h", "PPGETMODES", _IOC_READ, 0x7097, 0x04 },
{ "linux/ppdev.h", "PPGETPHASE", _IOC_READ, 0x7099, 0x04 },
{ "linux/ppdev.h", "PPGETTIME", _IOC_READ, 0x7095, 0x08 },
{ "linux/ppdev.h", "PPNEGOT", _IOC_WRITE, 0x7091, 0x04 },
{ "linux/ppdev.h", "PPRCONTROL", _IOC_READ, 0x7083, 0x01 },
{ "linux/ppdev.h", "PPRDATA", _IOC_READ, 0x7085, 0x01 },
{ "linux/ppdev.h", "PPRELEASE", _IOC_NONE, 0x708c, 0x00 },
{ "linux/ppdev.h", "PPRSTATUS", _IOC_READ, 0x7081, 0x01 },
{ "linux/ppdev.h", "PPSETFLAGS", _IOC_WRITE, 0x709b, 0x04 },
{ "linux/ppdev.h", "PPSETMODE", _IOC_WRITE, 0x7080, 0x04 },
{ "linux/ppdev.h", "PPSETPHASE", _IOC_WRITE, 0x7094, 0x04 },
{ "linux/ppdev.h", "PPSETTIME", _IOC_WRITE, 0x7096, 0x08 },
{ "linux/ppdev.h", "PPWCONTROL", _IOC_WRITE, 0x7084, 0x01 },
{ "linux/ppdev.h", "PPWCTLONIRQ", _IOC_WRITE, 0x7092, 0x01 },
{ "linux/ppdev.h", "PPWDATA", _IOC_WRITE, 0x7086, 0x01 },
{ "linux/ppdev.h", "PPYIELD", _IOC_NONE, 0x708d, 0x00 },
{ "linux/ppp-ioctl.h", "PPPIOCATTACH", _IOC_WRITE, 0x743d, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCATTCHAN", _IOC_WRITE, 0x7438, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCBRIDGECHAN", _IOC_WRITE, 0x7435, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCCONNECT", _IOC_WRITE, 0x743a, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCDETACH", _IOC_WRITE, 0x743c, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCDISCONN", _IOC_NONE, 0x7439, 0x00 },
{ "linux/ppp-ioctl.h", "PPPIOCGASYNCMAP", _IOC_READ, 0x7458, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCGCHAN", _IOC_READ, 0x7437, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCGDEBUG", _IOC_READ, 0x7441, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCGFLAGS", _IOC_READ, 0x745a, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCGIDLE32", _IOC_READ, 0x743f, 0x08 },
{ "linux/ppp-ioctl.h", "PPPIOCGIDLE64", _IOC_READ, 0x743f, 0x10 },
{ "linux/ppp-ioctl.h", "PPPIOCGL2TPSTATS", _IOC_READ, 0x7436, 0x48 },
{ "linux/ppp-ioctl.h", "PPPIOCGMRU", _IOC_READ, 0x7453, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCGNPMODE", _IOC_READ|_IOC_WRITE, 0x744c, 0x08 },
{ "linux/ppp-ioctl.h", "PPPIOCGRASYNCMAP", _IOC_READ, 0x7455, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCGUNIT", _IOC_READ, 0x7456, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCGXASYNCMAP", _IOC_READ, 0x7450, 0x20 },
{ "linux/ppp-ioctl.h", "PPPIOCNEWUNIT", _IOC_READ|_IOC_WRITE, 0x743e, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCSACTIVE", _IOC_WRITE, 0x7446, 0x06 },
{ "linux/ppp-ioctl.h", "PPPIOCSASYNCMAP", _IOC_WRITE, 0x7457, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCSCOMPRESS", _IOC_WRITE, 0x744d, 0x0c },
{ "linux/ppp-ioctl.h", "PPPIOCSDEBUG", _IOC_WRITE, 0x7440, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCSFLAGS", _IOC_WRITE, 0x7459, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCSMAXCID", _IOC_WRITE, 0x7451, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCSMRRU", _IOC_WRITE, 0x743b, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCSMRU", _IOC_WRITE, 0x7452, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCSNPMODE", _IOC_WRITE, 0x744b, 0x08 },
{ "linux/ppp-ioctl.h", "PPPIOCSPASS", _IOC_WRITE, 0x7447, 0x06 },
{ "linux/ppp-ioctl.h", "PPPIOCSRASYNCMAP", _IOC_WRITE, 0x7454, 0x04 },
{ "linux/ppp-ioctl.h", "PPPIOCSXASYNCMAP", _IOC_WRITE, 0x744f, 0x20 },
{ "linux/ppp-ioctl.h", "PPPIOCUNBRIDGECHAN", _IOC_NONE, 0x7434, 0x00 },
{ "linux/ppp-ioctl.h", "PPPIOCXFERUNIT", _IOC_NONE, 0x744e, 0x00 },
{ "linux/pps.h", "PPS_FETCH", _IOC_READ|_IOC_WRITE, 0x70a4, 0x04 },
{ "linux/pps.h", "PPS_GETCAP", _IOC_READ, 0x70a3, 0x04 },
{ "linux/pps.h", "PPS_GETPARAMS", _IOC_READ, 0x70a1, 0x04 },
{ "linux/pps.h", "PPS_KC_BIND", _IOC_WRITE, 0x70a5, 0x04 },
{ "linux/pps.h", "PPS_SETPARAMS", _IOC_WRITE, 0x70a2, 0x04 },
{ "linux/pr.h", "IOC_PR_CLEAR", _IOC_WRITE, 0x70cd, 0x10 },
{ "linux/pr.h", "IOC_PR_PREEMPT", _IOC_WRITE, 0x70cb, 0x18 },
{ "linux/pr.h", "IOC_PR_PREEMPT_ABORT", _IOC_WRITE, 0x70cc, 0x18 },
{ "linux/pr.h", "IOC_PR_REGISTER", _IOC_WRITE, 0x70c8, 0x18 },
{ "linux/pr.h", "IOC_PR_RELEASE", _IOC_WRITE, 0x70ca, 0x10 },
{ "linux/pr.h", "IOC_PR_RESERVE", _IOC_WRITE, 0x70c9, 0x10 },
{ "linux/psp-dbc.h", "DBCIOCNONCE", _IOC_READ|_IOC_WRITE, 0x4401, 0x34 },
{ "linux/psp-dbc.h", "DBCIOCPARAM", _IOC_READ|_IOC_WRITE, 0x4403, 0x28 },
{ "linux/psp-dbc.h", "DBCIOCUID", _IOC_WRITE, 0x4402, 0x30 },
{ "linux/psp-sev.h", "SEV_ISSUE_CMD", _IOC_READ|_IOC_WRITE, 0x5300, 0x10 },
{ "linux/ptp_clock.h", "PTP_CLOCK_GETCAPS", _IOC_READ, 0x3d01, 0x50 },
{ "linux/ptp_clock.h", "PTP_CLOCK_GETCAPS2", _IOC_READ, 0x3d0a, 0x50 },
{ "linux/ptp_clock.h", "PTP_ENABLE_PPS", _IOC_WRITE, 0x3d04, 0x04 },
{ "linux/ptp_clock.h", "PTP_ENABLE_PPS2", _IOC_WRITE, 0x3d0d, 0x04 },
{ "linux/ptp_clock.h", "PTP_EXTTS_REQUEST", _IOC_WRITE, 0x3d02, 0x10 },
{ "linux/ptp_clock.h", "PTP_EXTTS_REQUEST2", _IOC_WRITE, 0x3d0b, 0x10 },
{ "linux/ptp_clock.h", "PTP_MASK_CLEAR_ALL", _IOC_NONE, 0x3d13, 0x00 },
{ "linux/ptp_clock.h", "PTP_MASK_EN_SINGLE", _IOC_WRITE, 0x3d14, 0x04 },
{ "linux/ptp_clock.h", "PTP_PEROUT_REQUEST", _IOC_WRITE, 0x3d03, 0x38 },
{ "linux/ptp_clock.h", "PTP_PEROUT_REQUEST2", _IOC_WRITE, 0x3d0c, 0x38 },
{ "linux/ptp_clock.h", "PTP_PIN_GETFUNC", _IOC_READ|_IOC_WRITE, 0x3d06, 0x60 },
{ "linux/ptp_clock.h", "PTP_PIN_GETFUNC2", _IOC_READ|_IOC_WRITE, 0x3d0f, 0x60 },
{ "linux/ptp_clock.h", "PTP_PIN_SETFUNC", _IOC_WRITE, 0x3d07, 0x60 },
{ "linux/ptp_clock.h", "PTP_PIN_SETFUNC2", _IOC_WRITE, 0x3d10, 0x60 },
{ "linux/ptp_clock.h", "PTP_SYS_OFFSET", _IOC_WRITE, 0x3d05, 0x340 },
{ "linux/ptp_clock.h", "PTP_SYS_OFFSET2", _IOC_WRITE, 0x3d0e, 0x340 },
{ "linux/ptp_clock.h", "PTP_SYS_OFFSET_EXTENDED", _IOC_READ|_IOC_WRITE, 0x3d09, 0x4c0 },
{ "linux/ptp_clock.h", "PTP_SYS_OFFSET_EXTENDED2", _IOC_READ|_IOC_WRITE, 0x3d12, 0x4c0 },
{ "linux/ptp_clock.h", "PTP_SYS_OFFSET_PRECISE", _IOC_READ|_IOC_WRITE, 0x3d08, 0x40 },
{ "linux/ptp_clock.h", "PTP_SYS_OFFSET_PRECISE2", _IOC_READ|_IOC_WRITE, 0x3d11, 0x40 },
{ "linux/radeonfb.h", "FBIO_RADEON_GET_MIRROR", _IOC_READ, 0x4003, 0x04 },
{ "linux/radeonfb.h", "FBIO_RADEON_SET_MIRROR", _IOC_WRITE, 0x4004, 0x04 },
{ "linux/raid/md_u.h", "ADD_NEW_DISK", _IOC_WRITE, 0x0921, 0x14 },
{ "linux/raid/md_u.h", "CLEAR_ARRAY", _IOC_NONE, 0x0920, 0x00 },
{ "linux/raid/md_u.h", "CLUSTERED_DISK_NACK", _IOC_NONE, 0x0935, 0x00 },
{ "linux/raid/md_u.h", "GET_ARRAY_INFO", _IOC_READ, 0x0911, 0x48 },
{ "linux/raid/md_u.h", "GET_BITMAP_FILE", _IOC_READ, 0x0915, 0x1000 },
{ "linux/raid/md_u.h", "GET_DISK_INFO", _IOC_READ, 0x0912, 0x14 },
{ "linux/raid/md_u.h", "HOT_ADD_DISK", _IOC_NONE, 0x0928, 0x00 },
{ "linux/raid/md_u.h", "HOT_GENERATE_ERROR", _IOC_NONE, 0x092a, 0x00 },
{ "linux/raid/md_u.h", "HOT_REMOVE_DISK", _IOC_NONE, 0x0922, 0x00 },
{ "linux/raid/md_u.h", "PROTECT_ARRAY", _IOC_NONE, 0x0927, 0x00 },
{ "linux/raid/md_u.h", "RAID_AUTORUN", _IOC_NONE, 0x0914, 0x00 },
{ "linux/raid/md_u.h", "RAID_VERSION", _IOC_READ, 0x0910, 0x0c },
{ "linux/raid/md_u.h", "RESTART_ARRAY_RW", _IOC_NONE, 0x0934, 0x00 },
{ "linux/raid/md_u.h", "RUN_ARRAY", _IOC_WRITE, 0x0930, 0x0c },
{ "linux/raid/md_u.h", "SET_ARRAY_INFO", _IOC_WRITE, 0x0923, 0x48 },
{ "linux/raid/md_u.h", "SET_BITMAP_FILE", _IOC_WRITE, 0x092b, 0x04 },
{ "linux/raid/md_u.h", "SET_DISK_FAULTY", _IOC_NONE, 0x0929, 0x00 },
{ "linux/raid/md_u.h", "SET_DISK_INFO", _IOC_NONE, 0x0924, 0x00 },
{ "linux/raid/md_u.h", "STOP_ARRAY", _IOC_NONE, 0x0932, 0x00 },
{ "linux/raid/md_u.h", "STOP_ARRAY_RO", _IOC_NONE, 0x0933, 0x00 },
{ "linux/raid/md_u.h", "UNPROTECT_ARRAY", _IOC_NONE, 0x0926, 0x00 },
{ "linux/raid/md_u.h", "WRITE_RAID_INFO", _IOC_NONE, 0x0925, 0x00 },
{ "linux/random.h", "RNDADDENTROPY", _IOC_WRITE, 0x5203, 0x08 },
{ "linux/random.h", "RNDADDTOENTCNT", _IOC_WRITE, 0x5201, 0x04 },
{ "linux/random.h", "RNDCLEARPOOL", _IOC_NONE, 0x5206, 0x00 },
{ "linux/random.h", "RNDGETENTCNT", _IOC_READ, 0x5200, 0x04 },
{ "linux/random.h", "RNDGETPOOL", _IOC_READ, 0x5202, 0x08 },
{ "linux/random.h", "RNDRESEEDCRNG", _IOC_NONE, 0x5207, 0x00 },
{ "linux/random.h", "RNDZAPENTCNT", _IOC_NONE, 0x5204, 0x00 },
{ "linux/remoteproc_cdev.h", "RPROC_GET_SHUTDOWN_ON_RELEASE", _IOC_READ, 0xb702, 0x04 },
{ "linux/remoteproc_cdev.h", "RPROC_SET_SHUTDOWN_ON_RELEASE", _IOC_WRITE, 0xb701, 0x04 },
{ "linux/rfkill.h", "RFKILL_IOCTL_MAX_SIZE", _IOC_WRITE, 0x5202, 0x04 },
{ "linux/rfkill.h", "RFKILL_IOCTL_NOINPUT", _IOC_NONE, 0x5201, 0x00 },
{ "linux/rio_cm_cdev.h", "RIO_CM_CHAN_ACCEPT", _IOC_READ|_IOC_WRITE, 0x6307, 0x08 },
{ "linux/rio_cm_cdev.h", "RIO_CM_CHAN_BIND", _IOC_WRITE, 0x6305, 0x08 },
{ "linux/rio_cm_cdev.h", "RIO_CM_CHAN_CLOSE", _IOC_WRITE, 0x6304, 0x02 },
{ "linux/rio_cm_cdev.h", "RIO_CM_CHAN_CONNECT", _IOC_WRITE, 0x6308, 0x08 },
{ "linux/rio_cm_cdev.h", "RIO_CM_CHAN_CREATE", _IOC_READ|_IOC_WRITE, 0x6303, 0x02 },
{ "linux/rio_cm_cdev.h", "RIO_CM_CHAN_LISTEN", _IOC_WRITE, 0x6306, 0x02 },
{ "linux/rio_cm_cdev.h", "RIO_CM_CHAN_RECEIVE", _IOC_READ|_IOC_WRITE, 0x630a, 0x10 },
{ "linux/rio_cm_cdev.h", "RIO_CM_CHAN_SEND", _IOC_WRITE, 0x6309, 0x10 },
{ "linux/rio_cm_cdev.h", "RIO_CM_EP_GET_LIST", _IOC_READ|_IOC_WRITE, 0x6302, 0x04 },
{ "linux/rio_cm_cdev.h", "RIO_CM_EP_GET_LIST_SIZE", _IOC_READ|_IOC_WRITE, 0x6301, 0x04 },
{ "linux/rio_cm_cdev.h", "RIO_CM_MPORT_GET_LIST", _IOC_READ|_IOC_WRITE, 0x630b, 0x04 },
{ "linux/rio_mport_cdev.h", "RIO_ALLOC_DMA", _IOC_READ|_IOC_WRITE, 0x6d13, 0x18 },
{ "linux/rio_mport_cdev.h", "RIO_DEV_ADD", _IOC_WRITE, 0x6d17, 0x1e },
{ "linux/rio_mport_cdev.h", "RIO_DEV_DEL", _IOC_WRITE, 0x6d18, 0x1e },
{ "linux/rio_mport_cdev.h", "RIO_DISABLE_DOORBELL_RANGE", _IOC_WRITE, 0x6d0a, 0x08 },
{ "linux/rio_mport_cdev.h", "RIO_DISABLE_PORTWRITE_RANGE", _IOC_WRITE, 0x6d0c, 0x10 },
{ "linux/rio_mport_cdev.h", "RIO_ENABLE_DOORBELL_RANGE", _IOC_WRITE, 0x6d09, 0x08 },
{ "linux/rio_mport_cdev.h", "RIO_ENABLE_PORTWRITE_RANGE", _IOC_WRITE, 0x6d0b, 0x10 },
{ "linux/rio_mport_cdev.h", "RIO_FREE_DMA", _IOC_WRITE, 0x6d14, 0x08 },
{ "linux/rio_mport_cdev.h", "RIO_GET_EVENT_MASK", _IOC_READ, 0x6d0e, 0x04 },
{ "linux/rio_mport_cdev.h", "RIO_MAP_INBOUND", _IOC_READ|_IOC_WRITE, 0x6d11, 0x28 },
{ "linux/rio_mport_cdev.h", "RIO_MAP_OUTBOUND", _IOC_READ|_IOC_WRITE, 0x6d0f, 0x28 },
{ "linux/rio_mport_cdev.h", "RIO_MPORT_GET_PROPERTIES", _IOC_READ, 0x6d04, 0x30 },
{ "linux/rio_mport_cdev.h", "RIO_MPORT_MAINT_COMPTAG_SET", _IOC_WRITE, 0x6d02, 0x04 },
{ "linux/rio_mport_cdev.h", "RIO_MPORT_MAINT_HDID_SET", _IOC_WRITE, 0x6d01, 0x02 },
{ "linux/rio_mport_cdev.h", "RIO_MPORT_MAINT_PORT_IDX_GET", _IOC_READ, 0x6d03, 0x04 },
{ "linux/rio_mport_cdev.h", "RIO_MPORT_MAINT_READ_LOCAL", _IOC_READ, 0x6d05, 0x18 },
{ "linux/rio_mport_cdev.h", "RIO_MPORT_MAINT_READ_REMOTE", _IOC_READ, 0x6d07, 0x18 },
{ "linux/rio_mport_cdev.h", "RIO_MPORT_MAINT_WRITE_LOCAL", _IOC_WRITE, 0x6d06, 0x18 },
{ "linux/rio_mport_cdev.h", "RIO_MPORT_MAINT_WRITE_REMOTE", _IOC_WRITE, 0x6d08, 0x18 },
{ "linux/rio_mport_cdev.h", "RIO_SET_EVENT_MASK", _IOC_WRITE, 0x6d0d, 0x04 },
{ "linux/rio_mport_cdev.h", "RIO_TRANSFER", _IOC_READ|_IOC_WRITE, 0x6d15, 0x18 },
{ "linux/rio_mport_cdev.h", "RIO_UNMAP_INBOUND", _IOC_WRITE, 0x6d12, 0x08 },
{ "linux/rio_mport_cdev.h", "RIO_UNMAP_OUTBOUND", _IOC_WRITE, 0x6d10, 0x28 },
{ "linux/rio_mport_cdev.h", "RIO_WAIT_FOR_ASYNC", _IOC_WRITE, 0x6d16, 0x08 },
{ "linux/rpmsg.h", "RPMSG_CREATE_DEV_IOCTL", _IOC_WRITE, 0xb503, 0x28 },
{ "linux/rpmsg.h", "RPMSG_CREATE_EPT_IOCTL", _IOC_WRITE, 0xb501, 0x28 },
{ "linux/rpmsg.h", "RPMSG_DESTROY_EPT_IOCTL", _IOC_NONE, 0xb502, 0x00 },
{ "linux/rpmsg.h", "RPMSG_GET_OUTGOING_FLOWCONTROL", _IOC_READ, 0xb505, 0x04 },
{ "linux/rpmsg.h", "RPMSG_RELEASE_DEV_IOCTL", _IOC_WRITE, 0xb504, 0x28 },
{ "linux/rpmsg.h", "RPMSG_SET_INCOMING_FLOWCONTROL", _IOC_READ, 0xb506, 0x04 },
{ "linux/rtc.h", "RTC_AIE_OFF", _IOC_NONE, 0x7002, 0x00 },
{ "linux/rtc.h", "RTC_AIE_ON", _IOC_NONE, 0x7001, 0x00 },
{ "linux/rtc.h", "RTC_ALM_READ", _IOC_READ, 0x7008, 0x24 },
{ "linux/rtc.h", "RTC_ALM_SET", _IOC_WRITE, 0x7007, 0x24 },
{ "linux/rtc.h", "RTC_EPOCH_READ", _IOC_READ, 0x700d, 0x04 },
{ "linux/rtc.h", "RTC_EPOCH_SET", _IOC_WRITE, 0x700e, 0x04 },
{ "linux/rtc.h", "RTC_IRQP_READ", _IOC_READ, 0x700b, 0x04 },
{ "linux/rtc.h", "RTC_IRQP_SET", _IOC_WRITE, 0x700c, 0x04 },
{ "linux/rtc.h", "RTC_PARAM_GET", _IOC_WRITE, 0x7013, 0x18 },
{ "linux/rtc.h", "RTC_PARAM_SET", _IOC_WRITE, 0x7014, 0x18 },
{ "linux/rtc.h", "RTC_PIE_OFF", _IOC_NONE, 0x7006, 0x00 },
{ "linux/rtc.h", "RTC_PIE_ON", _IOC_NONE, 0x7005, 0x00 },
{ "linux/rtc.h", "RTC_PLL_GET", _IOC_READ, 0x7011, 0x1c },
{ "linux/rtc.h", "RTC_PLL_SET", _IOC_WRITE, 0x7012, 0x1c },
{ "linux/rtc.h", "RTC_RD_TIME", _IOC_READ, 0x7009, 0x24 },
{ "linux/rtc.h", "RTC_SET_TIME", _IOC_WRITE, 0x700a, 0x24 },
{ "linux/rtc.h", "RTC_UIE_OFF", _IOC_NONE, 0x7004, 0x00 },
{ "linux/rtc.h", "RTC_UIE_ON", _IOC_NONE, 0x7003, 0x00 },
{ "linux/rtc.h", "RTC_VL_CLR", _IOC_NONE, 0x7014, 0x00 },
{ "linux/rtc.h", "RTC_VL_READ", _IOC_READ, 0x7013, 0x04 },
{ "linux/rtc.h", "RTC_WIE_OFF", _IOC_NONE, 0x7010, 0x00 },
{ "linux/rtc.h", "RTC_WIE_ON", _IOC_NONE, 0x700f, 0x00 },
{ "linux/rtc.h", "RTC_WKALM_RD", _IOC_READ, 0x7010, 0x26 },
{ "linux/rtc.h", "RTC_WKALM_SET", _IOC_WRITE, 0x700f, 0x26 },
{ "linux/scif_ioctl.h", "SCIF_ACCEPTREG", _IOC_READ|_IOC_WRITE, 0x7305, 0x08 },
{ "linux/scif_ioctl.h", "SCIF_ACCEPTREQ", _IOC_READ|_IOC_WRITE, 0x7304, 0x10 },
{ "linux/scif_ioctl.h", "SCIF_BIND", _IOC_READ|_IOC_WRITE, 0x7301, 0x08 },
{ "linux/scif_ioctl.h", "SCIF_CONNECT", _IOC_READ|_IOC_WRITE, 0x7303, 0x08 },
{ "linux/scif_ioctl.h", "SCIF_FENCE_MARK", _IOC_READ|_IOC_WRITE, 0x730f, 0x0c },
{ "linux/scif_ioctl.h", "SCIF_FENCE_SIGNAL", _IOC_READ|_IOC_WRITE, 0x7311, 0x24 },
{ "linux/scif_ioctl.h", "SCIF_FENCE_WAIT", _IOC_READ|_IOC_WRITE, 0x7310, 0x04 },
{ "linux/scif_ioctl.h", "SCIF_GET_NODEIDS", _IOC_READ|_IOC_WRITE, 0x730e, 0x14 },
{ "linux/scif_ioctl.h", "SCIF_LISTEN", _IOC_WRITE, 0x7302, 0x04 },
{ "linux/scif_ioctl.h", "SCIF_READFROM", _IOC_READ|_IOC_WRITE, 0x730a, 0x24 },
{ "linux/scif_ioctl.h", "SCIF_RECV", _IOC_READ|_IOC_WRITE, 0x7307, 0x14 },
{ "linux/scif_ioctl.h", "SCIF_REG", _IOC_READ|_IOC_WRITE, 0x7308, 0x28 },
{ "linux/scif_ioctl.h", "SCIF_SEND", _IOC_READ|_IOC_WRITE, 0x7306, 0x14 },
{ "linux/scif_ioctl.h", "SCIF_UNREG", _IOC_READ|_IOC_WRITE, 0x7309, 0x10 },
{ "linux/scif_ioctl.h", "SCIF_VREADFROM", _IOC_READ|_IOC_WRITE, 0x730c, 0x24 },
{ "linux/scif_ioctl.h", "SCIF_VWRITETO", _IOC_READ|_IOC_WRITE, 0x730d, 0x24 },
{ "linux/scif_ioctl.h", "SCIF_WRITETO", _IOC_READ|_IOC_WRITE, 0x730b, 0x24 },
{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ADDFD", _IOC_WRITE, 0x2103, 0x18 },
{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_ID_VALID", _IOC_WRITE, 0x2102, 0x08 },
{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_RECV", _IOC_READ|_IOC_WRITE, 0x2100, 0x50 },
{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_SEND", _IOC_READ|_IOC_WRITE, 0x2101, 0x18 },
{ "linux/seccomp.h", "SECCOMP_IOCTL_NOTIF_SET_FLAGS", _IOC_WRITE, 0x2104, 0x08 },
{ "linux/sed-opal.h", "IOC_OPAL_ACTIVATE_LSP", _IOC_WRITE, 0x70df, 0x118 },
{ "linux/sed-opal.h", "IOC_OPAL_ACTIVATE_USR", _IOC_WRITE, 0x70e1, 0x110 },
{ "linux/sed-opal.h", "IOC_OPAL_ADD_USR_TO_LR", _IOC_WRITE, 0x70e4, 0x118 },
{ "linux/sed-opal.h", "IOC_OPAL_DISCOVERY", _IOC_WRITE, 0x70ef, 0x10 },
{ "linux/sed-opal.h", "IOC_OPAL_ENABLE_DISABLE_MBR", _IOC_WRITE, 0x70e5, 0x110 },
{ "linux/sed-opal.h", "IOC_OPAL_ERASE_LR", _IOC_WRITE, 0x70e6, 0x110 },
{ "linux/sed-opal.h", "IOC_OPAL_GENERIC_TABLE_RW", _IOC_WRITE, 0x70eb, 0x138 },
{ "linux/sed-opal.h", "IOC_OPAL_GET_GEOMETRY", _IOC_READ, 0x70ee, 0x1a },
{ "linux/sed-opal.h", "IOC_OPAL_GET_LR_STATUS", _IOC_WRITE, 0x70ed, 0x130 },
{ "linux/sed-opal.h", "IOC_OPAL_GET_STATUS", _IOC_READ, 0x70ec, 0x08 },
{ "linux/sed-opal.h", "IOC_OPAL_LOCK_UNLOCK", _IOC_WRITE, 0x70dd, 0x118 },
{ "linux/sed-opal.h", "IOC_OPAL_LR_SETUP", _IOC_WRITE, 0x70e3, 0x128 },
{ "linux/sed-opal.h", "IOC_OPAL_MBR_DONE", _IOC_WRITE, 0x70e9, 0x110 },
{ "linux/sed-opal.h", "IOC_OPAL_PSID_REVERT_TPR", _IOC_WRITE, 0x70e8, 0x108 },
{ "linux/sed-opal.h", "IOC_OPAL_REVERT_LSP", _IOC_WRITE, 0x70f0, 0x110 },
{ "linux/sed-opal.h", "IOC_OPAL_REVERT_TPR", _IOC_WRITE, 0x70e2, 0x108 },
{ "linux/sed-opal.h", "IOC_OPAL_SAVE", _IOC_WRITE, 0x70dc, 0x118 },
{ "linux/sed-opal.h", "IOC_OPAL_SECURE_ERASE_LR", _IOC_WRITE, 0x70e7, 0x110 },
{ "linux/sed-opal.h", "IOC_OPAL_SET_PW", _IOC_WRITE, 0x70e0, 0x220 },
{ "linux/sed-opal.h", "IOC_OPAL_SET_SID_PW", _IOC_WRITE, 0x70f1, 0x220 },
{ "linux/sed-opal.h", "IOC_OPAL_TAKE_OWNERSHIP", _IOC_WRITE, 0x70de, 0x108 },
{ "linux/sed-opal.h", "IOC_OPAL_WRITE_SHADOW_MBR", _IOC_WRITE, 0x70ea, 0x120 },
{ "linux/serio.h", "SPIOCSTYPE", _IOC_WRITE, 0x7101, 0x04 },
{ "linux/sev-guest.h", "SNP_GET_DERIVED_KEY", _IOC_READ|_IOC_WRITE, 0x5301, 0x1a },
{ "linux/sev-guest.h", "SNP_GET_EXT_REPORT", _IOC_READ|_IOC_WRITE, 0x5302, 0x1a },
{ "linux/sev-guest.h", "SNP_GET_REPORT", _IOC_READ|_IOC_WRITE, 0x5300, 0x1a },
{ "linux/sockios.h", "SIOCADDDLCI", 0, 0x8980, 0 },
{ "linux/sockios.h", "SIOCADDMULTI", 0, 0x8931, 0 },
{ "linux/sockios.h", "SIOCADDRT", 0, 0x890B, 0 },
{ "linux/sockios.h", "SIOCBONDCHANGEACTIVE", 0, 0x8995, 0 },
{ "linux/sockios.h", "SIOCBONDENSLAVE", 0, 0x8990, 0 },
{ "linux/sockios.h", "SIOCBONDINFOQUERY", 0, 0x8994, 0 },
{ "linux/sockios.h", "SIOCBONDRELEASE", 0, 0x8991, 0 },
{ "linux/sockios.h", "SIOCBONDSETHWADDR", 0, 0x8992, 0 },
{ "linux/sockios.h", "SIOCBONDSLAVEINFOQUERY", 0, 0x8993, 0 },
{ "linux/sockios.h", "SIOCBRADDBR", 0, 0x89a0, 0 },
{ "linux/sockios.h", "SIOCBRADDIF", 0, 0x89a2, 0 },
{ "linux/sockios.h", "SIOCBRDELBR", 0, 0x89a1, 0 },
{ "linux/sockios.h", "SIOCBRDELIF", 0, 0x89a3, 0 },
{ "linux/sockios.h", "SIOCDARP", 0, 0x8953, 0 },
{ "linux/sockios.h", "SIOCDELDLCI", 0, 0x8981, 0 },
{ "linux/sockios.h", "SIOCDELMULTI", 0, 0x8932, 0 },
{ "linux/sockios.h", "SIOCDELRT", 0, 0x890C, 0 },
{ "linux/sockios.h", "SIOCDEVPRIVATE", 0, 0x89F0, 0 },
{ "linux/sockios.h", "SIOCDIFADDR", 0, 0x8936, 0 },
{ "linux/sockios.h", "SIOCDRARP", 0, 0x8960, 0 },
{ "linux/sockios.h", "SIOCETHTOOL", 0, 0x8946, 0 },
{ "linux/sockios.h", "SIOCGARP", 0, 0x8954, 0 },
{ "linux/sockios.h", "SIOCGHWTSTAMP", 0, 0x89b1, 0 },
{ "linux/sockios.h", "SIOCGIFADDR", 0, 0x8915, 0 },
{ "linux/sockios.h", "SIOCGIFBR", 0, 0x8940, 0 },
{ "linux/sockios.h", "SIOCGIFBRDADDR", 0, 0x8919, 0 },
{ "linux/sockios.h", "SIOCGIFCONF", 0, 0x8912, 0 },
{ "linux/sockios.h", "SIOCGIFCOUNT", 0, 0x8938, 0 },
{ "linux/sockios.h", "SIOCGIFDSTADDR", 0, 0x8917, 0 },
{ "linux/sockios.h", "SIOCGIFENCAP", 0, 0x8925, 0 },
{ "linux/sockios.h", "SIOCGIFFLAGS", 0, 0x8913, 0 },
{ "linux/sockios.h", "SIOCGIFHWADDR", 0, 0x8927, 0 },
{ "linux/sockios.h", "SIOCGIFINDEX", 0, 0x8933, 0 },
{ "linux/sockios.h", "SIOCGIFMAP", 0, 0x8970, 0 },
{ "linux/sockios.h", "SIOCGIFMEM", 0, 0x891f, 0 },
{ "linux/sockios.h", "SIOCGIFMETRIC", 0, 0x891d, 0 },
{ "linux/sockios.h", "SIOCGIFMTU", 0, 0x8921, 0 },
{ "linux/sockios.h", "SIOCGIFNAME", 0, 0x8910, 0 },
{ "linux/sockios.h", "SIOCGIFNETMASK", 0, 0x891b, 0 },
{ "linux/sockios.h", "SIOCGIFPFLAGS", 0, 0x8935, 0 },
{ "linux/sockios.h", "SIOCGIFSLAVE", 0, 0x8929, 0 },
{ "linux/sockios.h", "SIOCGIFTXQLEN", 0, 0x8942, 0 },
{ "linux/sockios.h", "SIOCGIFVLAN", 0, 0x8982, 0 },
{ "linux/sockios.h", "SIOCGMIIPHY", 0, 0x8947, 0 },
{ "linux/sockios.h", "SIOCGMIIREG", 0, 0x8948, 0 },
{ "linux/sockios.h", "SIOCGRARP", 0, 0x8961, 0 },
{ "linux/sockios.h", "SIOCGSKNS", 0, 0x894C, 0 },
{ "linux/sockios.h", "SIOCGSTAMPNS_NEW", _IOC_READ, 0x8907, 0x10 },
{ "linux/sockios.h", "SIOCGSTAMP_NEW", _IOC_READ, 0x8906, 0x10 },
{ "linux/sockios.h", "SIOCOUTQNSD", 0, 0x894B, 0 },
{ "linux/sockios.h", "SIOCPROTOPRIVATE", 0, 0x89E0, 0 },
{ "linux/sockios.h", "SIOCRTMSG", 0, 0x890D, 0 },
{ "linux/sockios.h", "SIOCSARP", 0, 0x8955, 0 },
{ "linux/sockios.h", "SIOCSHWTSTAMP", 0, 0x89b0, 0 },
{ "linux/sockios.h", "SIOCSIFADDR", 0, 0x8916, 0 },
{ "linux/sockios.h", "SIOCSIFBR", 0, 0x8941, 0 },
{ "linux/sockios.h", "SIOCSIFBRDADDR", 0, 0x891a, 0 },
{ "linux/sockios.h", "SIOCSIFDSTADDR", 0, 0x8918, 0 },
{ "linux/sockios.h", "SIOCSIFENCAP", 0, 0x8926, 0 },
{ "linux/sockios.h", "SIOCSIFFLAGS", 0, 0x8914, 0 },
{ "linux/sockios.h", "SIOCSIFHWADDR", 0, 0x8924, 0 },
{ "linux/sockios.h", "SIOCSIFHWBROADCAST", 0, 0x8937, 0 },
{ "linux/sockios.h", "SIOCSIFLINK", 0, 0x8911, 0 },
{ "linux/sockios.h", "SIOCSIFMAP", 0, 0x8971, 0 },
{ "linux/sockios.h", "SIOCSIFMEM", 0, 0x8920, 0 },
{ "linux/sockios.h", "SIOCSIFMETRIC", 0, 0x891e, 0 },
{ "linux/sockios.h", "SIOCSIFMTU", 0, 0x8922, 0 },
{ "linux/sockios.h", "SIOCSIFNAME", 0, 0x8923, 0 },
{ "linux/sockios.h", "SIOCSIFNETMASK", 0, 0x891c, 0 },
{ "linux/sockios.h", "SIOCSIFPFLAGS", 0, 0x8934, 0 },
{ "linux/sockios.h", "SIOCSIFSLAVE", 0, 0x8930, 0 },
{ "linux/sockios.h", "SIOCSIFTXQLEN", 0, 0x8943, 0 },
{ "linux/sockios.h", "SIOCSIFVLAN", 0, 0x8983, 0 },
{ "linux/sockios.h", "SIOCSMIIREG", 0, 0x8949, 0 },
{ "linux/sockios.h", "SIOCSRARP", 0, 0x8962, 0 },
{ "linux/sockios.h", "SIOCWANDEV", 0, 0x894A, 0 },
{ "linux/sonet.h", "SONET_CLRDIAG", _IOC_READ|_IOC_WRITE, 0x6113, 0x04 },
{ "linux/sonet.h", "SONET_GETDIAG", _IOC_READ, 0x6114, 0x04 },
{ "linux/sonet.h", "SONET_GETFRAMING", _IOC_READ, 0x6116, 0x04 },
{ "linux/sonet.h", "SONET_GETFRSENSE", _IOC_READ, 0x6117, 0x06 },
{ "linux/sonet.h", "SONET_GETSTAT", _IOC_READ, 0x6110, 0x24 },
{ "linux/sonet.h", "SONET_GETSTATZ", _IOC_READ, 0x6111, 0x24 },
{ "linux/sonet.h", "SONET_SETDIAG", _IOC_READ|_IOC_WRITE, 0x6112, 0x04 },
{ "linux/sonet.h", "SONET_SETFRAMING", _IOC_WRITE, 0x6115, 0x04 },
{ "linux/sonypi.h", "SONYPI_IOCGBAT1CAP", _IOC_READ, 0x7602, 0x02 },
{ "linux/sonypi.h", "SONYPI_IOCGBAT1REM", _IOC_READ, 0x7603, 0x02 },
{ "linux/sonypi.h", "SONYPI_IOCGBAT2CAP", _IOC_READ, 0x7604, 0x02 },
{ "linux/sonypi.h", "SONYPI_IOCGBAT2REM", _IOC_READ, 0x7605, 0x02 },
{ "linux/sonypi.h", "SONYPI_IOCGBATFLAGS", _IOC_READ, 0x7607, 0x01 },
{ "linux/sonypi.h", "SONYPI_IOCGBLUE", _IOC_READ, 0x7608, 0x01 },
{ "linux/sonypi.h", "SONYPI_IOCGBRT", _IOC_READ, 0x7600, 0x01 },
{ "linux/sonypi.h", "SONYPI_IOCGFAN", _IOC_READ, 0x760a, 0x01 },
{ "linux/sonypi.h", "SONYPI_IOCGTEMP", _IOC_READ, 0x760c, 0x01 },
{ "linux/sonypi.h", "SONYPI_IOCSBLUE", _IOC_WRITE, 0x7609, 0x01 },
{ "linux/sonypi.h", "SONYPI_IOCSBRT", _IOC_WRITE, 0x7600, 0x01 },
{ "linux/sonypi.h", "SONYPI_IOCSFAN", _IOC_WRITE, 0x760b, 0x01 },
{ "linux/soundcard.h", "OSS_GETVERSION", _IOC_READ, 0x4d76, 0x04 },
{ "linux/soundcard.h", "SNDCTL_COPR_HALT", _IOC_READ|_IOC_WRITE, 0x4307, 0x14 },
{ "linux/soundcard.h", "SNDCTL_COPR_LOAD", _IOC_READ|_IOC_WRITE, 0x4301, 0xfb0 },
{ "linux/soundcard.h", "SNDCTL_COPR_RCODE", _IOC_READ|_IOC_WRITE, 0x4303, 0x14 },
{ "linux/soundcard.h", "SNDCTL_COPR_RCVMSG", _IOC_READ, 0x4309, 0xfa4 },
{ "linux/soundcard.h", "SNDCTL_COPR_RDATA", _IOC_READ|_IOC_WRITE, 0x4302, 0x14 },
{ "linux/soundcard.h", "SNDCTL_COPR_RESET", _IOC_NONE, 0x4300, 0x00 },
{ "linux/soundcard.h", "SNDCTL_COPR_RUN", _IOC_READ|_IOC_WRITE, 0x4306, 0x14 },
{ "linux/soundcard.h", "SNDCTL_COPR_SENDMSG", _IOC_READ|_IOC_WRITE, 0x4308, 0xfa4 },
{ "linux/soundcard.h", "SNDCTL_COPR_WCODE", _IOC_WRITE, 0x4305, 0x14 },
{ "linux/soundcard.h", "SNDCTL_COPR_WDATA", _IOC_WRITE, 0x4304, 0x14 },
{ "linux/soundcard.h", "SNDCTL_DSP_BIND_CHANNEL", _IOC_READ|_IOC_WRITE, 0x5041, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_CHANNELS", _IOC_READ|_IOC_WRITE, 0x5006, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETBLKSIZE", _IOC_READ|_IOC_WRITE, 0x5004, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETCAPS", _IOC_READ, 0x500f, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETCHANNELMASK", _IOC_READ|_IOC_WRITE, 0x5040, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETFMTS", _IOC_READ, 0x500b, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETIPTR", _IOC_READ, 0x5011, 0x0c },
{ "linux/soundcard.h", "SNDCTL_DSP_GETISPACE", _IOC_READ, 0x500d, 0x10 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETODELAY", _IOC_READ, 0x5017, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETOPTR", _IOC_READ, 0x5012, 0x0c },
{ "linux/soundcard.h", "SNDCTL_DSP_GETOSPACE", _IOC_READ, 0x500c, 0x10 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETSPDIF", _IOC_READ, 0x5043, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_GETTRIGGER", _IOC_READ, 0x5010, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_MAPINBUF", _IOC_READ, 0x5013, 0x08 },
{ "linux/soundcard.h", "SNDCTL_DSP_MAPOUTBUF", _IOC_READ, 0x5014, 0x08 },
{ "linux/soundcard.h", "SNDCTL_DSP_NONBLOCK", _IOC_NONE, 0x500e, 0x00 },
{ "linux/soundcard.h", "SNDCTL_DSP_POST", _IOC_NONE, 0x5008, 0x00 },
{ "linux/soundcard.h", "SNDCTL_DSP_PROFILE", _IOC_WRITE, 0x5017, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_RESET", _IOC_NONE, 0x5000, 0x00 },
{ "linux/soundcard.h", "SNDCTL_DSP_SETDUPLEX", _IOC_NONE, 0x5016, 0x00 },
{ "linux/soundcard.h", "SNDCTL_DSP_SETFMT", _IOC_READ|_IOC_WRITE, 0x5005, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_SETFRAGMENT", _IOC_READ|_IOC_WRITE, 0x500a, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_SETSPDIF", _IOC_WRITE, 0x5042, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_SETSYNCRO", _IOC_NONE, 0x5015, 0x00 },
{ "linux/soundcard.h", "SNDCTL_DSP_SETTRIGGER", _IOC_WRITE, 0x5010, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_SPEED", _IOC_READ|_IOC_WRITE, 0x5002, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_STEREO", _IOC_READ|_IOC_WRITE, 0x5003, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_SUBDIVIDE", _IOC_READ|_IOC_WRITE, 0x5009, 0x04 },
{ "linux/soundcard.h", "SNDCTL_DSP_SYNC", _IOC_NONE, 0x5001, 0x00 },
{ "linux/soundcard.h", "SNDCTL_FM_4OP_ENABLE", _IOC_WRITE, 0x510f, 0x04 },
{ "linux/soundcard.h", "SNDCTL_FM_LOAD_INSTR", _IOC_WRITE, 0x5107, 0x28 },
{ "linux/soundcard.h", "SNDCTL_MIDI_INFO", _IOC_READ|_IOC_WRITE, 0x510c, 0x72 },
{ "linux/soundcard.h", "SNDCTL_MIDI_MPUCMD", _IOC_READ|_IOC_WRITE, 0x6d02, 0x21 },
{ "linux/soundcard.h", "SNDCTL_MIDI_MPUMODE", _IOC_READ|_IOC_WRITE, 0x6d01, 0x04 },
{ "linux/soundcard.h", "SNDCTL_MIDI_PRETIME", _IOC_READ|_IOC_WRITE, 0x6d00, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_CTRLRATE", _IOC_READ|_IOC_WRITE, 0x5103, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_GETINCOUNT", _IOC_READ, 0x5105, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_GETOUTCOUNT", _IOC_READ, 0x5104, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_GETTIME", _IOC_READ, 0x5113, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_NRMIDIS", _IOC_READ, 0x510b, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_NRSYNTHS", _IOC_READ, 0x510a, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_OUTOFBAND", _IOC_WRITE, 0x5112, 0x08 },
{ "linux/soundcard.h", "SNDCTL_SEQ_PANIC", _IOC_NONE, 0x5111, 0x00 },
{ "linux/soundcard.h", "SNDCTL_SEQ_PERCMODE", _IOC_WRITE, 0x5106, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_RESET", _IOC_NONE, 0x5100, 0x00 },
{ "linux/soundcard.h", "SNDCTL_SEQ_RESETSAMPLES", _IOC_WRITE, 0x5109, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_SYNC", _IOC_NONE, 0x5101, 0x00 },
{ "linux/soundcard.h", "SNDCTL_SEQ_TESTMIDI", _IOC_WRITE, 0x5108, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SEQ_THRESHOLD", _IOC_WRITE, 0x510d, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SYNTH_CONTROL", _IOC_READ|_IOC_WRITE, 0x5115, 0xfa4 },
{ "linux/soundcard.h", "SNDCTL_SYNTH_ID", _IOC_READ|_IOC_WRITE, 0x5114, 0x8a },
{ "linux/soundcard.h", "SNDCTL_SYNTH_INFO", _IOC_READ|_IOC_WRITE, 0x5102, 0x8a },
{ "linux/soundcard.h", "SNDCTL_SYNTH_MEMAVL", _IOC_READ|_IOC_WRITE, 0x510e, 0x04 },
{ "linux/soundcard.h", "SNDCTL_SYNTH_REMOVESAMPLE", _IOC_READ|_IOC_WRITE, 0x5116, 0x0c },
{ "linux/soundcard.h", "SNDCTL_TMR_CONTINUE", _IOC_NONE, 0x5404, 0x00 },
{ "linux/soundcard.h", "SNDCTL_TMR_METRONOME", _IOC_WRITE, 0x5407, 0x04 },
{ "linux/soundcard.h", "SNDCTL_TMR_SELECT", _IOC_WRITE, 0x5408, 0x04 },
{ "linux/soundcard.h", "SNDCTL_TMR_SOURCE", _IOC_READ|_IOC_WRITE, 0x5406, 0x04 },
{ "linux/soundcard.h", "SNDCTL_TMR_START", _IOC_NONE, 0x5402, 0x00 },
{ "linux/soundcard.h", "SNDCTL_TMR_STOP", _IOC_NONE, 0x5403, 0x00 },
{ "linux/soundcard.h", "SNDCTL_TMR_TEMPO", _IOC_READ|_IOC_WRITE, 0x5405, 0x04 },
{ "linux/soundcard.h", "SNDCTL_TMR_TIMEBASE", _IOC_READ|_IOC_WRITE, 0x5401, 0x04 },
{ "linux/soundcard.h", "SOUND_MIXER_3DSE", _IOC_READ|_IOC_WRITE, 0x4d68, 0x04 },
{ "linux/soundcard.h", "SOUND_MIXER_ACCESS", _IOC_READ|_IOC_WRITE, 0x4d66, 0x80 },
{ "linux/soundcard.h", "SOUND_MIXER_AGC", _IOC_READ|_IOC_WRITE, 0x4d67, 0x04 },
{ "linux/soundcard.h", "SOUND_MIXER_GETLEVELS", _IOC_READ|_IOC_WRITE, 0x4d74, 0xa4 },
{ "linux/soundcard.h", "SOUND_MIXER_INFO", _IOC_READ, 0x4d65, 0x5c },
{ "linux/soundcard.h", "SOUND_MIXER_PRIVATE1", _IOC_READ|_IOC_WRITE, 0x4d6f, 0x04 },
{ "linux/soundcard.h", "SOUND_MIXER_PRIVATE2", _IOC_READ|_IOC_WRITE, 0x4d70, 0x04 },
{ "linux/soundcard.h", "SOUND_MIXER_PRIVATE3", _IOC_READ|_IOC_WRITE, 0x4d71, 0x04 },
{ "linux/soundcard.h", "SOUND_MIXER_PRIVATE4", _IOC_READ|_IOC_WRITE, 0x4d72, 0x04 },
{ "linux/soundcard.h", "SOUND_MIXER_PRIVATE5", _IOC_READ|_IOC_WRITE, 0x4d73, 0x04 },
{ "linux/soundcard.h", "SOUND_MIXER_SETLEVELS", _IOC_READ|_IOC_WRITE, 0x4d75, 0xa4 },
{ "linux/soundcard.h", "SOUND_OLD_MIXER_INFO", _IOC_READ, 0x4d65, 0x30 },
{ "linux/soundcard.h", "SOUND_PCM_READ_BITS", _IOC_READ, 0x5005, 0x04 },
{ "linux/soundcard.h", "SOUND_PCM_READ_CHANNELS", _IOC_READ, 0x5006, 0x04 },
{ "linux/soundcard.h", "SOUND_PCM_READ_FILTER", _IOC_READ, 0x5007, 0x04 },
{ "linux/soundcard.h", "SOUND_PCM_READ_RATE", _IOC_READ, 0x5002, 0x04 },
{ "linux/soundcard.h", "SOUND_PCM_WRITE_FILTER", _IOC_READ|_IOC_WRITE, 0x5007, 0x04 },
{ "linux/spi/spidev.h", "SPI_IOC_RD_BITS_PER_WORD", _IOC_READ, 0x6b03, 0x01 },
{ "linux/spi/spidev.h", "SPI_IOC_RD_LSB_FIRST", _IOC_READ, 0x6b02, 0x01 },
{ "linux/spi/spidev.h", "SPI_IOC_RD_MAX_SPEED_HZ", _IOC_READ, 0x6b04, 0x04 },
{ "linux/spi/spidev.h", "SPI_IOC_RD_MODE", _IOC_READ, 0x6b01, 0x01 },
{ "linux/spi/spidev.h", "SPI_IOC_RD_MODE32", _IOC_READ, 0x6b05, 0x04 },
{ "linux/spi/spidev.h", "SPI_IOC_WR_BITS_PER_WORD", _IOC_WRITE, 0x6b03, 0x01 },
{ "linux/spi/spidev.h", "SPI_IOC_WR_LSB_FIRST", _IOC_WRITE, 0x6b02, 0x01 },
{ "linux/spi/spidev.h", "SPI_IOC_WR_MAX_SPEED_HZ", _IOC_WRITE, 0x6b04, 0x04 },
{ "linux/spi/spidev.h", "SPI_IOC_WR_MODE", _IOC_WRITE, 0x6b01, 0x01 },
{ "linux/spi/spidev.h", "SPI_IOC_WR_MODE32", _IOC_WRITE, 0x6b05, 0x04 },
{ "linux/stm.h", "STP_POLICY_ID_GET", _IOC_READ, 0x2501, 0x10 },
{ "linux/stm.h", "STP_POLICY_ID_SET", _IOC_READ|_IOC_WRITE, 0x2500, 0x10 },
{ "linux/stm.h", "STP_SET_OPTIONS", _IOC_WRITE, 0x2502, 0x08 },
{ "linux/surface_aggregator/cdev.h", "SSAM_CDEV_EVENT_DISABLE", _IOC_WRITE, 0xa505, 0x07 },
{ "linux/surface_aggregator/cdev.h", "SSAM_CDEV_EVENT_ENABLE", _IOC_WRITE, 0xa504, 0x07 },
{ "linux/surface_aggregator/cdev.h", "SSAM_CDEV_NOTIF_REGISTER", _IOC_WRITE, 0xa502, 0x05 },
{ "linux/surface_aggregator/cdev.h", "SSAM_CDEV_NOTIF_UNREGISTER", _IOC_WRITE, 0xa503, 0x05 },
{ "linux/surface_aggregator/cdev.h", "SSAM_CDEV_REQUEST", _IOC_READ|_IOC_WRITE, 0xa501, 0x28 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_EVENTS_DISABLE", _IOC_NONE, 0xa522, 0x00 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_EVENTS_ENABLE", _IOC_NONE, 0xa521, 0x00 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_GET_BASE_INFO", _IOC_READ, 0xa529, 0x04 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_GET_DEVICE_MODE", _IOC_READ, 0xa52a, 0x02 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_GET_LATCH_STATUS", _IOC_READ, 0xa52b, 0x02 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_LATCH_CANCEL", _IOC_NONE, 0xa528, 0x00 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_LATCH_CONFIRM", _IOC_NONE, 0xa526, 0x00 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_LATCH_HEARTBEAT", _IOC_NONE, 0xa527, 0x00 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_LATCH_LOCK", _IOC_NONE, 0xa523, 0x00 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_LATCH_REQUEST", _IOC_NONE, 0xa525, 0x00 },
{ "linux/surface_aggregator/dtx.h", "SDTX_IOCTL_LATCH_UNLOCK", _IOC_NONE, 0xa524, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_ALLOC_SWAP_PAGE", _IOC_READ, 0x3314, 0x08 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_ATOMIC_RESTORE", _IOC_NONE, 0x3304, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_AVAIL_SWAP_SIZE", _IOC_READ, 0x3313, 0x08 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_CREATE_IMAGE", _IOC_WRITE, 0x3311, 0x04 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_FREE", _IOC_NONE, 0x3305, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_FREEZE", _IOC_NONE, 0x3301, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_FREE_SWAP_PAGES", _IOC_NONE, 0x3309, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_GET_IMAGE_SIZE", _IOC_READ, 0x330e, 0x08 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_PLATFORM_SUPPORT", _IOC_NONE, 0x330f, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_POWER_OFF", _IOC_NONE, 0x3310, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_PREF_IMAGE_SIZE", _IOC_NONE, 0x3312, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_S2RAM", _IOC_NONE, 0x330b, 0x00 },
{ "linux/suspend_ioctls.h", "SNAPSHOT_SET_SWAP_AREA", _IOC_WRITE, 0x330d, 0x0c },
{ "linux/suspend_ioctls.h", "SNAPSHOT_UNFREEZE", _IOC_NONE, 0x3302, 0x00 },
{ "linux/switchtec_ioctl.h", "SWITCHTEC_IOCTL_EVENT_CTL", _IOC_READ|_IOC_WRITE, 0x5743, 0x28 },
{ "linux/switchtec_ioctl.h", "SWITCHTEC_IOCTL_EVENT_SUMMARY", _IOC_READ, 0x5742, 0x4d4 },
{ "linux/switchtec_ioctl.h", "SWITCHTEC_IOCTL_EVENT_SUMMARY_LEGACY", _IOC_READ, 0x5742, 0x198 },
{ "linux/switchtec_ioctl.h", "SWITCHTEC_IOCTL_FLASH_INFO", _IOC_READ, 0x5740, 0x10 },
{ "linux/switchtec_ioctl.h", "SWITCHTEC_IOCTL_FLASH_PART_INFO", _IOC_READ|_IOC_WRITE, 0x5741, 0x10 },
{ "linux/switchtec_ioctl.h", "SWITCHTEC_IOCTL_PFF_TO_PORT", _IOC_READ|_IOC_WRITE, 0x5744, 0x0c },
{ "linux/switchtec_ioctl.h", "SWITCHTEC_IOCTL_PORT_TO_PFF", _IOC_READ|_IOC_WRITE, 0x5745, 0x0c },
{ "linux/sync_file.h", "SYNC_IOC_FILE_INFO", _IOC_READ|_IOC_WRITE, 0x3e04, 0x38 },
{ "linux/sync_file.h", "SYNC_IOC_MERGE", _IOC_READ|_IOC_WRITE, 0x3e03, 0x30 },
{ "linux/sync_file.h", "SYNC_IOC_SET_DEADLINE", _IOC_WRITE, 0x3e05, 0x10 },
{ "linux/synclink.h", "MGSL_IOCCLRMODCOUNT", _IOC_NONE, 0x6d0f, 0x00 },
{ "linux/synclink.h", "MGSL_IOCGGPIO", _IOC_READ, 0x6d11, 0x10 },
{ "linux/synclink.h", "MGSL_IOCGIF", _IOC_NONE, 0x6d0b, 0x00 },
{ "linux/synclink.h", "MGSL_IOCGPARAMS", _IOC_READ, 0x6d01, 0x1c },
{ "linux/synclink.h", "MGSL_IOCGSTATS", _IOC_NONE, 0x6d07, 0x00 },
{ "linux/synclink.h", "MGSL_IOCGTXIDLE", _IOC_NONE, 0x6d03, 0x00 },
{ "linux/synclink.h", "MGSL_IOCGXCTRL", _IOC_NONE, 0x6d16, 0x00 },
{ "linux/synclink.h", "MGSL_IOCGXSYNC", _IOC_NONE, 0x6d14, 0x00 },
{ "linux/synclink.h", "MGSL_IOCLOOPTXDONE", _IOC_NONE, 0x6d09, 0x00 },
{ "linux/synclink.h", "MGSL_IOCRXENABLE", _IOC_NONE, 0x6d05, 0x00 },
{ "linux/synclink.h", "MGSL_IOCSGPIO", _IOC_WRITE, 0x6d10, 0x10 },
{ "linux/synclink.h", "MGSL_IOCSIF", _IOC_NONE, 0x6d0a, 0x00 },
{ "linux/synclink.h", "MGSL_IOCSPARAMS", _IOC_WRITE, 0x6d00, 0x1c },
{ "linux/synclink.h", "MGSL_IOCSTXIDLE", _IOC_NONE, 0x6d02, 0x00 },
{ "linux/synclink.h", "MGSL_IOCSXCTRL", _IOC_NONE, 0x6d15, 0x00 },
{ "linux/synclink.h", "MGSL_IOCSXSYNC", _IOC_NONE, 0x6d13, 0x00 },
{ "linux/synclink.h", "MGSL_IOCTXABORT", _IOC_NONE, 0x6d06, 0x00 },
{ "linux/synclink.h", "MGSL_IOCTXENABLE", _IOC_NONE, 0x6d04, 0x00 },
{ "linux/synclink.h", "MGSL_IOCWAITEVENT", _IOC_READ|_IOC_WRITE, 0x6d08, 0x04 },
{ "linux/synclink.h", "MGSL_IOCWAITGPIO", _IOC_READ|_IOC_WRITE, 0x6d12, 0x10 },
{ "linux/tdx-guest.h", "TDX_CMD_GET_REPORT0", _IOC_READ|_IOC_WRITE, 0x5401, 0x440 },
{ "linux/tee.h", "TEE_IOC_CANCEL", _IOC_READ, 0xa404, 0x08 },
{ "linux/tee.h", "TEE_IOC_CLOSE_SESSION", _IOC_READ, 0xa405, 0x04 },
{ "linux/tee.h", "TEE_IOC_INVOKE", _IOC_READ, 0xa403, 0x10 },
{ "linux/tee.h", "TEE_IOC_OPEN_SESSION", _IOC_READ, 0xa402, 0x10 },
{ "linux/tee.h", "TEE_IOC_SHM_ALLOC", _IOC_READ|_IOC_WRITE, 0xa401, 0x10 },
{ "linux/tee.h", "TEE_IOC_SHM_REGISTER", _IOC_READ|_IOC_WRITE, 0xa409, 0x18 },
{ "linux/tee.h", "TEE_IOC_SUPPL_RECV", _IOC_READ, 0xa406, 0x10 },
{ "linux/tee.h", "TEE_IOC_SUPPL_SEND", _IOC_READ, 0xa407, 0x10 },
{ "linux/tee.h", "TEE_IOC_VERSION", _IOC_READ, 0xa400, 0x0c },
{ "linux/timerfd.h", "TFD_IOC_SET_TICKS", _IOC_WRITE, 0x5400, 0x08 },
{ "linux/toshiba.h", "TOSHIBA_ACPI_SCI", _IOC_READ|_IOC_WRITE, 0x7491, 0x18 },
{ "linux/toshiba.h", "TOSH_SMM", _IOC_READ|_IOC_WRITE, 0x7490, 0x18 },
{ "linux/tps6594_pfsm.h", "PMIC_GOTO_LP_STANDBY", _IOC_NONE, 0x5001, 0x00 },
{ "linux/tps6594_pfsm.h", "PMIC_GOTO_STANDBY", _IOC_NONE, 0x5000, 0x00 },
{ "linux/tps6594_pfsm.h", "PMIC_SET_ACTIVE_STATE", _IOC_NONE, 0x5003, 0x00 },
{ "linux/tps6594_pfsm.h", "PMIC_SET_MCU_ONLY_STATE", _IOC_WRITE, 0x5004, 0x03 },
{ "linux/tps6594_pfsm.h", "PMIC_SET_RETENTION_STATE", _IOC_WRITE, 0x5005, 0x03 },
{ "linux/tps6594_pfsm.h", "PMIC_UPDATE_PGM", _IOC_NONE, 0x5002, 0x00 },
{ "linux/trace_mmap.h", "TRACE_MMAP_IOCTL_GET_READER", _IOC_NONE, 0x5220, 0x00 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_ADD_DEV", _IOC_READ|_IOC_WRITE, 0x7504, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_DEL_DEV", _IOC_READ|_IOC_WRITE, 0x7505, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_DEL_DEV_ASYNC", _IOC_READ, 0x7514, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_END_USER_RECOVERY", _IOC_READ|_IOC_WRITE, 0x7511, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_GET_DEV_INFO", _IOC_READ, 0x7502, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_GET_DEV_INFO2", _IOC_READ, 0x7512, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_GET_FEATURES", _IOC_READ, 0x7513, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_GET_PARAMS", _IOC_READ, 0x7509, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_GET_QUEUE_AFFINITY", _IOC_READ, 0x7501, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_SET_PARAMS", _IOC_READ|_IOC_WRITE, 0x7508, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_START_DEV", _IOC_READ|_IOC_WRITE, 0x7506, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_START_USER_RECOVERY", _IOC_READ|_IOC_WRITE, 0x7510, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_CMD_STOP_DEV", _IOC_READ|_IOC_WRITE, 0x7507, 0x20 },
{ "linux/ublk_cmd.h", "UBLK_U_IO_COMMIT_AND_FETCH_REQ", _IOC_READ|_IOC_WRITE, 0x7521, 0x10 },
{ "linux/ublk_cmd.h", "UBLK_U_IO_FETCH_REQ", _IOC_READ|_IOC_WRITE, 0x7520, 0x10 },
{ "linux/ublk_cmd.h", "UBLK_U_IO_NEED_GET_DATA", _IOC_READ|_IOC_WRITE, 0x7522, 0x10 },
{ "linux/udf_fs_i.h", "UDF_GETEABLOCK", _IOC_READ, 0x6c41, 0x04 },
{ "linux/udf_fs_i.h", "UDF_GETEASIZE", _IOC_READ, 0x6c40, 0x04 },
{ "linux/udf_fs_i.h", "UDF_GETVOLIDENT", _IOC_READ, 0x6c42, 0x04 },
{ "linux/udf_fs_i.h", "UDF_RELOCATE_BLOCKS", _IOC_READ|_IOC_WRITE, 0x6c43, 0x04 },
{ "linux/udmabuf.h", "UDMABUF_CREATE", _IOC_WRITE, 0x7542, 0x18 },
{ "linux/udmabuf.h", "UDMABUF_CREATE_LIST", _IOC_WRITE, 0x7543, 0x08 },
{ "linux/uinput.h", "UI_ABS_SETUP", _IOC_WRITE, 0x5504, 0x1a },
{ "linux/uinput.h", "UI_BEGIN_FF_ERASE", _IOC_READ|_IOC_WRITE, 0x55ca, 0x0c },
{ "linux/uinput.h", "UI_BEGIN_FF_UPLOAD", _IOC_READ|_IOC_WRITE, 0x55c8, 0x58 },
{ "linux/uinput.h", "UI_DEV_CREATE", _IOC_NONE, 0x5501, 0x00 },
{ "linux/uinput.h", "UI_DEV_DESTROY", _IOC_NONE, 0x5502, 0x00 },
{ "linux/uinput.h", "UI_DEV_SETUP", _IOC_WRITE, 0x5503, 0x5c },
{ "linux/uinput.h", "UI_END_FF_ERASE", _IOC_WRITE, 0x55cb, 0x0c },
{ "linux/uinput.h", "UI_END_FF_UPLOAD", _IOC_WRITE, 0x55c9, 0x58 },
{ "linux/uinput.h", "UI_GET_VERSION", _IOC_READ, 0x552d, 0x04 },
{ "linux/uinput.h", "UI_SET_ABSBIT", _IOC_WRITE, 0x5567, 0x04 },
{ "linux/uinput.h", "UI_SET_EVBIT", _IOC_WRITE, 0x5564, 0x04 },
{ "linux/uinput.h", "UI_SET_FFBIT", _IOC_WRITE, 0x556b, 0x04 },
{ "linux/uinput.h", "UI_SET_KEYBIT", _IOC_WRITE, 0x5565, 0x04 },
{ "linux/uinput.h", "UI_SET_LEDBIT", _IOC_WRITE, 0x5569, 0x04 },
{ "linux/uinput.h", "UI_SET_MSCBIT", _IOC_WRITE, 0x5568, 0x04 },
{ "linux/uinput.h", "UI_SET_PHYS", _IOC_WRITE, 0x556c, 0x04 },
{ "linux/uinput.h", "UI_SET_PROPBIT", _IOC_WRITE, 0x556e, 0x04 },
{ "linux/uinput.h", "UI_SET_RELBIT", _IOC_WRITE, 0x5566, 0x04 },
{ "linux/uinput.h", "UI_SET_SNDBIT", _IOC_WRITE, 0x556a, 0x04 },
{ "linux/uinput.h", "UI_SET_SWBIT", _IOC_WRITE, 0x556d, 0x04 },
{ "linux/usb/cdc-wdm.h", "IOCTL_WDM_MAX_COMMAND", _IOC_READ, 0x48a0, 0x02 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_CLEAR_HALT", _IOC_NONE, 0x6703, 0x00 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_DMABUF_ATTACH", _IOC_WRITE, 0x6783, 0x04 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_DMABUF_DETACH", _IOC_WRITE, 0x6784, 0x04 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_DMABUF_TRANSFER", _IOC_WRITE, 0x6785, 0x10 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_ENDPOINT_DESC", _IOC_READ, 0x6782, 0x09 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_ENDPOINT_REVMAP", _IOC_NONE, 0x6781, 0x00 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_FIFO_FLUSH", _IOC_NONE, 0x6702, 0x00 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_FIFO_STATUS", _IOC_NONE, 0x6701, 0x00 },
{ "linux/usb/functionfs.h", "FUNCTIONFS_INTERFACE_REVMAP", _IOC_NONE, 0x6780, 0x00 },
{ "linux/usb/g_hid.h", "GADGET_HID_READ_GET_REPORT_ID", _IOC_READ, 0x6741, 0x01 },
{ "linux/usb/g_hid.h", "GADGET_HID_WRITE_GET_REPORT", _IOC_WRITE, 0x6742, 0x48 },
{ "linux/usb/g_printer.h", "GADGET_GET_PRINTER_STATUS", _IOC_READ, 0x6721, 0x01 },
{ "linux/usb/g_printer.h", "GADGET_SET_PRINTER_STATUS", _IOC_READ|_IOC_WRITE, 0x6722, 0x01 },
{ "linux/usb/g_uvc.h", "UVCIOC_SEND_RESPONSE", _IOC_WRITE, 0x5501, 0x40 },
{ "linux/usb/gadgetfs.h", "GADGETFS_CLEAR_HALT", _IOC_NONE, 0x6703, 0x00 },
{ "linux/usb/gadgetfs.h", "GADGETFS_FIFO_FLUSH", _IOC_NONE, 0x6702, 0x00 },
{ "linux/usb/gadgetfs.h", "GADGETFS_FIFO_STATUS", _IOC_NONE, 0x6701, 0x00 },
{ "linux/usb/iowarrior.h", "IOW_GETINFO", _IOC_READ, 0xc003, 0x26 },
{ "linux/usb/iowarrior.h", "IOW_READ", _IOC_WRITE, 0xc002, 0x04 },
{ "linux/usb/iowarrior.h", "IOW_WRITE", _IOC_WRITE, 0xc001, 0x04 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_CONFIGURE", _IOC_NONE, 0x5509, 0x00 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_READ", _IOC_READ|_IOC_WRITE, 0x5504, 0x08 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_STALL", _IOC_NONE, 0x550c, 0x00 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP0_WRITE", _IOC_WRITE, 0x5503, 0x08 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EPS_INFO", _IOC_READ, 0x550b, 0x384 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_CLEAR_HALT", _IOC_WRITE, 0x550e, 0x04 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_DISABLE", _IOC_WRITE, 0x5506, 0x04 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_ENABLE", _IOC_WRITE, 0x5505, 0x09 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_READ", _IOC_READ|_IOC_WRITE, 0x5508, 0x08 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_HALT", _IOC_WRITE, 0x550d, 0x04 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_SET_WEDGE", _IOC_WRITE, 0x550f, 0x04 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EP_WRITE", _IOC_WRITE, 0x5507, 0x08 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_EVENT_FETCH", _IOC_READ, 0x5502, 0x08 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_INIT", _IOC_WRITE, 0x5500, 0x101 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_RUN", _IOC_NONE, 0x5501, 0x00 },
{ "linux/usb/raw_gadget.h", "USB_RAW_IOCTL_VBUS_DRAW", _IOC_WRITE, 0x550a, 0x04 },
{ "linux/usb/tmc.h", "USBTMC488_IOCTL_GET_CAPS", _IOC_READ, 0x5b11, 0x01 },
{ "linux/usb/tmc.h", "USBTMC488_IOCTL_GOTO_LOCAL", _IOC_NONE, 0x5b14, 0x00 },
{ "linux/usb/tmc.h", "USBTMC488_IOCTL_LOCAL_LOCKOUT", _IOC_NONE, 0x5b15, 0x00 },
{ "linux/usb/tmc.h", "USBTMC488_IOCTL_READ_STB", _IOC_READ, 0x5b12, 0x01 },
{ "linux/usb/tmc.h", "USBTMC488_IOCTL_REN_CONTROL", _IOC_WRITE, 0x5b13, 0x01 },
{ "linux/usb/tmc.h", "USBTMC488_IOCTL_TRIGGER", _IOC_NONE, 0x5b16, 0x00 },
{ "linux/usb/tmc.h", "USBTMC488_IOCTL_WAIT_SRQ", _IOC_WRITE, 0x5b17, 0x04 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_ABORT_BULK_IN", _IOC_NONE, 0x5b04, 0x00 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_ABORT_BULK_OUT", _IOC_NONE, 0x5b03, 0x00 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_API_VERSION", _IOC_READ, 0x5b10, 0x04 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_AUTO_ABORT", _IOC_WRITE, 0x5b19, 0x01 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_CANCEL_IO", _IOC_NONE, 0x5b23, 0x00 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_CLEANUP_IO", _IOC_NONE, 0x5b24, 0x00 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_CLEAR", _IOC_NONE, 0x5b02, 0x00 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_CLEAR_IN_HALT", _IOC_NONE, 0x5b07, 0x00 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_CLEAR_OUT_HALT", _IOC_NONE, 0x5b06, 0x00 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_CONFIG_TERMCHAR", _IOC_WRITE, 0x5b0c, 0x02 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_CTRL_REQUEST", _IOC_READ|_IOC_WRITE, 0x5b08, 0x0c },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_EOM_ENABLE", _IOC_WRITE, 0x5b0b, 0x01 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_GET_SRQ_STB", _IOC_READ, 0x5b1b, 0x01 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_GET_STB", _IOC_READ, 0x5b1a, 0x01 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_GET_TIMEOUT", _IOC_READ, 0x5b09, 0x04 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_INDICATOR_PULSE", _IOC_NONE, 0x5b01, 0x00 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_MSG_IN_ATTR", _IOC_READ, 0x5b18, 0x01 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_READ", _IOC_READ|_IOC_WRITE, 0x5b0e, 0x10 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_SET_TIMEOUT", _IOC_WRITE, 0x5b0a, 0x04 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_WRITE", _IOC_READ|_IOC_WRITE, 0x5b0d, 0x10 },
{ "linux/usb/tmc.h", "USBTMC_IOCTL_WRITE_RESULT", _IOC_READ|_IOC_WRITE, 0x5b0f, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_ALLOC_STREAMS", _IOC_READ, 0x551c, 0x08 },
{ "linux/usbdevice_fs.h", "USBDEVFS_ALLOW_SUSPEND", _IOC_NONE, 0x5522, 0x00 },
{ "linux/usbdevice_fs.h", "USBDEVFS_BULK32", _IOC_READ|_IOC_WRITE, 0x5502, 0x10 },
{ "linux/usbdevice_fs.h", "USBDEVFS_CLAIMINTERFACE", _IOC_READ, 0x550f, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_CLAIM_PORT", _IOC_READ, 0x5518, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_CLEAR_HALT", _IOC_READ, 0x5515, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_CONNECT", _IOC_NONE, 0x5517, 0x00 },
{ "linux/usbdevice_fs.h", "USBDEVFS_CONNECTINFO", _IOC_WRITE, 0x5511, 0x06 },
{ "linux/usbdevice_fs.h", "USBDEVFS_CONTROL32", _IOC_READ|_IOC_WRITE, 0x5500, 0x10 },
{ "linux/usbdevice_fs.h", "USBDEVFS_DISCARDURB", _IOC_NONE, 0x550b, 0x00 },
{ "linux/usbdevice_fs.h", "USBDEVFS_DISCONNECT", _IOC_NONE, 0x5516, 0x00 },
{ "linux/usbdevice_fs.h", "USBDEVFS_DISCONNECT_CLAIM", _IOC_READ, 0x551b, 0x108 },
{ "linux/usbdevice_fs.h", "USBDEVFS_DISCSIGNAL32", _IOC_READ, 0x550e, 0x08 },
{ "linux/usbdevice_fs.h", "USBDEVFS_DROP_PRIVILEGES", _IOC_WRITE, 0x551e, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_FORBID_SUSPEND", _IOC_NONE, 0x5521, 0x00 },
{ "linux/usbdevice_fs.h", "USBDEVFS_FREE_STREAMS", _IOC_READ, 0x551d, 0x08 },
{ "linux/usbdevice_fs.h", "USBDEVFS_GETDRIVER", _IOC_WRITE, 0x5508, 0x104 },
{ "linux/usbdevice_fs.h", "USBDEVFS_GET_CAPABILITIES", _IOC_READ, 0x551a, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_GET_SPEED", _IOC_NONE, 0x551f, 0x00 },
{ "linux/usbdevice_fs.h", "USBDEVFS_HUB_PORTINFO", _IOC_READ, 0x5513, 0x80 },
{ "linux/usbdevice_fs.h", "USBDEVFS_IOCTL32", _IOC_READ|_IOC_WRITE, 0x5512, 0x0c },
{ "linux/usbdevice_fs.h", "USBDEVFS_REAPURB32", _IOC_WRITE, 0x550c, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_REAPURBNDELAY32", _IOC_WRITE, 0x550d, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_RELEASEINTERFACE", _IOC_READ, 0x5510, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_RELEASE_PORT", _IOC_READ, 0x5519, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_RESET", _IOC_NONE, 0x5514, 0x00 },
{ "linux/usbdevice_fs.h", "USBDEVFS_RESETEP", _IOC_READ, 0x5503, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_SETCONFIGURATION", _IOC_READ, 0x5505, 0x04 },
{ "linux/usbdevice_fs.h", "USBDEVFS_SETINTERFACE", _IOC_READ, 0x5504, 0x08 },
{ "linux/usbdevice_fs.h", "USBDEVFS_SUBMITURB32", _IOC_READ, 0x550a, 0x2a },
{ "linux/usbdevice_fs.h", "USBDEVFS_WAIT_FOR_RESUME", _IOC_NONE, 0x5523, 0x00 },
{ "linux/user_events.h", "DIAG_IOCSDEL", _IOC_WRITE, 0x2a01, 0x04 },
{ "linux/user_events.h", "DIAG_IOCSREG", _IOC_READ|_IOC_WRITE, 0x2a00, 0x04 },
{ "linux/user_events.h", "DIAG_IOCSUNREG", _IOC_WRITE, 0x2a02, 0x04 },
{ "linux/userfaultfd.h", "UFFDIO_API", _IOC_READ|_IOC_WRITE, 0xaa3f, 0x18 },
{ "linux/userfaultfd.h", "UFFDIO_CONTINUE", _IOC_READ|_IOC_WRITE, 0xaa07, 0x20 },
{ "linux/userfaultfd.h", "UFFDIO_COPY", _IOC_READ|_IOC_WRITE, 0xaa03, 0x28 },
{ "linux/userfaultfd.h", "UFFDIO_MOVE", _IOC_READ|_IOC_WRITE, 0xaa05, 0x28 },
{ "linux/userfaultfd.h", "UFFDIO_POISON", _IOC_READ|_IOC_WRITE, 0xaa08, 0x20 },
{ "linux/userfaultfd.h", "UFFDIO_REGISTER", _IOC_READ|_IOC_WRITE, 0xaa00, 0x20 },
{ "linux/userfaultfd.h", "UFFDIO_UNREGISTER", _IOC_READ, 0xaa01, 0x10 },
{ "linux/userfaultfd.h", "UFFDIO_WAKE", _IOC_READ, 0xaa02, 0x10 },
{ "linux/userfaultfd.h", "UFFDIO_WRITEPROTECT", _IOC_READ|_IOC_WRITE, 0xaa06, 0x18 },
{ "linux/userfaultfd.h", "UFFDIO_ZEROPAGE", _IOC_READ|_IOC_WRITE, 0xaa04, 0x20 },
{ "linux/userfaultfd.h", "USERFAULTFD_IOC_NEW", _IOC_NONE, 0xaa00, 0x00 },
{ "linux/uvcvideo.h", "UVCIOC_CTRL_MAP", _IOC_READ|_IOC_WRITE, 0x7520, 0x58 },
{ "linux/uvcvideo.h", "UVCIOC_CTRL_QUERY", _IOC_READ|_IOC_WRITE, 0x7521, 0x0a },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_ENUM_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x564b, 0x40 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_ENUM_FRAME_SIZE", _IOC_READ|_IOC_WRITE, 0x564a, 0x40 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_ENUM_MBUS_CODE", _IOC_READ|_IOC_WRITE, 0x5602, 0x30 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_CLIENT_CAP", _IOC_READ, 0x5665, 0x08 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_CROP", _IOC_READ|_IOC_WRITE, 0x563b, 0x38 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FMT", _IOC_READ|_IOC_WRITE, 0x5604, 0x58 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5615, 0x30 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_ROUTING", _IOC_READ|_IOC_WRITE, 0x5626, 0x40 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_G_SELECTION", _IOC_READ|_IOC_WRITE, 0x563d, 0x40 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_QUERYCAP", _IOC_READ, 0x5600, 0x40 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_CLIENT_CAP", _IOC_READ|_IOC_WRITE, 0x5666, 0x08 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_CROP", _IOC_READ|_IOC_WRITE, 0x563c, 0x38 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FMT", _IOC_READ|_IOC_WRITE, 0x5605, 0x58 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_FRAME_INTERVAL", _IOC_READ|_IOC_WRITE, 0x5616, 0x30 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_ROUTING", _IOC_READ|_IOC_WRITE, 0x5627, 0x40 },
{ "linux/v4l2-subdev.h", "VIDIOC_SUBDEV_S_SELECTION", _IOC_READ|_IOC_WRITE, 0x563e, 0x40 },
{ "linux/vboxguest.h", "VBG_IOCTL_ACQUIRE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560d, 0x24 },
{ "linux/vboxguest.h", "VBG_IOCTL_CHANGE_FILTER_MASK", _IOC_READ|_IOC_WRITE, 0x560c, 0x20 },
{ "linux/vboxguest.h", "VBG_IOCTL_CHANGE_GUEST_CAPABILITIES", _IOC_READ|_IOC_WRITE, 0x560e, 0x20 },
{ "linux/vboxguest.h", "VBG_IOCTL_CHECK_BALLOON", _IOC_READ|_IOC_WRITE, 0x5611, 0x20 },
{ "linux/vboxguest.h", "VBG_IOCTL_DRIVER_VERSION_INFO", _IOC_READ|_IOC_WRITE, 0x5600, 0x2c },
{ "linux/vboxguest.h", "VBG_IOCTL_HGCM_CONNECT", _IOC_READ|_IOC_WRITE, 0x5604, 0x9c },
{ "linux/vboxguest.h", "VBG_IOCTL_HGCM_DISCONNECT", _IOC_READ|_IOC_WRITE, 0x5605, 0x1c },
{ "linux/vboxguest.h", "VBG_IOCTL_INTERRUPT_ALL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560b, 0x18 },
{ "linux/vboxguest.h", "VBG_IOCTL_VMMDEV_REQUEST_BIG", _IOC_NONE, 0x5603, 0x00 },
{ "linux/vboxguest.h", "VBG_IOCTL_WAIT_FOR_EVENTS", _IOC_READ|_IOC_WRITE, 0x560a, 0x20 },
{ "linux/vboxguest.h", "VBG_IOCTL_WRITE_CORE_DUMP", _IOC_READ|_IOC_WRITE, 0x5613, 0x1c },
{ "linux/vduse.h", "VDUSE_CREATE_DEV", _IOC_WRITE, 0x8102, 0x150 },
{ "linux/vduse.h", "VDUSE_DESTROY_DEV", _IOC_WRITE, 0x8103, 0x100 },
{ "linux/vduse.h", "VDUSE_DEV_GET_FEATURES", _IOC_READ, 0x8111, 0x08 },
{ "linux/vduse.h", "VDUSE_DEV_INJECT_CONFIG_IRQ", _IOC_NONE, 0x8113, 0x00 },
{ "linux/vduse.h", "VDUSE_DEV_SET_CONFIG", _IOC_WRITE, 0x8112, 0x08 },
{ "linux/vduse.h", "VDUSE_GET_API_VERSION", _IOC_READ, 0x8100, 0x08 },
{ "linux/vduse.h", "VDUSE_IOTLB_DEREG_UMEM", _IOC_WRITE, 0x8119, 0x30 },
{ "linux/vduse.h", "VDUSE_IOTLB_GET_FD", _IOC_READ|_IOC_WRITE, 0x8110, 0x1a },
{ "linux/vduse.h", "VDUSE_IOTLB_GET_INFO", _IOC_READ|_IOC_WRITE, 0x811a, 0x30 },
{ "linux/vduse.h", "VDUSE_IOTLB_REG_UMEM", _IOC_WRITE, 0x8118, 0x30 },
{ "linux/vduse.h", "VDUSE_SET_API_VERSION", _IOC_WRITE, 0x8101, 0x08 },
{ "linux/vduse.h", "VDUSE_VQ_GET_INFO", _IOC_READ|_IOC_WRITE, 0x8115, 0x2a },
{ "linux/vduse.h", "VDUSE_VQ_INJECT_IRQ", _IOC_WRITE, 0x8117, 0x04 },
{ "linux/vduse.h", "VDUSE_VQ_SETUP", _IOC_WRITE, 0x8114, 0x20 },
{ "linux/vduse.h", "VDUSE_VQ_SETUP_KICKFD", _IOC_WRITE, 0x8116, 0x08 },
{ "linux/vfio.h", "VFIO_CHECK_EXTENSION", _IOC_NONE, 0x3b65, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_ATTACH_IOMMUFD_PT", _IOC_NONE, 0x3b77, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_BIND_IOMMUFD", _IOC_NONE, 0x3b76, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_DETACH_IOMMUFD_PT", _IOC_NONE, 0x3b78, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_FEATURE", _IOC_NONE, 0x3b75, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_GET_GFX_DMABUF", _IOC_NONE, 0x3b73, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_GET_INFO", _IOC_NONE, 0x3b6b, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_GET_IRQ_INFO", _IOC_NONE, 0x3b6d, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_GET_PCI_HOT_RESET_INFO", _IOC_NONE, 0x3b70, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_GET_REGION_INFO", _IOC_NONE, 0x3b6c, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_IOEVENTFD", _IOC_NONE, 0x3b74, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_PCI_HOT_RESET", _IOC_NONE, 0x3b71, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_QUERY_GFX_PLANE", _IOC_NONE, 0x3b72, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_RESET", _IOC_NONE, 0x3b6f, 0x00 },
{ "linux/vfio.h", "VFIO_DEVICE_SET_IRQS", _IOC_NONE, 0x3b6e, 0x00 },
{ "linux/vfio.h", "VFIO_EEH_PE_OP", _IOC_NONE, 0x3b79, 0x00 },
{ "linux/vfio.h", "VFIO_GET_API_VERSION", _IOC_NONE, 0x3b64, 0x00 },
{ "linux/vfio.h", "VFIO_GROUP_GET_DEVICE_FD", _IOC_NONE, 0x3b6a, 0x00 },
{ "linux/vfio.h", "VFIO_GROUP_GET_STATUS", _IOC_NONE, 0x3b67, 0x00 },
{ "linux/vfio.h", "VFIO_GROUP_SET_CONTAINER", _IOC_NONE, 0x3b68, 0x00 },
{ "linux/vfio.h", "VFIO_GROUP_UNSET_CONTAINER", _IOC_NONE, 0x3b69, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_DIRTY_PAGES", _IOC_NONE, 0x3b75, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_DISABLE", _IOC_NONE, 0x3b74, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_ENABLE", _IOC_NONE, 0x3b73, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_GET_INFO", _IOC_NONE, 0x3b70, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_MAP_DMA", _IOC_NONE, 0x3b71, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_SPAPR_REGISTER_MEMORY", _IOC_NONE, 0x3b75, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_SPAPR_TCE_CREATE", _IOC_NONE, 0x3b77, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_SPAPR_TCE_GET_INFO", _IOC_NONE, 0x3b70, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_SPAPR_TCE_REMOVE", _IOC_NONE, 0x3b78, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_SPAPR_UNREGISTER_MEMORY", _IOC_NONE, 0x3b76, 0x00 },
{ "linux/vfio.h", "VFIO_IOMMU_UNMAP_DMA", _IOC_NONE, 0x3b72, 0x00 },
{ "linux/vfio.h", "VFIO_MIG_GET_PRECOPY_INFO", _IOC_NONE, 0x3b79, 0x00 },
{ "linux/vfio.h", "VFIO_SET_IOMMU", _IOC_NONE, 0x3b66, 0x00 },
{ "linux/vhost.h", "VHOST_ATTACH_VRING_WORKER", _IOC_WRITE, 0xaf15, 0x08 },
{ "linux/vhost.h", "VHOST_FREE_WORKER", _IOC_WRITE, 0xaf09, 0x04 },
{ "linux/vhost.h", "VHOST_GET_BACKEND_FEATURES", _IOC_READ, 0xaf26, 0x08 },
{ "linux/vhost.h", "VHOST_GET_FEATURES", _IOC_READ, 0xaf00, 0x08 },
{ "linux/vhost.h", "VHOST_GET_VRING_BASE", _IOC_READ|_IOC_WRITE, 0xaf12, 0x08 },
{ "linux/vhost.h", "VHOST_GET_VRING_BUSYLOOP_TIMEOUT", _IOC_WRITE, 0xaf24, 0x08 },
{ "linux/vhost.h", "VHOST_GET_VRING_ENDIAN", _IOC_WRITE, 0xaf14, 0x08 },
{ "linux/vhost.h", "VHOST_GET_VRING_WORKER", _IOC_READ|_IOC_WRITE, 0xaf16, 0x08 },
{ "linux/vhost.h", "VHOST_NET_SET_BACKEND", _IOC_WRITE, 0xaf30, 0x08 },
{ "linux/vhost.h", "VHOST_NEW_WORKER", _IOC_READ, 0xaf08, 0x04 },
{ "linux/vhost.h", "VHOST_RESET_OWNER", _IOC_NONE, 0xaf02, 0x00 },
{ "linux/vhost.h", "VHOST_SCSI_CLEAR_ENDPOINT", _IOC_WRITE, 0xaf41, 0xe8 },
{ "linux/vhost.h", "VHOST_SCSI_GET_ABI_VERSION", _IOC_WRITE, 0xaf42, 0x04 },
{ "linux/vhost.h", "VHOST_SCSI_GET_EVENTS_MISSED", _IOC_WRITE, 0xaf44, 0x04 },
{ "linux/vhost.h", "VHOST_SCSI_SET_ENDPOINT", _IOC_WRITE, 0xaf40, 0xe8 },
{ "linux/vhost.h", "VHOST_SCSI_SET_EVENTS_MISSED", _IOC_WRITE, 0xaf43, 0x04 },
{ "linux/vhost.h", "VHOST_SET_BACKEND_FEATURES", _IOC_WRITE, 0xaf25, 0x08 },
{ "linux/vhost.h", "VHOST_SET_FEATURES", _IOC_WRITE, 0xaf00, 0x08 },
{ "linux/vhost.h", "VHOST_SET_LOG_BASE", _IOC_WRITE, 0xaf04, 0x08 },
{ "linux/vhost.h", "VHOST_SET_LOG_FD", _IOC_WRITE, 0xaf07, 0x04 },
{ "linux/vhost.h", "VHOST_SET_MEM_TABLE", _IOC_WRITE, 0xaf03, 0x08 },
{ "linux/vhost.h", "VHOST_SET_OWNER", _IOC_NONE, 0xaf01, 0x00 },
{ "linux/vhost.h", "VHOST_SET_VRING_ADDR", _IOC_WRITE, 0xaf11, 0x28 },
{ "linux/vhost.h", "VHOST_SET_VRING_BASE", _IOC_WRITE, 0xaf12, 0x08 },
{ "linux/vhost.h", "VHOST_SET_VRING_BUSYLOOP_TIMEOUT", _IOC_WRITE, 0xaf23, 0x08 },
{ "linux/vhost.h", "VHOST_SET_VRING_CALL", _IOC_WRITE, 0xaf21, 0x08 },
{ "linux/vhost.h", "VHOST_SET_VRING_ENDIAN", _IOC_WRITE, 0xaf13, 0x08 },
{ "linux/vhost.h", "VHOST_SET_VRING_ERR", _IOC_WRITE, 0xaf22, 0x08 },
{ "linux/vhost.h", "VHOST_SET_VRING_KICK", _IOC_WRITE, 0xaf20, 0x08 },
{ "linux/vhost.h", "VHOST_SET_VRING_NUM", _IOC_WRITE, 0xaf10, 0x08 },
{ "linux/vhost.h", "VHOST_VDPA_GET_AS_NUM", _IOC_READ, 0xaf7a, 0x04 },
{ "linux/vhost.h", "VHOST_VDPA_GET_CONFIG", _IOC_READ, 0xaf73, 0x08 },
{ "linux/vhost.h", "VHOST_VDPA_GET_CONFIG_SIZE", _IOC_READ, 0xaf79, 0x04 },
{ "linux/vhost.h", "VHOST_VDPA_GET_DEVICE_ID", _IOC_READ, 0xaf70, 0x04 },
{ "linux/vhost.h", "VHOST_VDPA_GET_GROUP_NUM", _IOC_READ, 0xaf81, 0x04 },
{ "linux/vhost.h", "VHOST_VDPA_GET_IOVA_RANGE", _IOC_READ, 0xaf78, 0x10 },
{ "linux/vhost.h", "VHOST_VDPA_GET_STATUS", _IOC_READ, 0xaf71, 0x01 },
{ "linux/vhost.h", "VHOST_VDPA_GET_VQS_COUNT", _IOC_READ, 0xaf80, 0x04 },
{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_DESC_GROUP", _IOC_READ|_IOC_WRITE, 0xaf7f, 0x08 },
{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_GROUP", _IOC_READ|_IOC_WRITE, 0xaf7b, 0x08 },
{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_NUM", _IOC_READ, 0xaf76, 0x02 },
{ "linux/vhost.h", "VHOST_VDPA_GET_VRING_SIZE", _IOC_READ|_IOC_WRITE, 0xaf82, 0x08 },
{ "linux/vhost.h", "VHOST_VDPA_RESUME", _IOC_NONE, 0xaf7e, 0x00 },
{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG", _IOC_WRITE, 0xaf74, 0x08 },
{ "linux/vhost.h", "VHOST_VDPA_SET_CONFIG_CALL", _IOC_WRITE, 0xaf77, 0x04 },
{ "linux/vhost.h", "VHOST_VDPA_SET_GROUP_ASID", _IOC_WRITE, 0xaf7c, 0x08 },
{ "linux/vhost.h", "VHOST_VDPA_SET_STATUS", _IOC_WRITE, 0xaf72, 0x01 },
{ "linux/vhost.h", "VHOST_VDPA_SET_VRING_ENABLE", _IOC_WRITE, 0xaf75, 0x08 },
{ "linux/vhost.h", "VHOST_VDPA_SUSPEND", _IOC_NONE, 0xaf7d, 0x00 },
{ "linux/vhost.h", "VHOST_VSOCK_SET_GUEST_CID", _IOC_WRITE, 0xaf60, 0x08 },
{ "linux/vhost.h", "VHOST_VSOCK_SET_RUNNING", _IOC_WRITE, 0xaf61, 0x04 },
{ "linux/videodev2.h", "VIDIOC_CREATE_BUFS", _IOC_READ|_IOC_WRITE, 0x565c, 0xf8 },
{ "linux/videodev2.h", "VIDIOC_CROPCAP", _IOC_READ|_IOC_WRITE, 0x563a, 0x2c },
{ "linux/videodev2.h", "VIDIOC_DBG_G_CHIP_INFO", _IOC_READ|_IOC_WRITE, 0x5666, 0xc8 },
{ "linux/videodev2.h", "VIDIOC_DBG_G_REGISTER", _IOC_READ|_IOC_WRITE, 0x5650, 0x38 },
{ "linux/videodev2.h", "VIDIOC_DBG_S_REGISTER", _IOC_WRITE, 0x564f, 0x38 },
{ "linux/videodev2.h", "VIDIOC_DECODER_CMD", _IOC_READ|_IOC_WRITE, 0x5660, 0x48 },
{ "linux/videodev2.h", "VIDIOC_DQBUF", _IOC_READ|_IOC_WRITE, 0x5611, 0x4c },
{ "linux/videodev2.h", "VIDIOC_DQEVENT", _IOC_READ, 0x5659, 0x80 },
{ "linux/videodev2.h", "VIDIOC_DV_TIMINGS_CAP", _IOC_READ|_IOC_WRITE, 0x5664, 0x90 },
{ "linux/videodev2.h", "VIDIOC_ENCODER_CMD", _IOC_READ|_IOC_WRITE, 0x564d, 0x28 },
{ "linux/videodev2.h", "VIDIOC_ENUMAUDIO", _IOC_READ|_IOC_WRITE, 0x5641, 0x34 },
{ "linux/videodev2.h", "VIDIOC_ENUMAUDOUT", _IOC_READ|_IOC_WRITE, 0x5642, 0x34 },
{ "linux/videodev2.h", "VIDIOC_ENUMINPUT", _IOC_READ|_IOC_WRITE, 0x561a, 0x4c },
{ "linux/videodev2.h", "VIDIOC_ENUMOUTPUT", _IOC_READ|_IOC_WRITE, 0x5630, 0x48 },
{ "linux/videodev2.h", "VIDIOC_ENUMSTD", _IOC_READ|_IOC_WRITE, 0x5619, 0x40 },
{ "linux/videodev2.h", "VIDIOC_ENUM_DV_TIMINGS", _IOC_READ|_IOC_WRITE, 0x5662, 0x94 },
{ "linux/videodev2.h", "VIDIOC_ENUM_FMT", _IOC_READ|_IOC_WRITE, 0x5602, 0x40 },
{ "linux/videodev2.h", "VIDIOC_ENUM_FRAMEINTERVALS", _IOC_READ|_IOC_WRITE, 0x564b, 0x34 },
{ "linux/videodev2.h", "VIDIOC_ENUM_FRAMESIZES", _IOC_READ|_IOC_WRITE, 0x564a, 0x2c },
{ "linux/videodev2.h", "VIDIOC_ENUM_FREQ_BANDS", _IOC_READ|_IOC_WRITE, 0x5665, 0x40 },
{ "linux/videodev2.h", "VIDIOC_EXPBUF", _IOC_READ|_IOC_WRITE, 0x5610, 0x40 },
{ "linux/videodev2.h", "VIDIOC_G_AUDIO", _IOC_READ, 0x5621, 0x34 },
{ "linux/videodev2.h", "VIDIOC_G_AUDOUT", _IOC_READ, 0x5631, 0x34 },
{ "linux/videodev2.h", "VIDIOC_G_CROP", _IOC_READ|_IOC_WRITE, 0x563b, 0x14 },
{ "linux/videodev2.h", "VIDIOC_G_CTRL", _IOC_READ|_IOC_WRITE, 0x561b, 0x08 },
{ "linux/videodev2.h", "VIDIOC_G_DV_TIMINGS", _IOC_READ|_IOC_WRITE, 0x5658, 0x84 },
{ "linux/videodev2.h", "VIDIOC_G_EDID", _IOC_READ|_IOC_WRITE, 0x5628, 0x24 },
{ "linux/videodev2.h", "VIDIOC_G_ENC_INDEX", _IOC_READ, 0x564c, 0x818 },
{ "linux/videodev2.h", "VIDIOC_G_EXT_CTRLS", _IOC_READ|_IOC_WRITE, 0x5647, 0x18 },
{ "linux/videodev2.h", "VIDIOC_G_FBUF", _IOC_READ, 0x560a, 0x2c },
{ "linux/videodev2.h", "VIDIOC_G_FMT", _IOC_READ|_IOC_WRITE, 0x5604, 0xcc },
{ "linux/videodev2.h", "VIDIOC_G_FREQUENCY", _IOC_READ|_IOC_WRITE, 0x5638, 0x2c },
{ "linux/videodev2.h", "VIDIOC_G_INPUT", _IOC_READ, 0x5626, 0x04 },
{ "linux/videodev2.h", "VIDIOC_G_JPEGCOMP", _IOC_READ, 0x563d, 0x8c },
{ "linux/videodev2.h", "VIDIOC_G_MODULATOR", _IOC_READ|_IOC_WRITE, 0x5636, 0x44 },
{ "linux/videodev2.h", "VIDIOC_G_OUTPUT", _IOC_READ, 0x562e, 0x04 },
{ "linux/videodev2.h", "VIDIOC_G_PARM", _IOC_READ|_IOC_WRITE, 0x5615, 0xcc },
{ "linux/videodev2.h", "VIDIOC_G_PRIORITY", _IOC_READ, 0x5643, 0x04 },
{ "linux/videodev2.h", "VIDIOC_G_SELECTION", _IOC_READ|_IOC_WRITE, 0x565e, 0x40 },
{ "linux/videodev2.h", "VIDIOC_G_SLICED_VBI_CAP", _IOC_READ|_IOC_WRITE, 0x5645, 0x72 },
{ "linux/videodev2.h", "VIDIOC_G_STD", _IOC_READ, 0x5617, 0x08 },
{ "linux/videodev2.h", "VIDIOC_G_TUNER", _IOC_READ|_IOC_WRITE, 0x561d, 0x54 },
{ "linux/videodev2.h", "VIDIOC_LOG_STATUS", _IOC_NONE, 0x5646, 0x00 },
{ "linux/videodev2.h", "VIDIOC_OVERLAY", _IOC_WRITE, 0x560e, 0x04 },
{ "linux/videodev2.h", "VIDIOC_PREPARE_BUF", _IOC_READ|_IOC_WRITE, 0x565d, 0x4c },
{ "linux/videodev2.h", "VIDIOC_QBUF", _IOC_READ|_IOC_WRITE, 0x560f, 0x4c },
{ "linux/videodev2.h", "VIDIOC_QUERYBUF", _IOC_READ|_IOC_WRITE, 0x5609, 0x4c },
{ "linux/videodev2.h", "VIDIOC_QUERYCAP", _IOC_READ, 0x5600, 0x68 },
{ "linux/videodev2.h", "VIDIOC_QUERYCTRL", _IOC_READ|_IOC_WRITE, 0x5624, 0x44 },
{ "linux/videodev2.h", "VIDIOC_QUERYMENU", _IOC_READ|_IOC_WRITE, 0x5625, 0x2c },
{ "linux/videodev2.h", "VIDIOC_QUERYSTD", _IOC_READ, 0x563f, 0x08 },
{ "linux/videodev2.h", "VIDIOC_QUERY_DV_TIMINGS", _IOC_READ, 0x5663, 0x84 },
{ "linux/videodev2.h", "VIDIOC_QUERY_EXT_CTRL", _IOC_READ|_IOC_WRITE, 0x5667, 0xe8 },
{ "linux/videodev2.h", "VIDIOC_REMOVE_BUFS", _IOC_READ|_IOC_WRITE, 0x5668, 0x40 },
{ "linux/videodev2.h", "VIDIOC_REQBUFS", _IOC_READ|_IOC_WRITE, 0x5608, 0x14 },
{ "linux/videodev2.h", "VIDIOC_STREAMOFF", _IOC_WRITE, 0x5613, 0x04 },
{ "linux/videodev2.h", "VIDIOC_STREAMON", _IOC_WRITE, 0x5612, 0x04 },
{ "linux/videodev2.h", "VIDIOC_SUBSCRIBE_EVENT", _IOC_WRITE, 0x565a, 0x20 },
{ "linux/videodev2.h", "VIDIOC_S_AUDIO", _IOC_WRITE, 0x5622, 0x34 },
{ "linux/videodev2.h", "VIDIOC_S_AUDOUT", _IOC_WRITE, 0x5632, 0x34 },
{ "linux/videodev2.h", "VIDIOC_S_CROP", _IOC_WRITE, 0x563c, 0x14 },
{ "linux/videodev2.h", "VIDIOC_S_CTRL", _IOC_READ|_IOC_WRITE, 0x561c, 0x08 },
{ "linux/videodev2.h", "VIDIOC_S_DV_TIMINGS", _IOC_READ|_IOC_WRITE, 0x5657, 0x84 },
{ "linux/videodev2.h", "VIDIOC_S_EDID", _IOC_READ|_IOC_WRITE, 0x5629, 0x24 },
{ "linux/videodev2.h", "VIDIOC_S_EXT_CTRLS", _IOC_READ|_IOC_WRITE, 0x5648, 0x18 },
{ "linux/videodev2.h", "VIDIOC_S_FBUF", _IOC_WRITE, 0x560b, 0x2c },
{ "linux/videodev2.h", "VIDIOC_S_FMT", _IOC_READ|_IOC_WRITE, 0x5605, 0xcc },
{ "linux/videodev2.h", "VIDIOC_S_FREQUENCY", _IOC_WRITE, 0x5639, 0x2c },
{ "linux/videodev2.h", "VIDIOC_S_HW_FREQ_SEEK", _IOC_WRITE, 0x5652, 0x30 },
{ "linux/videodev2.h", "VIDIOC_S_INPUT", _IOC_READ|_IOC_WRITE, 0x5627, 0x04 },
{ "linux/videodev2.h", "VIDIOC_S_JPEGCOMP", _IOC_WRITE, 0x563e, 0x8c },
{ "linux/videodev2.h", "VIDIOC_S_MODULATOR", _IOC_WRITE, 0x5637, 0x44 },
{ "linux/videodev2.h", "VIDIOC_S_OUTPUT", _IOC_READ|_IOC_WRITE, 0x562f, 0x04 },
{ "linux/videodev2.h", "VIDIOC_S_PARM", _IOC_READ|_IOC_WRITE, 0x5616, 0xcc },
{ "linux/videodev2.h", "VIDIOC_S_PRIORITY", _IOC_WRITE, 0x5644, 0x04 },
{ "linux/videodev2.h", "VIDIOC_S_SELECTION", _IOC_READ|_IOC_WRITE, 0x565f, 0x40 },
{ "linux/videodev2.h", "VIDIOC_S_STD", _IOC_WRITE, 0x5618, 0x08 },
{ "linux/videodev2.h", "VIDIOC_S_TUNER", _IOC_WRITE, 0x561e, 0x54 },
{ "linux/videodev2.h", "VIDIOC_TRY_DECODER_CMD", _IOC_READ|_IOC_WRITE, 0x5661, 0x48 },
{ "linux/videodev2.h", "VIDIOC_TRY_ENCODER_CMD", _IOC_READ|_IOC_WRITE, 0x564e, 0x28 },
{ "linux/videodev2.h", "VIDIOC_TRY_EXT_CTRLS", _IOC_READ|_IOC_WRITE, 0x5649, 0x18 },
{ "linux/videodev2.h", "VIDIOC_TRY_FMT", _IOC_READ|_IOC_WRITE, 0x5640, 0xcc },
{ "linux/videodev2.h", "VIDIOC_UNSUBSCRIBE_EVENT", _IOC_WRITE, 0x565b, 0x20 },
{ "linux/vm_sockets.h", "IOCTL_VM_SOCKETS_GET_LOCAL_CID", _IOC_NONE, 0x07b9, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_CTX_ADD_NOTIFICATION", _IOC_NONE, 0x07af, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_CTX_GET_CPT_STATE", _IOC_NONE, 0x07b1, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_CTX_REMOVE_NOTIFICATION", _IOC_NONE, 0x07b0, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_CTX_SET_CPT_STATE", _IOC_NONE, 0x07b2, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_DATAGRAM_RECEIVE", _IOC_NONE, 0x07ac, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_DATAGRAM_SEND", _IOC_NONE, 0x07ab, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_GET_CONTEXT_ID", _IOC_NONE, 0x07b3, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_INIT_CONTEXT", _IOC_NONE, 0x07a0, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_NOTIFICATIONS_RECEIVE", _IOC_NONE, 0x07a6, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_NOTIFY_RESOURCE", _IOC_NONE, 0x07a5, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_QUEUEPAIR_ALLOC", _IOC_NONE, 0x07a8, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_QUEUEPAIR_DETACH", _IOC_NONE, 0x07aa, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_QUEUEPAIR_SETPAGEFILE", _IOC_NONE, 0x07a9, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_QUEUEPAIR_SETVA", _IOC_NONE, 0x07a4, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_SET_NOTIFY", _IOC_NONE, 0x07cb, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_SOCKETS_GET_AF_VALUE", _IOC_NONE, 0x07b8, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_SOCKETS_GET_LOCAL_CID", _IOC_NONE, 0x07b9, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_SOCKETS_VERSION", _IOC_NONE, 0x07b4, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_VERSION", _IOC_NONE, 0x079f, 0x00 },
{ "linux/vmw_vmci_defs.h", "IOCTL_VMCI_VERSION2", _IOC_NONE, 0x07a7, 0x00 },
{ "linux/vt.h", "VT_ACTIVATE", 0, 0x5606, 0 },
{ "linux/vt.h", "VT_DISALLOCATE", 0, 0x5608, 0 },
{ "linux/vt.h", "VT_GETHIFONTMASK", 0, 0x560D, 0 },
{ "linux/vt.h", "VT_GETMODE", 0, 0x5601, 0 },
{ "linux/vt.h", "VT_GETSTATE", 0, 0x5603, 0 },
{ "linux/vt.h", "VT_LOCKSWITCH", 0, 0x560B, 0 },
{ "linux/vt.h", "VT_OPENQRY", 0, 0x5600, 0 },
{ "linux/vt.h", "VT_RELDISP", 0, 0x5605, 0 },
{ "linux/vt.h", "VT_RESIZE", 0, 0x5609, 0 },
{ "linux/vt.h", "VT_RESIZEX", 0, 0x560A, 0 },
{ "linux/vt.h", "VT_SENDSIG", 0, 0x5604, 0 },
{ "linux/vt.h", "VT_SETACTIVATE", 0, 0x560F, 0 },
{ "linux/vt.h", "VT_SETMODE", 0, 0x5602, 0 },
{ "linux/vt.h", "VT_UNLOCKSWITCH", 0, 0x560C, 0 },
{ "linux/vt.h", "VT_WAITACTIVE", 0, 0x5607, 0 },
{ "linux/vt.h", "VT_WAITEVENT", 0, 0x560E, 0 },
{ "linux/vtpm_proxy.h", "VTPM_PROXY_IOC_NEW_DEV", _IOC_READ|_IOC_WRITE, 0xa100, 0x14 },
{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_FILTER", _IOC_NONE, 0x5761, 0x00 },
{ "linux/watch_queue.h", "IOC_WATCH_QUEUE_SET_SIZE", _IOC_NONE, 0x5760, 0x00 },
{ "linux/watchdog.h", "WDIOC_GETBOOTSTATUS", _IOC_READ, 0x5702, 0x04 },
{ "linux/watchdog.h", "WDIOC_GETPRETIMEOUT", _IOC_READ, 0x5709, 0x04 },
{ "linux/watchdog.h", "WDIOC_GETSTATUS", _IOC_READ, 0x5701, 0x04 },
{ "linux/watchdog.h", "WDIOC_GETSUPPORT", _IOC_READ, 0x5700, 0x28 },
{ "linux/watchdog.h", "WDIOC_GETTEMP", _IOC_READ, 0x5703, 0x04 },
{ "linux/watchdog.h", "WDIOC_GETTIMELEFT", _IOC_READ, 0x570a, 0x04 },
{ "linux/watchdog.h", "WDIOC_GETTIMEOUT", _IOC_READ, 0x5707, 0x04 },
{ "linux/watchdog.h", "WDIOC_KEEPALIVE", _IOC_READ, 0x5705, 0x04 },
{ "linux/watchdog.h", "WDIOC_SETOPTIONS", _IOC_READ, 0x5704, 0x04 },
{ "linux/watchdog.h", "WDIOC_SETPRETIMEOUT", _IOC_READ|_IOC_WRITE, 0x5708, 0x04 },
{ "linux/watchdog.h", "WDIOC_SETTIMEOUT", _IOC_READ|_IOC_WRITE, 0x5706, 0x04 },
{ "linux/wireless.h", "SIOCGIWAP", 0, 0x8B15, 0 },
{ "linux/wireless.h", "SIOCGIWAPLIST", 0, 0x8B17, 0 },
{ "linux/wireless.h", "SIOCGIWAUTH", 0, 0x8B33, 0 },
{ "linux/wireless.h", "SIOCGIWENCODE", 0, 0x8B2B, 0 },
{ "linux/wireless.h", "SIOCGIWENCODEEXT", 0, 0x8B35, 0 },
{ "linux/wireless.h", "SIOCGIWESSID", 0, 0x8B1B, 0 },
{ "linux/wireless.h", "SIOCGIWFRAG", 0, 0x8B25, 0 },
{ "linux/wireless.h", "SIOCGIWFREQ", 0, 0x8B05, 0 },
{ "linux/wireless.h", "SIOCGIWGENIE", 0, 0x8B31, 0 },
{ "linux/wireless.h", "SIOCGIWMODE", 0, 0x8B07, 0 },
{ "linux/wireless.h", "SIOCGIWNAME", 0, 0x8B01, 0 },
{ "linux/wireless.h", "SIOCGIWNICKN", 0, 0x8B1D, 0 },
{ "linux/wireless.h", "SIOCGIWNWID", 0, 0x8B03, 0 },
{ "linux/wireless.h", "SIOCGIWPOWER", 0, 0x8B2D, 0 },
{ "linux/wireless.h", "SIOCGIWPRIV", 0, 0x8B0D, 0 },
{ "linux/wireless.h", "SIOCGIWRANGE", 0, 0x8B0B, 0 },
{ "linux/wireless.h", "SIOCGIWRATE", 0, 0x8B21, 0 },
{ "linux/wireless.h", "SIOCGIWRETRY", 0, 0x8B29, 0 },
{ "linux/wireless.h", "SIOCGIWRTS", 0, 0x8B23, 0 },
{ "linux/wireless.h", "SIOCGIWSCAN", 0, 0x8B19, 0 },
{ "linux/wireless.h", "SIOCGIWSENS", 0, 0x8B09, 0 },
{ "linux/wireless.h", "SIOCGIWSPY", 0, 0x8B11, 0 },
{ "linux/wireless.h", "SIOCGIWSTATS", 0, 0x8B0F, 0 },
{ "linux/wireless.h", "SIOCGIWTHRSPY", 0, 0x8B13, 0 },
{ "linux/wireless.h", "SIOCGIWTXPOW", 0, 0x8B27, 0 },
{ "linux/wireless.h", "SIOCIWFIRST", 0, 0x8B00, 0 },
{ "linux/wireless.h", "SIOCIWFIRSTPRIV", 0, 0x8BE0, 0 },
{ "linux/wireless.h", "SIOCIWLASTPRIV", 0, 0x8BFF, 0 },
{ "linux/wireless.h", "SIOCSIWAP", 0, 0x8B14, 0 },
{ "linux/wireless.h", "SIOCSIWAUTH", 0, 0x8B32, 0 },
{ "linux/wireless.h", "SIOCSIWCOMMIT", 0, 0x8B00, 0 },
{ "linux/wireless.h", "SIOCSIWENCODE", 0, 0x8B2A, 0 },
{ "linux/wireless.h", "SIOCSIWENCODEEXT", 0, 0x8B34, 0 },
{ "linux/wireless.h", "SIOCSIWESSID", 0, 0x8B1A, 0 },
{ "linux/wireless.h", "SIOCSIWFRAG", 0, 0x8B24, 0 },
{ "linux/wireless.h", "SIOCSIWFREQ", 0, 0x8B04, 0 },
{ "linux/wireless.h", "SIOCSIWGENIE", 0, 0x8B30, 0 },
{ "linux/wireless.h", "SIOCSIWMLME", 0, 0x8B16, 0 },
{ "linux/wireless.h", "SIOCSIWMODE", 0, 0x8B06, 0 },
{ "linux/wireless.h", "SIOCSIWNICKN", 0, 0x8B1C, 0 },
{ "linux/wireless.h", "SIOCSIWNWID", 0, 0x8B02, 0 },
{ "linux/wireless.h", "SIOCSIWPMKSA", 0, 0x8B36, 0 },
{ "linux/wireless.h", "SIOCSIWPOWER", 0, 0x8B2C, 0 },
{ "linux/wireless.h", "SIOCSIWPRIV", 0, 0x8B0C, 0 },
{ "linux/wireless.h", "SIOCSIWRANGE", 0, 0x8B0A, 0 },
{ "linux/wireless.h", "SIOCSIWRATE", 0, 0x8B20, 0 },
{ "linux/wireless.h", "SIOCSIWRETRY", 0, 0x8B28, 0 },
{ "linux/wireless.h", "SIOCSIWRTS", 0, 0x8B22, 0 },
{ "linux/wireless.h", "SIOCSIWSCAN", 0, 0x8B18, 0 },
{ "linux/wireless.h", "SIOCSIWSENS", 0, 0x8B08, 0 },
{ "linux/wireless.h", "SIOCSIWSPY", 0, 0x8B10, 0 },
{ "linux/wireless.h", "SIOCSIWSTATS", 0, 0x8B0E, 0 },
{ "linux/wireless.h", "SIOCSIWTHRSPY", 0, 0x8B12, 0 },
{ "linux/wireless.h", "SIOCSIWTXPOW", 0, 0x8B26, 0 },
{ "linux/wmi.h", "DELL_WMI_SMBIOS_CMD", _IOC_READ|_IOC_WRITE, 0x5700, 0x34 },
{ "media/drv-intf/exynos-fimc.h", "S5P_FIMC_TX_END_NOTIFY", _IOC_NONE, 0x6500, 0x00 },
{ "media/i2c/adv7842.h", "ADV7842_CMD_RAM_TEST", _IOC_NONE, 0x56c0, 0x00 },
{ "media/i2c/bt819.h", "BT819_FIFO_RESET_HIGH", _IOC_NONE, 0x6201, 0x00 },
{ "media/i2c/bt819.h", "BT819_FIFO_RESET_LOW", _IOC_NONE, 0x6200, 0x00 },
{ "media/i2c/saa6588.h", "SAA6588_CMD_CLOSE", _IOC_WRITE, 0x5202, 0x04 },
{ "media/i2c/saa6588.h", "SAA6588_CMD_POLL", _IOC_READ, 0x5204, 0x04 },
{ "media/i2c/saa6588.h", "SAA6588_CMD_READ", _IOC_READ, 0x5203, 0x04 },
{ "media/v4l2-common.h", "TUNER_SET_CONFIG", _IOC_WRITE, 0x645c, 0x08 },
{ "media/v4l2-common.h", "VIDIOC_INT_RESET", _IOC_WRITE, 0x6466, 0x04 },
{ "media/v4l2-ioctl.h", "VIDIOC_DQBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5611, 0x44 },
{ "media/v4l2-ioctl.h", "VIDIOC_DQEVENT_TIME32", _IOC_READ, 0x5659, 0x78 },
{ "media/v4l2-ioctl.h", "VIDIOC_PREPARE_BUF_TIME32", _IOC_READ|_IOC_WRITE, 0x565d, 0x44 },
{ "media/v4l2-ioctl.h", "VIDIOC_QBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x560f, 0x44 },
{ "media/v4l2-ioctl.h", "VIDIOC_QUERYBUF_TIME32", _IOC_READ|_IOC_WRITE, 0x5609, 0x44 },
{ "media/v4l2-subdev.h", "V4L2_DEVICE_NOTIFY_EVENT", _IOC_WRITE, 0x7602, 0x80 },
{ "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_RX_NOTIFY", _IOC_WRITE, 0x7600, 0x04 },
{ "media/v4l2-subdev.h", "V4L2_SUBDEV_IR_TX_NOTIFY", _IOC_WRITE, 0x7601, 0x04 },
{ "misc/cxl.h", "CXL_IOCTL_DOWNLOAD_IMAGE", _IOC_WRITE, 0xca0a, 0x40 },
{ "misc/cxl.h", "CXL_IOCTL_GET_AFU_ID", _IOC_READ, 0xca02, 0x40 },
{ "misc/cxl.h", "CXL_IOCTL_GET_PROCESS_ELEMENT", _IOC_READ, 0xca01, 0x04 },
{ "misc/cxl.h", "CXL_IOCTL_START_WORK", _IOC_WRITE, 0xca00, 0x40 },
{ "misc/cxl.h", "CXL_IOCTL_VALIDATE_IMAGE", _IOC_WRITE, 0xca0b, 0x40 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_ALLOC_DMA_BUFF", _IOC_READ|_IOC_WRITE, 0x5201, 0x10 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_FREE_DMA_BUFF", _IOC_READ|_IOC_WRITE, 0x5202, 0x04 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_GET_DSP_INFO", _IOC_READ|_IOC_WRITE, 0x520d, 0x1c },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_INIT_ATTACH", _IOC_NONE, 0x5204, 0x00 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_INIT_ATTACH_SNS", _IOC_NONE, 0x5208, 0x00 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_INIT_CREATE", _IOC_READ|_IOC_WRITE, 0x5205, 0x18 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_INIT_CREATE_STATIC", _IOC_READ|_IOC_WRITE, 0x5209, 0x10 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_INVOKE", _IOC_READ|_IOC_WRITE, 0x5203, 0x10 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_MEM_MAP", _IOC_READ|_IOC_WRITE, 0x520a, 0x3c },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_MEM_UNMAP", _IOC_READ|_IOC_WRITE, 0x520b, 0x2c },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_MMAP", _IOC_READ|_IOC_WRITE, 0x5206, 0x20 },
{ "misc/fastrpc.h", "FASTRPC_IOCTL_MUNMAP", _IOC_READ|_IOC_WRITE, 0x5207, 0x10 },
{ "misc/mrvl_cn10k_dpi.h", "DPI_ENGINE_CFG", _IOC_WRITE, 0xb802, 0x18 },
{ "misc/mrvl_cn10k_dpi.h", "DPI_MPS_MRRS_CFG", _IOC_WRITE, 0xb801, 0x08 },
{ "misc/ocxl.h", "OCXL_IOCTL_ATTACH", _IOC_WRITE, 0xca10, 0x20 },
{ "misc/ocxl.h", "OCXL_IOCTL_ENABLE_P9_WAIT", _IOC_READ, 0xca15, 0x20 },
{ "misc/ocxl.h", "OCXL_IOCTL_GET_FEATURES", _IOC_READ, 0xca16, 0x20 },
{ "misc/ocxl.h", "OCXL_IOCTL_GET_METADATA", _IOC_READ, 0xca14, 0x80 },
{ "misc/ocxl.h", "OCXL_IOCTL_IRQ_ALLOC", _IOC_READ, 0xca11, 0x08 },
{ "misc/ocxl.h", "OCXL_IOCTL_IRQ_FREE", _IOC_WRITE, 0xca12, 0x08 },
{ "misc/ocxl.h", "OCXL_IOCTL_IRQ_SET_FD", _IOC_WRITE, 0xca13, 0x10 },
{ "misc/uacce/hisi_qm.h", "UACCE_CMD_QM_SET_QP_CTX", _IOC_READ|_IOC_WRITE, 0x480a, 0x04 },
{ "misc/uacce/hisi_qm.h", "UACCE_CMD_QM_SET_QP_INFO", _IOC_READ|_IOC_WRITE, 0x480b, 0x10 },
{ "misc/uacce/uacce.h", "UACCE_CMD_PUT_Q", _IOC_NONE, 0x5701, 0x00 },
{ "misc/uacce/uacce.h", "UACCE_CMD_START_Q", _IOC_NONE, 0x5700, 0x00 },
{ "misc/xilinx_sdfec.h", "XSDFEC_ADD_LDPC_CODE_PARAMS", _IOC_WRITE, 0x6605, 0x4a },
{ "misc/xilinx_sdfec.h", "XSDFEC_CLEAR_STATS", _IOC_NONE, 0x660b, 0x00 },
{ "misc/xilinx_sdfec.h", "XSDFEC_GET_CONFIG", _IOC_READ, 0x6606, 0x1c },
{ "misc/xilinx_sdfec.h", "XSDFEC_GET_STATS", _IOC_READ, 0x660c, 0x0c },
{ "misc/xilinx_sdfec.h", "XSDFEC_GET_STATUS", _IOC_READ, 0x6602, 0x06 },
{ "misc/xilinx_sdfec.h", "XSDFEC_GET_TURBO", _IOC_READ, 0x6607, 0x06 },
{ "misc/xilinx_sdfec.h", "XSDFEC_IS_ACTIVE", _IOC_READ, 0x660a, 0x01 },
{ "misc/xilinx_sdfec.h", "XSDFEC_SET_BYPASS", _IOC_WRITE, 0x6609, 0x01 },
{ "misc/xilinx_sdfec.h", "XSDFEC_SET_DEFAULT_CONFIG", _IOC_NONE, 0x660d, 0x00 },
{ "misc/xilinx_sdfec.h", "XSDFEC_SET_IRQ", _IOC_WRITE, 0x6603, 0x02 },
{ "misc/xilinx_sdfec.h", "XSDFEC_SET_ORDER", _IOC_WRITE, 0x6608, 0x04 },
{ "misc/xilinx_sdfec.h", "XSDFEC_SET_TURBO", _IOC_WRITE, 0x6604, 0x06 },
{ "misc/xilinx_sdfec.h", "XSDFEC_START_DEV", _IOC_NONE, 0x6600, 0x00 },
{ "misc/xilinx_sdfec.h", "XSDFEC_STOP_DEV", _IOC_NONE, 0x6601, 0x00 },
{ "mtd/mtd-abi.h", "ECCGETLAYOUT", _IOC_READ, 0x4d11, 0x148 },
{ "mtd/mtd-abi.h", "ECCGETSTATS", _IOC_READ, 0x4d12, 0x10 },
{ "mtd/mtd-abi.h", "MEMERASE", _IOC_WRITE, 0x4d02, 0x08 },
{ "mtd/mtd-abi.h", "MEMERASE64", _IOC_WRITE, 0x4d14, 0x10 },
{ "mtd/mtd-abi.h", "MEMGETBADBLOCK", _IOC_WRITE, 0x4d0b, 0x08 },
{ "mtd/mtd-abi.h", "MEMGETINFO", _IOC_READ, 0x4d01, 0x1e },
{ "mtd/mtd-abi.h", "MEMGETOOBSEL", _IOC_READ, 0x4d0a, 0xc8 },
{ "mtd/mtd-abi.h", "MEMGETREGIONCOUNT", _IOC_READ, 0x4d07, 0x04 },
{ "mtd/mtd-abi.h", "MEMGETREGIONINFO", _IOC_READ|_IOC_WRITE, 0x4d08, 0x10 },
{ "mtd/mtd-abi.h", "MEMISLOCKED", _IOC_READ, 0x4d17, 0x08 },
{ "mtd/mtd-abi.h", "MEMLOCK", _IOC_WRITE, 0x4d05, 0x08 },
{ "mtd/mtd-abi.h", "MEMREAD", _IOC_READ|_IOC_WRITE, 0x4d1a, 0x3c },
{ "mtd/mtd-abi.h", "MEMREADOOB", _IOC_READ|_IOC_WRITE, 0x4d04, 0x0c },
{ "mtd/mtd-abi.h", "MEMREADOOB64", _IOC_READ|_IOC_WRITE, 0x4d16, 0x18 },
{ "mtd/mtd-abi.h", "MEMSETBADBLOCK", _IOC_WRITE, 0x4d0c, 0x08 },
{ "mtd/mtd-abi.h", "MEMUNLOCK", _IOC_WRITE, 0x4d06, 0x08 },
{ "mtd/mtd-abi.h", "MEMWRITE", _IOC_READ|_IOC_WRITE, 0x4d18, 0x30 },
{ "mtd/mtd-abi.h", "MEMWRITEOOB", _IOC_READ|_IOC_WRITE, 0x4d03, 0x0c },
{ "mtd/mtd-abi.h", "MEMWRITEOOB64", _IOC_READ|_IOC_WRITE, 0x4d15, 0x18 },
{ "mtd/mtd-abi.h", "MTDFILEMODE", _IOC_NONE, 0x4d13, 0x00 },
{ "mtd/mtd-abi.h", "OTPERASE", _IOC_WRITE, 0x4d19, 0x0c },
{ "mtd/mtd-abi.h", "OTPGETREGIONCOUNT", _IOC_WRITE, 0x4d0e, 0x04 },
{ "mtd/mtd-abi.h", "OTPGETREGIONINFO", _IOC_WRITE, 0x4d0f, 0x0c },
{ "mtd/mtd-abi.h", "OTPLOCK", _IOC_READ, 0x4d10, 0x0c },
{ "mtd/mtd-abi.h", "OTPSELECT", _IOC_READ, 0x4d0d, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCATT", _IOC_WRITE, 0x6f40, 0x18 },
{ "mtd/ubi-user.h", "UBI_IOCDET", _IOC_WRITE, 0x6f41, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCEBCH", _IOC_WRITE, 0x4f02, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCEBER", _IOC_WRITE, 0x4f01, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCEBISMAP", _IOC_READ, 0x4f05, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCEBMAP", _IOC_WRITE, 0x4f03, 0x08 },
{ "mtd/ubi-user.h", "UBI_IOCEBUNMAP", _IOC_WRITE, 0x4f04, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCMKVOL", _IOC_WRITE, 0x6f00, 0x98 },
{ "mtd/ubi-user.h", "UBI_IOCRMVOL", _IOC_WRITE, 0x6f01, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCRNVOL", _IOC_WRITE, 0x6f03, 0x1110 },
{ "mtd/ubi-user.h", "UBI_IOCRPEB", _IOC_WRITE, 0x6f04, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCRSVOL", _IOC_WRITE, 0x6f02, 0x0c },
{ "mtd/ubi-user.h", "UBI_IOCSETVOLPROP", _IOC_WRITE, 0x4f06, 0x10 },
{ "mtd/ubi-user.h", "UBI_IOCSPEB", _IOC_WRITE, 0x6f05, 0x04 },
{ "mtd/ubi-user.h", "UBI_IOCVOLCRBLK", _IOC_WRITE, 0x4f07, 0x80 },
{ "mtd/ubi-user.h", "UBI_IOCVOLRMBLK", _IOC_NONE, 0x4f08, 0x00 },
{ "mtd/ubi-user.h", "UBI_IOCVOLUP", _IOC_WRITE, 0x4f00, 0x08 },
{ "net/bluetooth/hci_sock.h", "HCIBLOCKADDR", _IOC_WRITE, 0x48e6, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIDEVDOWN", _IOC_WRITE, 0x48ca, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIDEVRESET", _IOC_WRITE, 0x48cb, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIDEVRESTAT", _IOC_WRITE, 0x48cc, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIDEVUP", _IOC_WRITE, 0x48c9, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIGETAUTHINFO", _IOC_READ, 0x48d7, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIGETCONNINFO", _IOC_READ, 0x48d5, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIGETCONNLIST", _IOC_READ, 0x48d4, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIGETDEVINFO", _IOC_READ, 0x48d3, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIGETDEVLIST", _IOC_READ, 0x48d2, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIINQUIRY", _IOC_READ, 0x48f0, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETACLMTU", _IOC_WRITE, 0x48e3, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETAUTH", _IOC_WRITE, 0x48de, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETENCRYPT", _IOC_WRITE, 0x48df, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETLINKMODE", _IOC_WRITE, 0x48e2, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETLINKPOL", _IOC_WRITE, 0x48e1, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETPTYPE", _IOC_WRITE, 0x48e0, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETRAW", _IOC_WRITE, 0x48dc, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETSCAN", _IOC_WRITE, 0x48dd, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCISETSCOMTU", _IOC_WRITE, 0x48e4, 0x04 },
{ "net/bluetooth/hci_sock.h", "HCIUNBLOCKADDR", _IOC_WRITE, 0x48e7, 0x04 },
{ "net/bluetooth/rfcomm.h", "RFCOMMCREATEDEV", _IOC_WRITE, 0x52c8, 0x04 },
{ "net/bluetooth/rfcomm.h", "RFCOMMGETDEVINFO", _IOC_READ, 0x52d3, 0x04 },
{ "net/bluetooth/rfcomm.h", "RFCOMMGETDEVLIST", _IOC_READ, 0x52d2, 0x04 },
{ "net/bluetooth/rfcomm.h", "RFCOMMRELEASEDEV", _IOC_WRITE, 0x52c9, 0x04 },
{ "net/bluetooth/rfcomm.h", "RFCOMMSTEALDLC", _IOC_WRITE, 0x52dc, 0x04 },
{ "net/nfc/nci_core.h", "NCIUARTSETDRIVER", _IOC_WRITE, 0x5500, 0x04 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_ACK_EVENT", _IOC_WRITE, 0x1bea, 0x04 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_ASSIGN_CTXT", _IOC_READ|_IOC_WRITE, 0x1be1, 0x1c },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_CREDIT_UPD", _IOC_NONE, 0x1be6, 0x00 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_CTXT_INFO", _IOC_WRITE, 0x1be2, 0x28 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_CTXT_RESET", _IOC_NONE, 0x1bec, 0x00 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_GET_VERS", _IOC_READ, 0x1bee, 0x04 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_POLL_TYPE", _IOC_WRITE, 0x1be9, 0x04 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_RECV_CTRL", _IOC_WRITE, 0x1be8, 0x04 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_SET_PKEY", _IOC_WRITE, 0x1beb, 0x02 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_TID_FREE", _IOC_READ|_IOC_WRITE, 0x1be5, 0x18 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_TID_INVAL_READ", _IOC_READ|_IOC_WRITE, 0x1bed, 0x18 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_TID_UPDATE", _IOC_READ|_IOC_WRITE, 0x1be4, 0x18 },
{ "rdma/rdma_user_ioctl.h", "HFI1_IOCTL_USER_INFO", _IOC_WRITE, 0x1be3, 0x78 },
{ "rdma/rdma_user_ioctl.h", "IB_USER_MAD_ENABLE_PKEY", _IOC_NONE, 0x1b03, 0x00 },
{ "rdma/rdma_user_ioctl.h", "IB_USER_MAD_REGISTER_AGENT", _IOC_READ|_IOC_WRITE, 0x1b01, 0x1c },
{ "rdma/rdma_user_ioctl.h", "IB_USER_MAD_REGISTER_AGENT2", _IOC_READ|_IOC_WRITE, 0x1b04, 0x28 },
{ "rdma/rdma_user_ioctl.h", "IB_USER_MAD_UNREGISTER_AGENT", _IOC_WRITE, 0x1b02, 0x04 },
{ "rdma/rdma_user_ioctl_cmds.h", "RDMA_VERBS_IOCTL", _IOC_READ|_IOC_WRITE, 0x1b01, 0x18 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_ATTACH", _IOC_READ|_IOC_WRITE, 0xca80, 0x90 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_DETACH", _IOC_READ|_IOC_WRITE, 0xca83, 0x60 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_MANAGE_LUN", _IOC_READ|_IOC_WRITE, 0xca86, 0x68 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_RECOVER_AFU", _IOC_READ|_IOC_WRITE, 0xca85, 0x78 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_RELEASE", _IOC_READ|_IOC_WRITE, 0xca82, 0x68 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_USER_DIRECT", _IOC_READ|_IOC_WRITE, 0xca81, 0x70 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_USER_VIRTUAL", _IOC_READ|_IOC_WRITE, 0xca87, 0x78 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_VERIFY", _IOC_READ|_IOC_WRITE, 0xca84, 0x90 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_VLUN_CLONE", _IOC_READ|_IOC_WRITE, 0xca89, 0x70 },
{ "scsi/cxlflash_ioctl.h", "DK_CXLFLASH_VLUN_RESIZE", _IOC_READ|_IOC_WRITE, 0xca88, 0x78 },
{ "scsi/cxlflash_ioctl.h", "HT_CXLFLASH_AFU_DEBUG", _IOC_READ|_IOC_WRITE, 0xcabe, 0x78 },
{ "scsi/cxlflash_ioctl.h", "HT_CXLFLASH_LUN_PROVISION", _IOC_READ|_IOC_WRITE, 0xcabf, 0xa0 },
{ "scsi/scsi.h", "SCSI_IOCTL_GET_BUS_NUMBER", 0, 0x5386, 0 },
{ "scsi/scsi.h", "SCSI_IOCTL_GET_IDLUN", 0, 0x5382, 0 },
{ "scsi/scsi.h", "SCSI_IOCTL_GET_PCI", 0, 0x5387, 0 },
{ "scsi/scsi.h", "SCSI_IOCTL_PROBE_HOST", 0, 0x5385, 0 },
{ "scsi/scsi_ioctl.h", "SCSI_IOCTL_DOORLOCK", 0, 0x5380, 0 },
{ "scsi/scsi_ioctl.h", "SCSI_IOCTL_DOORUNLOCK", 0, 0x5381, 0 },
{ "scsi/sg.h", "SG_EMULATED_HOST", 0, 0x2203, 0 },
{ "scsi/sg.h", "SG_GET_ACCESS_COUNT", 0, 0x2289, 0 },
{ "scsi/sg.h", "SG_GET_COMMAND_Q", 0, 0x2270, 0 },
{ "scsi/sg.h", "SG_GET_KEEP_ORPHAN", 0, 0x2288, 0 },
{ "scsi/sg.h", "SG_GET_LOW_DMA", 0, 0x227a, 0 },
{ "scsi/sg.h", "SG_GET_NUM_WAITING", 0, 0x227d, 0 },
{ "scsi/sg.h", "SG_GET_PACK_ID", 0, 0x227c, 0 },
{ "scsi/sg.h", "SG_GET_REQUEST_TABLE", 0, 0x2286, 0 },
{ "scsi/sg.h", "SG_GET_RESERVED_SIZE", 0, 0x2272, 0 },
{ "scsi/sg.h", "SG_GET_SCSI_ID", 0, 0x2276, 0 },
{ "scsi/sg.h", "SG_GET_SG_TABLESIZE", 0, 0x227F, 0 },
{ "scsi/sg.h", "SG_GET_TIMEOUT", 0, 0x2202, 0 },
{ "scsi/sg.h", "SG_GET_TRANSFORM", 0, 0x2205, 0 },
{ "scsi/sg.h", "SG_GET_VERSION_NUM", 0, 0x2282, 0 },
{ "scsi/sg.h", "SG_IO", 0, 0x2285, 0 },
{ "scsi/sg.h", "SG_NEXT_CMD_LEN", 0, 0x2283, 0 },
{ "scsi/sg.h", "SG_SCSI_RESET", 0, 0x2284, 0 },
{ "scsi/sg.h", "SG_SET_COMMAND_Q", 0, 0x2271, 0 },
{ "scsi/sg.h", "SG_SET_DEBUG", 0, 0x227e, 0 },
{ "scsi/sg.h", "SG_SET_FORCE_LOW_DMA", 0, 0x2279, 0 },
{ "scsi/sg.h", "SG_SET_FORCE_PACK_ID", 0, 0x227b, 0 },
{ "scsi/sg.h", "SG_SET_KEEP_ORPHAN", 0, 0x2287, 0 },
{ "scsi/sg.h", "SG_SET_RESERVED_SIZE", 0, 0x2275, 0 },
{ "scsi/sg.h", "SG_SET_TIMEOUT", 0, 0x2201, 0 },
{ "scsi/sg.h", "SG_SET_TRANSFORM", 0, 0x2204, 0 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_CLIENT_ID", _IOC_READ, 0x5301, 0x04 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_CREATE_PORT", _IOC_READ|_IOC_WRITE, 0x5320, 0xa2 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_CREATE_QUEUE", _IOC_READ|_IOC_WRITE, 0x5332, 0x8a },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_DELETE_PORT", _IOC_WRITE, 0x5321, 0xa2 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_DELETE_QUEUE", _IOC_WRITE, 0x5333, 0x8a },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_CLIENT_INFO", _IOC_READ|_IOC_WRITE, 0x5310, 0xbc },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_CLIENT_POOL", _IOC_READ|_IOC_WRITE, 0x534b, 0x58 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_CLIENT_UMP_INFO", _IOC_READ|_IOC_WRITE, 0x5312, 0x208 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_NAMED_QUEUE", _IOC_READ|_IOC_WRITE, 0x5336, 0x8a },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_PORT_INFO", _IOC_READ|_IOC_WRITE, 0x5322, 0xa2 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_QUEUE_CLIENT", _IOC_READ|_IOC_WRITE, 0x5349, 0x4c },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_QUEUE_INFO", _IOC_READ|_IOC_WRITE, 0x5334, 0x8a },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_QUEUE_STATUS", _IOC_READ|_IOC_WRITE, 0x5340, 0x5c },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_QUEUE_TEMPO", _IOC_READ|_IOC_WRITE, 0x5341, 0x2c },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_QUEUE_TIMER", _IOC_READ|_IOC_WRITE, 0x5345, 0x60 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_GET_SUBSCRIPTION", _IOC_READ|_IOC_WRITE, 0x5350, 0x50 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_PVERSION", _IOC_READ, 0x5300, 0x04 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_QUERY_NEXT_CLIENT", _IOC_READ|_IOC_WRITE, 0x5351, 0xbc },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_QUERY_NEXT_PORT", _IOC_READ|_IOC_WRITE, 0x5352, 0xa2 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_QUERY_SUBS", _IOC_READ|_IOC_WRITE, 0x534f, 0x56 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_REMOVE_EVENTS", _IOC_WRITE, 0x534e, 0x3e },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_RUNNING_MODE", _IOC_READ|_IOC_WRITE, 0x5303, 0x10 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SET_CLIENT_INFO", _IOC_WRITE, 0x5311, 0xbc },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SET_CLIENT_POOL", _IOC_WRITE, 0x534c, 0x58 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SET_CLIENT_UMP_INFO", _IOC_READ|_IOC_WRITE, 0x5313, 0x208 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SET_PORT_INFO", _IOC_WRITE, 0x5323, 0xa2 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SET_QUEUE_CLIENT", _IOC_WRITE, 0x534a, 0x4c },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SET_QUEUE_INFO", _IOC_READ|_IOC_WRITE, 0x5335, 0x8a },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SET_QUEUE_TEMPO", _IOC_WRITE, 0x5342, 0x2c },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SET_QUEUE_TIMER", _IOC_WRITE, 0x5346, 0x60 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SUBSCRIBE_PORT", _IOC_WRITE, 0x5330, 0x50 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_SYSTEM_INFO", _IOC_READ|_IOC_WRITE, 0x5302, 0x30 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_UNSUBSCRIBE_PORT", _IOC_WRITE, 0x5331, 0x50 },
{ "sound/asequencer.h", "SNDRV_SEQ_IOCTL_USER_PVERSION", _IOC_WRITE, 0x5304, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_CARD_INFO", _IOC_READ, 0x5501, 0x178 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_ADD", _IOC_READ|_IOC_WRITE, 0x5517, 0x110 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_INFO", _IOC_READ|_IOC_WRITE, 0x5511, 0x110 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_LIST", _IOC_READ|_IOC_WRITE, 0x5510, 0x46 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_LOCK", _IOC_WRITE, 0x5514, 0x40 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_READ", _IOC_READ|_IOC_WRITE, 0x5512, 0x2c2 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_REMOVE", _IOC_READ|_IOC_WRITE, 0x5519, 0x40 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_REPLACE", _IOC_READ|_IOC_WRITE, 0x5518, 0x110 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_UNLOCK", _IOC_WRITE, 0x5515, 0x40 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_ELEM_WRITE", _IOC_READ|_IOC_WRITE, 0x5513, 0x2c2 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_HWDEP_INFO", _IOC_READ, 0x5521, 0xdc },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_HWDEP_NEXT_DEVICE", _IOC_READ|_IOC_WRITE, 0x5520, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_PCM_INFO", _IOC_READ|_IOC_WRITE, 0x5531, 0x120 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_PCM_NEXT_DEVICE", _IOC_READ, 0x5530, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_PCM_PREFER_SUBDEVICE", _IOC_WRITE, 0x5532, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_POWER", _IOC_READ|_IOC_WRITE, 0x55d0, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_POWER_STATE", _IOC_READ, 0x55d1, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_PVERSION", _IOC_READ, 0x5500, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_RAWMIDI_INFO", _IOC_READ|_IOC_WRITE, 0x5541, 0x10c },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_RAWMIDI_NEXT_DEVICE", _IOC_READ|_IOC_WRITE, 0x5540, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_RAWMIDI_PREFER_SUBDEVICE", _IOC_WRITE, 0x5542, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_SUBSCRIBE_EVENTS", _IOC_READ|_IOC_WRITE, 0x5516, 0x04 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_TLV_COMMAND", _IOC_READ|_IOC_WRITE, 0x551c, 0x08 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_TLV_READ", _IOC_READ|_IOC_WRITE, 0x551a, 0x08 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_TLV_WRITE", _IOC_READ|_IOC_WRITE, 0x551b, 0x08 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_UMP_BLOCK_INFO", _IOC_READ|_IOC_WRITE, 0x5545, 0xb4 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_UMP_ENDPOINT_INFO", _IOC_READ|_IOC_WRITE, 0x5544, 0x148 },
{ "sound/asound.h", "SNDRV_CTL_IOCTL_UMP_NEXT_DEVICE", _IOC_READ|_IOC_WRITE, 0x5543, 0x04 },
{ "sound/asound.h", "SNDRV_HWDEP_IOCTL_DSP_LOAD", _IOC_WRITE, 0x4803, 0x50 },
{ "sound/asound.h", "SNDRV_HWDEP_IOCTL_DSP_STATUS", _IOC_READ, 0x4802, 0x40 },
{ "sound/asound.h", "SNDRV_HWDEP_IOCTL_INFO", _IOC_READ, 0x4801, 0xdc },
{ "sound/asound.h", "SNDRV_HWDEP_IOCTL_PVERSION", _IOC_READ, 0x4800, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_CHANNEL_INFO", _IOC_READ, 0x4132, 0x10 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_DELAY", _IOC_READ, 0x4121, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_DRAIN", _IOC_NONE, 0x4144, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_DROP", _IOC_NONE, 0x4143, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_FORWARD", _IOC_WRITE, 0x4149, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_HWSYNC", _IOC_NONE, 0x4122, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_HW_FREE", _IOC_NONE, 0x4112, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_HW_PARAMS", _IOC_READ|_IOC_WRITE, 0x4111, 0x232 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_HW_REFINE", _IOC_READ|_IOC_WRITE, 0x4110, 0x232 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_INFO", _IOC_READ, 0x4101, 0x120 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_LINK", _IOC_WRITE, 0x4160, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_PAUSE", _IOC_WRITE, 0x4145, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_PREPARE", _IOC_NONE, 0x4140, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_PVERSION", _IOC_READ, 0x4100, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_READI_FRAMES", _IOC_READ, 0x4151, 0x0c },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_READN_FRAMES", _IOC_READ, 0x4153, 0x0c },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_RESET", _IOC_NONE, 0x4141, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_RESUME", _IOC_NONE, 0x4147, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_REWIND", _IOC_WRITE, 0x4146, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_START", _IOC_NONE, 0x4142, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_STATUS", _IOC_READ, 0x4120, 0x6c },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_STATUS_EXT", _IOC_READ|_IOC_WRITE, 0x4124, 0x6c },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_SW_PARAMS", _IOC_READ|_IOC_WRITE, 0x4113, 0x68 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_SYNC_PTR", _IOC_READ|_IOC_WRITE, 0x4123, 0x84 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_TSTAMP", _IOC_WRITE, 0x4102, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_TTSTAMP", _IOC_WRITE, 0x4103, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_UNLINK", _IOC_NONE, 0x4161, 0x00 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_USER_PVERSION", _IOC_WRITE, 0x4104, 0x04 },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_WRITEI_FRAMES", _IOC_WRITE, 0x4150, 0x0c },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_WRITEN_FRAMES", _IOC_WRITE, 0x4152, 0x0c },
{ "sound/asound.h", "SNDRV_PCM_IOCTL_XRUN", _IOC_NONE, 0x4148, 0x00 },
{ "sound/asound.h", "SNDRV_RAWMIDI_IOCTL_DRAIN", _IOC_WRITE, 0x5731, 0x04 },
{ "sound/asound.h", "SNDRV_RAWMIDI_IOCTL_DROP", _IOC_WRITE, 0x5730, 0x04 },
{ "sound/asound.h", "SNDRV_RAWMIDI_IOCTL_INFO", _IOC_READ, 0x5701, 0x10c },
{ "sound/asound.h", "SNDRV_RAWMIDI_IOCTL_PARAMS", _IOC_READ|_IOC_WRITE, 0x5710, 0x1e },
{ "sound/asound.h", "SNDRV_RAWMIDI_IOCTL_PVERSION", _IOC_READ, 0x5700, 0x04 },
{ "sound/asound.h", "SNDRV_RAWMIDI_IOCTL_STATUS", _IOC_READ|_IOC_WRITE, 0x5720, 0x24 },
{ "sound/asound.h", "SNDRV_RAWMIDI_IOCTL_USER_PVERSION", _IOC_WRITE, 0x5702, 0x04 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_CONTINUE", _IOC_NONE, 0x54a2, 0x00 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_CREATE", _IOC_READ|_IOC_WRITE, 0x54a5, 0x20 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_GINFO", _IOC_READ|_IOC_WRITE, 0x5403, 0xe0 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_GPARAMS", _IOC_WRITE, 0x5404, 0x3c },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_GSTATUS", _IOC_READ|_IOC_WRITE, 0x5405, 0x40 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_INFO", _IOC_READ, 0x5411, 0xe0 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_NEXT_DEVICE", _IOC_READ|_IOC_WRITE, 0x5401, 0x14 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_PARAMS", _IOC_WRITE, 0x5412, 0x50 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_PAUSE", _IOC_NONE, 0x54a3, 0x00 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_PVERSION", _IOC_READ, 0x5400, 0x04 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_SELECT", _IOC_WRITE, 0x5410, 0x34 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_START", _IOC_NONE, 0x54a0, 0x00 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_STATUS", _IOC_READ, 0x5414, 0x58 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_STOP", _IOC_NONE, 0x54a1, 0x00 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD64", _IOC_WRITE, 0x54a4, 0x04 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TREAD_OLD", _IOC_WRITE, 0x5402, 0x04 },
{ "sound/asound.h", "SNDRV_TIMER_IOCTL_TRIGGER", _IOC_NONE, 0x54a6, 0x00 },
{ "sound/asound.h", "SNDRV_UMP_IOCTL_BLOCK_INFO", _IOC_READ, 0x5741, 0xb4 },
{ "sound/asound.h", "SNDRV_UMP_IOCTL_ENDPOINT_INFO", _IOC_READ, 0x5740, 0x148 },
{ "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_CLEAR_PATCHES", _IOC_NONE, 0x4840, 0x00 },
{ "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_INFO", _IOC_READ, 0x4820, 0x02 },
{ "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_PLAY_NOTE", _IOC_WRITE, 0x4822, 0x08 },
{ "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_RESET", _IOC_NONE, 0x4821, 0x00 },
{ "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_SET_CONNECTION", _IOC_WRITE, 0x4826, 0x04 },
{ "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_SET_MODE", _IOC_WRITE, 0x4825, 0x04 },
{ "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_SET_PARAMS", _IOC_WRITE, 0x4824, 0x09 },
{ "sound/asound_fm.h", "SNDRV_DM_FM_IOCTL_SET_VOICE", _IOC_WRITE, 0x4823, 0x12 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_AVAIL", _IOC_READ, 0x4321, 0x1c },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_DRAIN", _IOC_NONE, 0x4334, 0x00 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_GET_CAPS", _IOC_READ|_IOC_WRITE, 0x4310, 0xc4 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_GET_CODEC_CAPS", _IOC_READ|_IOC_WRITE, 0x4311, 0x2b88 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_GET_METADATA", _IOC_READ|_IOC_WRITE, 0x4315, 0x24 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_GET_PARAMS", _IOC_READ, 0x4313, 0x78 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_IOCTL_VERSION", _IOC_READ, 0x4300, 0x04 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_NEXT_TRACK", _IOC_NONE, 0x4335, 0x00 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_PARTIAL_DRAIN", _IOC_NONE, 0x4336, 0x00 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_PAUSE", _IOC_NONE, 0x4330, 0x00 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_RESUME", _IOC_NONE, 0x4331, 0x00 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_SET_METADATA", _IOC_WRITE, 0x4314, 0x24 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_SET_PARAMS", _IOC_WRITE, 0x4312, 0x84 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_START", _IOC_NONE, 0x4332, 0x00 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_STOP", _IOC_NONE, 0x4333, 0x00 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_TASK_CREATE", _IOC_READ|_IOC_WRITE, 0x4360, 0x34 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_TASK_FREE", _IOC_WRITE, 0x4361, 0x08 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_TASK_START", _IOC_READ|_IOC_WRITE, 0x4362, 0x34 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_TASK_STATUS", _IOC_READ|_IOC_WRITE, 0x4368, 0x2c },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_TASK_STOP", _IOC_WRITE, 0x4363, 0x08 },
{ "sound/compress_offload.h", "SNDRV_COMPRESS_TSTAMP", _IOC_READ, 0x4320, 0x14 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_CODE_PEEK", _IOC_READ|_IOC_WRITE, 0x4812, 0x18c },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_CODE_POKE", _IOC_WRITE, 0x4811, 0x18c },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_CONTINUE", _IOC_NONE, 0x4881, 0x00 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_DBG_READ", _IOC_READ, 0x4884, 0x04 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_INFO", _IOC_READ, 0x4810, 0x80c },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_PCM_PEEK", _IOC_READ|_IOC_WRITE, 0x4831, 0x46 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_PCM_POKE", _IOC_WRITE, 0x4830, 0x46 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_PVERSION", _IOC_READ, 0x4840, 0x04 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_SINGLE_STEP", _IOC_WRITE, 0x4883, 0x04 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_STOP", _IOC_NONE, 0x4880, 0x00 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_TRAM_PEEK", _IOC_READ|_IOC_WRITE, 0x4822, 0x0c },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_TRAM_POKE", _IOC_WRITE, 0x4821, 0x0c },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_TRAM_SETUP", _IOC_WRITE, 0x4820, 0x04 },
{ "sound/emu10k1.h", "SNDRV_EMU10K1_IOCTL_ZERO_TRAM_COUNTER", _IOC_NONE, 0x4882, 0x00 },
{ "sound/firewire.h", "SNDRV_FIREWIRE_IOCTL_GET_INFO", _IOC_READ, 0x48f8, 0x20 },
{ "sound/firewire.h", "SNDRV_FIREWIRE_IOCTL_LOCK", _IOC_NONE, 0x48f9, 0x00 },
{ "sound/firewire.h", "SNDRV_FIREWIRE_IOCTL_MOTU_COMMAND_DSP_METER", _IOC_READ, 0x48fd, 0x640 },
{ "sound/firewire.h", "SNDRV_FIREWIRE_IOCTL_MOTU_REGISTER_DSP_METER", _IOC_READ, 0x48fc, 0x30 },
{ "sound/firewire.h", "SNDRV_FIREWIRE_IOCTL_MOTU_REGISTER_DSP_PARAMETER", _IOC_READ, 0x48fe, 0x200 },
{ "sound/firewire.h", "SNDRV_FIREWIRE_IOCTL_TASCAM_STATE", _IOC_READ, 0x48fb, 0x100 },
{ "sound/firewire.h", "SNDRV_FIREWIRE_IOCTL_UNLOCK", _IOC_NONE, 0x48fa, 0x00 },
{ "sound/hda_hwdep.h", "HDA_IOCTL_GET_WCAP", _IOC_READ|_IOC_WRITE, 0x4812, 0x08 },
{ "sound/hda_hwdep.h", "HDA_IOCTL_PVERSION", _IOC_READ, 0x4810, 0x04 },
{ "sound/hda_hwdep.h", "HDA_IOCTL_VERB_WRITE", _IOC_READ|_IOC_WRITE, 0x4811, 0x08 },
{ "sound/hdsp.h", "SNDRV_HDSP_IOCTL_GET_9632_AEB", _IOC_READ, 0x4845, 0x08 },
{ "sound/hdsp.h", "SNDRV_HDSP_IOCTL_GET_CONFIG_INFO", _IOC_READ, 0x4841, 0x22 },
{ "sound/hdsp.h", "SNDRV_HDSP_IOCTL_GET_MIXER", _IOC_READ, 0x4844, 0x1000 },
{ "sound/hdsp.h", "SNDRV_HDSP_IOCTL_GET_PEAK_RMS", _IOC_READ, 0x4840, 0x3b0 },
{ "sound/hdsp.h", "SNDRV_HDSP_IOCTL_GET_VERSION", _IOC_READ, 0x4843, 0x06 },
{ "sound/hdsp.h", "SNDRV_HDSP_IOCTL_UPLOAD_FIRMWARE", _IOC_WRITE, 0x4842, 0x04 },
{ "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_CONFIG", _IOC_READ, 0x4841, 0x18 },
{ "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_LTC", _IOC_READ, 0x4846, 0x10 },
{ "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_MIXER", _IOC_READ, 0x4844, 0x04 },
{ "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_PEAK_RMS", _IOC_READ, 0x4842, 0x906 },
{ "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_STATUS", _IOC_READ, 0x4847, 0x1a },
{ "sound/hdspm.h", "SNDRV_HDSPM_IOCTL_GET_VERSION", _IOC_READ, 0x4848, 0x20 },
{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS32", _IOC_READ, 0x4120, 0x6c },
{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS64", _IOC_READ, 0x4120, 0x80 },
{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT32", _IOC_READ|_IOC_WRITE, 0x4124, 0x6c },
{ "sound/pcm.h", "SNDRV_PCM_IOCTL_STATUS_EXT64", _IOC_READ|_IOC_WRITE, 0x4124, 0x80 },
{ "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_INFO", _IOC_READ, 0x4810, 0x26 },
{ "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_LOAD_CODE", _IOC_WRITE, 0x4811, 0x3012 },
{ "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_PAUSE", _IOC_NONE, 0x4815, 0x00 },
{ "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_RESTART", _IOC_NONE, 0x4816, 0x00 },
{ "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_START", _IOC_WRITE, 0x4813, 0x08 },
{ "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_STOP", _IOC_NONE, 0x4814, 0x00 },
{ "sound/sb16_csp.h", "SNDRV_SB_CSP_IOCTL_UNLOAD_CODE", _IOC_NONE, 0x4812, 0x00 },
{ "sound/scarlett2.h", "SCARLETT2_IOCTL_ERASE_FLASH_SEGMENT", _IOC_NONE, 0x5363, 0x00 },
{ "sound/scarlett2.h", "SCARLETT2_IOCTL_GET_ERASE_PROGRESS", _IOC_READ, 0x5364, 0x02 },
{ "sound/scarlett2.h", "SCARLETT2_IOCTL_PVERSION", _IOC_READ, 0x5360, 0x04 },
{ "sound/scarlett2.h", "SCARLETT2_IOCTL_REBOOT", _IOC_NONE, 0x5361, 0x00 },
{ "sound/scarlett2.h", "SCARLETT2_IOCTL_SELECT_FLASH_SEGMENT", _IOC_WRITE, 0x5362, 0x04 },
{ "sound/sfnt_info.h", "SNDRV_EMUX_IOCTL_LOAD_PATCH", _IOC_READ|_IOC_WRITE, 0x4881, 0x10 },
{ "sound/sfnt_info.h", "SNDRV_EMUX_IOCTL_MEM_AVAIL", _IOC_WRITE, 0x4884, 0x04 },
{ "sound/sfnt_info.h", "SNDRV_EMUX_IOCTL_MISC_MODE", _IOC_READ|_IOC_WRITE, 0x4884, 0x10 },
{ "sound/sfnt_info.h", "SNDRV_EMUX_IOCTL_REMOVE_LAST_SAMPLES", _IOC_NONE, 0x4883, 0x00 },
{ "sound/sfnt_info.h", "SNDRV_EMUX_IOCTL_RESET_SAMPLES", _IOC_NONE, 0x4882, 0x00 },
{ "sound/sfnt_info.h", "SNDRV_EMUX_IOCTL_VERSION", _IOC_READ, 0x4880, 0x04 },
{ "sound/usb_stream.h", "SNDRV_USB_STREAM_IOCTL_SET_PARAMS", _IOC_WRITE, 0x4890, 0x10 },
{ "video/kyro.h", "KYRO_IOCTL_OVERLAY_CREATE", _IOC_NONE, 0x6b00, 0x00 },
{ "video/kyro.h", "KYRO_IOCTL_OVERLAY_OFFSET", _IOC_NONE, 0x6b04, 0x00 },
{ "video/kyro.h", "KYRO_IOCTL_OVERLAY_VIEWPORT_SET", _IOC_NONE, 0x6b01, 0x00 },
{ "video/kyro.h", "KYRO_IOCTL_SET_VIDEO_MODE", _IOC_NONE, 0x6b02, 0x00 },
{ "video/kyro.h", "KYRO_IOCTL_STRIDE", _IOC_NONE, 0x6b05, 0x00 },
{ "video/kyro.h", "KYRO_IOCTL_UVSTRIDE", _IOC_NONE, 0x6b03, 0x00 },
{ "video/sisfb.h", "SISFB_COMMAND", _IOC_READ|_IOC_WRITE, 0xf305, 0x54 },
{ "video/sisfb.h", "SISFB_GET_AUTOMAXIMIZE", _IOC_READ, 0xf303, 0x04 },
{ "video/sisfb.h", "SISFB_GET_AUTOMAXIMIZE_OLD", _IOC_READ, 0x6efa, 0x04 },
{ "video/sisfb.h", "SISFB_GET_INFO", _IOC_READ, 0xf301, 0x114 },
{ "video/sisfb.h", "SISFB_GET_INFO_OLD", _IOC_READ, 0x6ef8, 0x04 },
{ "video/sisfb.h", "SISFB_GET_INFO_SIZE", _IOC_READ, 0xf300, 0x04 },
{ "video/sisfb.h", "SISFB_GET_TVPOSOFFSET", _IOC_READ, 0xf304, 0x04 },
{ "video/sisfb.h", "SISFB_GET_VBRSTATUS", _IOC_READ, 0xf302, 0x04 },
{ "video/sisfb.h", "SISFB_GET_VBRSTATUS_OLD", _IOC_READ, 0x6ef9, 0x04 },
{ "video/sisfb.h", "SISFB_SET_AUTOMAXIMIZE", _IOC_WRITE, 0xf303, 0x04 },
{ "video/sisfb.h", "SISFB_SET_AUTOMAXIMIZE_OLD", _IOC_WRITE, 0x6efa, 0x04 },
{ "video/sisfb.h", "SISFB_SET_LOCK", _IOC_WRITE, 0xf306, 0x04 },
{ "video/sisfb.h", "SISFB_SET_TVPOSOFFSET", _IOC_WRITE, 0xf304, 0x04 },
{ "video/sstfb.h", "SSTFB_GET_VGAPASS", _IOC_READ, 0x46dd, 0x04 },
{ "video/sstfb.h", "SSTFB_SET_VGAPASS", _IOC_WRITE, 0x46dd, 0x04 },
{ "xen/evtchn.h", "IOCTL_EVTCHN_BIND_INTERDOMAIN", _IOC_NONE, 0x4501, 0x08 },
{ "xen/evtchn.h", "IOCTL_EVTCHN_BIND_STATIC", _IOC_NONE, 0x4507, 0x04 },
{ "xen/evtchn.h", "IOCTL_EVTCHN_BIND_UNBOUND_PORT", _IOC_NONE, 0x4502, 0x04 },
{ "xen/evtchn.h", "IOCTL_EVTCHN_BIND_VIRQ", _IOC_NONE, 0x4500, 0x04 },
{ "xen/evtchn.h", "IOCTL_EVTCHN_NOTIFY", _IOC_NONE, 0x4504, 0x04 },
{ "xen/evtchn.h", "IOCTL_EVTCHN_RESET", _IOC_NONE, 0x4505, 0x00 },
{ "xen/evtchn.h", "IOCTL_EVTCHN_RESTRICT_DOMID", _IOC_NONE, 0x4506, 0x02 },
{ "xen/evtchn.h", "IOCTL_EVTCHN_UNBIND", _IOC_NONE, 0x4503, 0x04 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_DMABUF_EXP_FROM_REFS", _IOC_NONE, 0x4709, 0x14 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_DMABUF_EXP_WAIT_RELEASED", _IOC_NONE, 0x470a, 0x08 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_DMABUF_IMP_RELEASE", _IOC_NONE, 0x470c, 0x08 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_DMABUF_IMP_TO_REFS", _IOC_NONE, 0x470b, 0x14 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_GET_OFFSET_FOR_VADDR", _IOC_NONE, 0x4702, 0x18 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_GRANT_COPY", _IOC_NONE, 0x4708, 0x08 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_MAP_GRANT_REF", _IOC_NONE, 0x4700, 0x18 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_SET_MAX_GRANTS", _IOC_NONE, 0x4703, 0x04 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_SET_UNMAP_NOTIFY", _IOC_NONE, 0x4707, 0x10 },
{ "xen/gntdev.h", "IOCTL_GNTDEV_UNMAP_GRANT_REF", _IOC_NONE, 0x4701, 0x10 },
{ "xen/xenbus_dev.h", "IOCTL_XENBUS_BACKEND_EVTCHN", _IOC_NONE, 0x4200, 0x00 },
{ "xen/xenbus_dev.h", "IOCTL_XENBUS_BACKEND_SETUP", _IOC_NONE, 0x4201, 0x00 },
